# Combined Documentation

## Table of Contents

- [What is Document360?](#document360-getting-started)
- [Sign up to Document360](#sign-up-to-document-360)
- [System and browser requirements](#system-and-browser-requirements)
- [Project dashboard](#document360-my-projects)
- [Top-right menu overview](#top-right-menu-overview)
- [Creating a project in Document360](#creating-a-project)
- [Dashboard](#dashboard)
- [Multilingual Knowledge bases](#getting-started-with-multi-lingual-knowledge-base)
- [Creating a sandbox project](#creating-a-sandbox-project)
- [Document360 security and infrastructure](#quick-summary-of-the-security-and-infrastructure-aspects)
- [X-Frame options](#x-frame-options)
- [Content security policy](#content-security-policy)
- [CSP and Whitelisting guidelines for Document360 widget](#csp-guidelines-for-document360-widget)
- [Bot management](#bot-management)
- [Fair usage policy for bot management](#fair-usage-policy-for-bot-management)
- [Editor choices in Document360](#using-the-text-editor)
- [Elements of the editor](#elements-of-the-editor)
- [Markdown editor](#markdown-editor-overview)
- [Basic Markdown syntax](#markdown-basics)
- [WYSIWYG editor](#wysiwyg-editor)
- [Advanced WYSIWYG editor](#advanced-wysiwyg-editor)
- [Advanced WYSIWYG editor basics](#advanced-wysiwyg-editor-basics)
- [Movable blocks in Advanced WYSIWYG editor](#movable-blocks-in-advanced-wysiwyg-editor)
- [Conditional content blocks in Advanced WYSIWYG editor](#conditional-content-blocks)
- [Tables in Advanced WYSIWYG editor](#tables-in-advanced-wysiwyg-editor)
- [Image formatting in the Advanced WYSIWYG editor](#image-formatting-in-the-advanced-wysiwyg-editor)
- [Tabs in the Advanced WYSIWYG editor](#tabs-in-the-advanced-wysiwyg-editor)
- [Categories and subcategories](#categories-and-subcategories)
- [Managing categories](#managing-categories)
- [Category types](#category-types)
- [Mapping a category with a folder in Drive](#assigning-drive-folder-for-a-category)
- [Downloading category and article in KB site](#downloading-category-and-article-in-kb-site)
- [Managing articles](#managing-articles)
- [Word .docx files](#article-import-from-word-files)
- [Publishing an article](#publishing-an-article)
- [Reviewing an article using Inline comments](#reviewing-an-article-inline-comments)
- [Adding images to articles](#adding-images-to-articles)
- [Adding videos in articles](#adding-videos-in-articles)
- [Adding files to article](#adding-files-to-articles)
- [Adding hyperlinks](#linking-to-other-articles)
- [Code blocks](#code-blocks)
- [Adding private notes](#private-notes)
- [Embedding Stream videos in articles](#embedding-microsoft-streams-video-in-articles)
- [Embedding Google forms in articles](#embedding-google-forms-in-article)
- [Embedding a Draw.io diagram](#embedding-a-drawio-diagram)
- [All articles - Overview page](#all-articles-overview-page)
- [Using filters in All articles page](#filter-bulk-operations)
- [Export All articles list](#export-bulk-operations)
- [Article review reminder](#review-reminders)
- [Article SEO](#article-seo)
- [Excluding articles from search engines](#excluding-articles-from-searches)
- [Change the URL of an article](#changing-the-url-of-an-article)
- [Article tags](#article-tags)
- [Add article labels](#adding-article-labels)
- [Related articles](#related-articles)
- [Featured image](#featured-image)
- [Attachments](#attachments)
- [Status indicator](#status-indicator)
- [Article status](#article-status)
- [Preferences](#preferences)
- [Show/hide table of contents for an article](#showhide-table-of-contents-for-an-article)
- [Mark as deprecated](#marking-articles-as-deprecated)
- [Update article contributors](#updating-article-contributors)
- [Schedule publishing](#schedule-publishing)
- [Discussion feed](#article-discussion-feed)
- [Revision history](#revision-history)
- [Article analytics](#article-analytics)
- [Security - Article access control](#article-access-control-knowledge-base-site)
- [Health check metrics](#health-check-metrics)
- [Readability score](#readability-score)
- [Sitemap](#sitemap-generator)
- [Public article comments](#public-comments)
- [Robots.txt](#robotstxt)
- [Read receipt](#read-receipt)
- [Share articles via private link](#share-articles-via-private-link)
- [Eddy AI customization](#ai-customization)
- [AI machine translation](#ai-machine-translation)
- [Eddy AI trust page](#eddy-ai-trust-page)
- [AI writer suite](#ai-writer-suite)
- [AI writer](#ai-writer)
- [AI FAQ generator](#ai-faq-generator)
- [AI title recommender](#ai-title-recommender)
- [AI SEO description generator](#seo-description-generator)
- [AI tag recommender](#ai-tag-recommender)
- [AI related articles recommender](#ai-related-articles-recommender)
- [AI Chart generator](#ai-chart-generator)
- [AI alt text generator](#ai-alt-text-generator)
- [AI search suite](#ai-search-suite)
- [AI assistive search (Ask Eddy AI)](#ai-assistive-search-ask-eddy)
- [AI dynamic related articles recommendation](#ai-dynamic-related-articles-recommendation)
- [AI Chatbot](#ai-chatbot)
- [Securing Chatbot authentication using JWT](#securing-chatbot-authentication-using-jwt)
- [Styling the Chatbot](#styling-the-chatbot)
- [Adding external sources for AI Assistive search](#eddy-ai-federated-search)
- [AI article summarizer](#ai-article-summarizer)
- [Ask Eddy AI API](#ask-eddy-ai-api)
- [Enhancing accessibility with our read out loud feature](#text-to-voice-functionality)
- [AI premium suite](#ai-premium-suite)
- [AI glossary generator](#ai-glossary-generator)
- [How to write GenAI friendly content](#how-to-write-genai-friendly-content)
- [Prompt engineering tips](#prompt-engineering-tips)
- [File management](#drive)
- [Adding folders and files](#adding-folders-and-files)
- [Folder actions in Drive](#folder-actions-in-drive)
- [File actions in Drive](#file-actions-in-drive)
- [All files overview](#all-content-overview)
- [Recent, Starred, and Recycle bin files](#recycle-bin-recent-and-starred-files)
- [Workflow designer](#workflow-designer)
- [Managing workflow status](#managing-workflow-status)
- [Workflow assignment](#workflow-assignment)
- [Templates](#article-templates)
- [Variables](#variables)
- [Snippet](#snippets)
- [Glossary](#glossary)
- [Adding glossary terms](#adding-glossary-term)
- [Inserting glossary term in an article](#adding-glossary-term-in-articles)
- [Managing glossary terms](#editing-and-deleting-glossary-term)
- [Managing the glossary landing page](#glossary-overview-page)
- [Feedback manager](#feedback-manager-overview)
- [Custom pages](#custom-pages)
- [Tags](#tags)
- [Manage tags page overview](#tag-manager-overview-page)
- [Adding a new tag](#adding-a-new-tag)
- [Tag groups page overview](#tag-groups-overview)
- [Manage tag dependencies](#tag-dependency-viewer)
- [Find and replace](#find-and-replace)
- [SEO descriptions](#seo-descriptions)
- [Exporting your Document360 project as a ZIP file](#export-documentation-as-zip)
- [Importing a Document360 project ZIP file](#import-a-documentation-project)
- [Migrating documentation from other platforms](#migrating-documentation-from-another-knowledge-base-platform)
- [Designing a PDF template](#pdf-design-templates)
- [Compiling content for PDF](#compliling-content-for-pdf)
- [Analytics](#analytics)
- [Articles analytics](#articles-analytics)
- [Eddy AI search analytics](#eddy-ai-search-analytics)
- [Search analytics](#analytics-search)
- [Reader analytics](#reader-analytics)
- [Team accounts analytics](#analytics-team-accounts)
- [Feedback analytics](#feedback)
- [Links status analytics](#links-status)
- [Ticket deflector analytics](#ticket-deflector-overview)
- [Managing API documentation](#manage-api-documentation)
- [Edit, Clone, and Delete widget](#edit-clone-and-delete)
- [Managing and customizing the Knowledge base widget](#managing-and-customizing-the-knowledge-base-widget)
- [URL Mapping](#url-mapping)
- [Customizing the Knowledge base widget using Custom CSS/JavaScript](#customizing-the-kb-widget-using-custom-css-javascript)
- [FAQ - Knowledge base widget](#faq-knowledge-base-widget)
- [Knowledge base site 2.0](#knowledge-base-site-20)
- [Customize site](#customize-site)
- [KB site 2.0 migration](#kb-site-20-migration)
- [Web Content Accessibility Guidelines (WCAG)](#web-content-accessibility-guidelines-wcag)
- [Header - Primary navigation](#header-primary-navigation)
- [Header - Secondary navigation](#header-secondary-navigation)
- [Footer](#footer-navigation)
- [Custom footer](#custom-footer)
- [RSS Feeds](#rss-feeds)
- [Main pages](#main-pages)
- [Hero section](#hero-section)
- [Rich text blocks](#text-block)
- [Multicolumn card section](#text-columns-block)
- [Image with text block](#image-and-text)
- [Custom code section](#html-block)
- [Knowledge base categories block](#knowledge-base-categories)
- [Widgets block](#widgets)
- [Error pages](#error-pages)
- [404 page](#404-page)
- [Access denied page](#access-denied-page)
- [Unauthorized page](#unauthorized-page)
- [IP restriction page](#ip-restriction-page)
- [Custom CSS & JavaScript](#custom-css-javascript)
- [CSS Snippets](#css-snippets)
- [Callout styles](#callout-styles)
- [Body font style](#body-font-style)
- [Image alignment](#image-alignment)
- [Header font style](#header-font-style)
- [Table style](#table-style)
- [Article redirect rule](#article-redirect-rules)
- [Article settings & SEO](#configuring-the-article-settings)
- [Article header](#article-header)
- [Site header-What's new](#document-header)
- [Follow articles and categories](#follow-articles-and-categories)
- [Search in Knowledge base site](#search-in-knowledge-base-site)
- [Liking or disliking an article](#liking-or-disliking-an-article)
- [Smart bars](#smart-bar)
- [Cookie consent](#cookie-consent)
- [Accessing the ticket deflectors in portal](#accessing-the-ticket-deflectors)
- [Adding a new ticket deflector](#adding-a-new-ticket-deflector)
- [Integrations in Document360](#integrations-getting-started)
- [Code inclusion and exclusion conditions](#advanced-insertion-rules-in-integration)
- [LiveChat](#livechat)
- [Olark](#olark)
- [Freshchat](#freshchat)
- [Crisp](#crisp)
- [Chatra](#chatra)
- [Doorbell](#door-bell)
- [Gorgias](#gorgias)
- [Belco](#belco)
- [Sunshine Conversations](#sunshine)
- [Kommunicate](#kommunicate)
- [Google Analytics](#google-analytics-integration)
- [Google Analytics (GA4)](#google-analytics-new)
- [Google Tag Manager](#google-tag-manager)
- [Heap](#heap)
- [Segment](#segment-integration)
- [Hotjar](#hotjar)
- [Amplitude](#amplitude)
- [FullStory](#fullstory)
- [Mixpanel](#mixpanel)
- [VWO](#vwo)
- [Freshmarketer](#freshmarketer)
- [ZOHO PageSense](#zoho-page-sense)
- [GoSquared](#gosquared)
- [Commento](#commento)
- [Disqus](#disqus)
- [Document360 Extensions - Getting started](#all-extensions)
- [Freshdesk](#freshdesk)
- [Freshservice](#freshservice)
- [Zendesk](#zendesk)
- [Intercom](#intercom-integration)
- [Salesforce](#salesforce)
- [Cases page](#cases-page)
- [Slack](#slack)
- [Microsoft Teams](#microsoft-teams)
- [Drift](#drift)
- [Zapier - Setup guide](#zapier-setup-guide)
- [Integrating Google Docs with Document360](#google-docs-document360-integration)
- [Integrating Google Sheets with Document360](#document360-with-google-sheets-integration)
- [Integrating Document360 with Google Drive](#google-drive-document360)
- [Integrating Trello with Document360](#document360-with-trello-integration)
- [Integrating GitHub with Document360](#github-document360)
- [Integrating Confluence Server with Document360](#confluence-document360)
- [Integrating Zoho CRM with Document360](#zoho-crm-document360)
- [Integrating Pipedrive with Document360](#pipedrive-document360)
- [Integrating Hubspot with Document360](#hubspot-document360)
- [Integrating Asana with Document360](#asana-document360)
- [Integrating Monday.com with Document360](#mondaycom-document360)
- [Integrating Typeform with Document360](#typeform-document360)
- [Integrating Gmail with Document360](#document360-gmail)
- [Integrating Mailchimp with Document360](#document360-mailchimp)
- [Make - Setup guide](#make-setup-guide)
- [Integrating Asana with Document360](#asana-and-document360-integration)
- [Integrating Monday.com with Document360](#monday-document360-integration)
- [Integrating Typeform with Document360](#typeform-and-document360-integration)
- [Integrating Google Docs with Document360](#google-docs-and-document360-integration)
- [Integrating Jira with Document360](#jira-and-document360-integration)
- [Chrome](#chrome-extension)
- [Crowdin](#crowdin)
- [Phrase](#phrase)
- [General project settings](#general-project-settings)
- [Team auditing](#team-auditing)
- [Localization - Getting started](#localization-getting-started)
- [Setting up a Multi-lingual knowledge base](#setting-up-a-multi-lingual-knowledge-base)
- [Localization variables](#localization-variables)
- [Workspaces](#workspaces)
- [Backup and restore](#backup-restore)
- [Notifications](#notifications)
- [Webhook notification channel](#webhook-notification-channel)
- [Slack notification channel](#slack-notification-channel)
- [Microsoft Teams notification channel](#microsoft-teams-notification-channel)
- [SMTP notification channel](#smtp-email-notification-channel)
- [Notification mapping](#notification-mapping)
- [Notification history](#notification-history)
- [Email domain](#send-notifications-from-custom-email-domain)
- [How to use Postman?](#how-to-use-postman)
- [How to use Swagger?](#how-to-use-swagger)
- [Portal search](#full-portal-search)
- [Article-portal search](#article-full-portal-search)
- [Drive-portal search](#drive-full-portal-search)
- [Users & groups-portal search](#users-groups-full-portal-search)
- [Tags-portal search](#tags-full-portal-search)
- [Settings-portal search](#settings-full-portal-search)
- [Custom domain mapping](#custom-domain-mapping)
- [Hosting Document360 on a sub-directory](#document360-on-a-sub-folder)
- [Nginx server - Subfolder hosting](#nginx-server)
- [ASP.NET Core server](#aspnet-core-server)
- [Microsoft - IIS server](#microsoft-iis-server)
- [Apache HTTP server](#apache-http-server)
- [Readers self registration](#reader-self-registration)
- [Managing reviewer accounts](#managing-reviewer-accounts)
- [Account locked](#account-locked)
- [Block inheritance](#block-inheritance)
- [IP restriction](#ip-restriction)
- [Single Sign-On (SSO)](#single-sign-on-sso)
- [Login using SSO - Knowledge base portal](#login-using-sso-knowledge-base-portal)
- [Login using SSO - Knowledge base site](#login-using-sso-knowledge-base-site)
- [Inviting or Adding SSO users](#inviting-or-adding-sso-users)
- [Mapping an existing SSO configuration to other projects](#mapping-an-existing-sso-configuration-to-other-projects)
- [Disable Document360 login page](#disable-document360-login-page)
- [Auto assign reader group](#auto-assign-reader-group)
- [Convert to SSO account](#convert-to-sso-account)
- [Sign out idle SSO team account](#team-account-idle-timeout)
- [SAML](#saml)
- [SAML SSO with Okta](#saml-sso-with-okta)
- [SAML SSO with Entra](#saml-sso-with-entra)
- [SAML SSO with Google](#google-sso-saml-configuration)
- [SAML SSO with OneLogin](#saml-sso-with-onelogin)
- [SAML SSO with ADFS](#saml-sso-with-adfs)
- [SAML SSO with other configurations](#saml-sso-with-other-configurations)
- [Identity Provider (IdP) initiated sign in](#idp-initiated-login)
- [Removing a configured SAML SSO](#removing-a-configured-saml-sso)
- [OpenID](#openid)
- [Okta with OpenID SSO](#okta-with-openid-sso)
- [Auth0 with OpenID SSO](#auth0-with-openid-sso)
- [ADFS with OpenID SSO](#adfs-with-openid-sso)
- [Other configurations with OpenID SSO](#other-configurations-with-openid-sso)
- [Removing a configured OpenID SSO](#removing-a-configured-openid-sso)
- [Setting up JWT SSO](#configuring-the-jwt-sso)
- [JWT reader groups](#jwt-reader-groups)
- [How to enlarge the pdf preview in the article?](#how-to-enlarge-the-pdf-preview-in-the-article)
- [How to change the color of the hyperlinks in Dark mode?](#how-to-change-the-color-of-the-hyperlinks-in-dark-mode)
- [How to change the highlighted search result color in articles?](#how-to-change-the-highlighted-search-result-color-in-articles)
- [How to hide the project's workspace dropdown in the Knowledge base site?](#how-to-hide-the-project-versions-dropdown-in-the-knowledge-base-site)
- [How to add a vertical scrollbar to the code blocks?](#how-to-add-a-vertical-scrollbar-to-the-code-blocks)
- [How to set the default height and width of the embedded PDF?](#how-to-set-the-default-height-and-width-of-the-embedded-pdf)
- [How to make the table border bold in knowledge base?](#how-to-make-the-table-border-bold-in-knowledge-base)
- [How to vertically align table contents at the top in the Knowledge base?](#how-to-vertically-align-table-contents-at-the-top-in-the-knowledge-base)
- [How to restrict the readers from copying the content?](#how-to-restrict-the-readers-from-copying-the-content)
- [How to keep dark mode for the Knowledge base site by default?](#how-to-keep-dark-mode-for-the-knowledge-base-site-by-default)
- [How to center align the text in Markdown?](#how-to-center-align-the-text-in-markdown)
- [How to change the color of the text in Markdown?](#how-to-change-the-color-of-the-text-in-markdown)
- [How to change the language name text in code blocks?](#how-to-change-the-language-name-text-in-code-blocks)
- [How to change the callouts color in dark mode?](#how-to-change-the-callouts-color-in-dark-mode)
- [How to center align the heading in the articles?](#how-to-center-align-the-heading-in-the-articles)
- [How to change the color of the table header?](#how-to-change-the-color-of-the-table-header)
- [How to add accordion in Markdown?](#how-to-add-accordion-in-markdown)
- [How to add extra space in Markdown?](#how-to-add-extra-space-in-markdown)
- [How to align the image in Markdown?](#how-to-align-the-image-in-markdown)
- [How to add a background image for a text content?](#how-to-add-a-background-image-for-a-text-content)
- [How to change the color of the table of contents?](#how-to-change-the-color-of-the-table-of-contents)
- [How to sort the contents of a table?](#how-to-sort-the-contents-of-a-table)
- [How to customize the hyperlink size?](#how-to-customize-the-hyperlink)
- [How to make all links open in new tab?](#how-to-make-all-links-open-in-new-tab)
- [How to set a default featured image in knowledge base?](#how-to-set-a-default-featured-image-in-knowledge-base)
- [How to add shadows to an image in Markdown?](#how-to-add-shadows-to-an-image-in-markdown)
- [How to add borders to an image in Markdown?](#how-to-add-borders-to-an-image-in-markdown)
- [How to embed YouTube Shorts?](#embed-youtube-shorts)
- [How to embed a Loom video?](#how-to-embed-loom-video)
- [How to embed an Excel file?](#how-to-embed-an-excel-file)
- [How to change the color of Feedback buttons?](#how-to-change-the-color-of-feedback-buttons)
- [How to hide footer in mobile view?](#how-to-hide-footer-in-mobile-view)
- [How to change the hover color of the header options?](#how-to-change-the-hover-color-of-the-header-options)
- [How to move the related articles above the feedback section?](#how-to-move-the-related-articles-above-the-feedback-section)
- [How to hide the change password option for readers?](#how-to-hide-the-change-password-option-for-readers)
- [How to hide the category manager?](#how-to-hide-the-category-manager)
- [How to configure a custom font in the knowledge base?](#how-to-configure-a-custom-font-in-the-knowledge-base)
- [How to hide the left navigation bar in the knowledge base site?](#how-to-hide-the-left-navigation-bar-in-knowledge-base-site)
- [Plans and pricing](#plans-and-pricing)
- [Upgrading your subscription plan](#upgrading-your-plan)
- [Downgrading your subscription plan](#downgrading-your-plan)
- [Purchasing add-ons](#add-ons)
- [Upgrading from trial version](#upgrading-from-trial-version)
- [Changing payment information](#changing-payment-information)
- [February 2025 - 11.1.2](#february-2025-1112)
- [January 2025 - 11.01.1](#january-2025-1111)
- [December 2024 - 10.12.1](#december-2024-10121)
- [November 2024 - 10.11.1](#november-2024-10111)
- [October 2024 - 10.10.1](#october-2024-10101)
- [September 2024 - 10.9.1](#september-2024-1091)
- [September 2024 - 10.8.2](#september-2024-1082)
- [August 2024 - 10.8.1](#august-2024-1081)
- [July 2024 - 10.7.1](#july-2024-1071)
- [July 2024 - 10.6.2](#july-2024-1062)
- [June 2024 - 10.6.1](#june-2024-1061)
- [June 2024 - 10.5.2](#june-2024-1052)
- [May 2024 - 10.5.1](#may-2024-1051)
- [May 2024 - 10.4.2](#may-2024-1042)
- [April 2024 - 10.4.1](#1041-release-note)
- [April 2024 - Minor release](#april-2024-minor-release)
- [March 2024](#march-2024)
- [February 2024](#february-2024)
- [January 2024](#january-2024)
- [December 2023](#december-2023)
- [November 2023](#november-2023)
- [August 2023](#august-3)
- [July 2023](#july-2)
- [June 2023](#june-3)
- [May 2023](#may-1)
- [April 2023](#april-3)
- [March 2023](#march-4)
- [February 2023](#february-3)
- [January 2023](#january-2)
- [December 2022](#december-2022-release-note)
- [November 2022](#november-2022-release-note)
- [October 2022](#october-2022-release-note)
- [September 2022](#september-2022-release-note)
- [August 2022](#august-2022-release-note)
- [July 2022](#july-2022-release-note)
- [June 2022](#june-2022-release-notes)
- [May 2022](#may-2022-release-note)
- [April 2022](#april-2022-release-note)
- [March 2022](#march-2022-release-note)
- [February 2022](#february-2022-release-note)
- [January 2022](#january-2022-release-note)
- [December 2021](#december-2021-release-note)
- [November 2021](#november-2021-release-note)
- [October 2021](#october-2021-release-note)
- [September 2021](#september-2021-release-note)
- [August 2021](#august-2021-release-notes)
- [July 2021](#july-2021-release-note)
- [June 2021](#june-2021-release-note)
- [May 2021](#may-2021-release-note)
- [April 2021](#april-2021-release-note)
- [March 2021](#march-2021-release-note)
- [February 2021](#february-2021-release-note)
- [January 2021](#january-2021-release-note)
- [November 2020](#november-2020-release-note)
- [October 2020](#october-2020-release-note)
- [August 2020](#august-2020-release-note)
- [June 2020](#june-2020-release-note)
- [May 2020](#may-2020-release-note)
- [April 2020](#april-2020-release-note)
- [March 2020](#march-2020-release-note)
- [February 2020](#february-2020-release-note)
- [January 2020](#january-2020)
- [December 2019](#december)
- [November 2019](#november)
- [October 2019](#october)
- [September 2019](#september-2019)
- [August 2019](#august)
- [July 2019](#july)
- [June 2019](#june)
- [May 2019](#may-2019)
- [April 2019](#april-2019)
- [March 2019](#march)
- [February 2019](#february)
- [January 2019](#january-2019)
- [Support ticket](#support-ticket)
- [Generating a HAR file](#document360-support-generating-a-har-file)

---

<a id="document360-getting-started"></a>

## What is Document360?

Here is an overview and a navigation guide to help you get started with your Document360 experience.

### What is Document360?

**Document360** is a Knowledge management platform that allows you to create and curate a self-service public, private, or mixed access Knowledge base.

When using Document360, you'll interact with several key interfaces:

* #### [My Projects](/help/docs/document360-getting-started#my-projects)
* #### [Knowledge base portal](/help/docs/document360-getting-started#knowledge-base-portal)
* #### [Knowledge base site](/help/docs/document360-getting-started#knowledge-base-site)
* #### [Document360 AI - Eddy AI](/help/docs/ai-features)
* #### [Resources](/help/docs/document360-getting-started#other-resources)

---

## My projects

The **project dashboard** is the first thing you see when logging in to [**Document360**](https://portal.document360.io). The dashboard features all the projects you own, projects associated with a team account, and projects associated with a reader.  
Here, each project will have a visibility tag to indicate the type of project (public, private, or mixed).

![1_Screenshot-My_projects](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-My_projects.png "My-Projects.png")

---

## Knowledge base portal

The **Knowledge base portal** is where you can:

* **Create** Category, Articles, and Templates
* **Manage** files, team accounts, and readers
* **Set up** branding, domain, security, and more for the Knowledge base site

  ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-What_is_Document360.png)

Here are some elements you'll find on the knowledge base portal:

1. Dashboard
2. Documentation
3. API Documentation
4. Analytics
5. Widgets
6. Drive
7. Settings
8. Search
9. Open Site

> NOTE
>
> Anything created and/or configured on the Knowledge base portal will affect what an end-user or reader would see on the Knowledge base site.

### 1. Dashboard

This page provides an overview of your entire project and serves as a hub for contributors. In the **Overview** section, Team accounts can access information such as created articles, published articles, drafts, and the performance insights of published articles (views, reads, likes, and dislikes). You can use the filter option to select the time frame. You can also view other project-related information including **Recently seen**, **Team accounts**, **Readers**, **Drive capacity**, **Broken links**, **No result searches** and **Last backed up** date.

![3_Screenshot-Knowledge_base_portal_dashboard_overview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Knowledge_base_portal_dashboard_overview.png)

In the **My contribution** section, the user can view their contributions to the project, article performance metrics, workflow assignments, review reminders, feedback, and broken links.

![Document360 dashboard showing article metrics summary with number of articles created, published or drafted, and an area to display assigned tasks.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Knowledge_base_portal_dashboard_my_contribution.png)

---

### 2. Documentation

The **Documentation** page is where you'll create and maintain the tree-view folder structure of categories that will keep your articles organized. Start a knowledge base by creating a Category and then populate them with Subcategory and Articles.

Drag and drop categories and articles to reorder, hide, rename, and delete them using the More options () menu that appears when you hover your mouse over any item on the Category manager (left navigation pane).

![ocument360 user interface showing navigation menus for managing articles, workflow assignments, starred items, recycle bin, site builder, content tools, and categories/articles hierarchy.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Knowledge_base_portal_documentation_view.png)

#### a. All articles

The **All articles** section allows you to perform bulk operations (publish, hide, move, delete, etc.) on multiple articles at once, saving time compared to performing these actions individually on each article.

![Document360's 'All articles' interface showing a list of articles with editing options like publish, hide, move, delete, review reminder, and live status, as well as features for reusing content through templates, variables, snippets, and a glossary.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Knowledge_base_portal_documentation_view_all_articles.png)

#### b. Workflow assignments

The Workflow assignments section gives you an idea about what the team is currently working on, and any recently published articles.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Knowledge_base_portal_documentation_view_workflow_assignments.png)

Any articles that you are assigned will show up on this page. You can filter articles based on the following workflow statuses: **Draft**, **In review**, or **Published**. If you missed the review due date for any article, it will appear under the **Overdue** category.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7.1_Screenshot-Knowledge_base_portal_workflow_assignments_page.png)

#### c. Starred

The Starred section contains the articles you marked as favorites. This allows quick access to important articles.

![Document360's 'Starred' interface showing a list of articles with the respective tags and article status, along with an arrow pointing at 'Starred' on the left navigation panel](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Knowledge_base_portal_documentation_view_starred.png)

#### d. Recycle bin

The Recycle bin section includes a list of articles and categories deleted in the past 30 days. You can restore the deleted categories and articles in the available time frame.

![Document360's 'Recycle bin' interface showing an empty recycle bin, along with an arrow pointing at 'Recycle bin' on the left navigation panel](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Knowledge_base_portal_documentation_view_recycle_bin.png)

#### e. Site builder

You can personalize the look and feel of your knowledge base site from the **Site builder** section.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-Knowledge_base_portal_documentation_view_site_builder.png)

You can choose the desired logo and icon for your knowledge base site. From this section, you can also customize the brand colors, font, and styling of the site.

#### f. Content tools

The **Content tools**, as the name implies, contain all the necessary tools to manage your article and project content.

![5_Screenshot-Knowledge_base_portal_Content_tools](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/11_Screenshot-Knowledge_base_portal_documentation_view_content_tools.png)

You can manage the following features from this menu.

* **Content reuse** - Manage all the variables, snippets, templates, and the glossary.
* **Import and Export** - Manage all your project import and export activities from this section. In this section, you can export your content as a PDF or migrate content from other knowledge management tools.
* **Content essentials** - Manage the project-level find and replace, review reminders, tags, and SEO descriptions from the menu.
* **Feedback manager** - View and respond to articles and no search feedback from a unified module.
* **Workflow designer** - Craft your workflow statuses and sequence from this section.

#### g. Categories & Articles (Category manager)

Writing and publishing articles in Document360 is simple: pick your category, create an article(title and slug), add SEO details, and publish to your knowledge base.

When you update or edit an article (Fork), Document360 will create a new Article revision without affecting the live/public workspace.

![12_Screenshot-Knowledge_base_portal_documentation_view_categories_and_articles](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/12_Screenshot-Knowledge_base_portal_documentation_view_categories_and_articles.png)

You can make the necessary changes and republish when you're ready. You can identify the articles easily using the Article status indicators (Yellow dot). Document360 maintains all the workspaces to check the differences between them.

---

### 3. API documentation

The API documentation feature in Document360 provides a complete solution for creating and managing API references. This feature allows you to create high-quality API documentation that helps users understand and consume your APIs effectively.

![13_Screenshot-Knowledge_base_portal_api_documentation](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/13_Screenshot-Knowledge_base_portal_api_documentation.png)

This API module includes the **Try it!** feature, which allows the users to test the API endpoints within the Knowledge base site. You can create dedicated versions of your API documentation. The feature provides an intuitive interface for uploading API references as URLs or JSON/YAML files. After uploading the OpenAPI definition, the interactive API endpoint articles are created in the Knowledge base portal. Now, end users can access the **Try it!** option with the available endpoints, parameters, and responses in the API documentation on the Knowledge base site.

---

### 4. Analytics

Document360 includes an **Analytics** menu with tools to help you understand end-user engagement with your knowledge base.

![12_Screenshot-Knowledge_base_portal_Analytics](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/14_Screenshot-Knowledge_base_portal_analytics.png)

Here is the list of metrics and modules you can track with the Analytics tool:

* **Articles**
* **Eddy AI**
* **Search**
* **Team accounts**
* **Feedback**
* **Links status**
* **Page not found**
* **Ticket deflector**

---

### 5. Widget

The Knowledge base widget (previously known as *Knowledge base assistant* (or) *In-app assistant*) helps readers find their answers without leaving your site or application.

![8_Screenshot-Knowledge_base_portal_Widget](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/15_Screenshot-Knowledge_base_portal_widgets.png)

You can update the following Knowledge base widget settings from this menu.

* **Installation & setup**
* **Custom CSS**
* **Custom JavaScript**
* **URL mapping**

---

### 6. Drive

Centralized and cloud-based storage for Document360 projects that stores and let team members manage all the Knowledge base artifacts (files). If you have already used any other heavyweights, such as Google Drive or OneDrive, getting accustomed to the functions in Document360 Drive should be relatively easy. You can access your Drive by clicking the Drive icon on the left menu.

![7_Screenshot-Knowledge_base_portal_Drive](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/16_Screenshot-Knowledge_base_portal_drive.png)

---

### 7. Settings

You can set and configure all aspects of the project and knowledge base in the **Project settings** such as inviting team members, editing notification settings, configuring domains, setting up article redirects, and more.

![9_Screenshot-Knowledge_base_portal_Settings](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/17_Screenshot-Knowledge_base_portal_settings.png)

The different features are mapped under the following classifications in the Settings menu:

* **Knowledge base portal**
* **Knowledge base site**
* **Users & Security**
* **AI Features**

---

### 8. Search

A dedicated space to search the entire project content is now available on the Knowledge base portal. Perform a combined search across all the workspaces and languages simultaneously. The search bar is available at the top of all the modules and pages in the Knowledge base portal.

![10_Screenshot-Knowledge_base_portal_Search](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/18_Screenshot-Knowledge_base_portal_search.png)

The search engine works similarly to the other search functionalities in the portal. Type in the keyword and narrow the results using filters such as workspace, language, visibility, tags, and date range. You can preview the article/category page, and then preview the article or navigate to the article in the Editor.

![11_Screenshot-Knowledge_base_portal_Search_results](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/19_Screenshot-Knowledge_base_portal_search_bar_dropdown.png)

As the search is performed universally in the project, it covers files. Users can switch between the article and Drive search using the tabs below the search bar.

---

### 9. Open site

The Open site () action is used to navigate to and view the Knowledge base site. Clicking the icon will take you to the Knowledge base site of the workspace that is currently open in your knowledge base portal. If you are in the API documentation workspace, the Open site action will take you to the API documentation home page. If your API documentation site does not have a home page, you will be directed to the first article or category page in the API documentation.

---

## Knowledge base site

The Knowledge base site is the website that end-users will access to read articles and find helpful answers.

Set your knowledge base access settings to public, private, or mixed. **Public** means it is accessible to anyone on the internet, **Private** is restricted by login screens, and **Mixed** combines elements of both public and private attributes.

![14_Screenshot-Knowledge_base_site_overview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/20_Screenshot-Knowledge_base_site_preview.png)

---

## Document360 AI - Eddy AI

Eddy AI is an AI writing assistant integrated into the Document360 platform. Eddy AI can help you with many actions, such as **writing articles**, **generating SEO descriptions**, and **recommending article tags**, **titles**, and **related articles**. Eddy AI is also available on the knowledge base site, helping your readers find information faster using **assistive search** and the **article summarizer**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/24_Screenshot-Eddy_settings_aifeatures_eddy.png)

---

## Other Resources

### Got Feedback?

We actively maintain a public [**product feedback portal**](https://feedback.document360.com/) to receive customer and user feedback. It also features our roadmap, so if you're curious about what's coming to the product, this is the best place to look!

![27_Screenshot-An_overview_of_project_feedback](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/21_Screenshot-User_feedback.png)

### Quick start (Feature explorer)

The **Quick start** is a learning wizard available on all Document360 trial projects. This feature explorer helps you track your progress as you learn about the various features included in Document360. Each time you use or explore a new part of the product, the Feature Explorer automatically updates your progress. It allows you to visualize how much of the product you have explored.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-What_is_Document360.png)

---

### Need Help?

If you need any help or have any questions, contact us! Just click your profile avatar to:

![21_Screenshot-My_projects_Help_module](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/23_Screenshot-Resources_need_help.png)

* Send an **in-app chat**
* Send us an **email** at [**support@document360.com**](mailto:support@document360.com)
* Read our [**documentation**](https://docs.document360.com/docs)
* Watch some [**tutorial videos**](https://document360.com/tutorial-videos/)

---

### FAQs

#### **What is Document360?**

Document360 is a Knowledge management platform that allows you to create and curate a self-service public, private, or mixed access Knowledge base.

#### **What can I do in the Knowledge base portal?**

In the Knowledge base portal, you can create categories, articles, and templates, manage files, team accounts, and readers, and set up branding, domain, and security for your Knowledge base site.

#### **What features are available in the Analytics section?**

The Analytics section includes tools to track metrics such as articles, user engagement, search performance, team accounts, feedback, and link status.

#### **Can I restore deleted articles in Document360?**

Yes, you can restore articles and categories that have been deleted within the past 30 days from the Recycle bin section.

#### **Is there an AI feature in Document360?**

Yes, Document360 includes Eddy AI, an AI writing assistant that helps with writing articles, generating SEO descriptions, and assisting readers in finding information.

#### **What is a knowledge base?**

A knowledge base is a centralized repository of information designed to provide answers, guidance, and support for users, customers, or employees. It contains structured content like articles, FAQs, guides, and documentation, allowing users to easily search and access information to solve problems or learn more about a product, service, or topic. Knowledge bases are commonly used in customer support, internal training, and product documentation to streamline information sharing and improve efficiency.

#### Why does it show ‘Maintenance’ on the top navigation bar in the knowledge base portal?

The **Maintenance** badge on the top navigation bar indicates scheduled maintenance of the Knowledge base portal. The knowledge base portal will be unavailable for the scheduled time however, the Knowledge base site will be accessible to all the users.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/26_ScreenShot-What_is_Document360.png)

For further assistance, please contact the Document360 support team: [Contact Document360 Support](https://document360.com/support/).

Organizes related articles under a common theme in the knowledge base.

A written document on a specific topic in your knowledge base, serving as a unit of organized information.

Pre-designed article structures in Document360 that team accounts can use to create consistent and well-organized articles for the Knowledge base.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The public-facing website where end-users can access articles and find answers to their questions.

Organizes related articles under a common theme in the knowledge base.

A secondary category in Document360 used to organize and display groups of related articles. Subcategories act as folders within a primary category, helping structure similar topics for better organization and navigation.

A written document on a specific topic in your knowledge base, serving as a unit of organized information.

A tool in the editor’s left pane for managing article-category relations.

The practice of optimizing content to improve its visibility in search engine results and attract organic traffic. In Document360, Search Engine Optimization (SEO) elements can be added for each article through the article settings.

An option in Document360 used to create a new version of an article, containing the content of the original version for revision.

A feature to view and manage an article’s revision history, workflow updates and compare different versions.

Custom styling code used to modify the appearance of elements on a webpage.

A tool in Document360 used by writers to draft and format content. Document360 offers three types of editors: Markdown, WYSIWYG, and Advanced WYSIWYG.

<a id="sign-up-to-document-360"></a>

## Sign up to Document360

Before you start using Document360, you need to create a Document360 account. To create a Document360 account, navigate to the [**signup page**](https://document360.com/signup/).

---

## **Signing Up to Document360**

### **Navigate to the Signup page**

1. On the signup page, you'll need to provide some basic details:

   * First Name
   * Last Name
   * Work Email
   * Job Title
   * Implementation timeline
   * Phone Number
2. After filling in these details, click the **Start Free Trial** button.

![Exploring the onboarding experience while signing up the Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Initial_step_of_onboarding.png)

### **Email verification**

3. You will receive a 6-digit verification code in your email. Enter this code on the verification page to continue.
4. Click **Verify.**

> NOTE
>
> If you enter the wrong verification code five times, your account activation will be locked. In such cases, you'll need to contact the Document360 support team for help.

### **Set your account password**

5. After verifying your email, you will need to create a password for your Document360 account. Make sure your password meets the following requirements:

   * At least 8 characters long
   * Includes at least one number
   * Includes at least one special character
   * Includes both uppercase and lowercase letters
6. Once you've created a password that meets these criteria, re-enter it to confirm, and then click **Get Started**.

### **Choose your use case**

7. Select any of your following primary use case for which you’re using Document360 by clicking **Get started.**

|  |  |
| --- | --- |
| **Knowledge base platform** | You can create a centralized hub where all your team's knowledge and resources are stored. It helps your team quickly find answers and enhances customer self-service by providing them with easy access to the information they need. |
| **Software documentation/****Technical documentation** | You can efficiently organize and maintain all your software or technical documentation. It helps your team document product features, APIs, release notes, and more, making sure that developers and users have clear and up-to-date information. |
| **SOP documentation** | You can create detailed SOPs that your team can follow consistently. It ensures that everyone adheres to the same processes, reduces errors, and helps in onboarding new employees by providing them with clear procedural guidelines. |
| **User manual** | You can develop comprehensive user manuals that guide your customers or team members through your product's features and usage. It helps in reducing support queries by offering step-by-step instructions and troubleshooting tips. |
| **API Documentation** | Document detailed information about API endpoints, request and response formats, authentication methods, and examples. This ensures developers have a clear understanding of how to integrate with your APIs. |
| **Others** | Choose this option if your use case does not fall into the predefined categories. You can customize your knowledge base based on specific organizational or project needs. |

### **Select a Template**

8. Select the type of content you'll create in your Document360 project. You can pick up to two templates that suit your needs.

> NOTE
>
> Based on your selection, these templates will be embedded within your project during creation.

**Knowledge base platform templates**

If you have selected the Knowledge base platform in step 7, you can choose any two templates from the list below.

|  |  |
| --- | --- |
| **Getting started guides** | Help new users quickly understand and begin using your product with clear, step-by-step instructions. This ensures a smooth onboarding experience. |
| **How-to guides** | Provide detailed instructions for specific tasks, enabling users to fully utilize and explore your product’s features efficiently. |
| **FAQs** | Address common questions at any stage of the user journey, helping users find quick answers and reducing support queries. |
| **Policy & procedures** | Outline essential organizational protocols, helping users understand and adhere to company guidelines effectively. |

**Software/Technical documentation templates**

If you have selected Software/Technical documentation in step 7, you can choose any two templates from the list below.

|  |  |
| --- | --- |
| **Release notes** | Keep users informed about updates, new features, bug fixes, and improvements with each software release. |
| **Software Design Documentation (SDD)** | Outline software architecture and design, including diagrams and specifications for development guidance. |
| **Software Requirement Documentation** | Describe the software's purpose, functionalities, and environment to ensure development aligns with project goals. |
| **Product Requirement Documentation (PRD)** | Define the product’s purpose, value, and functionalities to meet user needs and business objectives. |
| **Process documentation** | Detailed steps and procedures involved in software development to standardize workflows and enhance efficiency. |
| **User guide** | Give comprehensive instructions on using your product, covering all features and functionalities. |

**SOP documentation templates**

If you have selected SOP documentation in step 7, you can choose any two templates from the list below.

|  |  |
| --- | --- |
| **Compliance policies and procedures** | Ensure your organization meets regulatory requirements by documenting policies that enforce compliance. |
| **Operation SOP** | Enhance efficiency and productivity by standardizing operational procedures across your organization. |

**User manual templates**

If you have selected the User manual in step 7, you can choose any two templates from the list below.

|  |  |
| --- | --- |
| **Installation manual** | Provides all necessary setup information including product overview, specifications, and assembly instructions, ensuring a smooth start with the Knowledge base platform. |
| **Instruction manual** | Offers step-by-step assembly and usage instructions with diagrams and safety warnings, ideal for precise setup and safety warnings for proper usage. |
| **Maintenance manual** | Provide detailed instructions for regular upkeep, troubleshooting, and repair procedures to ensure optimal performance. |
| **Training manual** | Provides comprehensive guidance on installation, operation, and troubleshooting, and support for user training and effective platform usage. |
| **Operations manual** | Provide detailed instructions for daily maintenance and troubleshooting, ensuring ongoing effective management of the Knowledge Base platform. |

### **Personalize your Knowledge base**

9. Enter your preferred website URL. If you want to skip this step, the domain will default to the one linked to your registration email.

### **Brand guidelines**

10. Your project name, default language, branding logo, and brand colors will be automatically set based on your provided URL. However, you can edit the fields if needed.

    Your browser’s language settings determine the default language. English will be selected by default if other languages don’t support your browser’s language.

> NOTE
>
> * If you choose Spanish or Brazilian Portuguese as your default language, the portal language will be set to Spanish or Brazilian Portuguese. Otherwise, English will be the default language.
> * The branding logo and primary/secondary colors are extracted from your website. If you choose to **Skip** this step, the project name will be derived from your registration email, and Document360’s default logo and colors will be applied.

11. You can preview your Knowledge base on the right side of the screen.

### **Set documentation privacy**

12. Choose the desired privacy settings for your site:

    * **Private**: Restrict access to the Knowledge base so that only team accounts can view and interact with the content, keeping it secure and internal.
    * **Public**: Make the Knowledge base accessible to everyone, including external users, allowing open access to all content.
    * **Mixed**: Combine private and public access by allowing some sections of the Knowledge base to be visible to the public while keeping other sections restricted to team accounts only.
13. Click **Next** to proceed.

### **Access the Document360 Knowledge base portal**

Once you complete the setup, enter the Document360 Knowledge base portal. Here, you’ll find pre-loaded articles based on the use case and templates you selected.

> NOTE
>
> The articles seeded into your project are tailored to your selected use case and templates, giving you a head start on creating your content.

![Exploring the onboarding experience while signing up the Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Final_onboarding_process.gif)

---

### FAQs

**Does Document360 support different languages in the onboarding flow?**

Yes, Document360 offers multi-lingual support in the onboarding flow, including languages such as English, Spanish, Brazilian Portuguese, German, and Swedish. However, within the Document360 portal, language support is currently limited to English, Spanish, and Brazilian Portuguese.

**Do I need to pay to create a Document360 account?**

You don’t need to pay or enter your credit card details to create an account. When you sign up, you will get a 14-day trial account. After trying Document360, you can upgrade to one of the available plans to continue using it beyond the trial period.

**What are the available plans I can upgrade to?**

You can choose from 4 plans: Free, Professional, Business, and Enterprise. To learn about the pricing and features of each plan, [**click here**](https://document360.com/pricing/).

**I haven’t received the verification code. How do I continue with the signup process?**

If you haven’t received the code, click **Resend Code** on the **Email verification** page. If you still can’t find the email in your inbox, check your spam/junk folder. If you cannot locate the verification code, contact the Document360 support team for further assistance.

**I have an existing knowledge base, and I want to migrate to Document360. How should I proceed?**

Once you decide to sign up for Document360, there are two ways to migrate your existing knowledge. You can fill out the migration request form even before signing up, and our migration experts will contact you to kick-start the migration process. If you have already created a trial account, simply navigate to **Documentation** > **Content** **tools** > **Import & Export** > **Migrate content**. From there, follow the on-screen instructions to migrate your knowledge base to Document360. To learn more about migrating your existing knowledge base to Document360, click [**here**](/help/docs/migrating-documentation-from-another-knowledge-base-platform).

**My Document360 trial period ended. Can I still access my data?**

Once your Document360 trial ends, you can no longer access any content you created within Document360. To regain access to your data, you'll need to upgrade to one of our subscription plans. To learn more about selecting a subscription plan and upgrading your account, click [**here**](https://docs.document360.com/docs/billing).

**What happens if I don't complete the password setup during signup?**

If you return to the signup page and enter your details again, the system will recognize your previous session and automatically redirect you to the password creation screen.

<a id="system-and-browser-requirements"></a>

## System and browser requirements

## Recommended

Here are the system and browser requirements for the Document360 Knowledge base portal to function efficiently on your device.

> NOTE
>
> You can access the Document360 Knowledge base portal and site on your web browser, even if you are using earlier or less recent versions of the hardware and software mentioned below. However, the advanced features of our platform may not perform as quickly or efficiently.

---

### Operating System and Hardware

Ensure your computer is installed with one of the following operating systems:

| # | **Operating system requirements** |
| --- | --- |
| 1 | **Windows 7.0** or **higher** |
| 2 | **OSX Mavericks** or **higher** |
| 3 | **Linux** |
| 4 | **Android 5.0** or **higher** |
| 5 | **iOS 12.0** or **higher** |

| # | **Hardware requirements** |
| --- | --- |
| 1 | **2 core CPU** or **higher** |
| 2 | **4 GB RAM** or **higher** |

---

### Web browser requirements

Document360 works well on the latest versions of these web browsers, as mentioned below.

| # | **Supported web browsers** | **Knowledge base portal** | **Knowledge base site 1.0** | **Knowledge base site 2.0** |
| --- | --- | --- | --- | --- |
| 1 | **Google Chrome** version 91.0.4472 or higher | Yes | Yes | Yes |
| 2 | **Firefox** version 79.0 or higher | Yes | Yes | Yes |
| 3 | **Safari** version 13.1.2 or higher | Yes | Yes | Yes |
| 4 | **Microsoft Edge** version 88 or higher | Yes | Yes | Yes |
| 5 | **Internet Explorer** version 11 | No | No | No |
|  | Other web browsers |  |  |  |

#### Browser features

Depending on the browser of your choice, you must ensure the following browser attribute conditions are met.

* **JavaScript** must be **enabled**.

  > Limited access is provided when disabled.
* **Cookies** must be **enabled**.
* **Session Storage** must be **enabled**.
* **Local Storage** must be **enabled**.
* **IndexedDB** must be **enabled**.
* **HTTPS - TLS v1.2** or **higher**.

---

### Support and feedback

If you face any difficulty in working with Document360 using any of the requirements mentioned above, or if there are issues that are not previously specified, you can always **write to us** at [support@document360.com](mailto:support@document360.com).

## Troubleshooting

If you encounter any issues while logging in to the Knowledge base portal, refer to the following common errors and their solutions:

### reCAPTCHA Error: “Having trouble?”

**Error**: When attempting to log in, users may encounter the error message **"Having trouble?"** while interacting with the reCAPTCHA verification. This issue can occur due to browser restrictions, VPN interference, or network-related blocks preventing reCAPTCHA from loading correctly.

![Login form displaying an error message from Cloudflare regarding login issues.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Troubleshooting_srecaptcha_error.png)

**Steps to resolve**:

Follow these steps to resolve the issue:

1. Try accessing the site in a different browser**.** If the site loads successfully in another browser, disable any browser extensions in the affected browser and try again.
2. If you are using a VPN, disconnect it and attempt to log in again.

If the issue persists after following the above steps, follow the below steps:

* Generate a HAR file by following [these steps](https://docs.document360.com/docs/document360-support-generating-a-har-file).
* Take a screenshot of any console errors that appear.
* Contact [**support@document360.com**](mailto:support@document360.com) with the HAR file and screenshots for further investigation.

![Document360 console interface displaying support articles and troubleshooting options for users.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Browser_console.png)

### Access blocked: “Sorry, you have been blocked” / “You are unable to access us.document360.io”

**Error**: When attempting to access `us.document360.io`, you may receive an error message stating **"Sorry, you have been blocked"** or **"You are unable to access** `us.document360.io`**"**, along with a **Cloudflare Ray ID:** **8dbb32d07fb2e4d4**. This error indicates that access to the site has been restricted due to network, browser, or security-related issues.

![Access denied message indicating a block by Cloudflare with a Ray ID.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Troubleshooting_cloudfare_error.png)

**Steps to resolve**:

Follow these steps to resolve the issue:

1. Check if the site is accessible using a different browser, network, or computer.

   * If the site is accessible in another browser, provide the **browser name and version** of both working and non-working browsers.
   * If the site is accessible on a different computer, provide the **operating system name and version** of both devices.
   * If the site is accessible on a different network, provide details about the **network setup and the IP address** from which the error occurs.
2. Generate a HAR file by following [these steps](https://docs.document360.com/docs/document360-support-generating-a-har-file).
3. Take a screenshot of any console errors that appear.
4. Contact [**support@document360.com**](mailto:support@document360.com) with the HAR file, screenshots, and the details collected in Step 1 for further investigation.

![Document360 console interface displaying support articles and troubleshooting options for users.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Browser_console.png)

### Login issue: Knowledge base portal keeps loading

**Error**: You are unable to log in to the knowledge base portal because the login page keeps loading indefinitely. This issue may occur due to your browser cache, extensions interfering with the login process, or incorrect system time settings.

**Steps to resolve**:

To resolve this issue,

1. Clear your browser cache and cookies. If the issue persists, check whether it affects all team accounts or only specific users. Use the following steps to clear your cache:

   * **Google Chrome:** Menu (3 dots) > Settings > Privacy and security > Clear browsing data
   * **Mozilla Firefox:** Menu (3 lines) > Settings > Privacy & Security > Clear Data
   * **Microsoft Edge:** Menu (3 dots) > Settings > Privacy, search, and services > Choose what to clear
   * **Safari (Mac):** Safari > Preferences > Privacy > Manage Website Data > Remove All
   * **Safari (iPhone/iPad):** Settings > Safari > Clear History and Website Data
   * **Opera:** Menu > Settings > Advanced > Privacy & Security > Clear browsing data
2. Try accessing the portal in an incognito or private browser window. Some browser extensions may be blocking the login page or affecting loading times.
3. Inspect the page to check for loading time issues:

   * Right-click on the page and select **Inspect**.
   * Check the console for error messages and monitor loading times.
   * If you see an invalid login persisting for a long time, your system’s time settings may be incorrect.
4. Make sure your system time zone is set correctly. An incorrect system clock or time zone mismatch can cause login failures. Update your system time zone to match your region.
5. If the issue still persists, capture diagnostic data:

   * Generate a HAR file by following [these steps](https://docs.document360.com/docs/document360-support-generating-a-har-file).
   * Share the HAR file with [**support@document360.com**](mailto:support@document360.com) for further troubleshooting.

---

### FAQs

#### **Can I download the Document360 desktop application?**

Document360 is available only as a **web application**, which can be accessed using web browsers on desktop and laptop devices.

#### **Can I access the Knowledge base portal on smartphones and tablets?**

Yes, the Knowledge base portal can be accessed via a web browser on both computers and mobile devices (smartphones and tablets).

However, for the best user experience, it is not recommended to use a web-view workaround in the mobile browser to access the portal.

#### **How do I clear the Document360 project cache?**

Clearing the cache helps resolve display or functionality issues caused by old, cached data. To clear your project’s cache in Document360, follow these steps:

1. Navigate to the specific location in the Knowledge base portal where you need to clear the cache.
2. You can open the developer tools:

   1. On Windows: Press `Ctrl+Shift+I`.
   2. On macOS: Press `Cmd+Shift+I`.
3. Right-click and hold the **refresh** button.
4. Select **Empty Cache and Hard Reload** from the menu.

#### Why am I unable to log in to my Document360 account? The callback URL is not working.

This issue may occur due to an intermittent cache issue or an incorrect system time setting on your device. If your system's internal clock is not synchronized with your time zone or region, it can cause login failures, including issues with the callback URL (`portal.document360.io/callback`).

**Steps to resolve:**

* Clear your browser cache and cookies, then try logging in again.
* Verify your system time settings and ensure they are correctly synchronized with your time zone.

![Webpage displaying a loading document360 icon and a highlighted URL in the address bar.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Callback_while_logging.png)

<a id="document360-my-projects"></a>

## Project dashboard

**Plans supporting access to Your projects page**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

### What is Document360 - Your projects?

The "Your Projects" space serves as your main dashboard upon logging into your Document360 account. It provides a centralized view of all the projects you're associated with, whether as an owner, team member, or reader, along with essential navigational tools.

---

## Navigating the 'Your projects' page

Upon logging in, you are greeted with a dashboard displaying tiles representing each Document360 project you have access to. These tiles include projects you own or are associated with as part of a team account or as a reader. Here's what you can do from this space:

### 1. **Create New or Sandbox Project**

Easily initiate a new [Project](/help/docs/creating-a-project) or a [Sandbox project](/help/docs/creating-a-sandbox-project) using the buttons conveniently located at the top right corner of the dashboard.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/My projects.png "My projects.png")

---

### 2. Projects

The Document360 projects you own and those you are associated with as a team account or reader are available. You can click the project tile to navigate to the project easily.

#### Project tile elements - Team account

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Project tile elements.png "Project tile elements.png")

1. **Logo:** Project logo for quick identification.
2. **Project name:** Clearly labeled to identify each project
3. **Project site access:** Indicates whether the project is of Public, Private, or Mixed access.
4. **Settings:** Manage project-specific settings directly from the tile.
5. **Documentation editor:** Access the knowledge base portal to create and manage documentation within the project.
6. **View in knowledge base site:** Navigate directly to the knowledge base site associated with the project.

---

### 2. Profile

Manage your personal account settings and log out from Document360 using the profile menu.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Profile.png "Profile.png")

---

### 3. Release updates

Stay informed about the latest Document360 product enhancements and features by clicking on the Release updates () icon. Expand release posts to read detailed updates and improvements.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Release updates(1).png "Release updates(1).png")

---

### 4. Help

Access various support resources from the  Help menu:

* **Documentation:** Access detailed guides and resources to help you navigate and utilize the platform effectively.
* **Issues/Clarifications:** Report any issues or seek clarifications about the platform's features and functionality.
* **Submit a Feature Request:** Suggest new features or improvements to enhance your experience with Document360.
* **System Status:** Check the current status and performance of the platform’s services.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Help.png "Help.png")

This dashboard serves as a central hub for managing and accessing all your Document360 projects, ensuring streamlined navigation and efficient project management from a single interface.

<a id="top-right-menu-overview"></a>

## Top-right menu overview

**Plans supporting access to My profile page**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The top-right corner of the Knowledge base portal provides quick access to key features. Quickly access essential features, including viewing and editing your profile, checking access levels, changing your portal password, staying informed about the latest updates, and exploring help resources in Document360.

## Key features in the top-right menu

* **My profile**: Here, you can view and edit your personal information, including your profile picture and biography. This section also displays your assigned portal and content roles and permissions.
* **View access and permissions**: Check the roles and permissions assigned to your account. This helps ensure you have the right level of access to perform your tasks.
* **Change password**: Securely update your login credentials by setting a new password. Make sure to choose a strong password to protect your account.
* **Release updates**: Stay informed about the latest updates and feature releases in Document360. Notifications keep you aware of changes that may impact your work.
* **Help menu**: Access helpful resources, including:

  + **Documentation:** Explore user guides and feature instructions.
  + **Support portal**: Raise support tickets and seek assistance.
  + **Contact support**: Directly reach out for help with any issues.

![Document360 interface showing user profile settings.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Top_right_menu_overview.png)

---

## Accessing profile options

You can access the first three options —  **My profile,  View access and permissions, and  Change password** — by clicking your **profile picture** in the top-right corner of the portal.

> NOTE
>
> This icon displays your profile image or a default placeholder if no image is set. It will display your initials until you upload your profile image.

### My profile

The  **My profile** section allows you to view and edit your personal information.

To access your profile,

1. Click your profile picture.
2. Click  **My profile** from the dropdown menu. This will open the  **My profile** side panel.

![Document360 interface showing user profile access menu.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Top_right_menu_my_profile.png)

#### Features available in my profile

* **Profile image** - Update or delete your profile picture.
* **First and last name** - View and edit your name.
* **Email ID** - View your email address.
* **Author page URL** - View and edit your author page URL.
* **Author bio** - Add or update a biography. This field will be blank if no biography is added.
* **Edit button** - Use this button to update or delete your profile image, name, author URL slug, and biography directly within your profile settings.
* **Portal language** - You can use this dropdown to change the language for your knowledge base portal. The UI elements will adapt based on your selection. Available languages include English, Spanish, and Portuguese (Brazil). Note that this setting applies only to your portal view and does not change the content language.
* **Portal role** - View your assigned role (e.g., Owner, Admin, Contributor).
* **Content role & access** - Check content roles and access levels, including workspace names, languages, and categories.
* **View contributions** - Click the **Click here** hyperlink to view your contributions in the Team Accounts module under Analytics.

![User profile settings showing role, language, and access details in Document360.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-My_profile_side_panel.png)

> NOTE
>
> Email IDs in the user profile cannot be edited for SSO users.

### View access and permissions

The **View access and permissions** section allows you to check your assigned permissions within Document360 for the Portal role and Content role. Portal roles manage administrative settings within the knowledge base portal, while Content roles control access and actions related to content management.

![User interface showing access permissions in Document360.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Top_right_menu_view_access_permissions.png)

To view your access permissions,

1. Click your profile picture in the top-right corner.
2. Click  **View access and permissions** in the dropdown menu. This will open the **View access permissions** popup window.

In the View access permissions window, you will be able to see the permissions assigned to you for each feature under the Portal role and Content role.

You can edit/update your permissions from the Team accounts & groups [Insert article link here] page in Document360 settings. You will only be able to make any changes if you have the required Portal role permissions (For example, Owner or Admin).

To learn more about the various roles and permissions in Document360, and creating custom roles, read the article on Roles & permissions.

![Access permissions for project settings, team auditing, and event notifications overview.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-View_access_permissions_window.png)

> NOTE
>
> The View access and permissions option is only available when accessing the top-right menu from within a project.

### Change password

The **Change password** section allows you to securely update your login credentials in Document360.

![User interface showing the option to change password in settings.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Top_right_menu_change_password.png)

To update your Document360 password,

1. Click your profile picture in the top-right corner.
2. Click **Change password** from the dropdown menu. This will open the **Change password** popup window.
3. Enter your **current password** in the provided field.
4. Enter a **new password** in the next field. Ensure the new password meets security requirements.

> NOTE
>
> Your new password should:
>
> * Be at least 8 characters long
> * Contain at least 1 UPPERCASE letter
> * Contain at least 1 lowercase letter
> * Contain at least 1 number
> * Contain at least 1 special character

5. Confirm the new password by re-entering it.
6. Click **Save** to update your password.

![Password change interface with fields for current, new, and confirm password.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Change_password_popup.png)

> NOTE
>
> Changing your password will log you out immediately. You will need to log in with your updated password.

#### Best practices for updating your password

Here are a few pro tips for creating a strong and secure password.

**Dos**

* Create a unique password that uses a combination of numbers, words, symbols, and both uppercase and lowercase letters.

> **For example:** En37df\_n4r-hufling

**Don’ts**

* Don’t use easily guessed passwords, such as "password," "123456," or "user."
* Don’t choose passwords based on easily obtainable details, such as your birth date, Social Security number, phone number, or the names of family members.
* Don’t use words that can be found in the dictionary. Password-cracking tools often come with dictionary lists that will try thousands of familiar names and words.

  + If you must use dictionary words, try adding numbers and special characters to them, such as "In$t@llat10n."
* Don’t use simple adjacent keyboard combinations like "qwerty," "asdzxc," "abcdef," or "123456." These are generic and easy to crack.

---

## Release updates

Stay up-to-date with the latest updates and announcements from the Document360 team.

To read about the latest updates to Document360,

1. Click the **Release updates** icon () in the top-right corner in the Knowledge base portal. A popup appears, displaying information about the three latest releases.
2. Click any update to read a brief summary. To view the full details, click **Read the whole post.**
3. You can also click **Document360 updates**. This will redirect you to the [**Document360 Updates - Changelog**](https://changelog.document360.com/?utm_medium=widget) page.

![Document360 interface showing recent updates in a sidebar.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Top_right_menu_release_updates.png)

> NOTE
>
> To read the latest Document360 release note, click [**here**](https://docs.document360.com/docs/release-note).

---

## Help menu

The **Help menu** provides several tools to assist users in resolving queries, accessing resources, and staying informed about Document360.

Click  **HELP** in the top-right corner of the Knowledge base portal to access the help menu.

### Options available in the help menu

1. **Get assistance:** Opens a side-panel widget where you can search for answers to your queries or access Document360 documentation directly.
2. **Documentation:** Redirects you to the Document360 knowledge base at `https://docs.document360.com/docs`, where you can browse detailed articles, guides, and tutorials.
3. **Chat with us:** Opens a chat widget that connects you with the Document360 customer support team for real-time assistance.
4. **Issues and clarification:** Launches a widget allowing you to create a support ticket. You can include details and attachments to help the support team resolve your issue effectively.
5. **Submit a feature request:** Provides a platform to share feedback and suggest new features. Feature requests are visible to other users, who can vote to prioritize them.

> NOTE
>
> Only Document360 authenticated users can access the feedback portal.

6. **System updates:** Redirects you to `https://status.document360.com/`, where you can view the operational status and updates regarding Document360's services.

![Document360 interface showing help features for users.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Top_right_menu_help_menu.png)

> NOTE
>
> For further assistance, you can also contact the support team directly via email at [support@document360.com](mailto:support@document360.com).

---

### FAQs

#### What happens if the browser does not support the selected portal language?

If the browser does not support the selected language, Document360 automatically defaults to English.

#### What if I select Spanish as my portal language but my browser's preferred language is set to English?

If the browser's preferred language is English but the user selects Spanish within the application, all projects will be displayed in Spanish, following the user's preference. Similarly, if the browser's preferred language is set to Spanish, all projects are displayed accordingly.

<a id="creating-a-project"></a>

## Creating a project in Document360

#### Plans supporting the creation of new project

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

A project in Document360 serves as a comprehensive container for all your documentation needs. It encapsulates your articles, categories and subcategories, the home page, team accounts, readers, and groups (for private and mixed projects), and custom configurations or settings. This centralized approach ensures that your knowledge base is organized, easily accessible, and scalable.

## How to create a knowledge base project in Document360?

Projects in Document360 are designed to streamline your documentation process, offering a structured and efficient way to manage your information. Whether you're creating user manuals, internal process documents, or API documentation, a Document360 project provides the framework to store, manage, and distribute content effectively. Follow these steps to create your knowledge base project.

### Accessing the dashboard

1. Log in to the [**Document360 portal**](https://portal.document360.io/) with your account to access the **Dashboard**.   
   If you are logged in and are in a different project's Knowledge base portal, click the Document360 icon at the top left to be redirected to the **Dashboard**.
2. Click the **+****Project**button on the top right to create a new project.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/My projects.png "My projects.png")

### Choose your use case

3. Select any of your following primary use case for which you’re using Document360 by clicking **Get started.**

|  |  |
| --- | --- |
| **Use case** | **Description** |
| **Knowledge base platform** | You can create a centralized hub where all your team's knowledge and resources are stored. It helps your team quickly find answers and enhances customer self-service by providing them with easy access to the information they need. |
| **Software documentation/Technical documentation** | You can efficiently organize and maintain all your software or technical documentation. It helps your team document product features, APIs, release notes, and more, making sure that developers and users have clear and up-to-date information. |
| **SOP documentation** | You can create detailed SOPs that your team can follow consistently. It ensures that everyone adheres to the same processes, reduces errors, and helps in onboarding new employees by providing them with clear procedural guidelines. |
| **User manual** | You can develop comprehensive user manuals that guide your customers or team members through your product's features and usage. It helps in reducing support queries by offering step-by-step instructions and troubleshooting tips. |
| **API Documentation** | Document detailed information about API endpoints, request and response formats, authentication methods, and examples. This ensures developers have a clear understanding of how to integrate with your APIs. |
| **Others** | Choose this option if your use case does not fall into the predefined categories. You can customize your knowledge base based on specific organizational or project needs. |

### Select a Template

4. Select the type of content you'll create in your Document360 project. You can pick up to two templates that suit your needs.

> NOTE
>
> Based on your selection, these templates will be embedded within your project during creation.

**Knowledge base platform templates**

If you have selected the Knowledge base platform in step 3, you can choose any two templates from the list below.

|  |  |
| --- | --- |
| **Template** | **Purpose** |
| **Getting started guides** | Help new users quickly understand and begin using your product with clear, step-by-step instructions. This ensures a smooth onboarding experience. |
| **How-to guides** | Provide detailed instructions for specific tasks, enabling users to fully utilize and explore your product’s features efficiently. |
| **FAQs** | Address common questions at any stage of the user journey, helping users find quick answers and reducing support queries. |
| **Policy & procedures** | Outline essential organizational protocols, helping users understand and adhere to company guidelines effectively. |

**Software/Technical documentation templates**

If you have selected Software/Technical documentation in step 3, you can choose any two templates from the list below.

|  |  |
| --- | --- |
| **Template** | **Purpose** |
| **Release notes** | Keep users informed about updates, new features, bug fixes, and improvements with each software release. |
| **Software Design Documentation (SDD)** | Outline software architecture and design, including diagrams and specifications for development guidance. |
| **Software Requirement Documentation** | Describe the software's purpose, functionalities, and environment to ensure development aligns with project goals. |
| **Product Requirement Documentation (PRD)** | Define the product’s purpose, value, and functionalities to meet user needs and business objectives. |
| **Process documentation** | Detailed steps and procedures involved in software development to standardize workflows and enhance efficiency. |
| **User guide** | Give comprehensive instructions on using your product, covering all features and functionalities. |

**SOP documentation templates**

If you have selected SOP documentation in step 3, you can choose templates from the list below.

|  |  |
| --- | --- |
| **Template** | **Purpose** |
| **Compliance policies and procedures** | Ensure your organization meets regulatory requirements by documenting policies that enforce compliance. |
| **Operation SOP** | Enhance efficiency and productivity by standardizing operational procedures across your organization. |

**User manual templates**

If you have selected the User manual in step 3, you can choose any two templates from the list below.

|  |  |
| --- | --- |
| **Template** | **Purpose** |
| **Installation manual** | Provides all necessary setup information including product overview, specifications, and assembly instructions, ensuring a smooth start with the Knowledge base platform. |
| **Instruction manual** | Offers step-by-step assembly and usage instructions with diagrams and safety warnings, ideal for precise setup and safety warnings for proper usage. |
| **Maintenance manual** | Provide detailed instructions for regular upkeep, troubleshooting, and repair procedures to ensure optimal performance. |
| **Training manual** | Provides comprehensive guidance on installation, operation, and troubleshooting, and support for user training and effective platform usage. |
| **Operations manual** | Provide detailed instructions for daily maintenance and troubleshooting, ensuring ongoing effective management of the Knowledge Base platform. |

### Personalize your knowledge base

5. Enter your preferred website URL. If you want to skip this step, the domain will default to the one linked to your registration email.

### Brand guidelines

6. Your project name, default language, branding logo, and brand colors will be automatically set based on your provided URL. However, you can edit the fields if needed.   
   Your browser’s language settings determine the default language. English will be selected by default if other languages don’t support your browser’s language.

> NOTE
>
> * you choose Spanish or Brazilian Portuguese as your default language; the portal language will be set to Spanish or Brazilian Portuguese. Otherwise, English will be the default language.
> * The branding logo and primary/secondary colors are extracted from your website. If you choose to **Skip** this step, the project name will be derived from your registration email, and Document360’s default logo and colors will be applied.

7. You can preview your Knowledge base on the right side of the screen.

### Set documentation privacy

8. Choose the desired privacy settings for your site:

   * **Private**: Restrict access to the Knowledge base so that only team accounts can view and interact with the content, keeping it secure and internal.
   * **Public**: Make the Knowledge base accessible to everyone, including external users, allowing open access to all content.
   * **Mixed**: Combine private and public access by allowing some sections of the Knowledge base to be visible to the public while keeping other sections restricted to team accounts only.
9. Click **Next** to proceed.

### Access the Document360 Knowledge base portal

Once you complete the setup, enter the Document360 Knowledge base portal. Here, you’ll find pre-loaded articles based on the use case and templates you selected.

> NOTE
>
> The articles seeded into your project are tailored to your selected use case and templates, giving you a head start on creating your content.

![Exploring the onboarding experience while signing up the Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Final_onboarding_process.gif)

---

## Switching between Document360 projects

Once you’ve created your projects in Document360, you may need to work on multiple projects or switch between them for various tasks. Document360 provides an intuitive project switcher to help you manage this seamlessly.

There are two ways to switch projects from the Knowledge base portal:

1. Using the Projects dropdown
2. From the Projects dashboard

### Switching projects using the Projects dropdown

1. From any module in the Knowledge Base portal, click on the project dropdown at the top-left of the screen.
2. You can view the "Project Name," "Site Access" (Public -  , Private -  , or Mixed ), and a "Sandbox" label if it is a Sandbox project.
3. Click on the project you want to view from the list.

![Screenshot for switching between projects in Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Switching%20between%20projects%20-%201.png)

### Switching projects from the Projects dashboard

1. Click on the Document360 logo at the top-left.

   ![Screenshot for switching between projects in Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Switching%20between%20projects%20-%202.png)

   You will be redirected to the "My Projects" page.

   The list of all projects owned or associated with your account will be displayed.
2. Click on the project you want to navigate to.

   ![Screenshot for switching between projects in Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Switching%20between%20projects%20-%203.png)

---

### FAQs

#### **Does Document360 support different languages in the onboarding flow?**

Yes, Document360 offers multi-lingual support in the onboarding flow, including languages such as English, Spanish, Brazilian Portuguese, German, and Swedish. However, within the Document360 portal, language support is currently limited to English, Spanish, and Brazilian Portuguese.

#### **Can I customize the appearance and structure of my Document360 project?**

Yes, Document360 projects offer extensive customization options. You can customize the look and feel of your knowledge base by designing your home page, themes, adding your organization's branding, editor oriented, and organizing articles in a hierarchical structure (categories) that suits your documentation needs.

#### **Is it possible to control access and permissions within Document360 projects?**

Absolutely. Document360 offers robust access control and permission settings. You can assign roles and permissions to team accounts, restricting or granting access to specific features and contents based on their responsibilities and requirements.

#### **How does Document360 help with version control and documentation history?**

Document360 projects maintain a comprehensive article version control system referred to as "Article revisions." It automatically saves and tracks changes made to articles, allowing you to revert to previous versions if needed. This ensures the integrity of your documentation and simplifies collaboration on content updates.

#### **How do I know which project I am currently working on?**

You can check the project name displayed at the top-left of the screen in the Knowledge Base portal.

#### **What happens if I don't see the project I want to switch to?**

Ensure you have the necessary access permissions for that project. If the project still doesn't appear, contact your Document360 administrator for assistance.

#### **What is a "Sandbox" project, and how is it different from other projects?**

A Sandbox project is a test environment where you can experiment without affecting your live projects. It will have a "Sandbox" label in the project dropdown.

#### **What does "Site Access" mean in the project dropdown?**

"Site Access" indicates whether the project is Public, Private, or Mixed. This defines the accessibility level of the project's content.

#### **How can I request access to a project I am not currently associated with?**

Contact your team administrator or project owner to request access to the desired project.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="dashboard"></a>

## Dashboard

**Plans supporting the use of Dashboard**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The Document360 dashboard provides insights on your project, team members, and tasks to complete. There are two tabs in the dashboard: **My contribution** and **Overview**. The **My contribution** tab provides information regarding your articles and contributions to the knowledge base. The **Overview** tab provides information regarding all the team accounts associated with the project.

## My contribution tab

The **My Contribution** tab in the Document360 dashboard provides you with an overview of your contributions to the associated Document360 project. This includes all the workspaces and languages that are part of the project. You can view your contributions in terms of:

* **Article summary** (number of articles created and published, and performance metrics)
* **Articles assigned to you**
* **Review reminders**
* **Feedback to address**
* **Any broken links in your articles**

![Screenshot of the dashboard](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_GIF-Dashboard_my_contribution_overview.gif)

NOTE

You can filter the data in the **My contribution** page for a particular workspace and language from the dropdown at the top. You can also choose to view data for all workspaces and languages by selecting All workspaces and All languages from the dropdown at the top.

### Article summary

The section on the left of the **My contribution** tab is called **Article summary**. It contains information regarding any articles you have worked on. View your article count in three categories:

* **Created articles** (number of created articles)
* **Published articles** (number of articles published)
* **Draft articles** (number of articles updated, but still in Draft mode)

Along with these statistics, you can also view statistics related to the performance of all your articles. You can view these performance metrics:

* **Overall views** (total views for all articles)
* **Reads** (total reads)
* **Likes** (total likes received)
* **Dislikes** (total dislikes received)

> NOTE
>
> You can use the **Date** filter from the top right corner of the Article summary section to view the statistics for your articles during the last week, last month, or during a custom date range.

### Assigned to me

The **Assigned to me** tab shows all articles assigned to you across all workspaces and languages within the project. Each assigned article displays its current workflow status and, if applicable, the assigned due date.

### Review reminders

Each article in Document360 is marked as stale after a set period without updates. If you are a contributor to a stale article, it will appear under the **Review reminders** tab, along with the date it was marked as stale.

### Feedback

Any user feedback to an article in the knowledge base site will be recorded in the Feedback manager under Content tools. If any feedback from the Feedback manager is assigned to you, it will appear in the **Feedback** tab. You will also be able to view the Feedback status, as well as the date the feedback was assigned to you.

### Broken links

If any of your articles contain any broken links, the article will be listed under the **Broken links** tab. You can see the workspace and language of the article, along with the number of broken links in the article.

## Overview tab

The **Overview** section allows team members with Owner or Admin roles to view key project information, including article contributions, performance metrics, Drive capacity, total team accounts, reader count, broken links and more. You can view the following metrics on this page:

* **Article summary** (number of articles created and published, and performance metrics)
* **Project overview**

  + Recently seen
  + Team accounts
  + Readers
  + Drive capacity
  + Broken links
  + No result searches
  + Last backed up

![1_Screenshot-Dashboard_Project_overview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Project_dashboard_overview_page.png)

NOTE

You can filter the data in the **Overview** page for a particular workspace and language from the dropdown at the top. You can also choose to view data for all workspaces and languages by selecting All workspaces and All languages from the dropdown at the top.

### Article summary

The Article summary section shows the total articles created, published and in Draft mode as well as the article performance metrics for the time frame selected from the Date dropdown. You can filter this data by contributor by selecting one or more users from the Filter option.

### Project overview

This section allows you to manage the project by displaying important information, such as:

* **Recently seen**: Displays the gravatars of contributors who recently accessed the project.
* **Team accounts**: Shows the total team accounts added to the project. Click **View all** to navigate to the **Team accounts & groups** page (**Settings** > **Users & security**).
* **Readers**: Shows the total readers added to the project. Click **View all** to navigate to the **Readers & groups** page (**Settings** > **Users & security**)
* **Drive capacity**: Shows the used and total available Drive capacity. Click **View all** to navigate to the Drive module.
* **Broken links**: Shows the total broken links in the knowledge base. Click **View all** to navigate to the link status overview page (**Analytics** > **Link status**)
* **No result searches**: Shows the total searches on the Knowledge base site that showed no results. Click **View all** to navigate to the search analytics page (**Analytics** > **Search**)
* **Last backed up**: Shows the most recent date a backup was created for the project.

---

### FAQ

**How can I filter the data in the My Contribution page?**

You can filter the data by selecting a specific workspace and language from the dropdown at the top, or view data for all workspaces and languages by selecting **All workspaces** and **All languages**.

<a id="getting-started-with-multi-lingual-knowledge-base"></a>

## Multilingual Knowledge bases

**Plans supporting the use of multilingual knowledge base**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

### What is a multilingual Knowledge base?

A multilingual knowledge base is essentially similar to a standard knowledge base, with the primary distinction being that it provides content in various language choices, enabling users to obtain information in their chosen language for a more integrated experience.

> NOTE
>
> Document360 supports the internationalization (i18n) of your project's Knowledge base site.

---

## Adding multiple languages to a single workspace

To add multiple languages to a single project workspace or a language-specific Knowledge base in Document360.

Navigate to Settings () > **Knowledge base portal** > **Localization & workspaces** in the Knowledge base portal.

You can find a list of workspaces available in the project.

There are two ways to add a new language to the project workspace from here.

#### Method 1 - From the edit workspace module

1. Click the **Edit** (🖉) icon to the right of the workspace, and the **Edit workspace** blade window will appear.
2. Click the **New language** at the bottom, and a list of languages appears.
3. Use the search bar to search language(s).
4. Select the checkbox of the desired language(s) and click **Apply**.
5. Then click the **Update** button at the bottom of the blade.
6. Click on the More () icon for the below edit options,

   **Set as default** - To set the language as the default language of the workspace.

   **Edit display name** - To edit the display name of the language for the workspace.

   **Right to left** - Most languages are written from left to right, but a handful of languages are written in the opposite direction. By enabling this toggle, article content in the HTML editor and reader view (Knowledge base site) would start on the right and end on the left.

   **Hide** - To hide the language. The Knowledge Base portal indicates hidden languages by strikethrough for reference.

   **Remove** - To remove the language from the list of languages.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Multilingual_Knowledge_Base.gif)

#### Method 2 - Using the localization icon on the overview page

1. Click on the **Add new language** () icon next to the Edit icon.
2. Search for the desired language(s) in the search bar and select the checkbox of the languages you wish to add to your workspace.
3. Once done, click **Add**.

> NOTE
>
> While selecting a language for your workspace, all languages other than English will be displayed in their native script.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-Multilingual_language_base.gif)

> NOTE
>
> All the categories and articles from your default language will be available in the new language(s). However, these articles and categories have to be manually translated, using machine translation (HTML editor only) or with extensions like **Crowdin**.

---

## FAQ

**How many languages can I use per workspace in each plan?**

Each plan includes the following number of languages per workspace by default:

* **Professional Plan:** 2 languages
* **Business Plan:** 3 languages
* **Enterprise Plan:** 5 languages

Also, you can purchase more languages as an add-on on your existing plan.

The public-facing website where end-users can access articles and find answers to their questions.

An online library where users can find information about a product, service, department, or topic. It helps users self-serve by providing answers and guidance.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The public-facing website where end-users can access articles and find answers to their questions.

<a id="creating-a-sandbox-project"></a>

## Creating a sandbox project

**Plans supporting for creating a Sandbox project**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

### What is a Sandbox project?

A Sandbox project is an essential feature of Document360, offering an isolated test environment to explore features and configurations without impacting your live knowledge base. Whether testing new designs, refining workflows, or training your team, the Sandbox project provides a secure space to experiment and optimize your setup.

A sandbox project allows you to:

* Safely test new features and settings before going live.
* Identify and resolve issues early.
* Refine your setup and train your team without disturbing the end-user experience.

For instance, if you want to redesign your Knowledge base site's layout to enhance user-friendliness, you can use the Sandbox project to test the new design, gather feedback from internal teams and beta customers, and make adjustments before implementing changes in the live environment.

---

## Creating a Sandbox project

To create a new sandbox project,

1. Navigate to **Settings** () > **Knowledge base portal**> **General**in the Knowledge base portal.
2. In the **Sandbox** section, click **Create Sandbox**.

   The **Create a knowledge base sandbox** panel will appear.
3. Enter your desired project name in the **Project name** field.

> NOTE
>
> **Naming Guidelines:**
>
> * Only alphabets (A-Z, a-z), numbers, hyphens (-), and spaces are allowed.
> * Special characters, except hyphens, are restricted.
> * The project name must not exceed 30 characters (including spaces).

4. Select the language from the **Language** dropdown.
5. If required, select the **KB site 1.0** checkbox, if the Sandbox project should be based on KB site 1.0.
6. The **Knowledge base visibility** for Sandbox projects will be set to [**Private**](/docs/site-access#private-access) by default.
7. Click **Next**.
8. Optionally, to invite team accounts, enter their email addresses.

   For multiple team accounts, separate the addresses with commas (,).
9. Select the desired **Role** for each team account.
10. Once all details are entered, click **Create project**.

    Your Sandbox project will be created.
11. Click **Open Sandbox**  to access the newly created Sandbox.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/New_UI_1_ScreenGIF-Creating_a_Sandbox_project.gif)

The **Sandbox** badge will appear next to **Open site**  in the top bar and beside the workspace name in the dropdown, indicating that the workspace is a Sandbox project.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-New_Sandbox_badge_in_the_top_bar.png)

> NOTE
>
> SSO users cannot create sandbox projects because logging in as an SSO user requires having a regular user who assigns SSO access to another user. Therefore, a new SSO user cannot create a sandbox project.

### Reasons to own a sandbox project

* **Reduced Risk**: By isolating the sandbox from the live knowledge base, you can experiment without risk.
* **Increased Efficiency**: Pre-launch testing in the Sandbox project ensures that transitions to the live environment are seamless and efficient.
* **Testing and Exploration**: The Sandbox project empowers you to explore Document360’s features and integrations in a safe and dynamic environment, completely free from any live project disruptions.
* **Training Through Isolation**: The sandbox serves as an excellent training platform, equipping team members with hands-on experience in Document360 without risking unintended impacts on the live environment.

---

### FAQs

#### How do I configure my subdomain name for the Sandbox?

The subdomain name for a Sandbox project will have `sandbox` appended to distinguish it from your live project. Once the Sandbox is created, you can modify the subdomain name using [custom domain mapping](https://docs.document360.com/docs/custom-domain-mapping).

#### How does the Sandbox project improve knowledge base management?

By offering a controlled environment, the Sandbox project lets you assess and refine new features before implementing them in the live knowledge base. This enhances content quality and customer support.

#### Can I test new configurations without disrupting the live project?

Yes. The Sandbox project allows you to evaluate different configurations, such as templates, integrations, and scripts, without impacting your primary knowledge base.

#### How does the Sandbox project prevent customer impact during testing?

Before introducing them to customers, you can verify changes like navigation menus and search algorithms in the Sandbox project. This safeguards their experience and helps identify and address issues before launch.

#### Can I migrate a sandbox project to production in Document360?

No, there is currently no direct option to migrate a sandbox project to production in Document360. To achieve this, you need to manually export the data from the sandbox project and then import it into the production environment.

#### Why can't I log in as an SSO user in the Sandbox environment?

Only non-SSO users can access the Sandbox environment. To gain access, request a team member with a non-SSO account to create a standard user account for you.

<a id="quick-summary-of-the-security-and-infrastructure-aspects"></a>

## Document360 security and infrastructure

**Plans supporting the Document360 security and infrastructure**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Security is one of the most important aspects of any SaaS application. As a company specializing in SaaS products, we ensure our offerings align with the latest market standards. **Document360** prioritizes data protection, ensuring your information is always secure.

We collaborate with industry-leading partners like **Algolia** and **MongoDB Atlas**, who are certified for TLS-standard encryption for data in transit. **Microsoft Azure Blob Storage** also safeguards your project backups with robust security protocols.

---

## Quick summary - Security and infrastructure

* Your data is securely stored in a remote database hosted by **MongoDB Atlas**, utilizing a three-server cluster to ensure zero downtime.
* Network traffic is encrypted using TLS, and data at rest resides in encrypted storage volumes.
* **Daily**, **weekly**, and **monthly** backups are maintained for up to **one month**, enabling quick restoration.
* Project back-ups are stored in **Microsoft Azure Blob Storage** across multiple geolocations to maintain data integrity.
* Our secured API allows data access via authenticated API tokens, ensuring complete control over access permissions.
* Document360 is hosted on **Microsoft Azure Cloud**, leveraging its advanced security protocols and compliance standards.
* **Microsoft Azure Cloud** offers protection against Distributed denial of service (DDoS) attacks by defending against common network-layer attacks through always-on traffic monitoring and real-time mitigation.
* The core team is highly technical and understands the importance of security and staying up to date with new technologies. They coordinate with an offshore team to provide the best services for the customers.

For more details on using Document360 APIs, refer to the [**Document360 API documentation**](https://apidocs.document360.com/apidocs).

---

## Best practices

Here at **Kovai.co**, we believe that best practices create secure and robust applications. We recommend that Document360 users follow our list of best practices to prevent unexpected data loss or unauthorized access.

### List of best practices:

1. **We do not recommend publicly sharing the API key via less-secured networks,** as it can result in unauthorized data access. The key can be used to view or exploit your data. In such a case, we recommend deleting the key immediately and creating a new API key for your usage.

> For more information, click [**here**](https://docs.document360.com/docs/creating-document360-api-tokens).

2. **We recommend giving** **an API key only the required permissions**, as this helps keep the data in safe hands and prevents unauthorized users from modifying it. For example, to view an *"example"* set of data, the API key only needs the GET method. This does not let users modify the data using the API key.

> For more information, click [**here**](https://docs.document360.com/docs/creating-document360-api-tokens).

3. **We suggest that the team manager give each user the correct access rights,** as most of our customers have a team that has access rights to the documentation. We simplify this by having roles corresponding to a certain access rights level.

> For more information, click [**here**](https://docs.document360.com/docs/team-roles-and-permissions-explained).

4. **We recommend that** **users take advantage of the backup functionalities**. The project will be automatically backed up every day at 00:00 UTC. You can also manually back up your project anytime to keep the changes made safe.  Both of these will back up the Settings, Landing Page, Documentation, and Entire Project contents and can be restored at any time to return to a previous version. This process is made available to keep the users in control and to prevent data loss.

> For more information, click [**here**](https://docs.document360.com/docs/backup-restore).

5. **We recommend you use the option to make the document private if needed**. Various customers have different use cases for our product. You might want the documentation to be visible to the public or internal team members. The project owners can make the documentation private in the latter case and make it not visible to the public.

> For more information, click [**here**](https://docs.document360.com/docs/making-a-knowledge-base-private).

---

## Security information of integrations and partners

### Algolia - Search partner

* **SOC2 and SOC3 compliant**- Algolia follows all SOC 2 best practices to ensure excellence in the AICPA’s five trust service principles. Resulting in securing your data from modern world threats.
* API servers use HTTPS and TLS (1.0, 1.1, and 1.2), which have an A rating from [Qualys SSL labs](https://www.ssllabs.com/ssltest/analyze.html?d=latency-dsn.algolia.net&hideResults=on).
* Algolia isolates each customer's data in separate applications, preventing leakage and exchange of information from preserving the integrity of your data.

> For more information about the security of Algolia Search, visit [**Algolia's security docs**](https://www.algolia.com/enterprise/security/).

### MongoDB Atlas - Database service partner

* **Network isolation** - MongoDB Atlas dedicated clusters are deployed in a unique Virtual Private Cloud (VPC) with dedicated firewalls. This means that a third party cannot access your private data.
* **MongoDB Atlas undergoes independent verification** of platform security, privacy, and compliance controls.
* **End-to-end encryption** - All network traffic is encrypted using TLS, and the minimum TLS protocol version can be configured. Encryption for data at rest is stored in encrypted storage volumes.

> For more information about the security of MongoDB Atlas, visit [**MongoDB's security docs**](https://www.mongodb.com/cloud/atlas/security).

### Azure Blob Storage

* **Encryption in transit** - HTTPS ensures data is encrypted during transfer. In contrast, client-side encryption secures data on your device before sending it to the server, where it is decrypted upon arrival.
* **Encryption at rest** - Storage-side encryption is always enabled and automatically encrypts storage service data when writing it to Azure Storage. Client-side encryption is also enabled to make the data stored as secure as possible.
* **Advanced threat protection** - Provides an additional layer of security to detect unusual behavior and potentially harmful attempts to access and exploit your storage account.

> For more information about the security of Microsoft Azure Blob storage, visit [**Azure security docs**](https://docs.microsoft.com/en-us/azure/security/security-storage-overview).

---

## GDPR compliance

Document360 is fully **GDPR compliant.** We collect and store only the data required to deliver our services, with explicit customer consent.

> For more information about GDPR compliance, visit [**Document360's GDPR compliance page**](https://document360.com/gdpr-compliance/).

---

## Business continuity and disaster recovery

We have High Availability configured for our web apps and database to ensure business continuity. Multiple nodes run for individual services, so if one goes down, you still get an uninterrupted experience using Document360.

For any possible disaster, our database and data storage are replicated in different geolocations, so your data is always safe with us.

### DevOps Team

The product owner defines and reviews a Product roadmap periodically. Security fixes are prioritized and bundled in the earliest possible sprint. Our DevOps sprints are powered by multidisciplinary team members, including the Product Owner, Director of Engineering, Developers, and Quality Assurance.

* **Code Review**

The Quality Assurance team tests all changes and establishes criteria for performing code reviews, web vulnerability assessments, and advanced security tests.

* **Quality Assurance**

Builds undergo a stringent functionality, performance, stability, and UX tests before they are certified "Good to go.”

* **Version Control**

Source code is managed centrally with version controls, and access is restricted based on various teams assigned to specific sprints. Records are maintained for code changes and code check-ins and check-outs.

* **Segregation of Duties**

Access to the production resources is restricted to a limited set of users based on the job roles.

### Highly Resilient Architecture

The architecture is built with resiliency to ensure the high availability of the product and data.

* **High Availability**

We have multiple instances of our services running to ensure the high availability of our services for our customers.

* **Highly Scalable DNS**

Route users to the best endpoint based on geo-proximity, latency, health, and other considerations.

* **Data Backup**

Cloud snapshots are taken daily and retained, weekly and monthly, and the backups are available for one month for restoration.

* **Incident & Breach Management**

Procedures are established for reporting and tracking incidents for timely communication, investigation, and resolution.

* **Azure CDN**

We use Azure CDN to make sure our application and customer documentation are served with speed and ensure that they are done from the nearest node.

---

## Help

**For more information about Document360's security and infrastructure,** [**contact us**](https://document360.com/contact-us/) **(or)** [**book a demo**](https://document360.com/request-demo) **with our experts today.**

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="x-frame-options"></a>

## X-Frame options

**Plans supporting access to security settings in the knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**X-Frame options** allow you to control whether your Knowledge base can be embedded in `<frame>, <iframe>`, `<embed>`, or `<object>` tags on other domains. This feature provides an additional layer of security by preventing malicious websites from embedding your Knowledge base using the above tags.

> NOTE
>
> Ensure that you are not using iframe-based embedding for unauthorized domains, as it will be blocked when the X-Frame options setting is enabled.

---

## Access X-Frame options

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Enable_xframe_options_toggle.png)

1. Navigate to **Settings** > **Users & security** > **Security**. This section contains controls for various security settings.
2. Locate the toggle labeled **Enable X-Frame options** and switch it on to restrict iframe embedding from external domains.

For example, if your knowledge base domain is `help.example.com` and you want to prevent other sites like `support.test.com` from embedding your content via iframes, ensure the **Enable X-Frame options** toggle is turned on.

![2_Screenshot-XFrame_options_before_after](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-XFrame_options_before_after.png)

---

### FAQ

#### What is an iframe?

An iframe, also known as an inline frame, is an HTML element that allows web developers to embed another HTML document within the current document. The content within an iframe is a separate web page displayed within a specific section of another web page. Due to its ability to embed external content, managing iframe usage with security settings such as X-Frame options is crucial to prevent security risks like clickjacking.

#### What are the embedded tags that I can restrict with the X-Frame options?

The X-Frame options setting allows you to control whether your knowledge base can be embedded in `<frame>`, `<iframe>`, `<embed>`, or `<object>` tags on external domains.

#### Why are X-Frame options important?

The X-Frame options are vital for security as they help prevent clickjacking attacks, where an attacker embeds your knowledge base in a malicious website. This embedding tricks users into performing unintended actions. Enabling X-Frame options ensures your knowledge base cannot be embedded on external domains, safeguarding user interactions.

#### How can I configure the X-Frame options for my knowledge base?

1. Navigate to **Settings** > **Users & security** > **Security**
2. Locate the toggle labeled **Enable X-Frame options** and switch it on to prevent your knowledge base from being embedded on unauthorized external domains.

#### Can I allow specific domains to embed my Knowledge Base?

Yes, you can specify the allowed domains in the Frame source of content security policy setting. For more information, see the [content security policy](/docs/content-security-policy) article.

#### How can I test if my X-Frame options are working?

You can test if your X-Frame options are correctly configured by:

1. Using your browser’s developer tools and checking the **Network** tab to inspect response headers for the **X-Frame-Options** setting.
2. Using third-party services like [securityheaders.com](http://securityheaders.com) to verify that the correct X-Frame-Options header is applied.

#### What are the potential risks of not using X-Frame options?

If the X-Frame options are not enabled for your knowledge base, it may be embedded in an iframe on another website without your authorization. This lack of control exposes your site to clickjacking attacks, where attackers overlay invisible or misleading elements over your interface to trick users into performing unintended actions, such as divulging passwords or clicking on malicious links. Such vulnerabilities can compromise user security and potentially lead to data breaches.

#### What is clickjacking?

Clickjacking, also known as UI redressing or UI masking, is a malicious technique where attackers trick users into clicking on a button or link that is hidden or obscured within a web page or application. This is often achieved by overlaying a transparent layer with deceptive elements over a legitimate website or application. Users may think they are interacting with the actual site, but in reality, they are engaging with elements controlled by the attacker. Such interactions can lead to adverse outcomes, like downloading malware, making unauthorized purchases, or inadvertently sharing sensitive information. Utilizing security settings like X-Frame options can help protect against such attacks by preventing unauthorized embedding of your content.

#### What is a malicious website?

A malicious website is a site designed to cause harm to visitors or their devices. These sites may trick visitors into downloading malware, stealing personal information, or engaging in fraudulent activities. Using X-Frame options helps prevent your content from being embedded on such sites, enhancing your security measures against these risks.

An online library where users can find information about a product, service, department, or topic. It helps users self-serve by providing answers and guidance.

<a id="content-security-policy"></a>

## Content security policy

**Plans supporting Content security policy in the knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Content Security Policy** (CSP) is a security related feature which helps to manage and prevent the external CSS, scripts, and frames embedded in your Knowledge base. When the content security policy is enabled in the project, the `Content-Security-Policy` response header will be added to the request header with the default allowed domains for each source. It restricts the resource loading from external domains and allows resources only from the configured list of domains for each source.

---

## Enable the content security policy

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Content_Security_Policy_in_the_Knowledge_base_portal.png)

1. Navigate to **Settings** () > **Users & Security** > **Security** in the Knowledge base portal.
2. Turn on the **Enable content security policy** toggle.
3. You can find the following source fields:  
    a. [**Style source**](/docs/content-security-policy#a-style-source)  
    b. [**Script source**](/docs/content-security-policy#b-script-source)  
    c. [**Frame source**](/docs/content-security-policy#c-frame-source)**.**
4. Type in the desired domain URLs in the respective fields.
5. Click **Save.**

> NOTE
>
> * The character limit for each limit is 5000.
> * Use commas (,) to separate the URLs.
> * Keep the URLs in the following format: `https://example.com.`

### a. Style source

In the **Style source** field, you can define the valid sources of stylesheets that can be applied to your Knowledge base. Configuring the style sources will prevent malicious styles from being used to execute Cross-Site Scripting (XSS) attacks on your Knowledge base.

* Type the domain URLs of **stylesheet sources** in this field.
* All the stylesheets from other URLs will be restricted.

> NOTE
>
> Ensure that you have added Nonce attribute placeholder in all custom HTML script sections.
>
> **Example**: `<Script nonce='{{Document360-Nonce}}'>`

---

### b. Script source

In the **Script source** field, you can define the valid sources of JavaScript codes that can be executed on your Knowledge base. This helps to prevent malicious JavaScript code from being executed, even if it has been injected into the Knowledge base by an attacker.

* Type the domain URLs of **Javascript sources** in this field.
* All the JavaScript codes from other URLs will be restricted.

---

### c. Frame source

In the **Frame source** field, you can define the valid sources of frame elements like `<frame>` and `<iframe>` that can be embedded in your Knowledge base.

* Type the domain URLs of **frame sources** in this field.
* All the frames from other URLs will be restricted.

---

## Testing your content security policy settings

After setting up your CSP, it’s important to verify that the settings are working as expected. To check if the content security policy has been applied correctly:

1. Open the **Network** tab in your browser's developer tools.
2. Visit your knowledge base and review the **response headers** for the CSP.
3. Alternatively, you can use online tools like [securityheaders.com](http://securityheaders.com) to verify if your website has the correct **Content-Security-Policy** headers set.

---

### FAQs

#### **Why is my video showing as "This content is blocked" in one article but not another?**

This issue typically occurs due to Content Security Policy (CSP) settings in Document360. The video might not be allowed by the current CSP settings. Different articles might have different CSP settings. Ensure that the video source is allowed in the CSP settings for all articles where the video needs to be displayed.

#### **How can I resolve the issue of a blocked video in my article?**

To fix this, navigate to **Settings** > **Users & security** > **Security**. Under **Enable content security policy** section, add the video source (e.g., https://www.youtube.com/) to the "Frame source" list and click **Save**.

#### **Why does my CSP validation indicate that CSP is missing in the response header?**

In Document360, the Content Security Policy (CSP) is implemented using **meta elements** rather than the response header. If you validate CSP by inspecting the response header, it will appear as though CSP is missing or disabled.

To confirm that CSP is enabled on your Knowledge base site, follow these steps:

1. Open your Knowledge base site in a browser.
2. Right-click anywhere on the webpage and select **View page source**.

   The page's source code will appear.
3. Use the search function (**Ctrl + F** on Windows or **Cmd + F** on Mac) and look for the term “**Content-Security-Policy**”.
4. If the term “**Content-Security-Policy**” is found, the CSP configuration will appear as the code following this term.

By validating through the meta element in the page source, you can confirm that CSP is enabled for your Knowledge base site.

<a id="csp-guidelines-for-document360-widget"></a>

## CSP and Whitelisting guidelines for Document360 widget

**Plans supporting addition of widget**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Content Security Policy (CSP)** is a security feature that helps prevent attacks like Cross-Site Scripting (XSS) by allowing developers to specify which sources of content are trusted and can be loaded by the browser.

Whitelisting in software products involves specifying a list of approved entities (e.g., IP addresses, domains, email addresses) that are allowed to access certain resources or perform specific actions, thereby blocking any entities not on the list to enhance security.

### Adding trusted content sources for the Document360 widget

When using the Document360 widget, certain trusted content sources need to be added to your existing CSP. This ensures that the widget functions correctly and securely.

#### For US users

Add the following sources to your `connect-src`, `script-src-elem`, `font-src`, and `style-src-elem` directives:

```
<!DOCTYPE html>
<html lang="en">
<head>
    <meta http-equiv="Content-Security-Policy" content="
    connect-src 
        https://jx9o5re9su-dsn.algolia.net
        https://apihub.us.document360.io/
        https://api.us.document360.io/
        https://gateway.us.document360.io
        https://*.algolianet.com
        https://js.monitor.azure.com;
    script-src-elem 
        'nonce-document360Nonce'
        https://cdn.us.document360.io
        https://*.algolianet.com
        https://cdn.jsdelivr.net
        https://cdnjs.cloudflare.com;
    font-src 
        https://fonts.gstatic.com
        https://cdn.us.document360.io;
    style-src-elem 
        'unsafe-inline'
        'unsafe-eval'
        https://cdn.us.document360.io/
        https://cdn.jsdelivr.net
        https://fonts.googleapis.com;">
</head>
</html>
```

XML

Copy

Replace `"document360Nonce"` with the nonce variable already available in your system.

#### For EU users

Add the following sources to your `connect-src`, `script-src-elem`, `font-src`, and `style-src-elem` directives:

```
<!DOCTYPE html>
<html lang="en">
<head>
    <meta http-equiv="Content-Security-Policy" content="
    connect-src 
        https://jx9o5re9su-dsn.algolia.net
        https://apihub.document360.io/
        https://api.document360.io/
        https://gateway.document360.io
        https://*.algolianet.com
        https://js.monitor.azure.com;
    script-src-elem 
        'nonce-document360Nonce'
        https://cdn.document360.io
        https://*.algolianet.com
        https://cdn.jsdelivr.net
        https://cdnjs.cloudflare.com;
    font-src 
        https://fonts.gstatic.com
        https://cdn.document360.io;
    style-src-elem 
        'unsafe-inline'
        'unsafe-eval'
        https://cdn.document360.io/
        https://cdn.jsdelivr.net
        https://fonts.googleapis.com;">
</head>
</html>
```

XML

Copy

Replace `"document360Nonce"` with the nonce variable already available in your system.

### Updating your widget configuration

In your knowledge base portal:

1. Go to **Widget** () on the left navigation sidebar.
2. Select the required widget and click **Edit** ().
3. In the **Configure and connect** tab, expand the **Widget JavaScript** accordion under the **Connection** group.

### For US customers

Update your code as follows, replacing `"document360Nonce"` with the nonce variable already available in your system:

```
<!-- Document360 knowledge base assistant start -->
    <script nonce="document360Nonce">
        (function (w,d,s,o,f,js,fjs) {
            w['JS-Widget']=o;w[o] = w[o] || function () { (w[o].q = w[o].q || []).push(arguments) };
            js = d.createElement(s), fjs = d.getElementsByTagName(s)[0];
            js.id = o; js.src = f; js.async = 1; fjs.parentNode.insertBefore(js, fjs);
        }(window, document, 'script', 'mw', './widget.js'));
        mw('init', { nonce:'document360Nonce',apiKey: 'klhgeGoqB8wlUwq2hraJ1zbOCq/V+wBiyGQNhXEKQ6MO7V1AhLuakiEimM6ims92AR7Bqt/eOaAz3SgInMvZTkZrt3F7QaEmWtX7DDDTtIJTruZdyIv+bDBTKVuPx4BsVUavm68/y4HV7h0ahKmDgQ==' });
        //var jQuery_2_2_4 = $.noConflict(true);
    </script>
  <!-- Document360 knowledge base assistant end -->
```

XML

Copy

### For EU customers

Update your code as follows, replacing `"document360Nonce"` with the nonce variable already available in your system:

```
    <!-- Document360 knowledge base assistant start -->
    <script nonce="document360Nonce">
        (function (w,d,s,o,f,js,fjs) {
            w['JS-Widget']=o;w[o] = w[o] || function () { (w[o].q = w[o].q || []).push(arguments) };
            js = d.createElement(s), fjs = d.getElementsByTagName(s)[0];
            js.id = o; js.src = f; js.async = 1; fjs.parentNode.insertBefore(js, fjs);
        }(window, document, 'script', 'mw', './widget.js'));
        mw('init', { nonce:'document360Nonce',apiKey: 'klhgeGoqB8wlUwq2hraJ1zbOCq/V+wBiyGQNhXEKQ6MO7V1AhLuakiEimM6ims92AR7Bqt/eOaAz3SgInMvZTkZrt3F7QaEmWtX7DDDTtIJTruZdyIv+bDBTKVuPx4BsVUavm68/y4HV7h0ahKmDgQ==' });
        //var jQuery_2_2_4 = $.noConflict(true);
    </script>
  <!-- Document360 knowledge base assistant end -->
```

XML

Copy

By following these steps, you can ensure that the Document360 widget operates securely and efficiently in your environment.

---

## Troubleshooting

### Unable to view certain content on the site

**Error:** This content is blocked. Contact the site owner to fix this issue

You might encounter this issue when the CSP settings in the Knowledge Base portal block the requested content. It typically happens due to restrictions on file source URLs or incorrect CSP configurations.

**Steps to resolve:**

1. **Update the Content Security Policy:**

   a. Navigate to **Settings**() > **Users & Security** > **Security** in the **Knowledge base portal**.

   b. Under the **Content Security Policy** section, add the affected domain URL to the Source field to whitelist the required file source URLs.

   c. If you do not wish to enable this feature, toggle off the **Content Security Policy** option.
2. **Clear your browser cache:** After making changes, clear your browser cache and revisit the site to verify if the issue is resolved. It may take a few moments for the updated settings to take effect.
3. **Test the article in different environments:**

   a. Open the article in an incognito window.

   b. Test it across different browsers to confirm the issue is fixed.
4. **Review KB widget settings:** Ensure the application’s CSP settings are correctly configured to prevent errors in the Knowledge Base widget.

   If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

   Provide the following details:

   a. To verify whether the CSP has been applied correctly, open the **Network** tab in your browser’s **Developer tools**.

   b. Share the details of the response headers to confirm the presence and configuration of the CSP.

---

### FAQ

#### Why is the scroll bar not showing up on the Knowledge base widget?

The issue may be related to your application’s CSP rules. If your domain is not whitelisted in your CSP, it can prevent the scroll functionality from working properly. To resolve this issue, [add the domain URL to your application’s CSP](/help/docs/csp-guidelines-for-document360-widget#adding-trusted-content-sources-for-the-document360-widget).

<a id="bot-management"></a>

## Bot management

**Plans enabled with bot management capabilities**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

A bot, short for "robot," is a software program that works on the Internet and handles repetitive tasks. While some bots are helpful, others can harm websites or apps.

## Types of bots

Bots fall into two main categories: Good Bots and Bad Bots.

• **Good Bots**: These bots, like GoogleBot, BingBot, and GPTBot, are transparent about their identity and purpose. They're often called Verified Bots.

• **Bad Bots/Malicious Bots**: These bots engage in harmful activities like scraping content, spreading spam, or perform credential stuffing attacks. Examples include bots used in DoS and DDoS attacks, web scrapers, and brute force password cracking.

---

## Bot management

Bot management involves blocking bad or malicious bots while still allowing good bots access online resources. This is crucial for keeping the online environment safe and efficient by mitigating potential threats.

### Why bot management matters?

Good bot management means legitimate users can have uninterrupted access to online resources by filtering harmful and bad bots. By spotting and stopping bad bots, it keeps servers running smoothly and makes things more secure. Plus, it helps watch for any suspicious bot activity to stop threats before they cause bigger issues.

---

## Heuristics and Machine Learning Detection

Cloudflare, as part of its security setup, utilizes both heuristics and machine learning to detect bots. This helps to proactively block malicious bots based on traffic patterns, user-agent anomalies, and other behavioral markers. By continuously analyzing incoming requests, this method effectively reduces the risk of sophisticated bot attacks.

---

## Security setup

Document360 provides enhanced security with bot detection and blocking for the knowledge base portal and knowledge base site. The bot management operates in Block mode for definite bot requests. This proactive measure prevents unwanted traffic safeguarding data integrity.

## User-Agent monitoring and IP/Port blocking

Cloudflare identifies bots using user-agent patterns. For instance, requests with empty user agents or unreleased browser versions are flagged and blocked. Additionally, if a site is accessed using unsupported port numbers, such as port 8443, Cloudflare will automatically block these attempts. Furthermore, it detects unusual traffic patterns coming from the same IP or ISP and blocks such traffic to protect against potential attacks.

> CAUTION
>
> Certain bot management measures, such as blocking specific bots or user agents, may impact custom automation scripts or integrations.

> NOTE
>
> Implementing these security measures is critical for safeguarding against malicious bot activity and maintaining the integrity of our online platforms.

<a id="fair-usage-policy-for-bot-management"></a>

## Fair usage policy for bot management

**Plans enabled with fair usage policy for bot management**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

To ensure optimal system performance and equitable access for all users, Document360 implements a Fair Usage Policy for bot management. This policy outlines the restrictions on bot usage to maintain service quality and prevent abuse.

---

## Fair usage policy details

Document360's fair usage policy includes rate limiting rules to manage bot traffic effectively and protect the application against Denial of Service (DoS) attacks. Rate limiting is used to limit the number of requests made by one user, ensuring a seamless experience for other users. These rules are designed to balance the needs of all users while maintaining system integrity.

## Rate limiting

* Maximum request limit of **1,500 requests** per **minute** per **IP address,** or
* Maximum request limit of **300 requests** per **10 seconds** per **IP address.**

Cloudflare also complements this rate-limiting process by analyzing bot activity patterns using heuristics and machine learning detection.

---

## Purpose of the policy

This policy helps ensure equitable access to our services for all users by preventing any single bot or user from monopolizing system resources. By implementing these limits, we can maintain consistent performance and availability for everyone using the platform.

## Importance of compliance

Adhering to this Fair Usage Policy is crucial for maintaining the overall health of the system. It helps prevent server overload, ensures responsive service for all users, and protects against potential abuse or unintended high-volume requests that could impact other users' experience.

---

> NOTE
>
> If you have specific use cases that may require higher limits, please contact our support team to discuss your needs and potential solutions.

<a id="using-the-text-editor"></a>

## Editor choices in Document360

**Plans supporting the use of editors**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Using the text editor in Document360 is essential for creating and managing Knowledge base articles efficiently.

Document360 allows you to draft articles in three versatile editor options:

1. The [Markdown editor](/help/docs/the-markdown-editor) lets writers use syntax and HTML to customize articles.
2. The [WYSIWYG](/help/docs/the-wysiwyg-editor) (What You See Is What You Get) editor uses rich text formatting and includes an extensive formatting toolbar; however, you cannot use custom code in articles.
3. The [Advanced WYSIWYG editor](/help/docs/advanced-wysiwyg-editor-overview) is the latest addition to the editor options in Document360 and acts as a hybrid between the Markdown and WYSIWYG editors.

Document360 ensures a user-friendly experience that enhances content clarity, consistency, and engagement.

---

## Markdown editor

The Markdown editor has a split-screen workspace and features to help you manage an article as you write it.

1. The left side of the screen is where you type and apply the Markdown syntax.
2. The preview screen on the right side allows you to view how your article will look before publishing.
3. The Scroll on indicates that both sections scroll simultaneously. Click **Scroll on** to turn off auto-scroll.
4. Click  **preview** to see how your article will appear on the Knowledge base site.
5. After publishing, you can find the **Copy link** () icon near the View in Knowledge base () icon.

Use the arrows on the divider to collapse either window of the editor.

![1_Screenshot-Markdown_editor_new_UI](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Markdown_editor_overview.png)

### Scenarios where the Markdown editor is recommended

The Markdown editor provides guided flexibility for article creation and customization and enforces a consistent writing style and formatting across the documentation. This consistency is crucial for maintaining a professional appearance in product documentation.

> **For example**, you can insert images using the toolbar, which injects the following Markdown:
>
> `![Image Alt Text] (Image URL){height="" width=""}.`
>
> You can adjust the image size by adding desired values (e.g., height="600px" width="400px"). Advanced formatting, such as shadows and borders, can be achieved with HTML customization snippets.

  

NOTE

For more information, refer to the articles on the [Markdown editor](/help/docs/markdown-editor-overview) and [Markdown basics](/help/docs/markdown-basics).

---

## WYSIWYG editor

The WYSIWYG, which stands for What You See Is What You Get, is an HTML-based editor that differs from the Markdown editor. It allows you to view the actual formatting of the article as you type or insert content.

![2_Screenshot-WYSIWYG_editor_new_UI](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-WYSIWYG_editor_overview.png)

### Scenarios where the WYSIWYG editor is recommended

If team members who contribute to articles are familiar with HTML-based editors like WordPress, this editor is relatively easy to use. Additionally, if your documentation articles contain a lot of code and media, the WYSIWYG editor provides extensive formatting options for text, images, videos, and more.

> NOTE
>
> For more information, read the article on [WYSIWYG editor](/help/docs/the-wysiwyg-editor).

---

## Advanced WYSIWYG editor

The lightweight and powerful 'Advanced WYSIWYG editor' offers rich text editing capabilities and supports Markdown syntax, providing a more visual and intuitive experience compared to the Markdown editor while maintaining flexibility similar to the WYSIWYG editor.

Type `/` in the editor, and a list of options appears. You can search for the options by typing command names. Click the desired command or press Enter key to select the command.

![3_Screenshot-Advanced_WYSIWYG_editor_new_UI](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Advanced_WYSIWYG_editor_overview.png)

### Scenarios where the Advanced WYSIWYG editor is recommended

Suppose you have Knowledge base articles with text-centric, code-heavy, and media-rich articles. In such cases, the Advanced WYSIWYG editor is a flexible alternative to the Markdown and WYSIWYG. This provides quick syntax-based editing similar to Markdown and broad text and image formatting options like the WYSIWYG editor.

> NOTE
>
> For more information, refer to the Document360 help article on [Advanced WYSIWYG editor](/help/docs/advanced-wysiwyg-editor-overview).

---

## Changing the default editor at the project level

To make the WYSIWYG/Advanced WYSIWYG editor the default editor:

1. Navigate to **Settings** () > **Knowledge base portal** > **General** in the Knowledge base portal.
2. In the **Editor** section, choose your desired editor.
3. Click **Save**.

![4_Screenshot-settingup_default_editor_in_settings](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Changing_the_default_editor_in_settings.png)

> NOTE
>
> If you change your project's default editor, all the new articles you create will be in your respective editor's choice.

---

## Switching between Markdown - WYSIWYG - Advanced WYSIWYG editor

Markdown editor is the default editor for all new projects and articles in Document360. If you want to use the WYSIWYG or Advanced WYSIWYG editor, you can switch to it at a project or article level.

### Editor switching at article-level

|  |  |
| --- | --- |
| **Possible** | * Markdown > Advanced WYSIWYG (only in 'Edit' mode) * WYSIWYG > Advanced WYSIWYG (only in 'Edit' mode) |
| **Not possible** | * Markdown > WYSIWYG * WYSIWYG > Markdown * Advanced WYSIWYG > Markdown * Advanced WYSIWYG > WYSIWYG |

To switch editors in an individual /category page, follow the below steps

1. In the article/category page, click the **More** (•••) icon, and select **More article options**.

   The **Article settings** panel will appear.
2. In the **Editor** tab, select your desired editor.
3. Select **Are you sure want to continue?** checkbox.
4. Click **Save**.

   The same steps apply to API documentation.

   5\_Screenshot-Switching\_editors

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Switching_editors.png)

> NOTE
>
> Once you have switched to the Advanced WYSIWYG editor at the article level, you cannot revert the editor type for that particular article. However, for future articles, the user with the **Project Settings - Update** permission can set the default editor from **Settings** > **Knowledge base portal** > **General** > **Editor**.

---

### Handling unsupported HTML tags and attributes in the Advanced WYSIWYG editor

The Advanced WYSIWYG editor in Document360 ensures content security by managing unsupported HTML tags and attributes. Instead of removing them, the editor flags and preserves these elements for users to review and fix.

#### When does this happen?

1. **Migrating from WYSIWYG to Advanced WYSIWYG editor**

   When switching between the editors, unsupported content is automatically identified and flagged for users to address potential issues.
2. **Editing content in Advanced WYSIWYG editor**

   When unsupported tags or attributes are added in the **Code view**, the editor detects, flags, and visually marks them for correction.

#### What happens when unsupported elements are detected?

* The editor detects unsupported HTML tags (e.g., `<marquee>`, `<blink>`) and attributes (e.g., `onmouseover`, `style="text-decoration:blink"`) during parsing.
* These elements are visually flagged within the content using custom indicators, such as tooltips and block highlights, without disrupting the content structure.
* In editor, you cannot edit the desired unsupported element’s block. However, users can interact with flagged elements, receiving options to modify, remove, or correct them in the **Code view**.

**Supported tags in the Advanced WYSIWYG editor**

Below is the list of tags with custom attribute support in the Advanced WYSIWYG editor:

#### **Text formatting tags**

Tags that define or modify how text appears:

* **Abbr**: Represents abbreviations or acronyms.
* **Blockquote**: Indicates quoted content.
* **Heading**: Represents headings (e.g., `<h1>`, `<h2>`).
* **Paragraph**: Defines a paragraph of text.
* **Sub & Super Scripts**: Used for subscript (`<sub>`) and superscript (`<sup>`).
* **Inline Code**: Represents a short snippet of code within a line of text.

#### **List tags**

Tags that structure content as lists:

* **Bullet List**: Represents unordered lists (`<ul>`).
* **Ordered List**: Represents ordered lists (`<ol>`).
* **Task List**: Used for interactive or visual checklists.
* **List Items**: Represents individual list elements (`<li>`).

#### **Form and interactive tags**

Tags used for creating forms and interactive elements:

* **Input**: Defines input fields.
* **Label**: Labels associated with form elements.
* **Text Area**: Allows multi-line text input.

#### **Link and media tags**

Tags for linking or embedding media:

* **Link**: Defines hyperlinks (`<a>`).
* **Image**: Embeds images (`<img>`).
* **Video**: Embeds videos (`<video>`).
* **Object**: Embeds external resources (e.g., Flash).
* **Iframe**: Embeds inline frames (`<iframe>`).

#### **Additional tags**

Additional tags with unique purposes:

* **Div**: A generic container for grouping content.
* **Kbd**: Represents keyboard input.
* **Details**: Creates a disclosure widget for showing or hiding content.
* **Summary**: Provides a summary for the `<details>` tag.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-describing_the_unsupported_tags_in_the_Advanced_WYSIWYG_editor_.png)

---

### FAQs

#### **What is a text editor in Document360's knowledge base?**

A tool that allows team accounts to create, edit, and format content for their articles and category pages. Each editor option provides a user-friendly interface to facilitate content creation within the Knowledge base portal.

#### **What are the key features of any text editor for documentation?**

Text editors with context to knowledge bases typically offer features such as basic text formatting (bold, italics, underline, strikethrough), text type formatting (headings, callouts lists, tables), media embedding (images, videos), file attachments, code formatting, and most importantly an easy to use interface.

#### **Can I embed images and videos directly within the text editor?**

Yes, all the text editors available in Document360 support media embedding. Users can easily add images, videos, and other multimedia elements directly into their articles for better visual appeal.

#### **Can I switch between different text editor options?**

You have the option that allows you to choose the editor that best suits your preferences and needs at a project level. You can also switch the editors once at an article level, but switching back has some limitations. Please refer to the [Switching editor](https://docs.document360.com/help/docs/using-the-text-editor#switching-between-markdown---wysiwyg---advanced-wysiwyg-editor) section in this article.

#### **Do the keyboard shortcuts work in the different Document360 editors?**

Yes, each of the three editors (Markdown, WYSIWYG, and Advanced WYSIWYG editor) has its collection of keyboard shortcuts. Most conventional shortcuts universally used in tools such as Microsoft Word and Google Docs are available with the Document360 editors.

> NOTE
>
> There are plenty of shortcuts available in Advanced WYSIWYG editor, click [here](/help/docs/advanced-wysiwyg-editor-basics) to know more.

#### **How do keyboard shortcuts in the editor help in documentation?**

Keyboard shortcut, as the name implies, improves efficiency in writing by minimizing the need to use the mouse to perform specific actions and access tools in the article without your fingers leaving the device's keyboard.

#### **How do I choose the right text editor option for my knowledge base?**

Consider the following factors before selecting the editor at a project-level or article-level

* Ease of use
* Type of documentation you create
* Media files usage
* Author familiarity with the editor

#### **Will the existing articles be affected by the change in the default editor?**

Existing articles will continue to use the same editor as before, while only the newly created articles will use the newly selected default editor.

<a id="elements-of-the-editor"></a>

## Elements of the editor

**Plans supporting the use of editors**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The Document360 Knowledge base portal editor exhibits fluid interactions, a simplified interface, and an enhanced user experience.

![1_Screenshot-Fresh_new_look](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Overview_of_the_Knowledge_base_portal_editor.png)

---

### Aesthetics and Functionality

#### Switching multiple projects

Within the project section, users can view a list of projects along with their respective icons denoting the type of knowledge base.

![2_Screenshot-Project_section](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Project_section_new.png)

#### Switching Workspaces and languages

![3_Updated_Screenshot-Workspace_area](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_New_Screenshot-Switching_workspaces_and_languages.png)

* The options for Workspace and Language are merged in the dropdown menu at the workspace.
* The Workspace name is displayed alongside the flag representing the language.
* From the dropdown, you can select the desired workspace and language.
* Clicking **Manage workspace & language** redirects you to the [**Localization and Workspaces**](/docs/localization-workspace) section in the settings.

  > NOTE
  >
  > The **Create** button is available in the header. With this, you can create a category, new article, article from template or import articles.

---

## Left navigation bar: Category tree manager

![4_Screenshot-Left_navigation_bar](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Left_navigation_bar_in_the_Knowledge_bse_portal.png)

1. The left navigation bar includes key sections such as Dashboard (), Documentation (), API Documentation (), Analytics (), Widgets (), Drive (), and Settings ().
2. At the top of **Categories & Articles** section, you will find the following options:

   * [All articles](/help/docs/all-articles-overview-page) ()
   * [Workflow assignments](/help/docs/workflow-assignment) ()
   * [Starred](/help/docs/starred-categories) ()
   * [Recycle bin](/help/docs/recycle-bin-recent-and-starred-files) ()
   * [Site builder](/help/docs/customize-site) ()
   * [Content tools](/help/docs/content-tools) ()

   The **Site builder** feature, now part of the category tree manager, redirects you to the **Customize site** section in the settings.
3. The **Categories & Articles** section is where all articles and categories are created. Recent enhancements to the **More options** () menu provide a more user-friendly and intuitive interface for improved usability.

> NOTE
>
> For more information, read the article on [Knowledge base portal](/docs/document360-getting-started#knowledge-base-portal).

---

## Article editor’s header section

The elements are positioned to enhance usability, providing you with a more intuitive and efficient workflow:

![5_Screenshot-UI_enhancements_in_the_editor_header_section](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-UI_enhancements_in_the_editor_header_section.png)

1. **Slug of the article**: The article's URL/slug is displayed for easy reference.
2. **Status of the article**: The article's status is prominently positioned to provide quick insights into its current state. An article can be in **New**, **Draft**, **Published**, or **Stale** state.
3. **Article information**: You can now access article information such as contributors, stats, last updated, and created dates. Additionally, the **Manage** option allows users to manage [add or remove] contributors efficiently.
4. **Preview**: You can instantly preview the article's appearance on the knowledge base site.
5. **Title**: You can modify the article's title, URL slug, and description. Once you have made your changes, click **Update.**
6. **Recommendations**: A dropdown menu displays terms recommended by the **AI Glossary generator.**
7. **Workflow status**: You can add or update the workflow status of the articles.
8. **More menu** (•••): Here you can access additional actions such as clone article, move, hide, and delete. Moreover, SEO, tags, and Related articles are conveniently separated.
9. **Comments**: You can engage in discussions and provide feedback.
10. **View full screen**(): Allows users to view Document360 in full-screen mode.

<a id="markdown-editor-overview"></a>

## Markdown editor

**Plans supporting the use of Markdown editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Markdown Editor** uses a short-hand syntax style text to create documents and then converts that text to HTML. Markdown is useful when articles contain more text and fewer multimedia elements.

> NOTE
>
> To learn more about Markdown comments, refer to [**Basic Markdown syntax**](/help/docs/markdown-basics) article.

---

## Using Markdown in your Knowledge base

For more information on text editor options, refer to [**Editor choices in Document360**](/help/docs/using-the-text-editor)**.**

* When using the Markdown editor, you can use Markdown syntax manually while writing or formatting text using the Markdown toolbar.

  For example, you can make a text appear **Bold** by writing the respective syntax (such as `**word**` or using the **Bold** icon in the Markdown toolbar.
* When you write a syntax, ensure that the reference matches the required character arrangement.
* To learn more about Markdown syntax, read the [**Markdown basic syntax**](https://www.markdownguide.org/basic-syntax/) page.

> For example, In **Bold** syntax, no space should be present at the end or beginning of the characters mentioned inside the syntax.  
> `**Text**` and not `** Text **`
>
> In **Headings**, a space is required between the respective syntax and characters.  
> `### Heading3` and not `###Heading3`

---

## Markdown toolbar

The WYSIWYG toolbar offers various options to edit and format your text including the option to insert media files as well. The different toolbar sections and their uses are shown and elaborated below.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Markdown_Editor.png)

* **Headings**
* **Basic text formatting**
* **List**
* **Insert**
* **Callouts**
* **Private notes**
* **Find and replace**
* **Insert LaTeX**
* **Content reuse**
* **Code block**
* **Glossary**
* **Video**

### Headings

* **H2**: Refers to **Heading 2**
* **H3**: Refers to **Heading 3**
* **H4**: Refers to **Heading 4**

### Basic text formatting

* **Bold:** To **Bold** the text.
* **Italic:** To *Italicize* the text.
* **Strikethrough:** To ~~Strikethrough~~ the text.
* **Blockquote:** To offset a quote or paragraph with a line. For example, the below sentence is in **Blockquote**:

  > This is an example of Blockquote.
* **Line**: To insert a line in the article.

### List

* **Unordered list:** To make a list denoted with bullet points for each item.
* **Ordered list:** To make a list denoted with numbers for each item.

### Insert

* **Insert Table:** To add a table to the article.
* **Insert image:** To insert an image from the URL, local Drive, or Document360 Drive.
* **Insert file:** To insert a PDF or Word document from the Drive.
* **Insert a link:** Add a hyperlink from a provided URL or a Knowledge base article to the selected text.

### Callouts

* **Info**: To insert an editable blue info box. You can use this to add additional information.
* **Warning:** To insert an editable yellow warning box. You can use this to add important information.
* **Error:** To insert an editable red error box. You can use this to add essential information.

### Private notes

* **Private notes**: To insert an editable purple internal comment box that will only be visible to logged-in team members.

> **For example**, you can add internal feedback to the respective team members.

### Insert LaTeX

* **Insert LaTeX**: To add expressions and equations,

  1. Click on **Insert LaTeX** option and a sample latex syntax (a² + b² = c²) appears.
  2. Type in your desired syntax.
  3. The syntax must start and end with **$**.
  > NOTE
  >
  > Don't add a space between $ and syntax.

  + [**Read the help article**](http://docs.mathjax.org/en/latest/input/tex/macros/index.html) to view the basic latex commands used in latex syntax.

### Find and Replace

* **Find and Replace:** Search a text within your article and replace it with another text. You can also use this to find the article's text content occurrences. This is particularly handy in long articles.

### Content reuse

* **Content reuse:** To reuse the content across the project. Two content reuse options are available:  
  a. **Variable**: Only text content can be added inside a variable.  
  b. **Snippet**: You can add images, tables, etc., inside a snippet.

### Codeblock

* **Insert Codeblock**: Add a code block to your article.

### Glossary

* **Glossary:** Add a glossary to your article.

### Video

* **Insert Video**: To embed a video from YouTube, Wistia, or Vimeo.

### Scroll

* **Scroll on/off:** To enable or disable simultaneous scroll functionality for both the editor and the article preview sections.

---

### Spell checker in Markdown

1. Right-click on the misspelled word.
2. The suggestions for corrections will be displayed through your browser's native functions.
3. Click on the suggested correction to apply it as needed.

   ![5_Screenshot-Markdown_Spell_checker](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Markdown_Spell_checker.png)

---

### FAQs

#### What is a Markdown editor, and how does it differ from a regular text editor?

Markdown editor is a specialized text editor designed to simplify the process of writing in Markdown language — a lightweight markup language that converts plain text into HTML. Unlike regular text editors, Markdown editors provide live previews, making it easier to visualize how the content will appear once published. You can experience the full potential of the Markdown editor on Document360 using the customization solution objects help articles we offer.

#### What are the key features of the Markdown editor in Document360?

Markdown editor in Document360 includes real-time previews, syntax highlighting, keyboard shortcuts, drag-and-drop image support, and seamless integration with the article version control (revisions) feature.

#### Is a Markdown editor suitable for beginners with no syntax-based writing experience?

Absolutely! Markdown's simple syntax makes it accessible for beginners without coding experience. Its intuitive structure allows users to focus on content creation without learning complex markup languages.

#### How do I add ASCII code to my article?

You can add ASCII code to your article using the **Code Block** feature.

#### Is it possible to add a code block without any heading?

Yes, when using Markdown editor, you can add code blocks in your article without necessarily having any heading.

#### Can I use the HTML content in the Markdown editor?

Yes, you can use HTML content in the Markdown editor. However, using Markdown syntax in the Markdown editor is recommended to avoid inconsistency.

---

## Related blogs

#### [1. The Ins and Outs of Using Markdown for Technical Writing](https://document360.com/blog/markdown-for-technical-writing/)

#### [2. Introductory Guide to Markdown for Documentation Writers](https://document360.com/blog/introductory-guide-to-markdown-for-documentation-writers/)

A lightweight text-to-HTML conversion tool used to format content such as lists, headers, images, videos, and links. Document360 includes a powerful markdown editor as one of its two basic editors.

<a id="markdown-basics"></a>

## Basic Markdown syntax

**Plans supporting the use of Markdown editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The Markdown editor is a powerful tool for creating clear, organized, and professional content in Document360. Whether you are new to Markdown or already familiar, this article will help you learn the basic commands and formatting options step by step.

Markdown is a lightweight markup language that lets you format text easily using special characters. You don't need coding knowledge to use it—just follow the syntax provided in this guide to create headings, lists, links, and more.

---

## Markdown commands

To format your text using Markdown commands, follow the table below to understand how to type Markdown commands and what they do. Here, **syntax** represents the way you type the content in your editor. You can use the examples in the **Example** column as reference.

For some Markdown commands, you also have alternate keyboard shortcuts, which you can use to quickly format your text. You can find these shortcuts in the **Notes** column in the below table.

| Feature | Syntax | Example | Output | Notes |
| --- | --- | --- | --- | --- |
| **Headings (H2, H3, H4)** | `##`, `###`, `####` before the text | `## Heading 2` | Heading 2 | This syntax helps in creating section titles. Use 1-6 hash symbols for heading levels. Document360 restricts H1 for article titles. |
| **Bold** | `**text**` | `**bold**` | **bold** | This syntax helps emphasize important text. Shortcut: Ctrl+B / Cmd+B |
| **Italics** | `*text*` or `_text_` | `*italics*` | *italics* | This syntax helps highlight text subtly. Shortcut: Ctrl+I / Cmd+I |
| **Strikethrough** | `~~text~~` | `~~strikethrough~~` | ~~strikethrough~~ | This syntax helps to cross out text. No shortcut available |
| **Numbered List** | `1.` followed by text | `1. First item` | 1. First item | Numbered lists automatically increment |
| **Bulleted List** | `*` or `-` followed by text | `* Bullet item` | \* Bullet item | Use an asterisk `*` or a hyphen `-` |
| **Link** | `[text](URL)` | `[Document360](https://docs.document360.com)` | [Document360](https://docs.document360.com) | Links are displayed as clickable text |
| **Blockquote** | `>` before text | `> This is a quote` | Creates a callout/blockquote | For quoting or highlighting text |
| **Horizontal Line** | `***` | `***` | Creates a horizontal line | Used to separate sections |

---

## Heading levels

| Heading Level | Syntax | Example | Output |
| --- | --- | --- | --- |
| H2 | `## Heading 2` | `## This is Heading 2` | This is Heading 2 |
| H3 | `### Heading 3` | `### This is Heading 3` | This is Heading 3 |
| H4 | `#### Heading 4` | `#### This is Heading 4` | This is Heading 4 |

TIP

Ensure a blank line above Heading tags and a space between hash symbols and text.

---

## Styling text

| Style | Syntax | Example | Output |
| --- | --- | --- | --- |
| **Bold** | `**text**` | `**bold text**` | **bold text** |
| *Italics* | `*text*` or `_text_` | `*italic text*` or `_italic text_` | *italic text* or *italic text* |
| ~~Strikethrough~~ | `~~text~~` | `~~strikethrough text~~` | ~~strikethrough text~~ |
| **Highlight** | `==text==` | `==highlighted text==` | ==highlighted text== |
| **Superscript** | `text^superscript` | `E = mc^2` | E = mc2 |
| **Subscript** | `text~subscript` | `H~2~O` | H2O |

TIP

Avoid spaces between syntax and text for proper styling.

---

## Lists

| List Type | Syntax | Example | Output | Description |
| --- | --- | --- | --- | --- |
| **Numbered List** | `1. Item` | `1. First item` | 1. First item | Automatically increments numbers for each item. |
|  | `2. Item` | `2. Second item` | 2. Second item | Use this format for each subsequent item. |
|  | `3. Item` | `3. Third item` | 3. Third item |  |
| **Bulleted List** | `* Item` | `* Bullet item` | - Bullet item | Use an asterisk (`*`), hyphen (`-`), or plus (`+`). |
|  | `- Item` | `- Another bullet item` | - Another bullet item | Any of these symbols will create a bulleted item. |
|  | `+ Item` | `+ Yet another bullet item` | + Yet another bullet item |  |

---

## Links and blockquotes

| Feature | Syntax | Example | Output |
| --- | --- | --- | --- |
| Link | `[text](URL)` | `[Document360](https://docs.document360.com)` | [Document360](https://docs.document360.com) |

**Blockquote**  
Include quotes or highlight important points by using '>' before the text.  
`> This will quote the entire line of text`  
Output:

> This will quote the entire line of text

---

## Horizontal line

You can enter a horizontal line to divide two lines of text using the three asterisks.

`***`  
Output:

---

## Quick tips for beginners

1. Use Headings to structure your content (e.g., sections and subsections).
   * Example: Use `##` for large headings and `###` for smaller ones.
2. Highlight key points with **Bold** or *Italics* to make the text easier to read.
3. Add Lists to organize information.
   * Use `1.` for numbered lists or `*` for bullet points.
4. Use **Links** to direct users to additional resources or websites.

---

## More elements

| Feature | Syntax | Example |
| --- | --- | --- |
| Image | `![Alt text](URL "Optional title")` | `![Logo](https://example.com/logo.png "Logo")` |
| Reference Link | `[Link text][ref]``[ref]: URL` | `[Document360][doc]``[doc]: https://docs.document360.com` |
| Escaping Characters (to avoid special characters being processed) | `\character` | `\*This is not italic\*` |
| YouTube Video | `<iframe src="https://www.youtube.com/embed/VIDEO_ID" width="560" height="315" frameborder="0" allowfullscreen></iframe>` | `<iframe src="https://www.youtube.com/embed/dQw4w9WgXcQ" width="560" height="315" frameborder="0" allowfullscreen></iframe>` |
| Vimeo Video | `<iframe src="https://player.vimeo.com/video/VIDEO_ID" width="640" height="360" frameborder="0" allowfullscreen></iframe>` | `<iframe src="https://player.vimeo.com/video/76979871" width="640" height="360" frameborder="0" allowfullscreen></iframe>` |

If you're unsure about HTML, simply copy and paste the examples provided, replacing the URL with your own video link.

---

## Emoji usage

You can copy and paste the emojis directly into your document from the table below.

| **Emoji** | **Description** |
| --- | --- |
| 📝 | Memo |
| ✍️ | Writing Hand |
| 📄 | Page Facing Up |
| 📚 | Books |
| 📖 | Open Book |
| 🖋️ | Fountain Pen |
| 📑 | Bookmark Tabs |
| 🔍 | Magnifying Glass |
| 📅 | Calendar |
| 💻 | Laptop |
| 📊 | Bar Chart |
| 📈 | Chart with Upwards Trend |
| 🗂️ | Card Index Dividers |
| ✏️ | Pencil |
| 😊 | Smiling Face |
| ❤️ | Red Heart |
| 🌟 | Star |
| 🔥 | Fire |
| 🎉 | Party Popper |

Simply copy the emoji you want and paste it wherever you need it! You can also insert icons into your editor by pasting the HTML code from FontAwesome.

---

## Using Unicode characters in the Markdown editor

Unicode characters help you add symbols, special characters, and non-Latin scripts to your Markdown documents. This includes currency symbols, mathematical operators, arrows, and accented letters, which enhance your content's clarity and style.

### Syntax for inserting Unicode characters

In the Markdown editor, you can insert Unicode characters using either of the following methods:

1. **Direct copy-paste:** Copy the desired character from any Unicode reference site and paste it directly into your Markdown content.

   **Example:**

   ```
   ★ Star symbol

   ```

   Plain text

   Copy

   **Output:**  
   ★ Star symbol
2. **HTML entity code:** Use the Unicode hexadecimal code with the format `&#xXXXX;`, where `XXXX` is the character's hex code.

   **Example:**

   ```
   &amp;#x1F680; Rocket symbol

   ```

   Plain text

   Copy

   **Output:**  
   🚀 Rocket symbol

### Common Unicode characters

Here are some frequently used Unicode characters:

| Character | Description | Unicode (Hex) | HTML entity code |
| --- | --- | --- | --- |
| ★ | Star symbol | 2605 | `&#x2605;` |
| ✔ | Check mark | 2714 | `&#x2714;` |
| ✉ | Envelope | 2709 | `&#x2709;` |
| © | Copyright | 00A9 | `&#x00A9;` |
| € | Euro sign | 20AC | `&#x20AC;` |
| → | Right arrow | 2192 | `&#x2192;` |
| ♻ | Recycling symbol | 267B | `&#x267B;` |

#### Finding more Unicode characters

For an extensive list of Unicode characters and their corresponding codes, refer to the following resources:

* [Unicode Character Table](https://unicode-table.com/)
* [Unicode.org Code Charts](https://www.unicode.org/charts/)

Copy the character you need and paste it into your Markdown document, or use its HTML entity code for precise control.

---

## Example: Creating a simple article

Let’s bring it all together with an example.

```
#### Welcome to Markdown  
Learn how to use **Markdown** in Document360 to format your articles.  

#### Why use Markdown?  
* Easy to learn  
* Clean and organized formatting  
* Saves time  

#### Useful tips  
1. Use headings to structure your content.  
2. Add links for more resources: [Learn Markdown](https://markdownguide.org)  
3. Use `***` to create a divider.  

```

Plain text

Copy

### Output

#### Welcome to Markdown

Learn how to use **Markdown** in Document360 to format your articles.

#### Why use Markdown?

* Easy to learn
* Clean and organized formatting
* Saves time

#### Useful tips

1. Use headings to structure your content.
2. Add links for more resources: [Learn Markdown](https://markdownguide.org)
3. Use `***` to create a divider.

---

For more advanced Markdown syntax commands, refer to the official [Markdown syntax guide](https://www.markdownguide.org/basic-syntax/). With these tips, you’ll be formatting your articles like a pro in no time!

Tags in Document360 used to structure subheadings in an article. H1 is automatically applied to article titles and cannot be used in the editor. H2, H3, and H4 are available for creating subheadings, with each level displaying progressively smaller text.

A lightweight text-to-HTML conversion tool used to format content such as lists, headers, images, videos, and links. Document360 includes a powerful markdown editor as one of its two basic editors.

<a id="wysiwyg-editor"></a>

## WYSIWYG editor

**Plans supporting the use of WYSIWYG editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **WYSIWYG (What You See Is What You Get)** editor, also known as the HTML editor, is one of three editing options in Document360. It allows users to view content as it will appear on published articles or category pages within the Knowledge base site.

> NOTE
>
> You cannot switch from the WYSIWYG editor to the Markdown editor. Once articles are converted from Markdown to WYSIWYG, they cannot be reverted. However, switching from Markdown to WYSIWYG is possible.

---

## WYSIWYG toolbar

The WYSIWYG toolbar offers various options to edit and format your text including the option to insert media files as well. The different toolbar sections and their uses are shown and elaborated below.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-WYSIWYG_Editor(1).png)

### 1. Heading options

The below heading options are available:

Normal

## Heading 2

### Heading 3

#### Heading 4

### 2. Text formatting

The below text styling options are available:

* **Bold**: To Bold the text
* *Italic*: To Italicize the text
* Underline: To Underline the text
* ~~Strikethrough~~: To Strikethrough the text
* **More text**: Provides options to update font size, font family, text color, background color, subscript, superscript, and clear formatting.

### 3. Paragraph formatting

The below paragraph formatting options are available:

* **Unordered list**: Make a list denoted with the following symbols: •, ○, ◘. **Disc** and **Default** symbols are the same.
* **Ordered list**: Make a list denoted with numbering for each item. You can use numbers, alphabets, Roman numerals, and Greek numerals. Default refers to numbers.
* **More paragraph**: To update alignment, line height of paragraphs, indentations, and quote text.

### 4. Insert options

* **Insert link**: Add a hyperlink from a provided URL or Knowledge base article to the selected text. This is useful for referencing additional information.
* **Insert codeblock**: Add a codeblock to your article, such as a JavaScript snippet.
* **Insert image**: Insert an image from the URL, local storage, or Drive. For example, you can add a screenshot of the user interface. You can also use (Ctrl+p) to perform this action.
* **Insert file**: Add a {{glossary.File}} from the Drive, such as a Word or PDF file.
* **Insert callouts**: Add editable info boxes in blue, yellow, and red for additional, important, and essential information, respectively.
* **Private notes**: Insert an editable internal comment box visible only to logged-in team members for internal feedback.
* **Insert LaTeX**: Add mathematical expressions and equations using LaTeX syntax.

  + To add, click the **Insert LaTeX** option and an **Insert latex expression** window appears. Type in your desired LaTeX syntax and click **Insert**. For more information, [read this article](http://docs.mathjax.org/en/latest/input/tex/macros/index.html).
  + To edit, click the Edit (Pencil) icon on the expression. An **Insert latex expression** window appears. Make the required changes in the syntax and click **Update**.
  + To delete, click the Remove (Trashbin) icon.
* **Find & replace**: Search for and replace text within your article, useful in long articles.
* **Content reuse**: Reuse content across the project with:

  + **Variable**: For text content.
  + **Snippet**: For text, images, tables, code blocks, etc.
* **Glossary**:  Maintain a list of terms and their definitions within the Knowledge base.

### **5. More rich**

* **Insert video**: Embed videos from platforms like YouTube, Wistia, Streams, or Vimeo.
* **Insert table**: Add a table by selecting the desired number of rows and columns.
* **Insert horizontal line**: Add a line in the article.
* **Emoticons**: Insert emoticons to enhance the article's engagement.

### 6. Other options

Additional features include:

* **Code view**: Switch to HTML syntax editor.
* **Undo**: Undo the previous action.
* **Redo**: Repeat the previous action.

### 7. Editor switch

* The switch editor toggle comes in use if you want to convert your article to the Advanced WYSIWYG editor.
* Click the toggle and click **Switch to New Editor** and the article will be converted to Advanced WYSIWYG editor.
* For steps and guidance on using the Advanced WYSIWYG editor, refer to the article on [Advanced WYSIWYG editor](/help/docs/advanced-wysiwyg-editor-overview).

### Additional formatting options

### 1. Image

Once an image is added to an article, you can access the below options by clicking on the image:

a. **Replace**: To replace the image.  
b. **Align**: Add an image caption to align the image.  
c. **Image caption**. This will appear at the bottom of the image.  
d. **Remove**: To remove the image.  
e. **Insert link**: To add a link to the image. After adding the link, you can open, remove, and edit the link.  
f. **Display**: To change the display of the image. You can use Inline or Break Text options.  
g. **Style**: To change the border style of the image. You can use Rounded, Bordered, and Shadow options.  
h. **Alternative text**: To add alternative text for the image. If the image file cannot be loaded, the alternative text will appear in a blank box where the image will appear.  
i. **Change size**: Adjust the width and height of the image as pixels. Click update to confirm.  
j. **Advanced edit**: To edit your image, use advanced tools such as **Crop** for resizing, **Text** options to adjust **bold**, **italic**, **underline**, **color**, and **size**, and **Rotate** to adjust orientation. You can also **Zoom in** or **Zoom out** for detailed editing, use the **Hand** tool for navigation, and access **History** for previous states. Use **Undo** and **Redo** to reverse or repeat actions, **Reset** to return to the original image, **Delete** to remove specific edits, or **Delete all** to clear everything. When finished, click **Save** to apply and store your changes.

### 2. Video

Once you embed a video in an article, you can access the below options by clicking on the left or right of the video in the editor pane:

a. **Replace**: To replace the video.  
b. **Remove**: To remove the video.  
c. **Display**: To change the display of the video. You can use Inline or Break Text options.  
d. **Align**: To align the video.  
e. **Change size**: To change the size of the video.  
f. **Autoplay**: To turn the autoplay option on or off.

### 3. PDF

Once a PDF file is added to an article, you can access the below options by clicking on the left or right side near the PDF file in the editor pane:

a. **Remove**: To remove the PDF file.  
b. **Change size**: To change the size of the PDF file.

### 4. Word file

Once a Word file is added to an article, you can access the below options by clicking on the Word file:

a. **Open link**: Download the word file to the local system drive.  
b. **Remove**: To remove the Word file.

### 5. Table

Once a table is added to an article, you can access the below options by clicking on the table:

a. **Table header**: Turn the table header on or off. Click on this button, and the top row appears on the table.

b. **Remove table**: To remove the table. Click on this button, and the table and the content will be deleted. If you have accidentally clicked on the remove, you can always use the Undo action (Ctrl + Z) to restore the table.

c. **Row**: Place the cursor in any cell of the intended row and click 'Insert row above' or 'Insert row below' to add rows to the table. Click on the 'Delete row' to remove the current row.

d. **Column**: Place the cursor in any cell of the intended column and click 'Insert column above' or 'Insert column below' to add columns to the table. Click on the 'Delete column' to remove the current column.

e. **Table style**: To change the table style. You can use **Dashed Borders** and **Alternate Rows** options. The alternate rows option would distinguish the row color.

f. **Cell**: Click on this button and select the action to merge or split cells. You can split a cell vertically or horizontally any number of times. The merge option would be enabled only when you select more than one cell horizontally or vertically.

g. **Cell background**: To change the cell's background color. You can select from the color palette available or enter the HEX code.

h. **Vertical align**: To change the vertical alignment of the content in the cell. You can do this for a single cell or multiple selections of cells. If the cell height is bigger than the content fit, then you can choose to align the content at the top, middle, or bottom of the cell.

i. **Horizontal align**: To change the horizontal alignment of the content in the cell. You can do this for a single cell or multiple selections of cells. If the cell width is bigger than the content fit, you can align the content at the left, center, right, or justified style.

j. **Cell style**: To change the type of the cell border. You can use the options **Highlighted** (changes the cell border color) and **Thick** (increases the cell border thickness) of the selected cell.

---

## When, Where, and Why to Use the WYSIWYG Editor

#### Who can use the WYSIWYG editor?

Document360 users who are comfortable with HTML editors

#### Is the WYSIWYG editor easy to use?

Using the WYSIWYG editor will feel similar to using a word-processing application

> **For example**, Microsoft Word, Google Docs, etc.

You can copy and paste content directly from a Word document or any other source. No special syntax is required.

#### Why use the WYSIWYG editor?

* Unlike the Markdown editor, the WYSIWYG editor uses a single editing pane since the written content is already in preview mode.
* WYSIWYG editor provides a unique feature to paste large tables from a third-party site or another Knowledge base.

  ###

<a id="advanced-wysiwyg-editor"></a>

## Advanced WYSIWYG editor

**Plans supporting the use of Advanced WYSIWYG editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The 'Advanced WYSIWYG editor' combines lightweight design with powerful, rich text editing capabilities, supporting specific Markdown syntax. It offers a highly visual and intuitive experience that surpasses traditional Markdown editors yet maintains more flexibility than the WYSIWYG editors.

> NOTE
>
> You can seamlessly switch between the Advanced WYSIWYG editor and the WYSIWYG editor when the article is in the **Draft/New** state. Document360 does not support this switching when the article is in the **Published** state.

> CAUTION
>
> The articles switched from the Markdown editor to the Advanced WYSIWYG editor cannot be reverted to the Markdown editor again.

---

## Using Advanced WYSIWYG editor

You can use the slash commands, toolbars, and specific Markdown syntax to create and edit content in the Advanced WYSIWYG editor.

### Slash commands

Type `/` in the editor, and a list of options appears. You can also search for the options by typing the command names. Click the desired command or press the Enter key to select the command.

> NOTE
>
> Ensure you type `/` at the start of a line or after a space. The options will not appear if you type it immediately after a character. You can navigate through each command and section in slash commands using the up, down, right, and left arrow keys.

You can also easily access **Eddy AI** right from the top of the slash menu. Additionally, the slash command options are categorized into three sections:

| **Format** | **Insert** | **Content Reuse** |
| --- | --- | --- |
| Heading 2 | Image | Variables |
| Heading 3 | Video | Snippets |
| Heading 4 | Link | Glossary |
| Ordered list | Table |  |
| Bullet list | Callouts |  |
| Checklist | Private notes |  |
| Inline code | Code block |  |
| Page break | Insert file |  |
|  | Accordion |  |
|  | Latex |  |
|  | Emoji |  |
|  | Divider |  |

![Updated_ScrenGIF-Slash_command_in_Adv_WYSIWYG](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Updated_ScrenGIF-Slash_command_in_Adv_WYSIWYG.gif)

---

### Markdown syntax

The Advanced WYSIWYG editor supports a wide range of Markdown syntaxes; for a detailed list, read the article on [Markdown basics](/help/docs/markdown-basics).

> For example, if you want to add a Heading 2, type the following syntax: `## Heading of the section`. The syntax will be rendered and Heading 2 will be added instantly.

> NOTE
>
> The Markdown syntax will only work when you type it in manually. It will not be rendered when you copy and paste the syntax.
>
> To view the list of unsupported Markdown syntax, read the article on [Advanced WYSIWYG editor basics](/help/docs/Advanced-WYSIWYG-editor-basics#unsupported-markdown-syntax).

---

## Toolbar

The toolbar is categorized into three sections:

* **Format**: To change the layout or appearance of the content.
* **Insert**: To add elements such as images, videos, tables, and more.
* **Find & replace**: To search for a specific text and replace it with another text.

> NOTE
>
> By selecting the Pin () option, you can anchor the toolbar to the right side of the editor interface.

![1_Screenshot-General_view_of_toolbar_in advanced_WYSIWYG_editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-General_view_of_toolbar_in%20advanced_WYSIWYG_editor.png)

### Format

![2_Screenshot-Format_seciton_toolbar](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Format_seciton_toolbar.png)

#### 1. Text styles

* **Undo** (): To reverse the last action.
* **Redo** (): To reapply the last undone action.

* **Clear** ( ): To remove all styling from selected text.
* **Lettercase** (): To change the letter case of the text.

#### 2. Headings

* : To apply the H2 (Heading 2) style to the selected text.
* : To apply the H3 (Heading 3) style to the selected text.
* : To apply the H4 (Heading 4) style to the selected text.
* **Paragraph** (): To apply the standard paragraph style to the selected text.

#### 3. Typography

* **Font family**: To select the typeface for the text.
* **Font size**: To adjust the size of selected text.

#### 4. Palette

* **Font color**: To change the color of the selected text.
* **Background color**: To set a background color for the selected text.

#### 5. Formatting & Lists

* **Bold** (): To bold the selected text.
* ***Italic*** (): To italicize the selected text.
* **Underline** (): To underline the selected text.
* **~~Strikethrough~~** (): To apply a strikethrough to the selected text.
* `Inline code` (): To add inline code to the text.
* **Align left** (): To align the text content with the left margin.
* **Center** (): To center your text content.
* **Align right** (): To align the text content with the right margin.
* **Justify** (): To distribute the text content evenly between the margins.
* **Bullet list** (): To add a list denoted with symbols for each item.
* **Ordered list** (): To add a list denoted with numbering for each item.
* **Checklist** (): To add a list denoted with checkboxes that users can mark as complete or incomplete.

#### 6. Controls

* **Increase indent** (): To move the content farther away from the margin.
* **Decrease indent** (): To move the content closer to the margin.
* **Subscript** (): To lower the text below the baseline.
* **Superscript** (): To raise the text above the baseline.
* **Line height** (): To choose the spacing between the lines.
* **Letter space** (): To change the spacing between the letters.
* **Line break** (): To switch to the next line.
* **Page break** (): To specify where to end the current page and begin the next page while exporting content as PDF.

---

### Insert

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1736939177920.png)

* **Image**: To insert an image.

> NOTE
>
> You can use the different tools available to format your added image. Click on the image, and the formatting tools appear as a floating menu. You can align, crop, add borders, add shadows, add captions, and more.

* **Video**: To insert a video.
* **Link**: To insert a hyperlink. You can also use the "Ctrl + k" keyboard shortcut.
* **Insert file**: To insert a file within the article.
* **Table**: To insert a table.
* **Divider**: To insert a horizontal line.
* **Accordion**: To add a container that can be expanded or collapsed to show or hide its content.
* **Callout**: To insert a callout. An info callout will be inserted when you click this option. To customize the callout, click within the callout, and you can find the following options in the contextual toolbar:

  + Callout info
  + Callout warning
  + Callout error
  + Callout success
  + Callout background color - To change the background color of the callout
  + Callout border color - To change the border color of the callout
  + Delete - To delete the callout
* **Private notes**: To insert private notes.
* **Code block**: To insert a block of code. Click within the code block, and you can find the following options in the contextual toolbar:

  + Language dropdown - Select the desired language
  + Copy - To copy the code block
  + Delete - To delete the code block
* **FAQs:** To insert the FAQ(s) templates.
* **Latex**: To insert mathematical equations and symbols.
* **Variable**: To insert a variable.
* **Snippet**: To insert a snippet.
* **Glossary**: To insert a glossary term.
* **Emoji**: To insert an emoji.

### Creating FAQs templates in Advanced WYSIWYG editor:

1. Navigate to the desired article in the Advanced WYSIWYG editor.
2. Click the **Insert (****)** icon and select **FAQs** from the dropdown.

   Three FAQ accordion templates will be inserted into your article.
3. In the inserted FAQs templates, you can perform the following options:

   1. Click the **Settings** () icon to customize the FAQ templates according to your preferences.
   2. Click the **Expand/Collapse** () icon to expand or collapse the FAQ accordions.
   3. Click the **Delete** () icon to remove the entire FAQ section.
   4. Click **Add question** ()in between the FAQs, to insert additional custom FAQs.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGif-Advanced_WYSIWYG_Editor.gif)

> NOTE
>
> * FAQs templates is different from AI FAQ generator.
> * For more information, read the article [AI FAQ generator](/help/docs/ai-faq-generator).

#### Code view

* It allows you to view and edit the content in HTML code format.
* By switching to **Code view**, you can add custom HTML elements, apply inline styles, or make precise adjustments.

  ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1736939256244.png)

> NOTE
>
> * You must click the Save button to save the changes made in the code view. `Ctrl/Cmd +S` will not work in code view.
> * Ordered and Unordered list misses out on sequential ordering.
> * Nested list types are not supported in the following scenarios:
>
>   + When the content is copied and pasted.
>   + In certain content migration scenarios.

---

### Adding an inline comment in Advanced WYSIWYG editor

1. Navigate to your desired article from the Knowledge base portal.
2. Select the desired text to add a comment, and a floating menu appears.
3. Click on the **Comment icon** (💬) from the floating menu.
4. Use basic formatting tools such as bold and lists, and by using **@** you can mention your project team members if needed.
5. Once done, click on the **Send** icon.

> NOTE
>
> To turn off this mode, navigate to the Knowledge base portal, Documentation ()> **Content tools** > **Workflow designer**. Hover over the desired status and click on the Edit (✎) icon and turn off the **Read only** toggle.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1736939279601.png)

**To view all the comments in an article:**

1. Navigate to the desired article.
2. Click on the **Comment icon** (💬) located on the right side near the publish button.
3. The Comments panel will appear. Use the dropdown at the top to filter the options, such as All comments, mentioned comments, open comments, and resolved comments.

Here, you can reply to the comments.

![6_Screenshot-View_all_the_comments_in_an_article](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-View_all_the_comments_in_an_article.png)

> NOTE
>
> Only the user who created the inline comment can edit, resolve, or delete it.

---

### Formatting Choices for Pasting from Microsoft Word

You can choose to retain or clear formatting when pasting content from Microsoft Word, including elements like lists, tables, indentations, and fonts.

1. Click **Paste with formatting** to retain the content’s format from Microsoft Word.
2. Click **Paste as plain text** to clear the content’s format from Microsoft Word.

![Copy and pasting content from Microsoft Word](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-copy_pasting_from_Microsoft_word.png)

---

### FAQs

#### Is it possible to add a code block without any heading?

When using the Advanced WYSIWYG editor, it is not possible to add a code block without a name/heading. However, if you wish to hide the name of a code block, you can use Custom CSS code in the **Custom CSS & JavaScript** settings. Also, note that this change will apply to all the code blocks on your Knowledge base site.

To add a code block without a name/heading, you can use the Markdown editor.

#### How can I add spaces in LaTex formulas?

To insert spaces in LaTeX formulas, use `\;` (a backslash followed by a semicolon) between terms.

**Example:**  
`Area = length\;*\;width`

**Output:**

#### How can I add numbering to my content in the Advanced WYSIWYG editor?

You can add numbering to your content in three ways:

1. **Type and Press:** Type `1.` and press `space` to start numbering.
2. **Keyboard shortcut:** Select the desired content and use the shortcut `Ctrl + Shift + 7` or `Ctrl + Shift + O`.
3. **Format menu:** Select the desired content, go to **Format** () and choose the **Numbered list** () icon.

   You can choose from various numbering styles, including Default (1, 2, etc.), Lower Alpha, Lower Greek, Lower Roman, Upper Alpha, and Upper Roman.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="advanced-wysiwyg-editor-basics"></a>

## Advanced WYSIWYG editor basics

**Plans supporting the use of Advanced WYSIWYG editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## Keyboard shortcuts overview

To view the important keyboard shortcuts overview, follow these steps:

1. Navigate to the desired article on the Advanced WYSIWYG editor from the Knowledge base portal.
2. On the top-right corner click the **More** icon (•••) next to the **Publish** button.
3. Click **Keyboard shortcuts** from the dropdown menu.

#### Windows view

![image](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Keyboard_shortcuts_overview%281%29.png)

#### Mac view

![Updated_Portal_Screenshot-Mac_Keyboard_Screenshot](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Keyboard_shortcuts_overview_macos.png)

The following shortcuts can also be used in the Advanced WYSIWYG editor:

### General

| S. No. | Command | Windows | Mac |
| --- | --- | --- | --- |
| 1 | Copy | Ctrl + C | + C |
| 2 | Cut | Ctrl + X | + X |
| 3 | Paste | Ctrl + V | + V |
| 4 | Paste as plain text | Ctrl + Shift + V | + Shift + V |
| 5 | Undo | Ctrl + Z | + Z |
| 6 | Redo | Ctrl + Shift + Z | + Shift + Z |
| 7 | Add a line break | Shift + Enter | Shift + Enter |
| 8 | Insert link | Ctrl + K | + K |

### Text formatting

| S. No. | Command | Windows | Mac |
| --- | --- | --- | --- |
| 1 | Bold | Ctrl + B | + B |
| 2 | Italicize | Ctrl + I | + I |
| 3 | Underline | Ctrl + U | + U |
| 4 | Strikethrough | Ctrl + Shift + X | + Shift + X |
| 5 | Highlight | Ctrl + M | + M |
| 6 | Code | Ctrl + E | + E |

### Paragraph formatting

| S. No. | Command | Windows | Mac |
| --- | --- | --- | --- |
| 1 | Paragraph style | Ctrl + Alt + 0 | + Alt + 0 |
| 2 | Heading 1 | Ctrl + Alt + 1 | + Alt + 1 |
| 3 | Heading 2 | Ctrl + Alt + 2 | + Alt + 2 |
| 4 | Heading 3 | Ctrl + Alt + 3 | + Alt + 3 |
| 5 | Heading 4 | Ctrl + Alt + 4 | + Alt + 4 |
| 6 | Heading 5 | Ctrl + Alt + 5 | + Alt + 5 |
| 7 | Heading 6 | Ctrl + Alt + 6 | + Alt + 6 |
| 8 | Numbered list | Ctrl + Shift + 7 | + Shift + 7 |
| 9 | Bullet list | Ctrl + Shift + 8 | + Shift + 8 |
| 10 | Check list | Ctrl + Shift + 9 | + Shift + 9 |
| 11 | Blockquote | Ctrl + Shift + B | + Shift + B |
| 12 | Left align | Ctrl + Shift + L | + Shift + L |
| 13 | Center align | Ctrl + Shift + E | + Shift + E |
| 14 | Right align | Ctrl + Shift + R | + Shift + R |
| 15 | Justify | Ctrl + Shift + J | + Shift + J |
| 16 | Code block | Ctrl + Alt + C | + Alt + C |
| 17 | Subscript | Ctrl + , | + , |
| 18 | Superscript | Ctrl + . | + . |

### Text selection

| S. No. | Command | Windows | Mac |
| --- | --- | --- | --- |
| 1 | Complete article | Ctrl + A | + A |
| 2 | One character to the left | Ctrl + ← | + ← |
| 3 | One character to the right | Ctrl + → | + → |
| 4 | One line up | Ctrl + ↑ | + ↑ |
| 5 | One line down | Ctrl + ↓ | + ↓ |
| 6 | To the beginning of the article | Ctrl + Shift + Home | + Shift + Home |
| 7 | To the end of the article | Ctrl + Shift + End | + Shift + End |

---

## Typography

The following table shows the regular symbols/syntax list and its outcome in the Advanced WYSIWYG editor.

| S. No. | Name | Symbol/Syntax | Outcome |
| --- | --- | --- | --- |
| 1 | Em dash | -- | — |
| 2 | Ellipsis | ... | ... |
| 3 | Opening double quote | ' | ‘ |
| 4 | Closing double quote | ' | ’ |
| 5 | Left arrow | <- | ← |
| 6 | Right arrow | -> | → |
| 7 | copyright | (c) | © |
| 8 | Registered trademark | (r) | ® |
| 9 | Trademark | (tm) | ™ |
| 10 | Service mark | (sm) | ℠ |
| 11 | One half | 1/2 | ½ |
| 12 | One quarter | 1/4 | ¼ |
| 13 | Three quarters | 3/4 | ¼ |
| 14 | Plus minus | +/- | ± |
| 15 | Not equal | != | ≠ |
| 16 | Laquo | << | « |
| 17 | Raquo | >> | » |
| 18 | Multiplication | 2 \* 3 | 2×3 |
| 19 | Superscript two | ^2 | ² |
| 20 | Superscript three | ^3 | ³ |
| 21 | Indian rupee | (R) | ₹ |
| 22 | Dollar | (USD) | $ |
| 23 | Pound | (GBP) | £ |
| 24 | Australian dollar | (AUD) | A$ |
| 25 | Triple bar | === | ≡ |
| 26 | Approx | (approx) | ≈ |
| 27 | Greater than or equal to | >= | ≥ |
| 28 | Lesser than or equal to | <= | ≤ |
| 29 | Pi | (pi) | π |
| 30 | Euro | (e) | € |
| 31 | Equivalent | <==> | ⇔ |

---

## Unsupported markdown syntax

The Advanced WYSIWYG editor does not currently support the following markdown syntax:

**1. Tables**  
Markdown tables are not supported. For example, the following syntax will not render as a table:

```
| header | header |
| --- | --- |
| cell | cell |
| cell | cell |

```

Plain text

Copy

**2. Subscript**  
Subscript syntax is not supported directly in the editor. You will need to apply the subscript option manually using Format tools for it to appear correctly.

**3. Superscript**  
Superscript syntax is also not supported directly in the editor. You will need to apply the superscript option manually using Format tools for it to appear correctly.

<a id="movable-blocks-in-advanced-wysiwyg-editor"></a>

## Movable blocks in Advanced WYSIWYG editor

**Plans supporting the use of movable blocks**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

### **What are movable blocks?**

Movable blocks simplify editing in the Advanced WYSIWYG editor by allowing you to rearrange content sections. This feature provides more flexibility to organize your content and improve its structure efficiently.

> NOTE
>
> In the Advanced WYSIWYG editor, a block is a section of content that ends with a line break. The next piece of content that starts on a new line is considered a new block.

### Accessing movable blocks

By just clicking an arrow or a quick drag-and-drop action, you can position your content exactly how you envision it. Whether you’re shifting paragraphs or reorganizing entire sections, this flexibility allows you to craft your articles intuitively, enhancing your overall editing experience. Follow the below steps to access movable blocks.

1. Navigate to the desired article in the Advanced WYSIWYG editor.
2. Hover over the intended block within the editor.
3. On the left side of the block, you will see two icons: the settings () icon and the ellipsis () icon.
4. Click on the ellipsis () icon to manage the block’s position:

   * Move up: Click the up arrow () icon to move the block above the previous block.
   * Move down: Click the down arrow () icon to move the block below the next block.
   * Delete: Click on the delete () icon to remove the selected block. The following block will automatically move up the order.
5. Click the settings () icon to add new blocks:

   * Choose **Insert block above** to place a new block above the selected one.
   * Choose **Insert block below** to place a new block below the selected one.

> NOTE
>
> By holding the reorder icon () icon of a specific block, you can drag it to any desired location within the editor.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Movable_blocks_all_in_one.gif)

> NOTE
>
> * In the current implementation, dividers cannot be moved using Movable blocks.
> * The entire FAQ section is considered as a single block. Therefore, you cannot move individual FAQs within the Eddy AI generated FAQ section.

---

### FAQs

**How do I move a block to a specific location in the Advanced WYSIWYG editor?**

  

By holding the ellipsis () icon of a specific block, you can drag it to any desired location within the editor.

**Can I add new blocks between existing content sections?**

Yes, hover over the desired block and click the settings () icon. Then, choose **Insert block above** to place a new block above the selected one.

**What happens when I delete a block in the editor?**

When you delete a block, the following block automatically moves up the order. If you want to undo the deletion, use the `Ctrl+Z` shortcut to restore the content.

<a id="conditional-content-blocks"></a>

## Conditional content blocks in Advanced WYSIWYG editor

**Plans supporting the use of Conditional content blocks**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Conditional content blocks** provide a powerful way to tailor the user experience by showing or hiding specific content based on predefined conditions. Whether you want to target users based on parameters like IP address, country, device type, reader groups, workspace, or specific dates, conditional content blocks ensure that your readers only see what’s relevant to them.

This feature helps streamline content management for large, diverse audiences and improves user engagement by delivering personalized content.

> For instance, use conditional content to show region-specific pricing for customers in different countries or provide different support information based on whether the user is on a desktop or mobile device.

> NOTE
>
> * This feature is exclusively available for **KB site 2.0** projects.
> * When a condition is applied to a specific content block, it will not be indexed or retrieved by Eddy AI or in general search results.

---

## Set up **conditional content blocks**

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Navigating_to_the_conditional_content_panel.png)

To set up conditional content blocks, follow the steps below:

1. Navigate to the desired article in the Advanced WYSIWYG editor within the Knowledge base portal.
2. Hover over the content block and click the **Settings** () icon on the left.
3. Select **Conditional Content**.

   The **Conditional content** panel will appear.
4. Turn on the **Enable** toggle to activate the conditional content.

   In the **Visibility** section, choose:

   * **Show**: To display content when the condition is met.
   * **Hide**: To hide content when the condition is met.
   > NOTE
   >
   > When you select **Show**, the content will be visible only to users who meet the condition. When you select **Hide**, the content will be hidden from users who meet the condition.
5. Use the **AND** operator when all conditions need to be met, and the **OR** operator if any single condition should trigger the visibility rule.
6. Click **+ Add** to create a new condition.
7. In the **Parameter** dropdown menu, select the desired parameter, such as country, date, device type, workspace, reader groups, IP address.
8. Enter the relevant value for each parameter:

| **Parameter** | **Conditions** | **Example 1** | **Example 2** |
| --- | --- | --- | --- |
| **Country** | Equals, Not equals, In, Not in | If condition is **Equals** and value is **India**, only readers from India will see the content. | If condition is **Not in** and value is **USA**, readers from all countries except the USA will see the content. |
| **Date** | After, Before, Between | If condition is **Before** and date is **October 1, 2024**, only readers accessing before that date will see the content. | If condition is **Between** and range is **September 1, 2024, to October 1, 2024**, the content will be visible during that time. |
| **Device** | Equals, Not equals, In, Not in | If condition is **Equals** and value is **Mobile**, only users on mobile devices will see the content. | If condition is **Not in** and value is **Desktop**, the content will be hidden from desktop users but visible on mobile/tablet. |
| **Workspace** | Equals, Not equals, In, Not in | If condition is **Equals** and value is **Marketing workspace**, only content in that workspace will be visible. | If condition is **Not in** and value is **Sales workspace**, the content will be hidden from users in the Sales workspace. |
| **Reader groups** | Equals, Not equals, In, Not in | If condition is **Equals** and value is **Admins**, only users in the Admin group will see the content. | If condition is **Not in** and value is **Editors**, the content will be hidden from editors but visible to other groups. |
| **IP address** | Equals, Not equals, Range, In, Not in | If condition is **Equals** and value is **192.168.1.1**, only users from that IP address will see the content. | If condition is **Range** and range is **192.168.1.1 to 192.168.1.100**, users within that IP range will see the content. |

> NOTE
>
> * **Workspace** parameter will appear only if you have multiple workspaces.
> * For parameters with conditions like **In** or **Not in**, you can select multiple values from the dropdown. For example, if the parameter is **Country**, condition is **In** or **Not in**, you can select multiple countries in the Value dropdown.

10. Once you have set the condition for your content, click **Save for reuse** to save the condition.

> NOTE
>
> The **Save for reuse** is especially useful in large knowledge bases where similar conditions apply across multiple articles. For instance, a **Country equals India** condition can be saved and reused for all India-specific content, saving time and effort.

11. Enter a name for your condition and click the () icon.
12. Click **Save** to apply the condition, which will then be reflected on the Knowledge base site.
13. Click **Save as** to save the condition for future use, enter the condition name and click the () icon.
14. To remove a condition, click **Remove Condition** within the selected block.
15. Once done, click **Apply**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Performing_Conditional_content.gif)

---

### FAQs

**What are conditional content blocks?**

Conditional content blocks allow you to display specific content only when certain conditions are met, based on parameters like IP address, country, device type, reader groups, workspace, or specific dates.

**Can I create multiple conditions for a single article?**

Yes, you can create up to 25 conditions per article.

**Will the conditions remain intact if I move an article to a different workspace?**

Yes, the conditions will move along with the article to the new workspace.

**Can I edit conditions after publishing?**

To edit content conditions after publishing, fork the published article version. Once forked, you can modify the conditions as needed.

**If an article is translated into multiple languages, does conditional content apply to all languages?**

Yes, the conditions set on a content block will apply across all translated versions of the article. However, if different visibility rules are needed for different languages, you will need to apply conditions specifically for each translation.

**What happens if no conditions are met?**

If no conditions are met, the content block will behave according to the default visibility rules. By default, the block will be visible to all users unless explicitly set to **Hide** for all conditions.

**If I change the project type from Private to Public, what happens to the conditions?**

If your project type changes from **Private to Public**, any conditions using parameters like **IP address** or **Reader groups** (which are only applicable in private/mixed projects) will be automatically disabled, and those parameters will no longer be available for selection.

**What happens to conditional content if I clone a article?**

If you clone a article that contains conditional content blocks, all the conditions will be copied over as they are. You can then edit the conditions in the duplicated article if needed.

**Can I apply multiple "Or" conditions?**

Yes, you can apply multiple **OR** conditions. For example, if you want to show content to users in either **India** or **USA**, you can set the condition **Country equals India OR Country equals USA**. The content will be visible to users from either country.

**Can conditions be time-bound?**

Yes, conditions can be time-bound by using the **Date** parameter. For example, if you want content to be visible only between specific dates, you can set the condition **Date between Dec 1, 2024, and Dec 10, 2024**. The content will automatically stop being visible after Dec 10, 2024.

**What happens if I delete a reader group that is part of a condition?**

If a reader group that is part of a conditional content block is deleted, the condition associated with that group will no longer be applied.

**Can I apply conditions based on the user's session (e.g., logged-in vs. logged-out users)?**

At this time, conditional content does not apply directly to user session status (logged-in or logged-out).

**If I move an article with conditional content between workspaces, do the conditions still apply?**

Yes, the conditional content blocks and their conditions will move along with the article when it is transferred between workspaces. However, you should verify that the conditions are still relevant in the new workspace.

**How do conditions affect articles that have multiple versions (e.g., published and draft versions)?**

Conditional content settings are version-specific. If you fork an article to create a new version, the conditions set in the original version will carry over to the new version. You can then edit the conditions in the new version as needed.

**Is there a limit to the number of conditions I can apply to a single block?**

Yes, you can apply up to 25 conditions per article. However, for performance and clarity, it is recommended to limit the number of complex conditions to ensure that content loads efficiently and is easy to manage.

<a id="tables-in-advanced-wysiwyg-editor"></a>

## Tables in Advanced WYSIWYG editor

**Plans supporting the use of Advanced WYSIWYG editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Tables are an essential tool for organizing and presenting data in a clear, structured format. Whether you're comparing features, listing options, or summarizing information, tables enhance content readability and make complex data easier to understand.

The Advanced WYSIWYG editor offers a range of powerful table formatting and management features designed to help you easily create visually appealing and functional tables. From adding rows and columns to customizing cell colors and implementing advanced table styles, these features help you create tables that meet your specific needs.

In this article, we will explore the various table-related tools available in the Advanced WYSIWYG editor, providing you the steps to create, format, and manage tables.

## Creating a table

There are two methods for creating a table. You can use the

* **Slash (/) command**
* **Insert option** in the **Format menu**

### Slash (/) command

To insert a table using the slash command, type the slash command **(/table)** anywhere in the editor, and hit **Enter**. This inserts a **3X3** table in the editor at the text cursor’s location.

> NOTE
>
> Inserting a table using the **slash** (/) command will always insert a 3X3 table with a header row by default. You can insert more rows and columns as per your requirement.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_GIF-Insert_table_using_slash_command.gif)

### Insert option in the Format menu

To insert a table using the Format menu,

1. Click the **Insert** option in the Format menu on the right side of the editor to open the Insert menu.
2. From the Insert menu, click on the **Table** option.
3. Clicking the Table option opens the **Insert table** grid. Select the desired table size from the grid to insert the table in the editor.

> NOTE
>
> The maximum table size you can create from the Format menu is a **10X10** table. You can add additional rows/columns manually.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_GIF-Insert_table_using_format_menu.gif)

## Formatting table content

### Inserting or deleting rows/columns

To insert a row, select an entire row. In the menu that appears upon selecting the row, click **Insert row above/Insert row below** based on your requirement. Similarly, to insert a column, select an entire column. In the menu that appears upon selecting the column, click **Insert column left/Insert column right** based on your requirement.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Insert_row_in_tables.png)

Select the entire row, then click **Delete row** in the menu. You can delete a column using the same steps after selecting a column.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Insert_column_in_tables.png)

### Merging cells

To merge cells, select multiple cells in the table. After selecting multiple cells, click **Merge cells** in the menu. Once you click the **Merge cells** option, the selected cells will be combined together into one cell.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Merge_cells_in_tables.png)

### Cell alignment

To align text within a cell, select one or more cells, and select the alignment option that appears in the menu. There are two alignment options available: **Vertical align** and **Horizontal align**.

#### Vertical align

If you select the **Vertical align** option, you can align the text to either the **Top**, **Middle**, or **Bottom** of the cell.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Vertical_alignment_in_tables.png)

#### Horizontal align

If you select the **Horizontal align** option, there are four options available: **Left**, **Center**, **Right**, and **Justify**. If you select either **Left**, **Center**, or **Right**, the text will be aligned accordingly. If you select **Justify**, the text will be aligned to the left, while the text will be equally spaced to cover the entire width of the cell.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Horizontal_alignment_in_tables.png)

### Fit table to page width

To fit a table to the page width, select the table. In the menu that appears upon selecting the table, click the **Fit to page width** option. This will automatically adjust the table to span the full width of the page, ensuring the content within the table is evenly distributed across the available space.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/16_Screenshot-Fit_table_to_page_width.png)

---

## Customizing table appearance

### Changing background

1. To change the cell background color, select one or more cells.
2. In the menu that appears, click the **Background color** option.
3. Select the desired color from the displayed color palette.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Background_color_in_tables.png)

> PRO TIP
>
> Once you make updates to the background color in tables, check the article preview in dark mode to verify the table’s visibility.

### Changing border

#### Border color

1. To change the cell border color, select one or more cells.
2. In the menu that appears, click the **Border color** option.
3. Select the desired color from the displayed color palette.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Border_color_in_tables.png)

#### Border style

1. To change the border style, select the entire table.
2. In the menu that appears, click the **Border style** option.
3. Choose your preferred border style: **Solid**, **Dashed**, or **Dotted**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-Border_style_in_tables.png)

### Header rows

The top row is a header row by default when you insert a table in the Advanced WYSIWYG editor. The header row is indicated with the grey background.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/11_Screenshot-Header_row_in_tables.png)

* If you want to hide the header row, select the entire table and click the **Hide table header** option.

  ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/12_Screenshot-Hide_header_row_in_tables.png)
* If you have hidden the header row and wish to show it again, select the entire table and click the **Show table header** option.

  ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/13_Screenshot-Show_header_row_in_tables.png)

### Alternate row style

To customize your tables even further, you can choose to have banded rows. If you implement this option, the color of your rows will alternate between white and light gray.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/14_Screenshot-Banded_rows_in_tables.png)

1. To implement this customization, select the entire table.
2. In the menu that appears, click the **Alternate row style** option.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/15_Screenshot-Alternate_rows_in_tables.png)

> PRO TIP
>
> You can customize your tables even further using **CSS code snippets**. To learn more, visit the [**Table Style**](https://docs.document360.com/docs/table-style) article.

---

### FAQs

#### **How do I copy the entire table?**

To copy the table, select the entire table and click the **Copy** option that appears in the menu.

#### **How do I delete the entire table?**

To delete a table: Select the table by clicking the top-left corner. Then, choose **Delete** from the menu that appears.

#### **Can I use automatic number in a table?**

While numbered lists are possible within a cell, you cannot apply automatic number for rows in a table.

#### **Can I add symbols or icons in a table?**

Yes, you can add symbols and icons in a table. For in-built symbols/icons, you can them directly from the **Format** menu. Symbols and icons from external sources can be added using **HTML**. To add symbols/icons in HTML,

1. Switch to **Code view** within the editor.
2. Place the text cursor in the desired location.
3. Paste the HTML code for the required symbol/icon.

Now, the symbol/icon should be visible within the table in the editor.

#### **Will slash commands work inside a table?**

Yes, all the slash commands will work inside a table.

#### Can I paste tables from Microsoft Word or Excel?

Document360 supports pasting tables from Microsoft Word and the web application of Microsoft Excel directly in the editor while retaining their structure.

At this time, pasting tables from the desktop application of Microsoft Excel is not supported. If you need to insert a table from Excel, we recommend using the web application, while will allow you to directly paste the table in Document360 without loss of formatting.

<a id="image-formatting-in-the-advanced-wysiwyg-editor"></a>

## Image formatting in the Advanced WYSIWYG editor

**Plans supporting formatting images in the Advanced WYSIWYG editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Unlike the Markdown editor, the Advanced WYSIWYG editor offers different image formatting options. You can access the image formatting options when you click an image you wish to edit.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-floating_menu_in_image.png)

Click on the image, and you’ll have a floating menu with the following features to edit the selected image:

1. **Align**

   There are three common alignment options available for images:

   * **Align Left** ()**:** Aligns the image to the left side of the content.
   * **Center** ()**:** Centers the image within the content.
   * **Align Right** ()**:** Aligns the image to the right side of the content.
2. **Inline left** (), **Inline block** (), and **Inline right** ():

   When you select an inline display option, the image aligns side by side with the text. The alignment (left or right) places the image on the corresponding side of the text, while the inline block option keeps the image within the text flow without disrupting the layout.
3. **Image caption** ():

   You can add a caption to your image, which will appear at the bottom of the image. This is useful for providing additional context or descriptions.
4. **Alt text** ()**:**

   Also known as alt tags or alt descriptions, alt text is the written copy that appears in place of an image if it fails to load on a user's screen.

   Enter the alternative text for the image and click the () icon to save it.
5. **Hyperlinking images** ()**:**

   Click on the link icon to add hyperlinks to your images. Paste the URL and select the **Open in a new tab** box below if you want the link to be opened in a **new tab** and click **Insert**. After linking your image, three new options will appear in the formatting tray:

   * **Open Link:** Opens the link in a new tab.
   * **Edit Link:** Edits the attached link.
   * **Unlink:** Removes the link from the image.
6. Click on the [**Advanced edit**](/help/docs/image-formatting-in-the-advanced-wysiwyg-editor#advanced-editing-options-for-images) () icon to edit your image such as resize, crop, etc.,
7. **Style** ():

   There are three styling options available for images:

   * **Rounded:** The image appears as a rounded rectangle with blunt corners.
   * **Bordered:** A light gray border is added to the image.
   * **Shadow:** The image casts a visible drop shadow effect.
8. **Resize** (): You can customize the width and height of the image.
9. **Replace** (): Click the **Replace** icon to switch the current image with another using any of the three insert image methods.
10. **Copy** (): Click the **Copy** icon to copy the selected image for use elsewhere in the article.
11. **Delete** (): Click the **Delete** icon to remove the selected image from the article.

### Advanced editing options for images

![Editing images in the Advanced WYSIWYG editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Editing_an_image(top_bottom).png)

### **1. Top menu options**

![Editing images in the Advanced WYSIWYG editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-top_menu_over_view.png)

1. **Zoom In/Zoom Out:** Click **Zoom In** or **Zoom Out** to adjust the image size.
2. **Hand:** Click the **Hand** icon to move the image while editing.
3. **History:** Click **History** to view the edit history of the image.
4. **Undo:** Click **Undo** to revert the most recent action.
5. **Redo:** Click **Redo** to reapply the previously undone action.
6. **Reset:** Click **Reset** to return the image to its original state, removing all edits.
7. **Delete:** Select any edited element (e.g., circle, shape) and click **Delete** to remove that particular element.
8. **Delete All:** Click **Delete All** to remove all the edited elements from the image.

---

### **2. Bottom menu options**

![Editing images in the Advanced WYSIWYG editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-bottom_menu_over_view.png)

1. **Resize:** Click **Resize** to adjust the width and height of the image, and lock aspect ratio. Once done, click **Apply**.
2. **Crop:** Click **Crop** to choose a cropping option such as Custom, Square, etc. Once done, click **Apply**.
3. **Flip:** Click **Flip** to select either horizontal or vertical flip. Use **Reset** to revert to the original image.
4. **Rotate:** Click **Rotate** to rotate the image between 0° to 360° (custom range available).
5. **Draw:** Click **Draw** to add lines or shapes. Options include:

   * **Free Draw:** Allows custom drawing.
   * **Straight:** Draw straight lines.
   * **Color:** Select the desired color for the drawing.
   * **Range Slider:** Adjusts the thickness of the drawing line.
6. **Shape:** Click **Shapes** to insert shapes like rectangles, circles, or triangles. Options include:

   * **Fill Color:** Choose a color to fill the shape.
   * **Stroke:** Select the outline color for the shape. You can also adjust the thickness using custom **Stroke** range slider.
7. **Icon:** Click **Icons** to add icons such as arrows, location markers, polygons, etc. You can also upload a custom icon from local storage. Adjust the icon color as needed.
8. **Text:** Click **Add** text to the image with formatting options (bold, italic, underline, alignment, color, text size).
9. **Filter:** Click **Filter** adjust image parameters such as grayscale, blur, brightness, sepia, contrast, etc., Once done, click **Save**.

---

### FAQs

**What image formatting options are available in the Advanced WYSIWYG editor?**

The Advanced WYSIWYG editor offers options such as alignment, inline display, image captions, alt text, hyperlinking, advanced edit options, styling, resizing, replacing, copying, and deleting images.

**How can I align an image in the Advanced WYSIWYG editor?**

You can align an image to the left, center, or right by selecting the corresponding alignment option from the floating menu after clicking on the image.

**Can I add a caption to my image?**

Yes, in the advanced WYSIWYG editor, you can add a caption to your image, which will appear at the bottom of the image for additional context or descriptions.

**Is it possible to hyperlink an image?**

Yes, you can hyperlink an image by clicking the link () icon, pasting the URL, and choosing to open the link in a new tab if desired.

<a id="tabs-in-the-advanced-wysiwyg-editor"></a>

## Tabs in the Advanced WYSIWYG editor

**Plans supporting Tabs in the Advanced WYSIWYG editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Tabs** feature in the Advanced WYSIWYG Editor helps writers organize related content into separate tabs within a single article. This helps to present lengthy or complex information in a clear and structured way. Readers can quickly find the content they need without scrolling through long pages, improving their experience.

---

## Creating tabs

### Adding tabs using the Insert option

To create tabs in your article,

1. Open the **Advanced WYSIWYG editor**.
2. Access the **Insert** option from either the **floating menu** or by using the **slash (/)** **command**.
3. Select **Tabs** from the available options.
4. A default tab structure with two tabs will appear in your article.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_GIF-Adding_new_tab_block.gif)

### Adding additional tabs

To add additional tabs in an existing tab structure,

1. Hover over the tab bar and click the **+ button** to add a new tab.
2. Enter a title for the new tab (up to 50 characters).
3. Repeat as needed to create multiple tabs.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_GIF-Adding_additional_tabs.gif)

> NOTE
>
> * The tabs feature requires a minimum of two tabs to function.
> * A maximum of 10 tabs can be created within a single tab structure.

### Supported elements inside tabs

You can add the following elements to your tab content,

* **Text formatting**: Use headings (H2, H3, H4), bullet lists, numbered lists, and checklists.
* **Images and videos**: Insert, resize, and manage images or videos.
* **Tables**: Add and customize rows and columns.
* **Hyperlinks**: Insert and format links for easy navigation.
* **Callouts and private notes**: Add callouts or private notes that are visible only to specific users.
* **Code blocks and inline code**: Display code snippets or inline code for technical references.
* **Variables and snippets**: Reuse content across tabs using snippets and variables.
* **Glossary terms**: Add terms with definitions visible on hover or click.
* **Other enhancements**: Use emojis, dividers, accordions, and LaTeX equations.

---

## Editing tabs

### Duplicating tabs

To duplicate a tab,

1. Click the **Edit ()** icon next to the tab name.
2. Click the **Duplicate tab** option from the menu that appears.
3. A new tab will appear next to the original tab, with the same title, content, and color. You can edit the duplicated tab as needed.

### Changing tab names

To change the name of a tab,

1. Click the **Edit ()** icon next to the tab name.
2. Hover over the **Change tab name** option in the menu that appears.
3. Enter the new name (up to 50 characters) in the **Change tab name** field. The updated tab name will automatically reflect in the tab.

### Deleting tabs

To delete a tab,

1. Click the **Edit ()** icon next to the tab name.
2. Click the **Delete tab** option in the menu that appears.

Clicking this option will delete the tab immediately. Deleted tabs can be restored using the **Undo (Ctrl + Z)** option in the editor.

> NOTE
>
> If your content block contains only two tabs, you cannot delete either tab.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_GIF-Editing_tabs.gif)

---

## Customizing tabs

### Changing tab background and border color

To change the background/border color of a tab,

1. Select the tab content block to access the tab customization options.
2. Click **Tab background color** or **Tab border color** from the customization options.
3. Use the color picker to select a background or border color. You can choose from:

   * Preset colors
   * HEX values
   * RGB values

Click **Clear** in the color picked to remove any background or border color applied to the tab.

> NOTE
>
> The selected background or border color will be applied to the entire tab content block. It is not possible to apply different background or border colors to individual tabs.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_GIF-Customizing_tabs.gif)

### Moving tabs

To rearrange the order of tabs in your article,

1. Find the tab in the list of tabs under the **Tabs** section in the editor.
2. Hover over the **six-dot drag icon** to the left of the tab name.
3. Click on the drag icon, hold it down, and move the tab to your desired position.
4. Release the cursor to drop the tab in the new location.

#### Considerations when moving tabs

Keep the following tips in mind when working with multiple tabs to ensure smooth navigation and placement:

* **Scrolling while moving tabs:** If your list of tabs extends beyond the visible area, drag the tab toward the **dark grey area** near the **right or left arrow** to scroll and access hidden sections.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_GIF-Scrolling_while_moving_tabs.gif)

* **Moving a tab to the right:** Drag the tab until a **blue line** appears in the center of the target tab’s position. Dropping the tab here will replace the target tab, and the list will automatically realign.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_GIF-Moving_tabs_to_the_right.gif)

* **Moving a tab to the left:** Drag the tab until the **blue line** appears in the center of the tab **immediately to the left** of the desired position. This ensures the tab is placed correctly.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_GIF-Moving_tabs_to_the_left.gif)

* **Moving a tab to the first position:** To place a tab at the very beginning of the list, drag it near the first tab. Hold until a **blue line** appears on top of the first tab, then drop it.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_GIF-Moving_tabs_to_the_first_position.gif)

> NOTE
>
> For better control, drag tabs slowly and make small adjustments to avoid accidental replacements.

---

## Viewing tabs in the Knowledge base site

You can view tabs in the Knowledge base site exactly as they are configured in the editor:

* You can switch between tabs without needing to refresh the page.
* The tab colors, titles, and layouts will appear the same across the Knowledge base site, widgets, and extensions.
* Tabs work seamlessly on mobile devices, allowing you to switch between them just as you would on a computer.
* If you export an article with tabs as a PDF, the contents of the tabs will appear sequentially, and each tab's title will be displayed as a heading.

---

### FAQ

#### Can I create tabs within another tab?

No, nested tabs are not supported. You cannot create tabs inside other tabs. This ensures the layout and functionality of the editor remain consistent.

#### Can I include tab headings in the table of contents?

No, headings within tabs will not be included in the table of contents on the Knowledge base site.

#### Can I add page breaks inside a tab?

No, the page break option is disabled within tabs to preserve the layout and structure of the content.

#### Can I use tabs inside other editor components?

No, tabs cannot be created inside certain editor controls like tables, accordions, or callouts. This restriction ensures proper functionality and layout consistency.

<a id="categories-and-subcategories"></a>

## Categories and subcategories

In Document360, Category and Subcategory is essential for organizing and displaying articles on similar topics. They function as folders that group related content, offering a structured approach to knowledge management.

Imagine you manage a product support knowledge base for an e-commerce platform. You create a category called **Shipping Information** with subcategories like **Domestic shipping**, **International shipping**, **Shipping rates**, and **Delivery times**. This structure enables customers to easily find the exact information they need, reducing frustration and improving their overall experience.

![Document360 interface showing categories, articles, and their publication statuses for user guidance.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Catagory_n_subcategory_in_portal.png)

---

### FAQs

#### What are categories and subcategories in documentation?

Categories and subcategories are organizational structures in a knowledge base used to group related articles by topic. This makes it easier for users to navigate and find relevant information.

#### How do categories and subcategories differ?

Categories represent broad topics, while subcategories provide more specific divisions within those topics. Articles are hierarchically organized under subcategories, which are grouped under their respective parent categories.

#### Why do I need subcategories?

Subcategories help segment information into smaller, focused groups, enhancing understanding, accessibility, and navigation.

**Example:** If "Cars" is the main category, subcategories like "Sedan," "SUV," and "Convertible" allow users to quickly locate content specific to their interests.

#### Can I customize the categories and subcategories?

Yes, Document360 allows team accounts to create, edit, and delete categories and subcategories based on organizational needs. Customization options include changing icons for better visual appeal.

> NOTE
>
> For more information, read the article on Managing categories.

#### How can categories and subcategories improve knowledge base usability?

Logical groupings simplify browsing, enabling readers to find relevant information without sifting through unrelated content.

#### Can a single article belong to multiple categories or subcategories?

Yes, you can display an article in multiple categories or subcategories using the **Replicate** () option in Document360.

#### What is the best practice for naming categories and subcategories?

Use clear and descriptive names that reflect the content contained within each category or subcategory. Avoid jargon and aim for user-friendly naming conventions.

#### How should I organize my categories and subcategories for optimal user experience?

Structure categories and subcategories based on logical relationships and user needs. A tree-like format broad categories divided into specific subcategories works best.

**Example:** In the Document360 Knowledge base, categories and subcategories align with the sequential flow of features and menus in the portal.

#### Can I apply different access permissions to certain categories or subcategories?

Yes, Document360 supports role-based content access control, allowing restrictions on specific categories or subcategories. If no explicit restrictions are set, permissions inherit from parent categories.

#### Is it possible to reorder categories and subcategories after they are created?

Yes, Document360 lets you reorder categories and subcategories using the drag-and-drop () icon.

#### Why is the category/subcategory not visible on my Knowledge base site? How can I resolve this issue?

A category or subcategory might not appear on the site in the following scenarios:

* All articles within it are hidden or not published.
* The category/subcategory is empty, with no articles added.

Try the below steps if the category tree fails to load on the Knowledge base site:

* Check if JavaScript is enabled in your browser settings.
* Clear your browser cache and cookies to resolve potential caching issues.
* Ensure your browser is updated to the latest version.
* Test the category tree on a different browser or device to verify if the issue is browser-specific.

Organizes related articles under a common theme in the knowledge base.

A secondary category in Document360 used to organize and display groups of related articles. Subcategories act as folders within a primary category, helping structure similar topics for better organization and navigation.

<a id="managing-categories"></a>

## Managing categories

**Plans supporting management of categories**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Organizing content effectively is key to creating a user-friendly and efficient knowledge base. In Document360, categories and subcategories play a pivotal role in structuring your documentation. Whether you’re creating, renaming, deleting, or moving categories, Document360 provides a wide range of options to customize and manage them to meet your specific needs.

Managing categories helps to create and customize category icons to advanced tasks like cloning, reordering, and starring categories for quick access. With these features, you can ensure your knowledge base remains well-organized and accessible to your team and end users.

---

## Creating a category

In the Knowledge base portal, you can create a category using one of the following methods:

1. Method 1: Using the **Create** button on the top bar
2. Method 2: Using the **Flywheel** () icon
3. Method 3: Using the **More** () icon in the **Categories & Articles** section.
4. Method 4: Using the **Create** button in **Folder/Index** type category

![Document360 interface showing options to create  categories in a workspace.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Creating_a_categories.png)

Method 1

Method 2

Method 3

Method 4

To create a category using the **Create** button on the top bar:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Click the **Create**dropdown and select **Category**.

   The **Create new category** panel will appear.
3. Enter a **Name** for the new category.
4. In the **Nest category under** the dropdown, choose the category’s position (root level or inside an existing category).
5. Click **Reset** to create the category in Root level.
6. Choose the **Type** of category (Folder, Index, Page, or GitHub).
7. Click **Create**.

   A new category or subcategory is added.

To create a category using the **Flywheel** () icon:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Hover over just below the desired category, and click the **Flywheel** () icon.
3. Click **Category**.

   The **Create new category** panel will appear.
4. Enter a **Name** for the new category.
5. In the **Nest category under** the dropdown, choose the category’s position (root level or inside an existing category).
6. Click **Reset** to create the category in Root level.
7. Choose the **Type** of category (Folder, Index, Page, or GitHub).
8. Click **Create**.

   A new category or subcategory is added.

To create a category or sub category using the **More** **(****)** icon in the **Categories & Articles**section:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Hover over the desired category, and click the **More** () icon.

   The **Create new category** panel will appear.
3. Enter a **Name** for the new category.
4. In the **Nest category under** the dropdown, choose the category’s position (root level or inside an existing category).
5. Click **Reset** to create the category in Root level.
6. Choose the **Type** of category (Folder, Index, Page, or GitHub).
7. Click **Create**.

   A new category or subcategory is added.

To create a category using the **Create** button in a Folder/Index type category:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Click the desired Folder/Index type category in the **Categories & Articles** section.
3. Click **Create** dropdown (on the right side of the category page) and select **Sub category**.

   The **Create new category** panel will appear.
4. Enter a **Name** for the new category.
5. In the **Nest category under** the dropdown, choose the category’s position (root level or inside an existing category).
6. Click **Reset** to create the category in Root level.
7. Choose the **Type** of category (Folder, Index, Page, or GitHub).
8. Click **Create**.

   A new category or subcategory is added.

![Creating a new category in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-Creating_a_category_panel.png)

### Subcategories level

You can create up to **seven levels** of categories (1 root category + 6 subcategory levels). The **New category** option will be disabled for subcategories beyond this limit.

![4_Screenshot-Category_manager-Subcategory_levels](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Category_manager-Subcategory_levels.png)

> **NOTE**
>
> * When you have more subcategory levels, the user will find it challenging to navigate and discover the desired article without using the **Search** option.
> * You can structure the Knowledge base based on your requirement as Document360 facilitates content discoverability using tags, all-in-one search, related articles, internal linking, cloning articles, replicating or sharing one article in multiple categories, and the starred categories/articles feature.

> TIP
>
> Use up to three subcategory levels for optimal navigation. Two subcategory levels are ideal.

---

## Changing category icon

When you create a category or subcategory, a default folder icon is assigned. You can change this icon to an emoji to better convey the category’s purpose to your end-users.

1. Navigate to the **Documentation** () in the Knowledge base portal.
2. In the left navigation panel, click the folder icon or emoji adjacent to the desired category.

   An emoji pop-up window will appear. You can find an emoji by using the search bar, looking through the categories along the top, or using the color-tone icons next to the search bar.
3. Select your desired emoji to apply it.

> **NOTE**
>
> * To revert to the folder icon, click the 🚫 icon in the emoji pop-up window.
> * Emoji styles may vary depending on the browser.
> * You cannot update the category icon for **Page** type categories. Category icon can only be updated for **Folder** or **Index** type categories.

![Document360 interface showing how to change the category icon in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_ScreenGIF-Changing_the_Category_icons.gif)

---

## Deleting a category

There are four ways to delete a category in the Knowledge base portal:

1. Method 1: Using the **More**() icon in the **Categories & Articles**section.
2. Method 2: Using the **More** () icon in the **Folder**/**Index** category.
3. Method 3: Deleting multiple articles/categories in the **Folder**/**Index** category.
4. Method 4: Deleting a specific article/sub category in the **Folder**/**Index** category.

![User interface showing options for managing delete options in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Deleting_Categories.png)

Method 1

Method 2

Method 3

Method 4

To delete a specific category from the **Categories & Articles**section:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Hover over the desired category in the **Categories & Articles** section.
3. Click the **More** () icon and select **Delete** ().
4. Click **Yes** in the **Delete** confirmation panel.

To delete a specific Folder/Index type category:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Go to the desired Folder/Index category.
3. Click the **More** () icon and select **Delete** ().
4. Click **Yes** in the **Delete** confirmation panel.

To delete a multiple articles and sub categories within a specific **Folder**/**Index** category:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category.
3. Select the checkboxes for the appropriate articles and subcategories.
4. Click **Delete** ().
5. Click **Yes** in the **Delete** confirmation panel.

To delete a specific article/sub category within a specific **Folder**/**Index** category:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category.
3. Hover over the desired article/sub category.
4. Click the **More** () icon and select **Delete** ().
5. Click **Yes** in the **Delete** confirmation panel.

> **NOTE**
>
> When you delete a root-level category, all the subcategories and articles under that level will also be deleted. Deleted items will be available in the recycle bin for 30 days.

---

## Hiding and unhiding a category

In Document360, you can hide a category or subcategory within the documentation editor to restrict access to team accounts only. Hidden categories are indicated by a strikethrough in the categories list of the Documentation window.

> Suppose your documentation team is drafting a new feature guide that isn't ready for public release. You can temporarily hide the category while it's under review, ensuring that only internal team members can access it. Once finalized, you can unhide the category to make it publicly available.

There are four ways to hide a category in the Knowledge base portal:

1. Method 1: Using the **More** () icon in the **Categories & Articles**section.
2. Method 2: Using the **More**() icon in the **Folder**/**Index** category.
3. Method 3: Hiding/Unhiding multiple articles/categories in the **Folder**/**Index** category.
4. Method 4: Hiding/Unhiding a specific article/category in the **Folder**/**Index** category.

![User interface showing options for managing Hide options in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Hiding_Categories.png)

Method 1

Method 2

Method 3

Method 4

To hide/unhide a specific category from the **Categories & Articles**section:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Hover over the desired category in the **Categories & Articles** section
3. Click the **More**() icon and select **Hide** ().

   To Unhide, click the **Unhide** () icon.

To hide/unhide a specific Folder/Index type category:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Go to the desired Folder/Index category.
3. Click the **More**() icon and select **Hide** ().

   To Unhide, click the **Unhide** () icon.

To hide/unhide multiple articles and sub categories within a specific **Folder**/**Index** category:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category.
3. Select the checkboxes for the appropriate articles and subcategories.
4. Click **Hide** ().

   To Unhide, click the **Unhide** () icon.

To hide/unhide a specific article/sub category within a specific **Folder**/**Index** category:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category.
3. Hover over the desired article/sub category.
4. Click the **More**() icon and select **Hide** ().

   To Unhide, click the **Unhide** () icon.

> **NOTE**
>
> When you hide a category or subcategory, all its subcategories and articles will also be hidden.

---

## Renaming a category

In Document360, you can rename categories and subcategories as many times as needed.

1. Navigate to **Documentation**() in the Knowledge base portal.
2. Go to the desired category or subcategory.
3. On the category page, click the **category name** to edit.

   Alternatively, hover over the desired category in the **Categories & Articles** section, click the **More** () icon, and select **Rename** to edit the category name.
4. Enter the new category name and click **Update**.

> **NOTE**
>
> Renaming the category or subcategory does not impact the category slug.

![Renaming a category in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/13_ScreenGIF-Renaming_a_category.gif)

---

## Moving a category

You can move a category or subcategory across workspaces. All subcategories and articles within the category will also be moved when you perform the **Move** operation.

There are five ways to move a category in the Knowledge base portal:

1. Method 1: Using the **drag and drop** () icon in the **Categories & Articles**section.
2. Method 2: Using the **More**() icon in the **Categories & Articles**section.
3. Method 3: Using the **More**() icon in the **Folder**/**Index** category.
4. Method 4: Moving multiple articles/categories in the **Folder**/**Index** category.
5. Method 5: Moving a specific article/category in the **Folder**/**Index** category.

![User interface showing options for managing Move options in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Moving_a_category.png)

Method 1

Method 2

Method 3

Method 4

Method 5

To move a category using the drag and drop () icon in the **Categories & Articles** section:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Hover over the desired category.

   The drag and drop () icon will appear.
3. Hold and drag the category to the appropriate location.

> **NOTE**
>
> * You cannot move a root-level category into its subcategory.
> * Drag and drop () icon allows moving categories only within the same workspace.

From the **Categories & Articles**, you can move a category within or across workspaces:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Hover over the desired category or subcategory in the left navigation pane.

   The **More** **(****)** icon will appear.
3. Click the **More** **(****)** icon and select the **Move** () icon.
4. In the **Move category** panel, perform the following:

   * **Workspace:** Select the desired workspace from the dropdown. Click **Reset** to assign it under the main workspace.
   * **Category:** Select an existing category from the selected workspace. Click **Reset** to assign it under the root category.
   * **Auto update referenced links:** Select this checkbox to ensure links in the article content are updated based on the destination workspace/category.
5. Click **Move**.

You can move a **Folder**/**Index** category using the **More** () option in it:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category.
3. Click the **More**() icon and select the **Move** () icon.
4. In the **Move category** panel, perform the following:

   * **Workspace:** Select the desired workspace from the dropdown. Click **Reset** to assign it under the main workspace.
   * **Category:** Select an existing category from the selected workspace. Click **Reset** to assign it under the root category.
   * **Auto update referenced links:** Select this checkbox to ensure links in the article content are updated based on the destination workspace/category.
5. Click **Move**.

To move multiple articles/sub categories within a specific **Folder**/**Index** category:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category.
3. Select the checkboxes for the appropriate articles and subcategories.
4. Click the **Move** () icon.

   In the **Move category** panel, perform the following:

   1. **Workspace:** Select the desired workspace from the dropdown. Click **Reset** to assign it under the main workspace.
   2. **Category:** Select an existing category from the selected workspace. Click **Reset** to assign it under the root category.
   3. **Auto update referenced links:** Select this checkbox to ensure links in the article content are updated based on the destination workspace/category.
5. Click **Move**.

To move a specific article/sub category within a specific **Folder**/**Index** category:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category.
3. Hover over the desired article/sub category.

   The **More**() icon will appear.
4. Click the **More**() icon and Click the **Move** () icon.

   In the **Move category** panel, perform the following:

   1. **Workspace:** Select the desired workspace from the dropdown. Click **Reset** to assign it under the main workspace.
   2. **Category:** Select an existing category from the selected workspace. Click **Reset** to assign it under the root category.
   3. **Auto update referenced links:** Select this checkbox to ensure links in the article content are updated based on the destination workspace/category.
5. Click **Move**.

![Screenshot of Moving category in Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/11_Moving_a_category_panel.png)

---

## Cloning a category

Clone categories are exact copies of the content created as new articles. You can clone the categories within or across workspaces.

There are three ways to clone a category in the Knowledge base portal:

1. Method 1: Using the **More**() icon in the **Categories & Articles**section.
2. Method 2: Using the **More**() icon in the **Folder**/**Index** category.
3. Method 3: Cloning a specific article/sub category within a **Folder/Index** category.

![Document360 interface showing options to manage clone options in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Cloning_categories.png)

Method 1

Method 2

Method 3

From the **Categories & Articles**section, you can clone a category within or across workspaces:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Hover over the desired category or subcategory in the left navigation pane.

   The **More** () icon will appear.
3. Click the **More** () icon and select the **Clone** () icon.
4. In the **Clone category** panel, perform the following:

   1. **Name**: Enter the name for the cloning category.
   2. **Workspace:** Select the desired workspace from the dropdown. Click **Reset** to assign it under the main workspace.
   3. **Category:** Select an existing category from the selected workspace. Click **Reset** to assign it under the root category.
   4. **Auto update referenced links:** Select this checkbox to ensure links in the article content are updated based on the destination workspace/category.
5. Click **Clone**.

You can clone a **Folder**/**Index** category using the **More** () option in it:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category.
3. Click the **More** () icon and select the **Clone** () icon.
4. In the **Clone category** panel, perform the following:

   1. **Name**: Enter the name for the cloning category.
   2. **Workspace:** Select the desired workspace from the dropdown. Click **Reset** to assign it under the main workspace.
   3. **Category:** Select an existing category from the selected workspace. Click **Reset** to assign it under the root category.
   4. **Auto update referenced links:** Select this checkbox to ensure links in the article content are updated based on the destination workspace/category.
5. Click **Move**.

To move a specific article/sub category within a specific **Folder**/**Index** category:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category.
3. Hover over the desired article/subcategory.

   The **More** () icon will appear.
4. Click the **More** () icon and select the **Clone** () icon.

   In the **Clone category** panel, perform the following:

   1. **Name**: Enter the name for the cloning category.
   2. **Workspace:** Select the desired workspace from the dropdown. Click **Reset** to assign it under the main workspace.
   3. **Category:** Select an existing category from the selected workspace. Click **Reset** to assign it under the root category.
   4. **Auto update referenced links:** Select this checkbox to ensure links in the article content are updated based on the destination workspace/category.
5. Click **Clone**.

![Cloning a category in Document360 with workspace and category options displayed.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/12_Cloning_a_category_panel.png)

> NOTE
>
> Security restrictions will be applied based on the destination workspaces/categories.

---

## Starring a category

If you frequently use certain categories in your documentation, you can move them to **Starred** for quick and easy access. This feature functions like a favorites section and is available only in the **Knowledge base portal**.

> **NOTE**
>
> You can star categories, subcategories, and articles.

To add a category to **Starred**, follow these steps:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Select the desired category.
3. Click the **Starred** () icon next to the category title.

   Alternatively, hover over a subcategory in the **Folder/Index** overview and click the **Starred** () icon.
4. For a page category type, click the **Starred** () icon near the category title.

![Document360 interface showing how to add a star a category in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Starring_a_category.png)

You can remove a Starred categories in two ways:

Method 1: Direct removal

Method 2: Removing from the **Starred** () section

Method 1

Method 2

To remove a starred category directly from the categories, follow the steps below:

1. Navigate to the desired category or subcategory in the **Folder/Index** overview page.
2. Click the **Starred** () icon next to the category or subcategory title to unstar it.

To remove a Starred categories in the **Starred** () section:

1. Navigate to **Documentation** () > **Starred** () in the Knowledge base portal.

   The **Starred** () page will appear, displaying a list of starred categories.
2. Select the checkboxes next to the categories you want to remove.
3. Click the **Remove from starred** option.

![Document360 interface showing how to remove a star a category in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_ScreenGIF-removing_starred_categories.gif)

> **NOTE**
>
> When the category filter is applied to the starred items, you cannot view the article status for starred folders or index categories. This is because the starred articles are treated as independent items and are not associated with the category filter. However, only page categories will display the article status.

---

### FAQs

#### What types of categories can I create?

You can create categories of type Folder, Index, Page, or GitHub.

#### Is there a limit to the number of categories I can create?

Yes, you can create up to 1,000 categories per workspace.

#### Can I create subcategories under a main category?

Yes, you can create up to seven levels of categories, including one root category and six subcategory levels.

#### What is the character limit for the article or category title?

The character limit for article or category titles is 150, including spaces.

#### Can I change the category icon to an emoji?

Yes, you can change the icon for Folder or Index type categories or subcategories to an emoji.

#### Is there a way to remove the emoji and revert to the folder icon?

Yes, you can click the 🚫 icon in the emoji popup window to remove the emoji and revert to the folder icon.

#### Do emoji styles vary by browser?

Yes, some emoji styles may vary by browser.

#### What is the purpose of hiding a category in Document360?

Hiding a category restricts access to certain information, making it visible only to team accounts while keeping it hidden from the Knowledge base site.

#### How can I identify hidden categories in Document360?

Hidden categories are indicated by a strikethrough in the categories list in the **Documentation**() section.

#### Can I hide multiple subcategories at once?

Yes, in **Folder/Index** type categories, you can hide multiple subcategories under the same parent category simultaneously by selecting the desired subcategories and clicking **Hide** ().

#### Is it possible to hide a category after it has been published?

Yes, you can hide a category even after it has been published by navigating to the **Categories & Articles**section and selecting the **Hide** () option.

> **NOTE**
>
> When you hide a category or subcategory, all its subcategories and articles will also be hidden.

#### Can I move a category across workspaces?

Yes, you can move a category between workspaces.

#### Does moving a category also move its subcategories and articles?

Yes, moving a category will also move its subcategories and articles to the desired location.

#### Can I move a root-level category into its subcategory?

No, you cannot move the root-level category into its subcategory.

#### Are there any security restrictions when moving categories?

Yes, security restrictions will be applied based on the destination workspaces/categories.

#### What are cloned categories?

Cloned categories are exact copies of the content created as new articles.

#### Can I clone categories across different workspaces?

Yes, you can clone categories within or across workspaces.

#### Is it possible to create new categories or articles within a cloned category?

Yes, you can create new categories or articles within a cloned category.

#### Can I change the type of a cloned category after it has been created?

Can I change the type of a cloned category after it has been created?

#### What is the purpose of starring categories in the Knowledge base portal?

Starring categories allows you to easily access frequently used categories, similar to a favorites section.

#### Is it possible to remove multiple categories from 'Starred' at once?

Yes, you can remove multiple categories from 'Starred' at once from the Starred () page.

#### How long are deleted categories available in the recycle bin?

Deleted categories will be available in the recycle bin for 30 days.

#### Does renaming a category update its slug?

No, renaming a category or article does not automatically update its slug. You must manually update the slug if required.

#### What are some best practices for naming categories?

Best practices include clarity and simplicity, consistent formatting, reader-centric language, avoiding repetition, logical hierarchy, keyword optimization, avoiding abbreviations, considering scalability, and ensuring contextual relevance.

<a id="category-types"></a>

## Category types

**Plans supporting category types**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In Document360, **categories** and **subcategories** help organize and display groups of similar topic articles, acting as folders containing related content.

## Types of categories

here are three types of categories you can add to your knowledge base:

**1.** **Folder**  
**2.** **Index**  
**3.** **Page**

> NOTE
>
> You can choose the category type when creating a category and switch the category type at any time, as often as needed.

---

**Choosing a category type during category creation**

1. Navigate to the desired category, click the **More** (•••) icon and select **Add sub category**.

   The **Create new category** panel will appear.
2. Select the desired category type.
3. Click **Create.**

![ScreenGIF-Choosing a category type during category creation](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScrenGIF-New_Choosing_a_category_type_during_category_creation.gif)

---

### 1. Folder

The **Folder** is the primary category type, acting as a simple container for articles and subcategories. The default folder icon can be customized with a wide range of icons. This category type does not have a seperate view point of link/URL to the category in the Knowledge base site.

The folder category page also allows you to perform bulk operations like Hide (), Unhide (), Delete (), Move (), and Add to starred () for articles within the category.

**Knowledge base portal view**  
![Screenshot of New Knowledge base portal view for folder category type](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-New_Knowledge_base_portal_view_%20for_folder_category_type.png)

### **2. Index**

The **Index** category type serves as an index to all articles within the folder.

**Knowledge base portal view**  
A URL is generated for this category type, which can be accessed and shared. The page lists articles with details such as title, contributors, last update date, status, and tags.

1. **Index category slug**: Each Index category has a unique slug. Like articles, you can share Index category links with end-users and apply redirection rules.
2. **Bulk operations**: The Index category page supports bulk operations like Hide (), Unhide (), Delete (), Move (), and Add to starred () for the articles.

![Screenshot of a Knowledge base portal view for index category type](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-New_Knowledge_base_portal_view_%20for_index_category_type.png)

**Knowledge base site view**  
When readers click on the Index category type, they get an overview of the articles within the category. The page includes:

1. Category title
2. Number of articles/categories in the category

![Screenshot of Knowledge base site for indx category type](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-New_Knowledge_base_site_view_%20for_index_category_type.png)

### 3. Page

The **Page** category type is similar to the articles you create under other categories in your project. You can create content, publish it, and perform all the same actions as you perform with a regular article.

You can write the page content using the editor (Markdown, WYSIWYG, or Advanced WYSIWYG), change the page title and slug, and perform all other actions available for a typical article in Document360.

**Knowledge base portal view**  
![Screenshot of Knowledge base portal for page category typ](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-New_Knowledge_base_portal_view_%20for_page_category_type.png)

**Knowledge base site view**  
![Screenshot of Knowledge base site for page category type](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-New_Knowledge_base_site_view_%20for_page_category_type.png)

---

### FAQ (s)

**What are the different category types available in Document360?**

There are three category types you can add to your knowledge base: Folder, Index, and Page.

**How do I change the category type?**

1. Navigate to the desired category in the Knowledge base portal.
2. Click on the **More (•••)** icon and select **Change type**.
3. Select the intended category type and click **Update**.

**Can I change the category type after it has been created?**

Yes, you can change the category type at any time as often as needed.

**What is the purpose of the Index category type?**

The Index category type serves as an index to all articles within the folder and generates a URL that can be accessed and shared.

**What happens if I change a page category to an index category? Will my content be erased?**

No, your content will not be erased. The category type will change to an index category, and if you switch it back to a page category, your content will be restored.

**Is there a URL associated with the Folder category type?**

No, the Folder category type does not have a separate viewpoint or link/URL to the category in the Knowledge base site.

**What operations can I perform on articles within a Folder category?**

You can perform bulk operations like Hide, Unhide, Delete, Move, and Add to starred for articles within the Folder category.

**What is the main difference between an article and a page category?**

The main difference is that within a Page category, you can create additional categories and articles, whereas in an article, you cannot.

<a id="assigning-drive-folder-for-a-category"></a>

## Mapping a category with a folder in Drive

**Plan support for mapping a category to a folder in Drive**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## What is a 'Drive folder mapping'?

When a Contributor upload images in the article on the Editor from their local storage or URL, the image would automatically be placed in the designated Drive folder for the article's category/subcategory.

---

## Associating a Drive folder to a category

1. Navigate to Documentation () in the Knowledge base portal.
2. Hover over the desired category and click **More** (•••) icon.
3. Click the **Set drive folder** option.

   The **Set drive folder - Getting started** panel will appear.
4. Select the intended folder/subfolder from the project's Drive where the images need to be saved.
5. Click the **Update** button.

The Drive folder is now mapped to the category/subcategory.

![Screenshot-Updated_mapping_category_with_drive_folder](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-Updated_mapping_category_with_drive_folder.gif)

---

#### FAQ(s)

**Can I map the drive folder for subcategories?**

Yes, the **Set Drive Folder** option is available for all categories and subcategories.

**How is setting a drive folder different from the Editor folder?**

If a category is mapped to a drive folder, that mapped folder takes precedence over the Editor folder. All images added to any article in that category will be uploaded to the mapped drive folder. If the category is not mapped to a drive folder, images will be saved in the Editor folder.

**Can I map drive folders at an article level?**

Currently, drive folder mapping is only available for categories and subcategories.

**Can I change or remove a category's drive folder mapping?**

Yes, you can change or remove a category's mapped drive folder as many times as needed. However, changing the mapping to a different drive folder will not move images previously added to the article. Only images added after updating the mapping will be saved in the newly selected drive folder.

**I have a subcategory mapped to a different drive folder and the parent category mapped to another drive folder. Which mapping will be used for articles inside the subcategory?**

The immediate mapping will take precedence, overriding all other settings. In this case, the subcategory mapping will be applied.

> NOTE
>
> **Preference settings:**
>
> 1. Subcategory drive folder mapping
> 2. Parent Category drive folder mapping
> 3. Editor folder

A team account in Document360 that has contributed to a project by creating, editing, saving, or publishing articles. Document360 automatically tracks these activities and includes contributors in the public contributor list.

A tool in Document360 used by writers to draft and format content. Document360 offers three types of editors: Markdown, WYSIWYG, and Advanced WYSIWYG.

A secondary category in Document360 used to organize and display groups of related articles. Subcategories act as folders within a primary category, helping structure similar topics for better organization and navigation.

Organizes related articles under a common theme in the knowledge base.

The default folder in the Document360 Drive where all image files uploaded directly from the editor using the 'Insert Image' option are saved.

<a id="downloading-category-and-article-in-kb-site"></a>

## Downloading category and article in KB site

**Plans supporting the Downloading category and article in the KB site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Downloading articles individually can be time-consuming and cumbersome. This feature allows you to generate and export entire categories and articles into PDFs, choosing appropriate templates for customization. Users can access these tailored PDF templates directly from the Knowledge Base site, making the process more efficient and user-friendly.

> For your information (FYI)
>
> This feature is available exclusively in private projects and private workspaces within mixed projects in KB site 2.0.

---

#### Enabling PDF download and template selection

Follow these steps to enable PDF downloads and choose a template in the Knowledge base portal:

1. Navigate to **Settings**() > **Knowledge base site**> **A****rticle settings & SEO**>**Article settings** in the Knowledge base portal.
2. Go to **Show download as PDF button** toggle and turn it on.

   By default, this option is enabled.
3. Selecting the **Allow you to choose PDF template while exporting** checkbox enables you to choose your PDF template during the export process.

> **NOTE**
>
> To create or manage the PDF templates, go to **Documentation**() > **Content tools** > **Export to PDF** and select the **PDF template** section.

![Enabling the Show download as PDF button for Downloading categories and articles](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Settingup_Knowledge_base_portal_new.png)

---

#### Downloading categories and articles

1. Navigate to the desired category and click the **More**() icon in the category manager.
2. Click **Export PDF**.
3. The **Export Articles** panel, select the desired subcategories and articles, and choose the appropriate template from the PDF templates dropdown.

   If no template is selected, the default template will be used.
4. Click **Export PDF**.

> NOTE
>
> * Customization added to the knowledge base site will not be reflected in the PDF downloaded.
> * In a Mixed project, if some categories are set to private but the overall workspace is public, the **Export PDF** option will not be available. The workspace visibility (public) takes precedence over individual category settings.

![2_Screenshot-Downloading_PDf_on_KB_site](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Downloading_PDf_on_KB_site.gif)

---

#### Generate PDF download link

* Based on the selected categories, articles, and chosen templates, the PDF will be downloaded.
* If only one article is chosen, it will be downloaded instantly. If more than one article is selected, a downloadable link will be sent via email.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image(150).png "image(150).png")

> **NOTE**
>
> The download link expires after 48 hours.

---

### FAQs

#### What happens if my download exceeds the 500 MB limit?

By default, all plans have a daily download limit of 500 MB. If a download exceeds this threshold, the process will complete, but further downloads will be restricted until the next day. For example, if a Reader generates a PDF on April 9, 2024, at 9:20 PM and exceeds the limit, further downloads will be blocked for 24 hours. **KB PDF download quota** add-ons can be purchased to increase the download capacity for all plans.

#### How can I increase my download capacity?

If you need additional download capacity beyond your daily limit, you can purchase **KB PDF download quota** add-ons from the billing section.

<a id="managing-articles"></a>

## Managing articles

**Plans supporting for Managing articles**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Articles are the foundation of a knowledge base. Managing them effectively ensures that your documentation remains organized, user-friendly, and up to date. Document360 offers a range of options for creating, editing, and organizing articles to suit diverse needs.

Imagine you're managing a large knowledge base with multiple contributors and a wide audience. You need tools to create, edit, and organize articles efficiently while maintaining consistency and accuracy. Document360 simplifies this process with intuitive methods for article management.

---

## Creating an article

The most important building block of any knowledge base is the information it contains. As a Document360 user, you can add this information in the form of articles. Articles are usually grouped into user-defined categories, based on the information they contain.

While you can create articles from a template, or import an article from another source, creating an article from scratch is the most common article creation process.

> **NOTE**
>
> Article limits by plan:
>
> * Professional: **5,000** articles/workspace
> * Business: **5,000** articles/workspace
> * Enterprise: **10,000** articles/workspace
>
> For the best experience, we recommend maintaining articles within these soft limits. If you need a higher limit, contact [support@document360.com](mailto:support@document360.com).

There are four methods to create an article in the Knowledge base portal:

1. Method 1: Using the **Create** button on the top bar
2. Method 2: Using the **Flywheel** () icon
3. Method 3: Using the **More** () icon in the **Categories & Articles** section
4. Method 4: Using the **Create** button in **Folder/Index** type category

![Instructions for creating articles in Document360 interface.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Creating_a_new_article.png)

Method 1

Method 2

Method 3

Method 4

To create an article using the **Create** button on the top bar:

1. Navigate to **Documentation**() in the Knowledge base portal.
2. Click the **Create** dropdown and select **Article**.

   The **Create new article**panel will appear.
3. Enter a **Name** for the new article.
4. In the **Category** dropdown, choose the category’s position.
5. Click **Create** to add the article.

To create an article using the **Flywheel** () icon:

1. Navigate to **Documentation**() in the Knowledge base portal.
2. Hover over just below the desired article, and click the **Flywheel** () icon.
3. Click **Article**.

   The **Create new article** panel will appear.
4. Enter a **Name** for the new article.
5. In the **Category** dropdown, choose the category’s position.
6. Click **Create** to add the article.

To create an article using the **More (****)** icon in the **Categories & Articles** section:

1. Navigate to **Documentation**() in the Knowledge base portal.
2. Hover over the desired category in the **Categories & Articles** section, and click the **More** () icon.
3. Click **Create article** and select **Blank**.

   The **Create new article** panel will appear.
4. Enter a **Name** for the new article.
5. In the **Category** dropdown, choose the category’s position.
6. Click **Create** to add the article.

To create an article using the **Create** button in a **Folder/Index** type category:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Click the desired **Folder/Index** type category.
3. Click **Create** dropdown (on the right side of the category page) and select **Article**.

   The **Create new article** panel will appear.
4. Enter a **Name** for the new article.
5. In the **Category** dropdown, choose the category’s position.
6. Click **Create** to add the article.

![Creating a new article in the Markdown editor with title and category fields.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Creating_a_new_article_panel.png)

---

## Creating article templates

In Document360, you can create, save, and reuse any article as a template for future articles. When you create a new article using a template, it automatically imports all predefined properties and formatting, saving you time and ensuring consistency across your knowledge base.

Imagine you're managing a knowledge base for a software product with a standard troubleshooting format. Instead of recreating the same structure every time, you can use a saved template to maintain consistency and reduce effort, allowing you to focus on customizing the content.

You can create an article from the template using three methods:

1. Method 1: Using the **Flywheel** () icon
2. Method 2: Using the **More** () option
3. Method 3: Using the **Create** button on the top bar

![Instructions for creating articles in the Document360 workspace interface.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Article_from_template_methods.png)

Method 1

Method 2

Method 3

Use the **Flywheel** () icon in the **Categories & Articles** section to quickly create an article from a template:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Hover over just below the desired article in the **Categories & Articles** section and click the **Flywheel** () icon.
3. Select **Article from template**.

   The **Article from template**panel will appear.
4. Choose a template from the list, and you can preview the template content in the right-side pane.
5. Enter the intended article name and select the category for the article.
6. Click **Create** to add the article.

Use the **More** () icon in a specific category to create an article from a template:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. In the **Categories & Articles** section, go the desired category.
3. Click **More**() > **Create article** > **From template**.

   The **Article from template**panel will appear.
4. Choose a template from the list, and you can preview the template content in the right-side pane.
5. Enter the intended article name and select the category for the article.
6. Click **Create** to add the article.
7. The article's name and slug will automatically populate using the template's title.

To create an article from template using the **Create** button on the top bar:

1. Navigate to **Documentation**() in the Knowledge base portal.
2. Click the **Create** dropdown and select **Article from template**.

   The **Article from template**panel will appear.
3. Choose a template from the list, and you can preview the template content in the right-side pane.
4. Enter the intended article name and select the category for the article.
5. Click **Create** to add the article.
6. The article's name and slug will automatically populate using the template's title.

![Creating a troubleshooting guide template with fields for version, date, and author.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Article_from_template_panel.png)

> **NOTE**
>
> If you want to add, manage, or change any existing template, you can navigate to the **Templates overview** page by clicking on the **Go to manage templates** above the list of templates in the **Article from template** panel.
>
> For more information, read the article on [Templates](/help/docs/article-templates).

---

## Editing an article

Editing a published article is essential for maintaining up-to-date and accurate content in your Knowledge base. When an article is published, the following changes occur:

1. Your article will appear on your Knowledge base site for readers.
2. The article's status changes from **Draft** to **Published** in the Knowledge base portal

When you select a published article, you'll notice the editor displays only the live version, not the editing pane.

To edit the published article:

1. Navigate to the desired editor and click the **Edit** button at the top-right corner.

   The **Article status** at the top of the editor changes to **Draft**.
2. Make the necessary changes to the article content.
3. Once the changes are complete, click **Publish** to republish the updated article to your Knowledge base site.

When you publish an edited article, the updated version automatically replaces the previously published version in your Knowledge base.

![Overview of Document360 platform with highlighted knowledge management features and navigation options.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Editing_an_Article.png)

### Markdown view of a published article

If you've published an article using the Markdown editor, you can view the Markdown formatting without creating a new version of the article.

1. Navigate to any published article in the Markdown editor.
2. Click **More**() on the top right and select **View markdown**.
3. Once done, click **Close markdown**.

![Accessing the Markdown view of the published article in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_ScreenGIF-Markdown_view_of_a_published_article.gif)

---

## Locking an article

When you or another team member actively edits an article, it is automatically locked to prevent other contributors from making simultaneous changes that could lead to conflicts or content overwrites.

This feature is useful when multiple team members collaborate on a single article. Once you finish editing, you can unlock the article to allow others to make changes.

An article is unlocked when:

* There is **no activity** for **15 minutes**.
* You click the **Lock** () icon and select **Unlock**.
* You navigate to another article or page within the Knowledge base portal.

![Locking and unlocking an article in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/14_ScreenGIF-Locking_an_Article.gif)

---

## Deleting an article

There are five ways to delete an article in the Knowledge base portal:

1. Method 1: Using the **More**() icon in the **Categories & Articles**section.
2. Method 2: Using the **More** () icon in the desired article.
3. Method 3: Deleting multiple articles in the **Folder**/**Index** category.
4. Method 4: Deleting a specific article in the **Folder**/**Index** category.
5. Method 5: Deleting multiple articles in the **All articles** () section.

![Various methods are used to delete the articles in the knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_ScreenGIF-Deleting_an_article_methods.gif)

Method 1

Method 2

Method 3

Method 4

Method 5

To delete a specific article from the **Categories & Articles**section:

1. Navigate to **Documentation**() in the Knowledge base portal.
2. Hover over the desired article in the **Categories & Articles** section.
3. Click the **More** () icon and select **Delete**().
4. Click **Yes**in the **Delete confirmation** panel.

To delete an article while editing it:

1. In the desired article, click the **More** () icon and select **Delete** ().
2. Click **Yes**in the **Delete confirmation** panel.

To delete multiple articles within a specific **Folder**/**Index** category:

1. Navigate to **Documentation**() in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category.
3. Select the checkboxes for the appropriate articles.
4. Click **Delete** ().
5. Click **Yes**in the **Delete confirmation** panel.

To delete a specific article within a specific **Folder**/**Index** category:

1. Navigate to **Documentation**() in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category.
3. Hover over the desired article, click the **More** () icon and select **Delete** ().
4. Click **Yes**in the **Delete confirmation** panel.

To delete multiple articles in the **All articles** () section:

1. Navigate to **Documentation** () > **All articles** () on top of the **Categories & Articles** section.

   The **All articles** page will appear. If required, use the [**filter**](/help/docs/filter-bulk-operations) options to narrow down the articles.
2. Select the desired articles and select **Delete** ().
3. Click **Yes**in the **Delete confirmation** panel.

> NOTE
>
> For more information, read the article on [**All articles**](/help/docs/all-articles-overview-page).

---

## Hiding and Unhiding an article

In Document360, you can hide an article within the documentation editor to restrict access to team accounts only. Hidden articles are indicated by a strikethrough in the Documentation window.

For instance, if you want your sales team to access an article containing pricing details but don't want that article visible to customers, you can hide it so that it won't appear in your public documentation.

There are four ways to hide or unhide an article in the Knowledge base portal:

1. Method 1: Using the **More** () icon in the **Categories & Articles**section.
2. Method 2: Hiding/Unhiding multiple articles in the **Folder**/**Index** category.
3. Method 3: Hiding/Unhiding a specific article in the **Folder**/**Index** category.
4. Method 4: Hiding/Unhiding multiple articles in the **All articles** () section.

![Hiding and unhiding articles in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_ScreenGIF-Hiding_Unhiding_the_articles.gif)

Method 1

Method 2

Method 3

Method 4

To hide/unhide a specific article from the **Categories & Articles**section:

1. Navigate to **Documentation**() in the Knowledge base portal.
2. Hover over the desired article in the **Categories & Articles** section
3. Click the **More** () icon and select **Hide** ().

   To Unhide, click the **Unhide**() icon.

To hide/unhide multiple articles within a specific **Folder**/**Index** category:

1. Navigate to **Documentation**() in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category.
3. Select the checkboxes for the appropriate articles.
4. Click **Hide** ().

   To Unhide, click the **Unhide**() icon.

To hide/unhide a specific article within a specific **Folder**/**Index** category:

1. Navigate to **Documentation**() in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category.
3. Hover over the desired article.
4. Click the **More** () icon and select **Hide** ().

   To Unhide, click the **Unhide**() icon.

To hide multiple articles in the **All articles** () section:

1. Navigate to **Documentation** () > **All articles** () on top of the **Categories & Articles** section.

   The **All articles** page will appear. If required, use the [**filter**](/help/docs/filter-bulk-operations) options to narrow down the articles.
2. Select the desired articles and click **Hide** ().

   To Unhide, click the **Show** () icon.

> NOTE
>
> For more information, read the article on [**All articles**](/help/docs/all-articles-overview-page).

---

## Renaming an article

To rename an article, follow the steps below:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Go to the desired article and click the article name to edit it.

   Alternatively, hover over the desired article in the **Categories & Articles** section, click the **More** () icon, and select **Rename**.
3. Enter the new article name and click **Update**.

   1. If the article is in the **Published** state, a **Article details confirmation** panel will appear.
   2. Click **Yes**.

![Renaming an article in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/13_ScreenGIF-Renaming_an_Article_update.gif)

---

## Moving an article

You can move an article across workspaces. There are five ways to move an article in the Knowledge base portal:

1. Method 1: Using the **drag and drop** () icon in the **Categories & Articles**section.
2. Method 2: Using the **More** () icon in the **Categories & Articles**section**.**
3. Method 3: Moving multiple articles in the **Folder**/**Index** category.
4. Method 4: Moving a specific article in the **Folder**/**Index** category.
5. Method 5: Moving multiple articles in the **All articles** () section.

![Moving and reordering the articles in the knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_ScreenGIF-Moving_an_Article.gif)

Method 1

Method 2

Method 3

Method 4

Method 5

To move an article using the **drag and drop** () icon in the **Categories & Articles**section:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Hover over the desired category.

   The **drag and drop** () icon will appear.
3. Hold and drag the category to the appropriate location.

From the **Categories & Articles** section, you can move an article within or across workspaces:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Hover over the desired article in the left navigation pane.

   The **More** **(****)** icon will appear.
3. Click the **More** **(****)** icon and select the **Move** () icon.
4. In the **Move article** panel, perform the following:

   * **Workspace:** Select the desired workspace from the dropdown.
   * **Category:** Select an existing category from the selected workspace.
   * **Auto update referenced links:** Select this checkbox to ensure links in the article content are updated based on the destination workspace/category.
5. Click **Move**.

To move multiple articles within a specific **Folder**/**Index** category:

1. Navigate to **Documentation**() in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category.
3. Select the checkboxes for the appropriate articles.
4. Click the **Move**() icon.

   In the **Move article** panel, perform the following:

   1. **Workspace:** Select the desired workspace from the dropdown.
   2. **Category:** Select an existing category from the selected workspace.
   3. **Auto update referenced links:** Select this checkbox to ensure links in the article content are updated based on the destination workspace/category.
5. Click **Move**.

To move a specific article within a specific **Folder**/**Index** category:

1. Navigate to **Documentation**() in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category and hover over the desired article.

   The **More** () icon will appear.
3. Click the **More** () icon and Click the **Move**() icon.

   In the **Move article** panel, perform the following:

   1. **Workspace:** Select the desired workspace from the dropdown.
   2. **Category:** Select an existing category from the selected workspace.
   3. **Auto update referenced links:** Select this checkbox to ensure links in the article content are updated based on the destination workspace/category.
4. Click **Move**.

To move multiple articles in the **All articles**() section:

1. Navigate to **Documentation** () > **All articles** () on top of the **Categories & Articles** section.

   The **All articles** page will appear. If required, use the [**filter**](/help/docs/filter-bulk-operations) options to narrow down the articles.
2. Select the desired articles and click the **Move** **to**() icon.

   In the **Move article** panel, perform the following:

   1. **Workspace:** Select the desired workspace from the dropdown.
   2. **Category:** Select an existing category from the selected workspace.
   3. **Auto update referenced links:** Select this checkbox to ensure links in the article content are updated based on the destination workspace/category.
3. Click **Move**.

> **NOTE**
>
> When moving articles, security restrictions will be applied based on the destination workspaces and categories.

---

## Replicating an article

The **Replicate** article feature allows you to display a single article across multiple categories. Replicating articles streamlines content organization and accessibility, enhancing the user experience and improving knowledge base management.

To replicate an article, follow the steps below:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. In the **Categories & Articles** section, hover over the desired article and click the **More** () icon.

   Alternatively, if the article is in a **Folder/Index** type category, navigate to the category, hover over the desired article and click the **More** () icon.
3. Select **Replicate** ().

   The **Replicate** panel will appear.
4. Choose the appropriate category and click **Replicate**.

   The article is now available in the selected location on the Knowledge base portal and as a regular article on the Knowledge base site.

> NOTE
>
> * Security restrictions will be applied based on the destination category.
> * You can only edit the source article and not the replicated article. Certain article settings are turned off in the replicated articles.

![Various methods of replicating articles in the KNowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/11_Screenshot-Replicating_an_article.png)

---

## Cloning an article

Clone articles are exact copies of the content created as new articles. You can clone articles within or across workspaces.

There are two methods to clone an article in the Knowledge base portal:

1. Method 1: Using the **More** () icon in the **Categories & Articles**section.
2. Method 2: Cloning a specific article within a **Folder/Index** category.

![Various methods of cloning articles in the KNowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/12_Screenshot-Cloning_an_Article.png)

Method 1

Method 2

From the **Categories & Articles**section, you can clone an article within or across workspaces:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Hover over the desired article in the left navigation pane.

   The **More** () icon will appear.
3. Click the **More** () icon and select the **Clone**() icon.
4. In the **Clone article** panel, perform the following:

   1. **Name**: Enter the name for the cloning article.
   2. **Workspace:** Select the desired workspace from the dropdown. Click **Reset** to assign it under the main workspace.
   3. **Category:** Select an existing category from the selected workspace.
   4. **Auto update referenced links:** Select this checkbox to ensure links in the article content are updated based on the destination workspace/category.
5. Click **Clone**.

To move a specific article within a specific **Folder**/**Index** category:

1. Navigate to **Documentation**() in the Knowledge base portal.
2. Go to the desired **Folder**/**Index** category.
3. Hover over the desired article.
4. Click the **More** () icon and select the **Clone** () icon.
5. In the **Clone article** panel, perform the following:

   1. **Name**: Enter the name for the cloning article.
   2. **Workspace:** Select the desired workspace from the dropdown. Click **Reset** to assign it under the main workspace.
   3. **Category:** Select an existing category from the selected workspace.
   4. **Auto update referenced links:** Select this checkbox to ensure links in the article content are updated based on the destination workspace/category.
6. Click **Clone**.

> **NOTE**
>
> When moving articles, the **Security restrictions** will be applied based on the destination workspaces and categories.

---

## Troubleshooting

### **Article limit reached**

**Error:** `documentation.categoriesAndArticles.maxArticlesCountReached` and `documentation.categoriesAndArticles.articleLimitExceedsPerCategory`

These errors occurs when the article limit for a **category** or **project** has been exceeded. It commonly happens in the following scenarios:

* Creating a **large number of articles** within a category or project that exceeds the allowed limit.
* **Bulk importing** a significant number of articles into a category.
* Adding a **page type subcategory** within another category.

**Steps to resolve**

1. Check if the error occurs across **all categories** in your workspace.
2. In Document360, the maximum number of articles per category and per project depends on your plan:

   **Category limits**

   * Professional, Business, and Enterprise plans: Up to **100 articles per category**.

   **Project Limits**

   * Professional & Business plans: Up to **5,000 articles per workspace**.
   * Enterprise plan: Up to **10,000 articles per workspace**.
3. If your workspace has exceeded these limits, reduce the number of articles in a category or upgrade your plan if needed.

If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

![Overview of document categories and articles with highlighted error message that indicates the article creation limit is reached.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1739518144665.png)

---

### FAQs

#### What is the character limit for article titles?

The character limit for article titles is 150 characters, including spaces. Special characters like $, %, \*, {, }, ", <, and > are not allowed.

#### What are the best practices for creating an article title and URL slug?

When creating an article title, remember that the URL slug is derived from the title. Document360 automatically separates words with hyphens and removes special characters/punctuation in the slug. Further updates to the URL slug can be made later.

#### How can I identify the published status of an article?

The published status of an article is indicated by a colored dot next to the article name:

* Light blue dot: A new article which is not yet published.
* Light green dot: The article is published.

#### Do I need to save my content frequently?

No, Document360 automatically saves your content every 5 seconds. You can also save manually using **Ctrl+S** (Windows) or **Cmd+S** (Mac).

#### What should I do if I cannot access an article or see recent updates?

If you’re having trouble accessing an article or viewing recent updates, try the following steps:

* Refresh the page.
* Ensure the article title or link is correct.
* Clear your browser cache and cookies, then try again.
* If the article was recently published or updated, allow a few moments for the changes to reflect.

If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

#### What happens after I create a new article from a template?

Your article will be added to the respective category/subcategory with a New article status indicator (light-blue dot).

#### What happens after an article is published?

After an article is published, it will appear in your Knowledge base site for readers, and its status will be updated from Draft to Published in the Knowledge base portal.

#### How can I edit a published article?

To edit a published article, click the **Edit** button at the top-right of the editor. This will change the article status back to Draft, allowing you to make changes.

#### What happens when I publish an edited article?

When you publish an edited article, the edited version replaces the previously published version in your Knowledge base.

#### Is the 'Edit article' option available for all readers in the Knowledge base site?

No, the 'Edit article' option is only available for logged-in team accounts on the Knowledge base site.

#### What happens when an article is locked because a user is editing it, and how can it be released?

In Document360, when a user begins editing an article, the article is locked, preventing others from making changes. This lock is automatically released 15 minutes after the user stops editing, at which point the article becomes available for other users to edit.

If you need to unlock it before that time, the user editing the article can manually click **Unlock** () icon at the top of the article, near the preview.

#### Can I move articles from one project to another?

The inbuilt move functionality to move articles from one project to another is currently unavailable.  As a workaround, when transferring multiple articles, use the export feature to save the articles along with all media files from the original project, then import them into the new project. Alternatively, you can manually copy and paste content from articles in one project to another. As a best practice, upload images from the original article to the drive of the new project and then insert them into the new article.

#### What happens to the links and references within an article when it is moved to a new category or workspace?

When you move an article to a new category or workspace, all internal links and references within the article will be updated automatically to reflect the new location. This ensures that all links and references remain functional.

#### Are there any security restrictions when moving articles across workspaces?

Yes, security restrictions will apply based on the destination workspace and category. Ensure that you have the appropriate permissions to move articles to the target workspace and category.

#### What is a hidden article?

A hidden article will not be listed in the Knowledge base site and cannot be accessed through the direct link, but will appear in the Knowledge base portal for internal use.

#### How can I hide a single article?

To hide a single article, navigate to  **Documentation** () in the Knowledge base portal, hover over the desired article, click on the **More** () icon, and select **Hide**.

#### Can I hide multiple articles at once?

Yes, you can hide multiple articles at once by navigating to the **All articles** () section in **Documentation** (), selecting the desired articles, and clicking the **Hide** option at the top of the pane.

#### Will hidden articles appear in search results?

No, hidden articles are excluded from search results.

#### How can I hide an article from the Knowledge base site while still allowing access via its URL?

To hide an article while maintaining access through its URL, follow these steps:

1. Navigate to Settings () > **Knowledge base site** > **Customize site**.
2. Click on **Custom CSS & JavaScript**.
3. Paste the following code in the JavaScript tab:

```
$(document).ready(function() {
    $('a[href="SLUG NAME"]').parent().css({"display": "none"});
    $('a[href="SLUG NAME"]').parent().css({"display": "none"});
});
```

JavaScript

Copy

4. Click **Save**.

#### How do I restore my deleted articles?

You can restore your deleted articles from the **Recycle bin**. The deleted articles will remain in the Recycle bin for 30 days. For more information, read the article on [Recycle bin](/help/docs/recycle-bin-recent-and-starred-files).

#### Why doesn't the article name change reflect on the Knowledge base site?

* If the article is in **Draft** status, the change in the article name doesn't reflect immediately on the site. The article name change will only be reflected after publishing it.
* If the article is in **Published** status, the change in the article name will reflect immediately on the Knowledge base site.

#### Can I clone and replicate articles across different workspaces?

You can clone articles within or across workspaces. However, replication is limited to the same workspace.

#### What happens if I delete the source article of a replicated article?

If the source article is deleted, the replicated articles will also be removed from their respective categories.

#### Is there a limit to the number of times an article can be replicated or cloned?

Document360 does not limit the number of times you can replicate or clone articles, allowing flexibility in content management.

#### Why am I getting 404 errors when trying to access articles other than the homepage or the first article? How do I resolve it?

This issue typically occurs due to incorrect slug configuration or folder name changes in the subfolder hosting page. Follow these steps to resolve the issue:

1. Verify article slugs: Ensure the slugs for your articles are correctly configured. For example, the first article might load using the slug /docs, but other articles may require a different slug, such as /help. In such cases, make sure all the slugs are consistent.
2. Check subfolder settings: Navigate to the subfolder hosting page and confirm if the `/docs` folder has been renamed or altered. If it has been renamed, update it back to `docs` to maintain consistency.
3. Test access: After correcting the folder name, try accessing the articles again to confirm the issue is resolved.
4. Clear cache and perform hard refresh:

   a. Right-click anywhere on the page and select Inspect to open the developer tools menu.

   b. Right-click the browser's reload button and choose Hard reload or Empty cache and Hard reload.

If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

 Provide the following details:

* Screenshots or video recordings of the subfolder hosting page.
* Information about any recent changes to your website or system settings.
* An exported CSV file from the article redirect rule feature.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The public-facing website where end-users can access articles and find answers to their questions.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="article-import-from-word-files"></a>

## Word .docx files

**Plans supporting the import of articles from Word**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Importing article content directly from Word files can significantly streamline the process of building your knowledge base. Document360 supports importing .docx files, allowing you to effortlessly transfer your pre-written content into your knowledge base.

> NOTE
>
> Document360 supports only Word files with the **.docx** extension. Ensure your file size is **under 15MB**. Other file formats are not supported.

---

## Importing Word files

### Import as a single article

To import a .docx Word file as a Document360 article,

1. Log in to the **Knowledge base portal** and select your desired project.
2. Select the **Documentation** tab from the left navigation sidebar.
3. Navigate to the desired category in the **Categories & Articles** pane.
4. Click the **More ()** icon next to the category name.
5. Select **Add article** > **Import ().** The **Import** window will appear.
6. **Drag and drop** the .docx source document or click **Upload a file** to import it from your local storage. By default, the **Single article** tab will be selected in the **Import** window.
7. Click **Replace** if you want to select a different .docx source document.

Document360 automatically populates the **Article name** and **Category** fields based on the filename of the source document and the category you selected in step 3. You can edit both fields if needed.

> NOTE
>
> If the article name is manually updated during the Word import process, the change will not be captured in the Team auditing.

7. Select the location where your media files should be saved from the **Drive location** dropdown menu.
8. Click **Import**. A success message will appear once the article has been imported.
9. Click **Done** to close the Import window and view the imported article in the editor.

> NOTE
>
> * Images in the Word document will be uploaded as individual files in the selected Drive folder.
> * Document360 retains all external hyperlinks in the imported article.

![Importing the word document as a single article](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Importing_a_single_article.gif)

---

### Importing a Word file as multiple articles

To import a .docx Word file as a Document360 article,

1. Log in to the **Knowledge base portal** and select your desired project.
2. Select the **Documentation** tab from the left navigation sidebar.
3. Navigate to the desired category in the **Categories & Articles** pane.
4. Click the **More ()** icon next to the category name.
5. Select **Add article** > **Import ().** The **Import** window will appear.
6. **Drag and drop** the .docx source document or click **Upload a file** to import it from your local storage.
7. Click **Replace** if you want to select a different .docx source document.
8. Select the **Multiple articles** tab in the Import window.
9. Select the location where your media files should be saved from the **Drive location** dropdown menu.
10. Select the desired heading levels (e.g., H1, H2) in the field labeled **"Which heading levels create a new article?"** for splitting the document into articles. By default, **H1** is selected and cannot be removed. For example:

    * If only H1 is selected, a new article is created at the start of each H1.
    * If both H1 and H2 are selected, a new article is created at each H1, and H2 headings within an H1 section will also create separate articles. This is helpful when your document has multiple subsections that you want to organize as individual articles for better clarity and navigation.
11. Click **Proceed** to process the document based on the selected heading levels.

After processing, a list of articles will appear, with the heading text from the .docx file serving as the article name for each generated article. The **Category** fields are also auto populated based on the category you selected in step 3. You can select a different category from the dropdown menu.

When you hover over an article in the article list, the **Merge**, **Preview**, and **Delete** options are displayed.

* Click the **Merge** option to merge a sub-heading article with its parent article. This will combine the sub-heading article (e.g., created from H2) into the parent article (e.g., created from H1).
* Click the **Preview** option to view the content of the article.
* Click the **Delete** option to delete the article.

11. Once you are done reviewing the articles, click **Import** to finish importing the articles to your knowledge base. A success message will confirm that the articles have been imported.
12. Click Done to close the Import window. The imported articles will now appear in the selected category.

> NOTE
>
> * Images in the Word document will be uploaded as individual files in the selected Drive folder.
> * Document360 retains all external hyperlinks in the imported article.

![Importing a document as multiple articles](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Importing_multiple_article.gif)

---

## Determining editors while importing .docx files

When importing articles from Word files, the editor used will be based on your selection in the Knowledge base portal settings. Follow these steps to check or change your editor selection:

1. Navigate to **Settings** > **Knowledge base portal** > **General** > **Editor**.
2. Select the editor to determine how articles are imported:

   1. Choose Markdown or WYSIWYG editors to import Word files using the WYSIWYG editor.
   2. Choose the Advanced WYSIWYG editor to import Word files using the Advanced WYSIWYG editor.

---

### FAQs

**What is the best practice for managing large documents in the Advanced WYSIWYG editor?**

As a best practice, split large documents into multiple articles for better performance and easier management. For instance, if you are importing content from a Word file, you can use the [**Import Word File into Multiple Articles**](/help/docs/article-import-from-word-files) feature for a more efficient workflow.

**What is the maximum file size for .docx files that can be imported?**

The .docx file size should be less than 15MB. If your Word file exceeds this limit, you will get an error saying, ‘*File size can’t be larger than 15 MB*’ and you will need to split the file into smaller parts before attempting to import the file again.

**Can I import multiple .docx files at once?**

You can import only one .docx at a time. However, during the upload, you can choose to import it as either a single article or multiple articles.

**Is it possible to import Word files using the Markdown editor?**

No, importing Word files (.docx) is not supported in the Markdown editor.

**Why am I facing an error while importing a Word document into Document360?**

There are several reasons for errors when importing Word documents into Document360:

1. **Missing or empty headers in the Table of Contents (TOC)**

If your document contains missing or empty headers in the TOC section, this can cause an error saying “*An item with the same key has already been added*” during the import process. To resolve this, remove any empty or missing headers from the TOC and then try importing the file again. Once corrected, the import should work as expected.

2. **Firewall blocking the upload**

Another potential issue could be related to your network firewall. If your firewall is blocking the upload, you might receive an object error. In such cases, ensuring that the Word document upload is allowed in your firewall settings should resolve the issue.

3. **Password-protected or restricted files**

Word files that are password-protected or restricted to specific users cannot be imported. Ensure the file is accessible to everyone.

4. **Conflicting styles between Microsoft Word and Google Docs**

If a Word file was created in Microsoft Word and later modified in Google Docs, changes to the heading styles in Google Docs can result in duplicate or conflicting styles. This occurs because Microsoft Word and Google Docs handle styles differently, leading to mismatched style tags. To resolve this:

a. After uploading the Word document to Google Docs, apply the default Google Docs styles to the document.  
b. This will reset all styles to Google Docs' default settings, removing any duplicated or conflicting styles.

If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

**Why do I see the error “You have reached the maximum number of articles you can have in a project”?**

This error occurs when the number of articles in your project exceeds the allowed limit. If you are importing a Word file, Document360 uses heading tags to divide the file into multiple articles. For example, if the Word file generates 10 articles, but the target category has a soft limit that allows fewer than 10 articles, this error may occur. As a solution,

1. Review the heading tags in your Word file to understand how the content is structured and split into articles.
2. Adjust the heading structure in the Word file to reduce the number of articles generated during the import.

If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

<a id="publishing-an-article"></a>

## Publishing an article

**Plans supporting for publishing an articles**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Once you have drafted and reviewed an article, the final step in the content creation process is publishing the article. Publishing an article is crucial as it makes the information available to your end-users.

## Publishing from the editor

The following steps outline the process of publishing an article directly from the editor within Document360:

1. Click **Publish** at the top right of the editor.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1717940422587.png)

2. You can add an optional comment for internal purposes in the **Publish confirmation** dialog box.
3. Click the **Configure article settings** dropdown to expand the Publish confirmation dialog box.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Configure_article_settings.png)
4. Once you configure the article settings, click **Yes** to publish the article.

### Configure article settings

#### Tags

Add **tags** to enhance the discoverability of your article.

* Ask **Eddy AI** to generate tags based on your article content.
* Select existing tags from the dropdown menu.
* Manually input a tag.

  ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Configure_article_settings_tags.png)

#### SEO description

You can add an SEO description to boost your content’s visibility on search engines.

* Ask **Eddy AI** to generate an SEO description based on your article content.
* Manually add an SEO description.

  ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Configure_article_settings_seo_description.png)

#### Related articles

Add Related articles to keep your readers engaged with related content, encouraging them to spend more time on your site.

* Ask **Eddy AI** to suggest related articles based on your article content, and the existing articles in your knowledge base.
* Manually search for specific articles and add them as related articles.

  ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Configure_article_settings_related_articles.png)

#### Status indicator

Add a Status indicator to your article to help users quickly identify new or updated content.

* **New Article**: A green circle displayed next to the article name in the left navigation pane indicates that the entire article is newly added.
* **Updated Article**: A yellow circle displayed next to the article name in the left navigation pane indicates that an existing article has been recently modified or updated with new or revised information.
* **Custom:** You can be set by the Team account manually.

  ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Configure_article_settings_status_indicator.png)

> NOTE
>
> * You can automatically update status indicators for new and updated articles by toggling on **Automatically set article status** from **Settings** () > **Knowledge base site** > **Article settings & SEO.**

## Publishing articles in bulk

You can publish more than one article at the same time in Document360. Follow the below steps to publish articles in bulk:

1. Navigate to **Documentation** () > **All articles** () in the knowledge base portal.
2. Select the checkbox next to the articles you want to publish.
3. Click  **Publish** from the available bulk actions.

   ![Document360 interface showing article management with options to publish and edit articles.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/screenshot-Bulk_publish_in_all_Articles.png)

> TIP
>
> To ensure you only select unpublished articles, you can use the  **Filter** option from the top right corner.

> NOTE
>
> You can bulk publish articles within specific categories as well.

---

### FAQs

#### **Why is the Ask Eddy AI button disabled when I try to add tags?**

The **Ask Eddy AI** functionality for tag suggestions requires a minimum article length of **50 words**. This threshold ensures sufficient content for accurate tag generation based on the article's subject matter.

#### **Why is the Ask Eddy AI button disabled when I try to add an SEO description?**

For SEO description generation, the **Ask Eddy AI** feature requires a minimum article length of **200 words.** This requirement allows for a comprehensive analysis of the content to produce an effective SEO description.

#### **Why is the Ask Eddy AI button disabled when I try to add related articles?**

The **Ask Eddy AI** function for suggesting related articles requires a minimum of **200 words** in the article. This word count threshold facilitates a thorough content analysis for identifying relevant related articles.

#### **Why can't I see the “ Publish” option when attempting to publish multiple articles at once?**

When you are selecting the articles you wish to publish, ensure that you are not selecting any already published articles.

#### **If an article is hidden, will it be ignored by Google search?**

Yes, if an article is hidden, it will be ignored by Google Search. Hidden articles are not indexed and therefore not visible in search results.

#### **If an article is published, you have Knowledge base access, but it is restricted for you for a particular article, will it be ignored?**

Yes, if an article is published and you have KB access but are restricted from viewing a particular article, it will be ignored.

#### **I published an article, but I can't see it on the Knowledge base site. What should I do?**

If your published article is not visible on the Knowledge base site, check the following:

1. Ensure the article is not set to [hidden](/help/docs/hiding-article) in the Knowledge base portal.
2. Verify if any [restrictions](/help/docs/article-access-control-knowledge-base-site) have been applied to the article.
3. Check for any [redirection rule](/help/docs/article-redirect-rules) associated with the article and clear them if needed.
4. Confirm that the selected [workspace](/help/docs/workspaces) is set to Public.

<a id="reviewing-an-article-inline-comments"></a>

## Reviewing an article using Inline comments

**Plans supporting discussion/inline comments**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Efficient collaboration and feedback are crucial for maintaining high-quality documentation. With Document360’s inline comment feature, reviewing and refining articles becomes a seamless process.

> NOTE
>
> You can use the **Inline comments** feature only in the Advanced WYSIWYG editor.

---

## Adding inline comments to an article

1. Navigate to the desired article within the Knowledge base portal.
2. Ensure that the article is in **Advanced WYSIWYG editor**.
3. Select the desired text by clicking and dragging the cursor over it.   
   A bubble menu appears.
4. Click the **Comment** (  ) icon, to open the comment box.

![1. Adding inline comments to an article](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1.%20Adding%20inline%20comments%20to%20an%20article.png)

5. Inside the comment box,

   1. You can enter the desired comments.
   2. Using **@** symbol you can mention another Team account in your project.
   3. Basic text formatting options such as bold and lists are available.   
      Comments are visually indicated by a yellow highlight.

6. Once done, click **send** (  ) or press **Ctrl + Enter** to create an inline comment.
7. If you wish to cancel, click on any other area of the article, or press **ESC.**

> **NOTE**
>
> Once the article is published, all unresolved comments will be automatically deleted.

![2.Managing-comments](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2.Managing-comments.png)

---

### Enabling comment notification

1. Navigate to Settings () > **Knowledge base portal** > **Notifications** in the Knowledge base portal.
2. Select the **Notification mapping** tab and scroll to the bottom to find the **All comments notification** toggle.
3. Turn on the **All comments notification** toggle.

All contributors to the article will receive email notifications when inline comments are added once the comment notification toggle is turned on.

![Portal-Screenshot-Enhanced_Comment_notification_system](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-All_comments_notification_toggle.png)

---

## Managing comments

* **View comment**: Click the yellow highlighted area or the comment icon next to the article settings to view the comment.
* **Resolve comment**: If a comment has been addressed, a Team account can mark it as resolved by clicking the (  ) icon.

  > NOTE
  >
  > Inline comments can only be resolved by the team account that created them. Other team accounts do not have the ability to resolve these comments.
* **Edit or Delete comment**: You can edit or delete your comments by selecting the **More** (•••) icon at the top of the comment box. Note that these actions are only available for comments that you have added.
* **Reply to comment**: Team accounts can respond to the comments from other Team accounts in the **Write a reply** field.

![Inline comments](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/_Screenshot-Managing_contents_in_inline_comments.png)

In the discussion section, you can filter comments by:

* **All comments:** Displays all comments, including mentioned and resolved, except deleted ones.
* **Mentioned me:** Shows only comments where you are mentioned.
* **Open**: Displays all comments that are not resolved.
* **Resolved:** Shows only resolved comments.

![Inline comments](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/_Screenshot-Managing_contents_in_inline_commentsfrom_discussion.png)

---

### FAQ (s)

**How many replies can I add to an inline comment?**

You can reply up to 20 times to an inline comment.

**What is the maximum number of inline comments I can add to an article version?**

You can add up to 500 inline comments per article version.

**Is there a character limit for the inline comment text box?**

Yes, the inline comment text box has a character limit of 500 characters.

A powerful Document360 editor with rich text editing and Markdown support, offering a visual, flexible experience compared to the Markdown and basic WYSIWYG editors.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="adding-images-to-articles"></a>

## Adding images to articles

**Plans supporting the addition of images to articles**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Adding images to your articles enhances comprehension and engagement. Visual aids clarify complex procedures and illustrate desired outcomes more effectively than text alone. Images simplify instructions, making them easier to follow and understand. They enhance the user experience and contribute to the overall effectiveness of the documentation.

There are several methods for inserting images into your articles using the Markdown editor or the Advanced WYSIWYG editor. Each method offers its own set of advantages and allows for customization to suit your preferences.

---

## Inserting an image in the Markdown editor

You can insert images in your documentation with the Markdown editor in four methods:

Method 1: Insert image from Upload/URL

Method 2: Insert image from file picker

Method 3: Insert image using Insert file ()

Method 4: Insert image by drag and drop

Method 1

Method 2

Method 3

Method 4

#### Using upload

To insert an image:

1. Navigate to the desired article in the Markdown editor.
2. Click the Insert image () icon and select **From Upload/URL**.
3. In the **File** tab, click the **Choose File** button.
4. Select the image file you want from your local storage and click **Open**.
5. In the **Description** field, type in a description for the image.
6. Click **OK**.

   The image will be inserted into the article where the cursor is placed.

> NOTE
>
> The **height** and **width** of the imagewill not be set by default `{height="" width=""}`.

7. If required, you can specify the pixel (px) dimensions for displaying your image in the documentation.

> **For example**, {height="720" width="1280"}.

You can see the size of the image in the documentation in the Preview window.

![Adding images in the Markdown and Advanced WYSIWYG editors](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_New_Screenshot-Insert_image_from_Upload_URL.gif)

#### From URL

To insert an image using an URL:

1. Navigate to the desired article in the Markdown editor.
2. Click the Insert image () icon and select **From Upload/URL**.
3. In the **URL** tab, enter the desired **Image URL**.
4. In the **Description** field, type in a description for the image.
5. Click **OK**.   
   The image will be inserted into the article where the cursor is placed.

> NOTE
>
> The **height** and **width** of the imagewill not be set by default `{height="" width=""}`.

5. If required, you can specify the pixel (px) dimensions for displaying your image in the documentation.

> **For example**, {height="720" width="1280"}.

You can see the size of the image in the documentation in the Preview window.

![Adding images in the Markdown and Advanced WYSIWYG editors](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_New_Screenshot-Insert_image_from_URL.gif)

> NOTE
>
> We recommend adding images to the Document360 Drive and then inserting them into articles. When you upload using the image URL, If the image is removed or renamed in the future, it will appear broken in the Knowledge base sites.

To insert an image from the file picker:

1. Navigate to the desired article in the Markdown editor.
2. Click the Insert image () icon and select **From file picker**.

   The [Drive](/help/docs/drive-getting-started) window will appear with only image format files.

> NOTE
>
> You can insert any number of images in one go. The multiple image selection is available only on Markdown and Advanced WYSIWYG editors.

4. Navigate to the desired folder where the image you wish to upload is available.
5. Select the desired image(s) and click **Insert**.  
   The image will be inserted into the article where the cursor is placed.
6. If required, you can specify the pixel (px) dimensions for displaying your image in the documentation.

> **For example**, {height="720" width="1280"}.

You can see the size of the image in the documentation in the Preview window.

![Adding images in the Markdown and Advanced WYSIWYG editors](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_New_Screenshot-Insert_the_image_from_the_file_picker.gif)

To insert an image using the Insert file ():

1. Navigate to the desired article in the Markdown editor.
2. Click the Insert file ().

   The [Drive](/help/docs/drive-getting-started) panel will appear.
3. Navigate to the desired folder where the image you wish to upload is available.
4. Select the image and click **Insert**.  
   The image will be inserted into the article where the cursor is placed.

> NOTE
>
> The **height** and **width** of the imagewill not be set by default `{height="" width=""}`.

5. If required, you can specify the pixel (px) dimensions for displaying your image in the documentation.

> **For example**, {height="720" width="1280"}.

You can see the size of the image in the documentation in the Preview window.

![Adding images in the Markdown and Advanced WYSIWYG editors](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_New_Screenshot-Insert_an_image_using_the_Insert_file.gif)

You can add an image to the editor by dragging it from your local system to your editor.

The images you insert in an article through drag and drop will be saved automatically in the Document360 Drive. Any changes made to your local file will not affect the inserted image.

---

## Inserting an image in the Advanced WYSIWYG editor

You can insert images in your documentation with the Advanced WYSIWYG editor in the following methods.

1. Using the **Slash** command or **Insert** menu
2. Using copy and paste or drag and drop

Method 1

Method 2

To insert an image using the **Slash** command or **Insert** menu:

1. Navigate to the desired article in the Advanced WYSIWYG editor.
2. You can use the **slash menu** `/image` to insert the **Image**

   Alternatively, click the **Insert menu** () and select **Image**.
3. Select **Image**,and a panel will appear with following options:

   * **Upload from my device**: Click to upload or drag and drop the image file from your device's local storage.
   * **Choose from Drive**: Opens the file picker, and you can choose any image format available in your Document360 Drive.
   * **External URL**: Paste the URL of the image in the field.
4. Click **Insert**, and the image is added to the article.

You can perform a copy/paste operation for the image or click, drag, and drop an image from your device's local storage inside the article.

The images you insert in an article through drag and drop will be saved automatically in the Document360 Drive. Any changes made to your local file will not affect the inserted image.

> NOTE
>
> You can format images in the Advanced WYSIWYG editor. For more information, read the article on [Image formatting in the advanced WYSIWYG editor](/help/docs/image-formatting-in-the-advanced-wysiwyg-editor).

---

## **Troubleshooting**

### Broken image in the Knowledge base site

A broken image is an image that fails to load on a webpage, displaying a missing image icon and its alt text instead. This typically happens when the image file is deleted, moved, renamed, or the URL pointing to the image is incorrect or inaccessible.

**Steps to resolve:**

1. Retrieve the image URL from the article’s **code view** in the Knowledge base portal or by inspecting the element in the Knowledge base site.
2. Open the image URL in a browser.
3. If it results in a **404 error**, the image may have been deleted, moved, or renamed.
4. Ensure the image file still exists at the same path and with the same name.
5. As a best practice:

   1. Upload images directly to the Document360 Drive instead of using external URLs.
   2. Adding images from Document360 Drive helps organize assets efficiently and prevents broken images in the future.

![Document360 Knowledge base site appearing with a broken image](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-broken_image_troubleshooting.png)

---

### FAQs

#### Can I change the alignment of an image in Markdown?

Yes, you can change the image alignment in Markdown.

> NOTE
>
> For more information, read the article on [How to align the image in Markdown?](/help/docs/how-to-align-the-image-in-markdown)

#### What is the recommended method for inserting images into articles?

The recommended method is to upload images to the Document360 Drive and insert them directly into articles. This ensures image stability and prevents broken image links if the image is removed or renamed in the future.

#### Can I customize the appearance of the inserted images?

Yes, you can customize the alignment, size, and style of inserted images to suit your preferences and optimize the visual presentation within your articles.

#### How can I ensure accessibility for visually impaired users when adding images?

You can provide alternative text (alt text) for each image, which helps screen-reading tools describe images to visually impaired users and improves search engine optimization (SEO) for your Knowledge base.

#### How can I add icons in line with text?

To add icons in the markdown editor, simply paste the HTML code snippet of the icon wherever you want it to appear in your text. For example, use `<nor class="fa-light fa-comment"></nor>` for a comment icon.

If you are using the advanced WYSIWYG editor, place the cursor where you want the icon, switch to code view, and paste the same HTML code snippet. After pasting, save the file and switch back to the regular view. You should now see the icon in line with your text. You can find these icon snippets on websites like FontAwesome.

#### Will images copied from any external source that are pasted into Document360 be permanently stored? If yes, what happens when the external source is deleted?

If images from any external source are copied and pasted into Document360, they will be stored in the Document360 Drive. However, it is recommended to upload images directly from the Drive rather than pasting them to ensure they are not linked to any external sources.

If the images point to any external source as their original location is deleted, the images will be broken in Document360.

A lightweight text-to-HTML conversion tool used to format content such as lists, headers, images, videos, and links. Document360 includes a powerful markdown editor as one of its two basic editors.

A powerful Document360 editor with rich text editing and Markdown support, offering a visual, flexible experience compared to the Markdown and basic WYSIWYG editors.

<a id="adding-videos-in-articles"></a>

## Adding videos in articles

**Plans supporting the addition of videos in articles**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Videos can explain complex concepts better than text alone. They make it easier for users to understand instructions, tutorials, and detailed processes. Videos capture attention and keep users engaged longer than plain text. In Document360, by using **Insert video** and **Insert file** options in the toolbar you can add videos to the article and category pages.

---

## Insert a video in the Markdown editor

Two methods exist to insert a video in your article or category page.

1. **Insert video**: To insert a video by URL.
2. **Insert file**: To insert a video available in the Drive.

#### Insert video

1. Navigate to the desired article in the Markdown editor.
2. Click the **Insert video** () icon.

   The **Insert video** panel appears.
3. Paste the video URL (YouTube, Wistia, and Vimeo) in the first text field.
4. Give an alternative text for the video in the **Alt Text** field.
5. Click **OK**.

![Adding videos in the markdown via video option](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Inserting_video_in_Markdown_.gif)

---

#### Insert file

Navigate to the desired article in the Markdown editor.

1. Click the **Insert file** () icon.
2. Select the desired video from the Drive and click **Insert**.
3. Update the desired pixel height and width.

> NOTE
>
> Similarly, you can add videos to the WYSIWYG editor.

![Inserting videos via file option](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Inserting_the_file_in_markdown_.gif)

---

## Insert a video in Advanced WYSIWYG editor

1. From the Advanced WYSIWYG editor, navigate to **Insert** () > **Video**.
2. The **Insert Video** panel has three options or methods to insert a video:

   1. **Embed URL**:

      * Enter video URL: Self-hosted video URL from platforms such as Wistia, YouTube, Vimeo, and more. Update the desired pixel height and width in the editor.
      * Enter embed URL: The URL available on Video hosting platforms.
   2. **Embed code**: The embed code snippet is available with the video on specific platforms such as Wistia, YouTube, Vimeo, and more.
   3. **Drive**: Choose the desired video from the drive.
3. Click "**Insert video**".

> NOTE
>
> You can also use Slash commands `/video` to insert videos in the Advanced WYSIWYG editor.

![Inserting videos in Advanced WYSIWYG editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-adding_videos_in_advanced_WYSWYG_Editor.gif)

---

### FAQ(s)

**Can the search function in Document360 search captions within videos?**

No, video captions will not be fetched in the search results.

**Can Document360 detect broken videos in the articles?**

Document360's link analytics feature can identify broken links. This feature validates your project's links, including media files, videos, and images.

> For more information, please refer to the article on [Link Status](/help/docs/links-status).

A centralized, cloud-based storage repository in Document360 for storing and managing all files.

<a id="adding-files-to-articles"></a>

## Adding files to article

**Plans supporting the use of Drive**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Supporting files can clarify and expand on the article’s content, making complex topics easier to understand. In Document360, there are two ways to add files in the articles and category pages:

1. Adding files
2. Attaching files

## Adding files to articles

Adding a file to an article means embedding it directly into the body of the article, rather than as an attachment for download. To do this, the file must first be uploaded to the [Drive](/help/docs/drive-getting-started).

### Adding files in Markdown editor

1. Navigate to the desired article in the Markdown editor.
2. Select the **Insert file** () icon.
3. Choose the file from the Drive that you wish to add.
4. Click **Insert**.

> NOTE
>
> In the **Drive**, you can filter () files by:
>
> * **Uploaded:** Filter by All, 7 days, 30 days, 3 months,  1 year, or even a custom date.
> * **Uploaded by:** Select the desired contributors from the list.
> * **Type:** Choose the file type, such as PDF, JPEG, etc.
> * **Tags:** Sort files based on the tags.

![1_ScreenGIF-Update_Adding_files_in_article](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Update_Adding_files_in_article.gif)

### Adding files in the Advanced WYSIWYG editor

1. Navigate to the desired article in the Advanced WYSIWYG editor.
2. To insert file, use slash command `/Insert file` or go to **Insert > Insert file**.

   The Insert file panel will appear in the editor.
3. You can insert the file in three ways:

   1. Drag and drop the file into the panel.
   2. Click on the **Click here to upload** text and select the desired file from your local storage.
   3. Click **Open file picker** and choose a file from the drive.
4. Click on the **Delete** () icon to remove the insert file panel if needed.

> NOTE
>
> After adding file in the article, click **Download** () to download the file in the Knowledge base site.

![Adding files to an article in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Adding_files_in_Adv_WYSIWYG_editor.png)

---

## Attaching files to articles

Attaching a file to an article allows it to appear as a downloadable link rather than embedding it directly into the article body. In the Knowledge base site, attached files are aligned above the tags and Table of Contents on the right side of the page.

1. From the desired article, click on **More** (•••) icon on the top right side.
2. Click on the **More article options**.
3. In the **Attachments** section, attach your file in one of two ways:

   * **URL**: Enter the URL and click **Insert**.
   * **Upload an attachment:** Choose your desired file and click **Upload**.
4. Once done, click **Save**.

> NOTE
>
> If you attach more than one file to an article, you can arrange the display order by dragging and dropping the file names in the menu.

![Adding files to an article in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Adding_attachments_in_the_article.gif)

**Knowledge base site view**

![Adding files to an article in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-attached_file_in_an_article.png)

---

### FAQ (s)

**What is the difference between adding and attaching files?**

Adding files embeds them directly into the article body, while attached files are aligned above the tags and Table of Contents on the right side of the page.

**Can I filter files in the Drive when adding them to an article?**

Yes, you can filter files by upload date, contributor, file type, and tags.

**What should I do if my attached file is not visible in the Knowledge base site?**

If the attached file is not visible in the desired article, follow these steps to enable article files on the Knowledge base site:

1. Navigate to **Settings** () > **Knowledge base site** > **Article settings & SEO**.
2. In the **Article settings** tab, expand the **Article right** accordion.
3. Turn on the **Show article files** toggle if it is turned off.

<a id="linking-to-other-articles"></a>

## Adding hyperlinks

**Plans supporting the use of hyperlinks**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In Document360, you can add hyperlinks to text, images, or files within your articles or category pages. Hyperlinks help users navigate seamlessly between related content, external resources, or specific sections within the same article, enhancing the overall reading experience.

Imagine you're writing a installation guide for software installation. You can add a hyperlink to the download page, so users can quickly access the required software without searching for it.

> NOTE
>
> Replicated articles cannot be added as internal links within other articles.

## Adding hyperlinks to an article

Markdown editor

Advanced WYSIWYG editor

To add a hyperlink in the Markdown editor, follow these steps:

1. Select the desired text and click the **Insert link** () icon at the top of the editor.

   The **Link** panel will appear.
2. In the **Link text** field, enter the text to be hyperlinked.
3. Choose one of the following linking options:

   * **Link to an existing article**: Start typing the article name in the **Search & link to existing article** field. A list of matching articles will appear.
   * **Link to a specific heading in the current article**: Use the **Link to the current article heading** dropdown to select an H2, H3, or H4 heading. The appropriate URL slug will be generated automatically.
   * **Link to an external URL**: Enter the desired URL in the **Link** field.
4. (Optional) To open the hyperlink in a new tab, select the **Open in a new tab** checkbox.
5. Click **Ok** to add the hyperlink to your content.

![Adding hyperlink in markdown editor in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Adding_hyperlink_to_an_markdown_article.gif)

To add a hyperlink in the Advanced WYSIWYG editor, follow these steps:

1. You can access the hyperlink option in three ways:

   * Select the desired text, go to **Insert** () and click **Link**.
   * Select the desired text and press `Ctrl + K`.
   * Use the **Slash** `/`command and type `/link`.

   The **Link** panel will appear.
2. In the **Link text** field, enter the text to be hyperlinked.
3. Choose one of the following linking options:

   * **Link to an existing article**: Start typing the article name in the **Search & link to existing article** field. A list of matching articles will appear.
   * **Link to a specific heading in the current article**: Use the **Link to the current article heading** dropdown to select an H2, H3, or H4 heading. The appropriate URL slug will be generated automatically.
   * **Link to an external URL**: Enter the desired URL in the **Link** field.
4. (Optional) To open the hyperlink in a new tab, select the **Open in a new tab** checkbox.
5. Click **Insert** to add the hyperlink to your content.

![Adding hyperlink in Advanced WYSIWYG editor in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Adding_hyperlinks_to_an_Advanced_WYSIWYG_editor.gif)

---

## Editing or unlinking a hyperlink

In the **Advanced WYSIWYG editor**, follow these steps to edit or remove a hyperlink:

1. Click the hyperlinked text. A floating menu will appear.
2. To manage the hyperlink:

   * **Open the link:** Click on the link to visit the URL.
   * **Edit the link:** Click on the **Edit** () icon to modify the hyperlink.
   * **Unlink the text:** Click on the **Unlink** () icon to remove the hyperlink.
   * **Copy the link:** Click on the **Copy** () icon to copy the hyperlink.

> NOTE
>
> In Markdown editor, you need to manually edit the hyperlink.

![Editing or unlinking a hyperlink in the Advanced WYSIWYG editor.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Editing_or_unlinking_an_article.gif)

---

## Bookmark links inside articles/page categories

When dealing with long articles or category pages, Bookmark links allow you to link directly to specific headings (H2, H3, H4) within the same article.

**For example:** If an article contains multiple sections, such as "Installation," "Configuration," and "Troubleshooting," you can create bookmark links for each heading. This allows readers to jump directly to the relevant section without scrolling.

In the **Advanced WYSIWYG editor**, follow these steps to bookmark links inside articles or page categories:

1. Select the desired text and click the **Insert** () and select **Link** ().

   Alternatively, select the desired text, and press `Ctrl+K`.

   The **Link** panel will appear.
2. In the **Link to the current article heading** field, choose a heading from the dropdown list. This creates a URL slug linking directly to that section.
3. If needed, select **Open in a new tab**.
4. Click **Insert**.

> NOTE
>
> * The **H3** and **H4** headings will only be available in the dropdown if enabled in settings. To enable them, navigate to Settings () > **Knowledge base site** > **Article settings & SEO** > **Article settings** > **Article right** and ensure **H3** and **H4** are selected.
> * If you're using the **Advanced WYSIWYG editor**, you can also press `Ctrl+K` to quickly add hyperlink to the text.

![Bookmark links inside articles or page categories in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGIF-Bookmark_links_inside_articles_page_categories.gif)

---

## Adding an Email link to an article

Markdown editor

Advanced WYSIWYG editor

To add an email link to an article in Markdown editor, follow the steps below:

1. Select the text you want to link and click the **Link** () icon.
2. In the Link field, use the following Markdown format to create an email link:

   `[link_text](mailto:email_id)`

> For example, if you want to add an email hyperlink to `test@gmail.com` with the link text "Email support", type:
>
> `[Email support](mailto:test@gmail.com)`.
>
> Outcome: [Email support](mailto:test@gmail.com)

![Adding an email link to an article in the markdown editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenGIF-Adding_an_email_link_to_an_Article_in_markdown.gif)

To add an email link to an article in the Advanced WYSIWYG editor, follow the steps below:

1. Select the desired text and press `Ctrl + K` or use the **slash** command `/link`.

   The **Link panel** will appear.
2. In the **Link** field, type the desired email in this format: `(mailto:email_id)`.
3. Click **Insert**.

![Adding an email link to an article in the Advanced WYSIWYG editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_ScreenGIF-Adding_an_Email_link_to_an_Article_in_Advanced_WYSIWYG_editor.gif)

---

## Effect of changing an article heading on Hyperlinks

If you change the heading, the existing hyperlink will break.

**For example:** If you add a hyperlink to an H3 heading titled "Markdown editor" and later change the heading to "The Markdown editor," the hyperlink will break and no longer work.

**How to overcome this scenario?**

This method is applicable only in the **WYSIWYG editor**. When you directly update a heading, both the heading link and name are updated. However, to change the heading without affecting the heading link, you need to update the HTML tag for the heading ID.

Typically, an H2 heading is formatted as `<h2>Heading name</h2>`. To separate the heading link from the name, you can modify the tag as `<h2><a name="heading-link"></a>Heading name</h2>`.

> For example, you want to update the H2 heading name 'How Risk Analytics Works' to 'Risk Analytics'
>
> * Your current heading tag would be `<h2>How Risk Analytics Works</h2>`
> * Replace it with `<h2><a name="How-Risk-Analytics-Works"></a>How Risk Analytics Works</h2>`  
>    Heading link - `How-Risk-Analytics-Works`  
>    Heading name - `How Risk Analytics Works`
> * Now change the heading name to Risking analytics, and don't change the heading link  
>   `<h2><a name="How-Risk-Analytics-Works"></a>Risk Analytics</h2>`
> * If you have added a hyperlink for this heading, it will work fine even after changing the heading name. This is because the heading link is kept the same.

---

## **Effect of Machine translation on Hyperlinks**

When an article is translated, all internal hyperlinks in the original language are updated to link to the corresponding translated articles in the new/draft state.

**For example:** An article in English contains internal links to other articles. When translated to French, those links will redirect to the French versions of the linked articles.

> NOTE
>
> To avoid broken links in translated articles, ensure that article slugs are consistent across languages.

> For example, if the English article has the slug `/getting-started`, use the same slug for the translated version (e.g., `/getting-started` for German). This will help maintain link consistency. This is because when you add a redirect rule, the hyperlink URL text for English language is `docs/en/article_slug` and for German language is `docs/de/article_slug`.

---

### Types of URLs

#### Absolute path/URL

An Absolute path/URL includes the entire web address, from the protocol (HTTP/HTTPS) to the domain name and the path within the site. It is the complete address required to access a specific webpage, regardless of the site you are currently on. An absolute URL is used when linking to external websites or when you want to specify the full address of a page.

**For example**: `https://docs.document360.com/docs/v3/overview/interface`

#### Relative path/URL

A Relative path/URL is a shortened version of the URL that only specifies the location after the domain. It assumes that the link is within the same site and shares the same root domain. The relative path always starts with a forward slash (`/`). It is commonly used for internal links within the same site.

In Document360, relative paths are used in several places, such as the linking feature in the editor, article redirect rules, tag redirect rules, and the ticket deflector.

**For example**: `https://docs.document360.com/docs/v3/overview/interface`

Relative path: `/v3/overview/interface`

---

### FAQs

#### How do I link to an existing article in my Knowledge base?

Highlight the text you want to link, click on the **Link** () icon in the editor toolbar, type the article name in the search field, select the article, and click **Insert**.

#### Can I link to headings within the same article?

Yes, you can link to headings (H2, H3, H4) within the same article using the hyperlink () tool in the editor.

#### Do hyperlinks get auto-updated when I translate an article?

Yes, when you translate an article, all hyperlinks in the default language will direct to the respective translated language in the new article.

#### How can I link a new article to another article before it gets published?

You can link new unpublished articles to other articles before publishing them by following these steps:

1. Hover over the desired text in the editor and click the **Insert link** () icon.
2. In the **Search & link to existing article** dropdown, enter the name of the new article and select it.
3. If needed, check the **Open in a new tab**option to have the link open in a new tab.
4. Once finished, click **Insert**.

> NOTE
>
> Until you publish the linked new article, the link will be in a broken state.

#### Does an article heading hyperlink still work when I change the heading name?

No, hyperlinks would not work when you change the heading name. For example, if you have added a hyperlink for the H3 heading as “Markdown editor”, and later you change the H3 heading to "The Markdown editor", then the hyperlink would not work.

Visit this [link](https://docs.document360.com/docs/linking-to-other-articles#does-an-article-heading-hyperlink-still-work-when-i-change-the-heading-name) to find a workaround.

**Bookmark links**, also known as internal hyperlinks or cross-references, allow readers to navigate to specific sections within the same document or webpage. These links improve accessibility and help users quickly find relevant content.

<a id="code-blocks"></a>

## Code blocks

**Plans supporting Code blocks**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 uses [Prism.js](https://prismjs.com/) for syntax highlighting and supports various programming languages in code blocks, including:

* HTML
* C#
* Java
* JavaScript
* XML
* JSON
* CSS
* SQL
* Python
* Markdown
* PHP
* PowerShell
* Text

For an exhaustive list of languages that are supported, please refer to the documentation for [Prism's Supported languages](https://prismjs.com/#supported-languages).

---

## Creating code blocks in the Markdown editor

In the Markdown editor, there are two methods to create fenced code blocks:

1. Use **triple backticks** ````` before and after the code snippet.

For example:

```csharp  
 [your code snippet]   
 ```

2. Use the shortcut `Ctrl+Shift+P` or click the **Insert codeblock** () icon from the formatting toolbar.

![1_ScreenGIF-Creating_code_blocks_in_the_Markdown_editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Creating_code_blocks_in_the_Markdown_editor.gif)

---

## Creating code blocks in the WYSIWYG (HTML) editor

1. Navigate to the desired article in the WYSIWYG editor.
2. Click the **Code block** () icon, and a panel will appear.
3. Select your desired language from the drop down menu.
4. Enter your code into the **Insert your code** field.
5. Click **Insert** to add the code block to your article.
6. To edit a code block, click the **Edit** () icon on the right side of the code block.
7. To delete a code block, click the **Delete** () icon on the right side of the code block.

![2_ScreenGIF-Creating_code_blocks_in_WYSIWYG_HTML](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Creating_code_blocks_in_WYSIWYG_HTML.gif)

---

## Creating code blocks in the Advanced WYSIWYG editor

1. Navigate to the desired article in the Advanced WYSIWYG editor.
2. You can create code blocks in three ways:

   1. In the **Insert** section, click **Code block** ().
   2. Enter three backticks ````` and press **Enter**.
   3. Use the slash command `/code block` and press **Enter**.
3. Click on the created code block, a floating menu will appear.
4. Select the desired heading .
5. Click the Copy () icon to copy the code.
6. Click the Delete () icon to delete the code block.
7. Enter the indented code inside the code block.

![3_ScreenGIF-Creating_code_blocks_in_Advanced_WYSIWYG_editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Creating_code_blocks_in_Advanced_WYSIWYG_editor.gif)

---

#### Language shortcodes

* C: c
* C++: CPP, c++
* C#: csharp
* CSS: css
* CoffeeScript: coffeescript
* HTML: html
* JSON: json
* Java: java
* JavaScript: javascript, js
* Objective-C: objective-c, obj-c, objc
* Objective-C++: objc++
* PHP: php
* Perl: perl, pl
* Python 3: python3, py3
* Python: python, py
* Ruby: ruby, rb
* Snobol: snobol
* XML: xml

#### Custom language

If the desired language is unavailable, you can create a **Custom Language** code block.

1. **In the Markdown editor**: After inserting the code block, add a title by entering the desired text after the initial backticks:

```
```HTML
Hello world
```
```

Markdown

Copy

2. **In the WYSIWYG editor**: Select **Custom** from the **Select Language** dropdown and enter your desired title in the **Enter your title** field.
3. **In the Advanced WYSIWYG editor**: Use the search bar in the dropdown to select **Custom**, then click the **Edit** () icon to enter your title and click **Update**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/ScreenGIF-Custom_Language_in_code_block.gif)

---

### Indentation and code blocks

Any text indented by at least four spaces will be treated as a code block. This method is useful for longer code snippets, but it will not include syntax highlighting.

The following code block is created using indents instead of backticks.

```
def test():
    logging.error('Test failed')
```

Python

Copy

---

### Code block examples

The following code blocks are created in various programming languages, including C#, JavaScript, XML, JSON, PowerShell, and Ruby, to dynamically showcase syntax and functionality.

**C# block**

```
using System;
namespace HelloWorld
{
    class Hello 
    {
        static void Main() 
        {
            Console.WriteLine("Hello World!");

            // Keep the console window open in debug mode.
            Console.WriteLine("Press any key to exit.");
            Console.ReadKey();
        }
    }
}
```

C#

Copy

**Javascript block**

```
function $initHighlight(block, cls) {
try {
if (cls.search(/\bno\-highlight\b/) != -1)
return process(block, true, 0x0F) +
` class="${cls}"`;
} catch (e) {
/* handle exception */
} 
export $initHighlight;
```

JavaScript

Copy

**XML block**

```
<book id="bk101">
      <author>Gambardella, Matthew</author>
      <title>XML Developer's Guide</title>
      <genre>Computer</genre>
      <price>44.95</price>
      <publish_date>2000-10-01</publish_date>
      <description>An in-depth look at creating applications 
      with XML.</description>
   </book>
```

XML

Copy

**JSON block**

```
{
    "one": 2,
    "three": {
        "point_1": "point_2",
        "point_3": 3.4
    },
    "list": [
        "one",
        "two",
        "three"
    ]
}

```

JSON

Copy

**PowerShell block**

```
$user = Read-Host "Enter Username"
$pass = Read-Host "Enter Password" -AsSecureString
```

PowerShell

Copy

**Ruby block**

```
require 'redcarpet'
markdown = Redcarpet.new("Hello World!")
puts markdown.to_html
```

Ruby

Copy

---

### FAQs

**What programming languages are supported for syntax highlighting in code blocks?**

Document360 supports syntax highlighting for languages such as HTML, C#, Java, JavaScript, XML, JSON, CSS, SQL, Python, Markdown, PHP, PowerShell, and Text.

**How do I indent the contents in a code block having multiple lines?**

To indent, manually add spaces at the start of each line where you want indentation. If you're pasting code, use the shortcut `Ctrl + Shift + V` to preserve the formatting.

**How can I create a code block in the Markdown editor?**

You can create a code block in the Markdown editor by using triple backticks ````` before and after your code snippet or by using the shortcut `Ctrl+Shift+P`.

**Is it possible to create a custom language code block?**

Yes, select **Custom** from the language dropdown, then enter your desired title.

A lightweight text-to-HTML conversion tool used to format content such as lists, headers, images, videos, and links. Document360 includes a powerful markdown editor as one of its two basic editors.

<a id="private-notes"></a>

## Adding private notes

**Plans support private notes**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Private notes** are a useful feature in Document360 that allow project team members and specific reader groups to see content that remains hidden from the general public. These notes can be added to articles in both the [**Markdown**](/help/docs/the-markdown-editor)and [**Advanced WYSIWYG**](/help/docs/advanced-wysiwyg-editor-overview) editors, giving you more control over what content is visible to different audiences.

## Using private notes

Private notes are ideal for leaving reminders or editorial comments within your article. They are especially useful for:

* Asking a team member to double-check information.
* Keeping notes for future updates or improvements.
* Providing extra context or instructions for other project team members working on the documentation.

> NOTE
>
> When readers download an article containing a private note via the **Download as PDF** option in the Knowledge base site, the private note is **not** included. However, if the team accounts use their browser's **Print/Save as PDF** function, the private note will be included in the exported file.

---

## Private notes in the Markdown editor

To add a private note in the Markdown editor:

Click the **Private notes** icon from the toolbar.

Alternatively, use the following syntax to create a private note:

```
:::(Internal) (Private notes)
Only visible to team accounts
:::
```

Markdown

Copy

![4-Screenshot-Markdown_editor_private_notes](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4-Screenshot-Markdown_editor_private_notes.png)

You can edit both the title (Private notes) and content (Only visible to team accounts) of the private note. You can remove a private note by deleting the corresponding syntax. This will remove the note from both the article and the preview pane. Private notes added in this format will not be visible on the public version of your article but can be accessed by team members.

### Delete private note

To remove a Private notes from the article or category page, delete the corresponding syntax from the editor.

---

## Private note in the WYSIWYG editor

1. Navigate to the desired article in the WYSIWYG editor.
2. Click the **Private note** icon from the toolbar.
3. Click on the private note, and a floating menu will appear with the following options:

   1. [Visibility settings](/help/docs/private-notes#visibility-settings) ()
   2. **Copy** () - Click to copy the private note.
   3. **Delete** () - Click to delete the private note.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-Private_note_in_Advanced_WYSIWYG_editor.png)

---

## Private note in the Advanced WYSIWYG editor

1. Navigate to the desired article in the Advanced WYSIWYG editor.
2. Use the slash comment `/Private note` or go to **Insert** () > **Private notes.**
3. Click on the private note, and a floating menu will appear with the following options:

   1. [Visibility settings](/help/docs/private-notes#visibility-settings) ()
   2. Copy () icon - Click on the Copy () icon to copy the private note.
   3. Delete () icon - Click on the delete () icon to delete the private note.

> NOTE
>
> Private notes cannot be deleted from a **published** article or category page. You must first **Edit** the article first to remove the note.

#### Visibility settings

Click on the **Visibility Settings** () icon. A popup window will appear with three options:

* **All team account:** This is the default setting when adding a private note. By default, the toggle is turned on, and the private note appears to all team members added to the project.
* **Security groups**: Click the dropdown arrow to view and select the intended team account groups available in the project. Only these groups can view the private note.
* **Reader groups**: This option applies only in **Private** and **Mixed** mode Knowledge Bases. Click the dropdown arrow to view and select the intended reader groups available in the project.

> NOTE
>
> Selective visibility settings for private notes are only available in the WYSIWYG and Advanced WYSIWYG editors.

![_ScreenGIF-Updated_Private_note_in_Advanced_WYSIWYG](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/_ScreenGIF-Updated_Private_note_in_Advanced_WYSIWYG.gif)

---

### FAQs

**What are private notes in Document360?**

Private notes are a feature that allows project team members and specific reader groups to see content that remains hidden from the general public.

**Can I add private notes in both Markdown and WYSIWYG editors?**

Yes, private notes can be added to articles in both the Markdown and Advanced WYSIWYG editors.

**How can I delete a private note?**

To delete a private note, you need to remove the corresponding syntax in the Markdown editor or use the delete option in the WYSIWYG or Advanced WYSIWYG editors.

**Can private notes be visible to all team members?**

Yes, by default, private notes are visible to all team members added to the project, but you can adjust visibility settings.

**What visibility settings are available for private notes?**

In WYSIWYG and Advanced WYSIWYG editors, the visibility settings include options for all team accounts, specific security groups, and reader groups in Private and Mixed mode Knowledge Bases.

**Is it possible to edit private notes after they are created?**

Yes, you can edit both the title and content of the private note after it has been created.

**Do private notes appear in the public version of the article?**

No, private notes are not visible in the public version of the article.

**Can I use private notes for reminders or editorial comments?**

Yes, private notes are ideal for leaving reminders or editorial comments within your article.

Text elements within an article that are visible only to project team accounts and specific reader groups. These notes do not appear in public articles and can be added using either editor in Document360.

<a id="embedding-microsoft-streams-video-in-articles"></a>

## Embedding Stream videos in articles

**Plan supporting embedding stream videos in articles**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You can insert both Microsoft sharePoint stream and the latest stream videos into a Document360 article. These videos can be embedded in both the Markdown and Advanced WYSIWYG editors.

---

## Embedding SharePoint Stream videos

1. Navigate to the [Streams](https://www.office.com/launch/stream) platform.
2. Select the video you wish to embed in your article.
3. Click on **Share** at the top-right of the video page, then select **Embed code**.
4. An embed panel will appear with additional parameters:

   * Choose the **Start from** timestamp (e.g., 01:23).
   * Choose the **Player size** (e.g., 640x360, 1280x720, etc.).
   * Optionally, select the following settings:

     + **Autoplay**
     + **Responsive**
     + **Show title**
5. Click **Copy embed code**.

> NOTE
>
> Ensure you manage the access permissions for the Stream video you embed in the article. Without proper permissions, the readers won't be able to view it. For more information, refer to the Microsoft Stream [support article](https://support.microsoft.com/en-us/topic/permissions-in-microsoft-stream-0b646420-0868-494f-8921-d7f3e5f9cced#) on permissions.

![Embedding stream videos in the article](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Embedding_sharepoint_stream_videos.gif)

---

## Embedding Microsoft Stream videos in article

#### Markdown editor

1. Navigate to the desired article in the Knowledge base portal.
2. Paste the embedded video code in the indented location within the article.

![Embedding stream videos in the article](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Embedding_videos_in_Markdown.png)

---

#### Advanced WYSIWYG editor

You can embed videos in two ways using the Advanced WYSIWYG editor:

**Method 1:**

1. While editing the article, click on the **Code View** () icon.
2. Paste the embed code in the desired location.
3. Press **Ctrl + S** to save the changes.

**Method 2:**

1. Using the slash menu `/Video` or go to **Insert** () > **Video**.

   The **Insert video** panel will appear.
2. In the **Embed code** tab, paste the copied embed code.
3. Click **Save**.

![Embedding stream videos in the article](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Microsoft_stream_videos_in_Advanced_WYSIWYG_editor.gif)

---

#### Knowledge base site view

![4_Screenshot of Knowledge base site view Embedding videos](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Knowledge_base_site_view_Embedding_videos.png)

---

### FAQs

**Can I embed Stream videos on external pages?**

Yes, you can use the **Embed Code** option on the video page. This option uses the `iframe` tag to add an inline video.

**How does embed code snippet look like?**

```
<iframe src="<Stream video URL>" width="640" height="360" frameborder="0" scrolling="no" allowfullscreen title="<Video_file_name>"></iframe>
```

Plain text

Copy

<a id="embedding-google-forms-in-article"></a>

## Embedding Google forms in articles

**Plans supporting Embedding google forms in articles**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You can embed **Google forms** inside your Knowledge base article using the Embed HTML code block.

## Embedding Google forms

1. Go to the [**Google forms**](https://docs.google.com/forms/u/0/) page and login with your Google account.
2. You can create a new form or choose from any existing one.
3. Select the form you want to embed in your article.
4. Click the **Send** button at the top.

   The **Send form** panel will appear.
5. Select the **<>** tab to get the **Embed HTML** code.
6. Click **Copy** to copy the **iframe src** link.
7. Head back to your desired article in the Knowledge base portal.
8. In the **Markdown** editor, paste the iframe src link directly into the article.
9. In the **Advanced WYSIWYG** editor, click the **Code view** () icon and paste the iframe src link.
10. The form will appear in your article.

After publishing, readers can interact with the form for data entry, surveys, feedback, or any other purpose.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Embedded_form_in_Advanced_WYSIWYG_editor.gif)

**Knowledge base site view**

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Embedded_form_Knowledge_base_site.png)

---

### FAQs

**How can I embed a Google form in my Knowledge base article?**

You can embed a Google form by using the Embed HTML code block in your article.

**What steps are involved in embedding a Google form?**

The steps include creating or selecting a form, copying the Embed HTML code, and pasting it into your article.

**Can readers interact with the embedded Google form after publishing?**

Yes, readers can interact with the form for data entry, surveys, feedback, or other purposes.

<a id="embedding-a-drawio-diagram"></a>

## Embedding a Draw.io diagram

**Plans supporting Embedding a Draw.io diagram**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Diagrams.net** (commonly referred to as Draw.io) is a web-based open-source tool for creating diagrams that enables users to design flowcharts, UML diagrams, entity relationships, network diagrams, mock-ups, and more.

> NOTE
>
> All mentions of Diagrams.net or Draw.io in this support article refer to the same tool.

Diagrams.net uses Google Drive to store finished diagrams. You can embed Diagrams.net images into Document360 by using HTML and an autogenerated link, which you can find in the Diagrams.net app.

> NOTE
>
> Diagrams stored on Google Drive, Dropbox, etc., are private by default. When embedding a diagram in an article, ensure that the privacy settings for that diagram are set to public.

---

## Embedding a Draw.io diagram

There are two methods to embed Draw.io (Diagrams.net) diagrams into your Document360 editors:

1. Using the embed option
2. Exporting as an image

#### Method 1: Using the embed option

1. Navigate to [Diagrams.net](https://www.drawio.com/).
2. Click **File** > **Embed** and choose **Image.**
3. Click **Embed.**
4. Click **Copy** to copy the generated image tag.
5. Head back to the Knowledge base portal.
6. In the **Markdown** editor, directly paste the copied code.
7. In the **Advanced WYSIWYG editor**, click the Code view () icon and paste the code in the desired location.

> NOTE
>
> You can adjust the height and width of the diagram as needed.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Using_the_embed_option_Draw_io.gif)

---

#### Method 2: Exporting as an image

1. Navigate to [Diagrams.net](https://www.drawio.com/).
2. Click **File** > **Export as** and choose your desired image format**.**
3. Click **Export.**
4. Enter the **File name** and save it to your desired location (**Google Drive**, **OneDrive**, **Dropbox**, **GitHub**, **GitLab**, or your **Device**).
5. Click **Download**.
6. Head back to the article in the Document360 editor.
7. Click **Insert image** () and select **From Upload/URL**.
8. Select the intended image and click **Insert**.

> NOTE
>
> For more information, read the article on [adding images to articles](/help/docs/adding-images-to-articles).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Embedding_Draw_io_via_image_Export.png)

---

### FAQs

**Can I embed a Draw.io diagram in Document360?**

Yes, you can embed Draw.io diagrams into Document360 articles using HTML and an autogenerated link from the Diagrams.net app.

<a id="all-articles-overview-page"></a>

## All articles - Overview page

**Plans supporting bulk operations on all articles**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **All articles** feature in Document360 simplifies article management by enabling users to perform bulk actions on multiple articles at once. Now, in addition to individual articles, this feature also displays page categories, allowing for a more comprehensive view and streamlined management. Available actions include publishing, previewing, copying links, hiding, moving, deleting, setting review reminders, checking live article status, creating tags, machine translation, downloading as PDF, and deprecating articles.

The **All articles** feature provides a solution to this challenge, enabling users to efficiently execute actions across multiple articles in one go.

For instance, imagine you're publishing ten articles and two page categories from various categories for a product launch. With the All articles feature, you can publish them simultaneously as part of your release documentation. In such a scenario, select the desired articles and page categories on the **All articles** page and execute a bulk publishing action.

> NOTE
>
> The **All articles** feature displays all articles, including page categories.

---

## Managing multiple articles with the All articles feature

To manage multiple articles and page categories with the **All articles** feature, follow the steps below:

1. Navigate to **Documentation** () > **All articles** () on top of the **Categories & Articles** section.  
    The **All articles** page will appear.
2. Navigate to your project's different workspaces and languages using the drop-down at the top.
3. Click the **All articles** dropdown to filter articles by status.
4. Click **Export** to export the article list as a CSV file.
5. Click the **Filter** button, and from the dropdown menu, select options like Status, Date, or Tags to narrow your results. For more information, read the article on [Using filter in All articles page](/help/docs/filter-bulk-operations).
6. Select the desired articles you wish to perform the following bulk operation actions:

1. **Publish**: Publish multiple selected articles in one go. This option will appear only if you have selected new or draft articles.
2. **Publish later:** Schedule the selected articles to be published at a specified time. This option is enabled only if you have selected new or draft articles.
3. **View preview/View in KB**: **View preview** option will appear to preview the article for new and draft articles in the Knowledge base site. For published articles, by selecting **View in KB**, you can open them in the Knowledge base site.
4. **Copy link:** Copy the link for the selected articles.
5. **Hide**: Hide the selected articles so they are no longer available on the Knowledge base site.
6. **Move** to: Move the selected articles to different categories or workspaces.
7. **Delete**: Delete the selected articles. They will be sent to the recycle bin for 30 days, during which time they can be restored if needed.
8. **Review reminder**: Set a review reminder for the selected articles.
9. **Live article status**: Define the status for the selected articles.
10. **Add tags**: Create and assign new or existing tags to the selected articles.
11. **Add labels:** Create and assign new or existing labels to the selected articles.
12. **Machine translate**: Automatically translate selected articles into other languages with the Machine Translate feature.
13. **Download as PDF**: Download the selected articles as a PDF. If multiple articles are selected, they will be combined into one PDF in the chosen order.
14. **Deprecate**: Mark the selected articles as deprecated. These articles will display a Deprecated status tag in the Knowledge base site.

> NOTE
>
> In the **All articles** feature, if a page category contains both articles and subcategories, you cannot perform actions such as Hide, Move, or Delete on that page category. However, if the page category has no sub-articles, the Hide, Delete, and Move options will be applicable.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-All_articles_Overview_page(1).png)

---

### FAQs

**Can I publish multiple articles at once?**

Yes, to publish multiple articles simultaneously using the All articles feature, navigate to the **All articles** page, select the desired articles and page categories, and then select **Publish**. This feature eliminates the need to publish each article individually.

**Can I hide multiple articles at once?**

With the All articles feature, you can easily hide several articles at once. Select the articles you want to hide and use the **Hide** option to make them inaccessible to readers. The hidden articles are visible to team accounts in the portal and can be unhidden anytime.

**How does the All articles feature enhance article management efficiency?**

The All articles feature enhances efficiency by allowing bulk actions such as deletion, status change, and more on multiple articles simultaneously. This streamlines tasks, saving time and effort compared to performing these actions individually.

**Can I reuse custom filters to narrow down results?**

Yes, the All articles feature in Document360 is designed to adapt to your needs. It offers a versatile approach, allowing you to set up custom filters and reuse them in the future.

**How do I change the status of all published articles to draft in a bulk operation?**

No, you cannot change the status of published articles to draft as a bulk operation on the **All articles** page. However, you can manually navigate to each article and change its status to draft individually.

<a id="filter-bulk-operations"></a>

## Using filters in All articles page

**Plans supporting bulk operations on all articles**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## Accessing 'All articles' filters

To manage filters in the **All articles** feature, follow the steps below:

1. Navigate to **Documentation** () > **All articles** () on top of the **Categories & Articles** section.  
    The **All articles** page will appear.
2. Navigate to your project's different workspaces and languages using the drop-down at the top.
3. Click the **All articles** dropdown to filter articles by status.
4. Use the basic filters or custom filters to narrow down the results.
5. The filters applied can be viewed at the top of the window, and they include the following:

   1. Status
   2. Review reminder
   3. Starred
   4. Visibility
   5. Read receipt
   6. Contributor
   7. Category
   8. Date
   9. Tags
   10. Labels

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-FIlters_in_All_Articles.png)

#### **a. Status**

* **All**: All articles, irrespective of the status.
* **Published**: Articles with **Published status**.
* **Scheduled**: Articles that are scheduled for publishing.
* **Draft**: Articles with **Draft status**.
* **New article**: Articles with **New article** status.
* **Broken links**: Articles that have broken links based on the recent [Link validation](/help/docs/links-status).
* **Deprecated**: Articles marked as **Deprecated** in the Knowledge base site.

#### b. Review reminder

* **All**: All articles, irrespective of the review status.
* **Fresh**: Articles without the **Needs review** status.
* **Stale**: Articles with the **Needs review** status.

#### c. Starred

* **All**: All articles, irrespective of the starred status.
* **Starred**: Articles with **Starred status**.
* **Not starred**: Articles without **Starred status**.

#### d. Visibility

* **All** - All the articles, irrespective of visibility status.
* **Visible** - All articles in the selected workspace/language except for hidden articles.
* **Hidden** - Hidden articles are marked with a strikethrough, meaning they are not visible on the Knowledge base site but still exist in your project.

#### **e. Read receipt**

* **All**: All articles, irrespective of read receipt status.
* **Enabled**: Articles with **Read receipt** enabled.
* **Disabled**: Articles with **Read receipt** disabled.

> NOTE
>
> Read receipt feature is available only for **Private** and **Mixed** projects in **KB site 2.0**. For more information, read the article on [Read receipt](/help/docs/read-receipt).

#### f. Contributor

You can search for individual contributors using the search bar and select one or more contributors from the list. The contributors are all Team accounts in the project. The default selection is **All**.

#### g. Category

You can filter articles based on their category or subcategory (visible when you expand the root-level category). You can choose one or more categories using this filter.

> NOTE
>
> Selecting a category will show only articles under that category. To select articles under a subcategory, pick them manually.

#### h. Date

You can filter articles based on their last **Updated date**. All articles in **Published**, **New**, **Draft**, and **Deprecated** status will appear.  
You can select from the preset time intervals or add custom dates. Once you choose the date, the specified time period (For example, `Jun 28, 2022` to `Jun 28, 2023`) will appear next to the selection.

* **All**
* **7 days**
* **30 days**
* **3 months**
* **1 year**
* **Custom date**

#### i. Tags

You can search for individual tags using the search bar and select one or more tags from the list. The default selection is **All tags** and **None** (articles with no tag association).

#### j. Labels

You can search for individual labels using the search bar and select one or more labels from the list. The default selection is **All labels** and **None** (articles with no label association).

---

### Custom filter

You can save a custom filter in **All articles** that you can reuse.

> **For example,** you can create a custom filter for your documentation team members with a specific date range and status indicator.

Saved custom filters can be accessed using the expand arrow to the right of the **Filter** button.

#### Saving a custom filter

1. Navigate to the Documentation () section in the Knowledge base portal.
2. Click **All articles** at the top-left of the page.  
   The **All articles** page will appear.
3. Click the **filters** dropdown, choose the desired filter, and click **Apply**.

   The applied filters are visible at the top of the list.
4. Click **Save filter**.
5. The **Save filter** panel will appear.
6. Type the intended **Filter name** (up to 30 characters).
7. Turn on the **Share filter with team members** toggle if you want the filter to be available to other team accounts. (If the toggle is not enabled, the custom filter can only be used by you).
8. Once done, click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Saving_a_Custom_filter.png)

#### Deleting a custom filter

1. Click the expand arrow () icon near the **Filter** button.
2. Hover over the desired custom filter and click **Delete** () icon.
3. Click **Yes** in the confirmation prompt.

> NOTE
>
> Once a custom filter is saved, you cannot edit it. After deleting a custom filter, you cannot revert back.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Deleting_a_custom_filter(1).png)

---

## Clear filters

You can clear the applied filter in three ways:

1. Click **Clear all** on the top of the window.
2. Navigate to the **Filter** dropdown and click **Clear**.
3. To remove an individual filter, click the **X** next to the applied filter visible above the articles list section.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Clear_filters_in_All_articles_page.png)

---

### FAQs

#### What filters can I apply to narrow down the articles?

In All articles section, you can apply filters such as Status, Review reminder, Starred, Visibility, Read receipt, Contributor, Category, Date, and Tags.

#### Can I save a custom filter for future use?

Yes, you can save a custom filter in **All articles** that you can reuse later.

#### What should I do if I want to clear all applied filters?

You can clear all applied filters by clicking **Clear all** at the top of the window or using the Filter dropdown.

#### Why is the Read receipt feature not available in my project?

The Read receipt feature is available only for **Private** and **Mixed** projects in KB site 2.0.

<a id="export-bulk-operations"></a>

## Export All articles list

**Plans supporting bulk operations on all articles**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In Document360, you can export the list of articles and their status as a .csv (comma-separated values) file. You can filter the desired fields from the extracted CSV file and export the report.

> For example, you might want to export the published articles of a specific contributor from the last month.

---

## Exporting All articles

To export a complete list of all articles in your knowledge base,

1. Navigate to **Documentation** () > **All articles** () on top of the **Categories & Articles** section.  
    The **All articles** page will appear.
2. Navigate to your project's different workspaces and languages using the drop-down at the top.
3. Click the **All articles** dropdown to filter articles by status.
4. Choose the desired filters from the **Filter** () button.

   The following filter options are available:

   * **Status**
   * **Review reminder**
   * **Starred**
   * **Visibility**
   * **Contributor**
   * **Category**
   * **Date**
   * **Tags**
   * **Labels**
5. Once done, click **Apply**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-FIlters_in_All_Articles.png)

3. Click the **Export** ()button next to the filter.

   This action downloads the generated file to your device’s local storage in .csv format.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Export_All_articles_list.png)

The exported file consists of the following details:

* **Article title**
* **Category title**
* **Article status**
* **Date**
* **Portal URLs**
* **Site URLs**

> NOTE
>
> The downloaded file can be viewed with Microsoft Excel, Open Office, Google Sheets, Notepad, or any CSV-compatible application.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Export_articles.png)

---

### FAQ

#### **How do I retrieve both articles and their URLs from my project?**

You can use our [API endpoint to get all article lists](https://apidocs.document360.com/apidocs/project-version-articles) article to get the article title and their corresponding URLs.

To retrieve this information:

1. Enter the required details in the API request.
2. Execute the query.

The Project Version ID needed for the query can be found using the [Get Project Versions endpoint](https://apidocs.document360.com/apidocs/get-project-versions) article.

#### How can I export draft articles?

You cannot export draft articles individually. However, you can export the category containing the draft articles. To do this, follow these steps:

1. Navigate to **Documentation** () > **All articles** () on top of the **Categories & Articles** section.  
    The **All articles** page will appear.
2. Click the **All articles** dropdown to filter articles by status. Select **Draft** status.
3. Choose the **Category** filter from the **Filter** () button.
4. Select the category that includes the draft articles you want to export.
5. Click **Export** to export the entire category to access the draft articles in it.

<a id="review-reminders"></a>

## Article review reminder

**Plans supporting article review reminder**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Review reminders** help team accounts deliver the most accurate information to customers and internal teams by alerting project members when an article is ready for review. This helps keep your articles up to date.

---

## Review reminder

Create and apply review reminders to flag an article for review immediately or set the review reminder to trigger on a specified date. You can also apply a review reminder individually or to a group of articles. When an article needs review, a red badge (article status indicator) will appear on the left of each article title in the documentation editor.

### Creating a review reminder for an article from the Documentation editor

1. Navigate to the desired article in the Knowledge base portal.
2. Click on the More (•••) icon in the top right corner and select **More article options**.

   The **Article settings** pane will appear.
3. The **Review reminder** tab will be selected by default.
4. Select a date for the reminder to trigger. Options include, Now, 30 days, 3 months, and Custom date.
5. Enter a reason for the review. Ensure it is descriptive enough to provide context for the team member reviewing the article. This field is **optional**.

   > NOTE
   >
   > In the **Reason for review** field, you can enter up to 100 characters.
6. Click **Save**.

A **Needs review** tag will appear next to the article slug in the Documentation editor. When team members hover over the **Needs review** tag, they can view the reason for the review.

![ Creating a review reminder for an article from the Documentation editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Review_reminder_in_more_options.png)

### Clearing a review reminder

Once an article in need of review has been edited and updated, follow these steps to clear the review reminder state:

1. Navigate to the desired article and click the **Needs review** tag at the top of the article editor.
2. Click **Mark as reviewed**.

The **Needs review** tag will be removed, and the article status indicator will revert to the updated/draft/new status.

![Clearing a review reminder in documentation editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-clearing_review_reminder.gif)

---

## Marking multiple articles as Reviewed or Needs review

You can mark multiple articles as Reviewed or Needs review using two methods:

### **All articles**

1. Navigate to the Documentation () and click on **All articles** tab.
2. In the **Filter** () option, expand the **Review reminder** dropdown and select **Stale**.
3. Select the articles you want to mark as reviewed.
4. Click the **Mark as Reviewed** option at the top
5. Similarly, to mark multiple articles as **Needs review**, select the desired articles, click **Review reminder**, and choose the intended reminder days.

![Article review reminders in all articles section](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Marking_multiple_articles_in_all_articles.gif)

---

### **Article review reminders in content tools**

1. Navigate to Documentation () > **Content tools** > **Documentation** > **Article review reminders**.

   The **Article review reminders** page will appear with a list of reminders you have already created.
2. Click **Create review reminder.**

   The **Create reminder** pane will appear.
3. Enter the Reminder name, set the reminder frequency, and add the desired reviewers.
4. Once done, click **Next**.
5. Select the desired **Workspace** and **Language**.
6. Select the desired articles and click **Set reminder**.

> NOTE
>
> You can apply **Filter ()** options to retrieve articles based on category, contributor, tags and date.

![Article review reminders in content tools](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGIF-Articles_review_reminder_in_content_tools.gif)

---

## FAQ(s)

**How do I set a review reminder for all articles in my project?**

To set a review reminder for specific articles or all articles in your project, navigate to Documentation () > **Content tools** > **Documentation** > **Article review reminders**.

<a id="article-seo"></a>

## Article SEO

**Plans supporting the use of article and SEO settings in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Search Engine Optimization (SEO) is crucial for ensuring your articles gain visibility and reach their target audience effectively. Add SEO title and descriptions to your article to make improve their visibility on the web and get the article indexed in web Search engines.

---

## Adding SEO title and description

1. Navigate to the desired article in the Knowledge base portal.
2. Click on the **More** (•••) icon and click **SEO.**

   The **Article settings** window will appear.
3. Go to the **SEO** tab.
4. If needed, you can select the **Exclude from external search engine results** checkbox to prevent the articles from appearing in external search engines like Google, Yahoo, Bing, and more.
5. Enter the desired [**Meta title**](/help/docs/article-seo#editing-the-meta-title).

   > NOTE
   >
   > A meta title is a concise, impactful title displayed on search engine results pages (SERPs) that summarizes a webpage’s content. For optimal visibility, it’s typically recommended that it be between 5 and 60 characters.
6. The slug is auto-generated when the article is created. If needed, you can edit the slug.
7. Enter the desired **Description**.

   A meta description is a brief summary beneath the meta title, providing a snippet of the webpage's content. It's advisable to keep it compelling, informative, and within 150-160 characters to enhance click-through rates on search results.
8. You can use the **Ask Eddy AI**, an AI SEO description generator to help you create the description.

![Excluding articles from the external search](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Excluding_articles_from_External_search_engines.png)

> NOTE
>
> To generate SEO description for multiple articles, navigate to Documentation **()** > **Content tools** > **Documentation** > **SEO description**.

---

### Editing the Meta title

The Meta title is a key HTML element that defines the title of a webpage. It plays an important role in **SEO**, helps with **search engine rankings**, and appears as the clickable title in search results and browser tabs.

To edit the Meta title, follow the below instructions:

1. Navigate to the desired article in the **Knowledge Base portal**.
2. Click on the **More (•••)** icon and select **SEO**.
3. Click on the **Meta title** field in the Article Settings panel.
4. Click **Save**.

   The updated Meta title will appear as the article title on the Knowledge base site.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Editing_Meta_title.gif)

---

### FAQs

#### If I update an SEO description for a document in English, will it automatically translate to French or any other language in which the document is available?

No, updating the SEO description for a document in one language will not automatically translate it into other languages. You will need to update the SEO descriptions in each specific language manually the document is available in to ensure accuracy and relevance.

#### Why is my AI SEO description generator disabled even though I have Eddy credits?

To use the Eddy AI for generating an SEO description, your article must have a word count of at least 200 words.

#### The article name on the Knowledge base site does not update even after renaming it in the portal. How can I change this?

To update the article name on the Knowledge base site, you will have to change the SEO’s meta title of the article.

1. Click on the More () icon and go to **SEO**.
2. Update the meta title and save the changes.

<a id="excluding-articles-from-searches"></a>

## Excluding articles from search engines

**Plans supporting the exclusion of articles from search engines**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

To manage the visibility and confidentiality of your content, you can easily exclude certain articles or category pages from search engine results using Document360. This helps in ensuring the sensitive or internal content remains private and not publicly searchable.

---

## Excluding articles from external search engines

1. Navigate to the desired article or page category you want to exclude from search results.
2. Click the **More** (•••) icon in the top right corner.
3. From the dropdown menu, choose the **SEO** option.

   The **Article settings** panel appears.
4. In the **SEO settings**, select the **Exclude from external search engine results** checkbox.
5. Click **Save** to apply the changes.

By following these steps, you can include/exclude articles from the external search results.

![Excluding articles from the external search](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Excluding_articles_from_External_search_engines.png)

---

## Excluding articles from Search results and Eddy AI assistive search

> NOTE
>
> For users on the new pricing plan, AI search suite is available for Business and Enterprise plans. For legacy (old plan) users, only customers who have purchased Eddy AI assistive search as an add-on will have **Exclude from Eddy AI assistive search** toggle.

1. Navigate to the desired article or category page in the Knowledge base portal.
2. Click the **More** (•••) icon in the top right corner of the article or category page.
3. From the dropdown menu, choose **More article options.**

   The **Article settings** panel will appear.
4. In the **Article settings** panel, go to **Search Visibility** section.
5. In the **Search visibility**, select the desired options:

   1. Click **Exclude from the knowledge base search** checkbox to excludes articles from search results within the knowledge base site.
   2. Click **Exclude from Eddy AI assistive search** checkbox to excludes articles from Eddy AI assistive search results within the knowledge base site.

> NOTE
>
> You can exclude articles from Eddy AI Assistive Search only if you have purchased the Eddy AI Suite.

6. Click **Save** to save the changes.

![Excluding articles from AI assistive search and knowledge base search](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Excluding_articles_from_Eddy_AI_assistive_and_Search_engines.png)

> NOTE
>
> The article will still be accessible via the URL or navigation menu even after configuring it to be excluded from Knowledge Base searches and Eddy AI searches.

---

### FAQs

**What happens if the article is cloned?  Will the Search visibility settings remain the same?**

If the article is cloned, the Search visibility settings will also apply to the cloned article.

**What happens to hidden articles if we select to exclude articles from search engines?**

By default, if your article is hidden, its information will not be fetched in the knowledge base search or the AI assistive search.

<a id="changing-the-url-of-an-article"></a>

## Change the URL of an article

**Plans supporting changing the URL for an article**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

By default, when you create an article, articles will convert the article title into a slug and add it to your knowledge base URL.

For example, if an article title is “*This is a really good content*,” the resulting URL would be: `docs.yourcompany.com/[project version]/docs/this-is-really-good-content`.

You can easily change the slug of the article URL inherited from the title, `.../this-is-really-good-content`.

> NOTE
>
> Changing an article’s title does not automatically change the article slug.

---

## Changing the slug of an article

You can change the slug of an article in two ways.

**Method 1**

1. Navigate to the desired article in the Knowledge base portal.
2. Click the **More**() icon in the top right corner and then choose **More article options**.
3. In the **Article settings** panel that appears, go to the **SEO** tab.
4. Update the slug in the Slug field.
5. Click **Save**.

> NOTE
>
> While changing the slug of an article, ensure that you apply the redirection rule to the new slug. For more information, read the article on [Article redirect rule](/help/docs/article-redirect-rules).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Changing_theURL_for_an_Article.png)

**Method 2**

You can also change an article URL in the editor.

1. Navigate to the desired article.
2. Click the slug field provided next to the article status badge.

![article slug 2](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/article%20slug%202.png)

3. Update the necessary changes in the field provided under **URL Slug**.
4. Click **Update** to save the changes.

![3_slugupdate_articleredirect.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_slugupdate_articleredirect.png)

5. Click **Yes** in the **Article details confirmation** prompt to redirect the article to the updated URL slug.
6. Deselect the checkbox to avoid applying the redirecting rule.

> **NOTE**
>
> **Redirect Rule:** If you change the article slug after publishing, Document360 will prompt you to set up a redirect rule to ensure that any links to the old slug remain functional. While setting up a redirect rule is optional, it is recommended.

---

### FAQs

#### What is the default URL format for an article?

The default URL format for an article is based on the article title, converted into a slug. For example, if the article title is '`This is a really good content`', the resulting URL would be: `docs.yourcompany.com/[project version]/docs/this-is-really-good-content`.

#### Does changing the article title automatically change the slug?

No, changing an article’s title does not automatically change the article slug.

#### Is it necessary to apply a redirect rule when changing the slug?

While applying a redirect rule is optional, it is recommended to ensure that any links to the old slug remain functional, avoiding broken links.

#### Why use special characters like ä, ö, ü in URLs?

Special characters like **ä**, **ö**, and **ü** are often part of words in languages such as German. When creating URLs for knowledge base articles or other web content, using these characters can make the URL:

1. **More intuitive:** The URL reflects the exact title or content of the article, making it easier for users to understand.
2. **Language-specific:** It preserves the linguistic integrity of terms or phrases specific to a language.
3. **SEO-friendly:** Search engines can associate the URL more accurately with the content, improving visibility for users searching in that language.

However, due to technical encoding requirements, these characters must be properly percent-encoded to function correctly in web links. Always copy URLs from the portal to ensure they work as expected when shared.

#### Why do URLs with special characters (e.g., ä, ö, ü) break when shared?

When URLs contain special characters like **ä**, **ö**, or **ü**, they need to be percent-encoded for proper handling in web links. If these characters are not encoded, the URLs may break when shared or accessed, resulting in errors. This behavior is consistent across all browsers and messaging tools.

1. **Copy the URL from the Document360 portal:**  
   Always copy the URL directly from the **portal** instead of from the browser's address bar. This ensures that the encoded URL remains intact when shared.
2. **Browser behavior:**

   * When you paste the URL in a browser, the percent-encoded characters may be decoded automatically.
   * This is normal behavior and does not impact the functionality if the link is used directly from the portal.

   By copying the link from the portal, the encoded characters remain intact, allowing the link to work as expected when shared with others.

If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

#### Is it possible to change the URL of articles to numbers instead of the title?

Yes, in Document360, you can change an article’s URL to use numbers instead of the title:

1. Navigate to the desired article.
2. Click the slug field provided next to the article status badge.
3. Update the necessary changes in the field provided under **URL Slug**.
4. Click **Update** to save the changes.

<a id="article-tags"></a>

## Article tags

**Plans supporting tags**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Article tags are keywords that users, readers, or team accounts might use to search for content related to the articles in the Knowledge base site. Team accounts can use these tags to search, filter, sort, and perform bulk operations on articles or category pages within the project.

> NOTE
>
> * The **Tags** page allows you to manage all tags across your project. The same tag can be applied to articles, category pages, and drive files. For more information, read the articles on [Tags](/help/docs/tags).
> * The tags added to the files in Drive can only be viewed in the Knowledge Base portal.

---

## Adding tags to an article or category page

To add tags to an article or category page, follow the steps below:

1. Navigate to the desired article in the Knowledge base portal.
2. Click the **More** () icon in the top right corner and select **Tags**.
3. Create a new tag or choose an existing one from the dropdown of relevant matches.
4. Click Ask Eddy AI to generate AI-suggested tags and select the appropriate ones.

   > NOTE
   >
   > To use the AI tag generator, your article must have a word count of at least 200 words.
5. After adding the tags, click **Save**.
6. Click **Publish** and expand the **Configure article settings** dropdown.
7. Add or delete tags as needed from the list in the **Tags** section.
8. Click **Yes** to publish the article.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Adding_tags_in_the_articles.gif)

---

### Guidelines for tags

Follow these guidelines when creating and adding tags to the **Tag** Library:

1. The tag character limit with spaces is **30**.
2. Tags names can include:

   * Upper and lowercase letters (multi-language support)
   * Numbers
   * Spaces
   * Certain special characters: **\_ + - @ # % ^ & ! ()**
3. Tags cannot contain: **\ / : \* ? “ < > |**

> NOTE
>
> For more information, read the article on [Tags](/help/docs/tags)**.**

---

### Tags in Knowledge base site

Once you add tags to an article or category page and publish it, readers will see those tags on the Knowledge base site.

![Tags readers POV.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Tags%20readers%20POV.png)

Readers can click on a tag to see a list of all articles and category pages associated with that tag.

![tags readers pov 2.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/tags%20readers%20pov%202.png)

<a id="adding-article-labels"></a>

## Add article labels

**Plans supporting the use of labels in articles**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Labels help streamline content management and organization within the Knowledge base portal. Using article labels, you can efficiently sort, filter, and categorize articles efficiently, saving time.

For instance, if you need to filter release notes specifically to perform updates or review them, use the label filter in the **All articles** () section to locate these articles quickly.

> NOTE
>
> Article labels are only available in the Knowledge base portal and are supported across all plans.

---

## Adding labels to articles

You have multiple options for adding labels to articles. The steps below outline each method available in the Knowledge base portal.

**Method 1:** Adding Labels from the article editor

**Method 2:** Adding Labels from the All articles section

**Method 3:** Adding Labels from the Workflow assignments section

**Method 4:** Adding Labels from the Starred section

**Method 5:** Adding Labels from the Folder or Index category

Method 1

Method 2

Method 3

Method 4

Method 5

To add labels to an article in the editor, follow these steps:

1. Navigate to the desired article in the Knowledge base portal.
2. Click the **More** () icon and select **Labels**.

   Alternatively, click **More** () > **More article options** and go to **Labels** tab in the **Article settings**panel.
3. In the **Add labels**panel, enter the desired label name and press **Enter**.

   Alternatively, to add an existing label, type the label name and select it from the dropdown list.
4. Click **Add**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Adding_labels_in_the_article_editor.gif)

###

To add labels in the **All articles** section, follow the steps below:

1. Navigate to **Documentation** () > **All articles** () icon on top of the **Categories & Articles** section.
2. Select the desired articles and at the top, click the **More** () icon > **Add labels**.

   The **Add labels** panel will appear.
3. Enter the desired label name and press **Enter**.

   Alternatively, to add an existing label, type the label name and select it from the dropdown list.
4. Click **Add**.
5. Use the Filter dropdown to sort articles by label:

   1. Click **Filter** and expand **Labels** section.
   2. Choose your labels or search for specific ones.
   3. Click **Show more** to view additional labels and click **Apply** to filter.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Adding_labels_in_the_All_articles_section.gif)

To add labels in the **Workflow assignments** section, follow the steps below:

1. Navigate to **Documentation** () > **Workflow assignments** () on top of the **Categories & Articles** section.
2. Select the desired articles and click **Add labels** at the top.
3. Enter the desired label name and press **Enter**.
4. Use the **Labels** filterto narrow articles based on labels.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Adding_labels_in_workflow_assignment.gif)

To add labels in the **Starred** section, follow the below steps:

1. Navigate to **Documentation** () > **Starred** () on top of the **Categories & Articles** section.
2. Select the desired articles and click **Add labels** at the top.
3. Enter the desired label name and press **Enter**.
4. To label a specific article, hover over it, click **More** (), and select **Add labels**.
5. Click **Add**.
6. Use the **Labels** filterto narrow articles based on labels.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGIF-Adding_labels_in_Starred_articles.gif)

To add labels from a Folder or Index type category, follow these steps:

1. Navigate to the desired category in the Knowledge base portal.
2. To label a specific article, hover over it, click the **More**() icon, and select **Add labels**.

   Alternatively, select multiple articles and click **Add labels** at the top.
3. Enter the desired label name and press **Enter**.
4. Click **Add**.

![Adding labels from the category in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenGIF_Adding_labels_from_category.gif)

---

### FAQs

#### How many labels can I add to a project?

You can add up to 10,000 labels per project.

#### Is there a limit on the number of labels per article?

Yes, you can add up to 10 labels per article.

#### Can I use the same label across different articles?

Yes, you can reuse labels across multiple articles within the same project.

#### What is the difference between tags and labels?

**Tags** are keywords visible on both the Knowledge base site and portal, helping users categorize articles, enhance navigation, and optimize search results.

Whereas **labels** are exclusively available in the Knowledge base portal. They are used for internal content organization and management and are not visible to end users on the site.

#### Can I search for a specific article using labels in the Knowledge base portal?

No, labels cannot be used directly in search. However, you can filter articles by labels in the **All articles** section.

#### Can I add labels to images and videos?

No, currently, labels can only be added to articles.

#### Will labels appear in the Knowledge base site?

No, labels are only for internal use within the Knowledge base portal and do not appear on the Knowledge base site.

<a id="related-articles"></a>

## Related articles

**Plans supporting addition of related articles**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Related articles help readers navigate between articles the author selects that relate to the article. The added articles appear at the bottom of the article on the Knowledge base site.

> NOTE
>
> * Only published articles can be used as related articles.
> * The related articles appear only in the Knowledge base site.
> * The related articles will not appear in the Knowledge base widget.

---

## Adding Related articles

To add related articles, from the Knowledge base portal:

1. Navigate to **Documentation** () in the Knowledge base portal.
2. Select any published or unpublished article.
3. Click the **More** () icon on the top right and click **Related articles**.
4. In the search bar enter the keyword you wish to search and the results will be displayed.
5. Click on the cross **(x)** icon to the right of the search bar to remove the search keyword.
6. Click on the add **(+)** icon to the right of the article you wish to add to the related article list.
7. All the added articles will be listed under the title **Added articles**.
8. Click the cross **(x)** icon to remove the article from the added list.
9. Once done, click **Save**.

   You can also add related articles in the Publish checklist popup.
10. Click **Publish** on any article.

    The **Publish confirmation** prompt will appear.
11. Expand the **Configure article settings** section.
12. Scroll down to view the Related articles.
13. Click **Yes** to save and publish the changes.

---

### Eddy AI recommender

1. Click **Ask Eddy** to get recommendations from the Eddy AI on adding related articles

   > NOTE
   >
   > To use the AI related article recommender, your article must have a word count of at least 50 words.
2. The suggested articles will be displayed under the title **Suggested articles from Eddy AI**.
3. Click on the add **(+)** icon to the right of the article you wish to add to the related article list.
4. The article will be added to the list of **Added articles**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Related_articles.gif)

> NOTE
>
> **AI related article recommender**
>
> After purchasing the Eddy AI add-on, click the **Ask Eddy AI** button below the search bar in the Related Articles tab to use the [AI-powered related article recommender](/help/docs/ai-related-articles-recommender).

---

### Auto relate

Turn on the **Auto relate this article to all related articles** toggle on the **Article settings** window to automatically link the active article to other related articles.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-Related_articles.png)

---

### FAQ

#### If a reader doesn't have access to an article, will it appear under the Related articles section in the Knowledge base site?

No, if a reader lacks access to a specific article, the link to that article will not appear in the **Related articles** section of any other articles in the Knowledge base site. Only articles accessible to the reader will be displayed in this section.

The public-facing website where end-users can access articles and find answers to their questions.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="featured-image"></a>

## Featured image

**Plans supporting for adding feature image**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

A featured image is a representative thumbnail commonly found at the top of content in most CMS (Content Management System) platforms. In Document360, the featured image serves a different purpose. Instead of being displayed at the top of an article, it is used mainly for SEO purposes, helping search engines and enhancing link previews when the article is shared on external platforms.

---

## Adding a featured image to an article

To add a featured image to an article:

1. Open any article (published or unpublished) in the Knowledge base portal.
2. Click the **More (•••)** icon in the top-right corner and select **More article options**.
3. In the **Article settings** panel, click the **Featured image** tab.
4. Click **Upload an image**.

   The Drive's file picker panel will appear.
5. Select the desired image and click **Save**.

> NOTE
>
> Follow these recommendations when uploading featured images:
>
> * **Image size**: Optimal dimensions range from 1200x800 pixels to 2000x1200 pixels for clarity and responsiveness across devices.
> * **Image type**: Use high-quality JPEG or PNG formats to maintain image integrity and enhance visual appeal.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Adding_Feature_Image_in_Articles.gif)

<a id="attachments"></a>

## Attachments

**Plans supporting for adding attachments**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## Adding attachments to an article

1. Navigate to any article (Published or Unpublished) in the Knowledge base portal.
2. Click on the **More** (•••) option and select **More article options**.
3. Click on the **Attachments** tab in the **Article settings** panel.
4. Add the file URL if hosted externally, or click **Upload an attachment** if the file is available in **Drive**.
5. Select the indented file and click **Insert**.
6. Rearrange the attachments using the reorder () icon.
7. Click the () icon to remove any attachment.

   The attachment will appear near the Table of Contents and Tags on the Knowledge base site.

![Adding attachments in the Knowledge base](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Adding_attachment_in_the_Knowledge_base_portal.gif)

**Knowledge base site view**

![Adding attachments in the Knowledge base](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Added_attachment_in_the_Knowledge_base_side.png)

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="status-indicator"></a>

## Status indicator

**Plans supporting status indicator**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Status indicator** is visible in the Knowledge base site near the article title. There are three possible indicators: **New**, **Updated**, and **Custom**.

---

## Automatic "Status indicator" update

If the **Automatically set article status** toggle is enabled, the status indicator automatically updates every time an article or category is published.

1. Navigate to **Settings** () > **Knowledge base site** > **Article settings & SEO** in the Knowledge base portal.

   By default, **Article settings** tab will be selected.
2. In the **Category manager** accordion, turn on the **Automatically set article status** toggle.
3. In the **Show article status for field**, enter the number of days the status should appear.

> NOTE
>
> For more information, read the article on [**Category manager**](/help/docs/knowledge-base-category-manager).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Automatic_Status_Indicator_update.png)

---

## Manually updating the "Status indicator" for an article

To manually update the status indicator for an article:

1. Navigate to your desired article (published or unpublished) in the Knowledge base portal.
2. Click the **More** (•••) icon and select **More article options**.
3. In the **Article settings** panel, select the **Status indicator** tab.
4. Choose the desired status from the drop-down.
5. In the **Show status for** field,enter the number of days the status should persist in the Knowledge base site.
6. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Manually_updating_status_indicator_in_an_Article.png)

### Setting a Custom status indicator

To customize the status indicator text:

1. Navigate to **Settings** () > **Knowledge base portal** > **Localization & Workspaces** > **Localization variables** in the Knowledge base portal[.](http://Variables.Select)
2. Expand the **Category manager** accordion and edit the **Custom** field to modify the status indicator text.
3. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Customizing_the_status_indicator_text.png)

To set the custom status indicator color:

1. Navigate to **Settings** () > **Article settings & SEO** in the Knowledge base portal.
2. By default, the **Article settings** tab will be selected.
3. In the **Category manager** accordion, choose the desired color for the **Custom status indicator.**
4. Click the  icon to save the changes.
5. Hover over the **Background color** () icon to preview the custom status indicator.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Custom_Status_Indicator_color.png)

> NOTE
>
> For more information on custom status indicator, read the article on [**Category manager**](/help/docs/knowledge-base-category-manager).

---

## Knowledge base site view

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Status_Indicator_KB_site_View.png)

* **New** (green dot): Appears when an article is published for the first time.
* **Updated** (orange dot): Appears when an article is edited and republished.
* **Custom**: Can be set manually by the team.

The public-facing website where end-users can access articles and find answers to their questions.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="article-status"></a>

## Article status

**Plans supporting Article status**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Article status helps you easily identify the current status of articles in the Knowledge base portal, eliminating the need to check each article individually.

For instance, a content manager can quickly identify **Draft** articles that need editing before publishing or spot **Needs review** articles flagged for review by contributors. This helps streamline the process of updating and maintaining the knowledge base efficiently without manually checking each article's progress.

> NOTE
>
> An article or category page will display article statuses (New/Updated/Custom) on the Knowledge base site, helping readers to know when content has been added or updated. For more information, read the article on [**Status indicator**](/help/docs/status-indicator).

---

## Article status in the Knowledge base portal

Within the Knowledge base portal, articles can have one of four statuses, each indicated by a unique color-coded icon next to the article in the left navigation pane.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-All_four_article_status.png)

> NOTE
>
> The article status also applies to category pages.

### New article (article status blue.png)

The article has been created and is in draft mode but yet to be published. It can be only accessible by team members within the portal.

> NOTE
>
> For category pages, the status appears as **New category page**.

### **Draft status (article status yellow)**

A published article is being forked to update the content in a draft form, while the original version remains live in the Knowledge base site.

### Published (article status-green)

The article is public and available for readers to view on your Knowledge base site.

### Needs review (article status pink)

The article has been flagged for review, either by a contributor or through an automated review reminder. For more information, read the article on [Article review reminder](/help/docs/review-reminders).

---

## Article status of hidden articles

Hidden articles are shown with a strikethrough and will not be available on the Knowledge base site. These articles are only accessible through the Knowledge base portal. You can hide articles in any status. For more information, read the article on [Hiding an article](/help/docs/hiding-article).

> NOTE
>
> Articles in a hidden category are also hidden on the Knowledge base site

---

### FAQs

**What is the purpose of article status in the Knowledge base portal?**

Article status helps you easily identify the current status of articles, streamlining the process of updating and maintaining the knowledge base.

**What are the different article statuses available?**

The article statuses are New, Draft, Published, and Needs review.

**What happens to articles flagged as Needs review?**

Articles flagged as Needs review have been marked for review by a contributor or through an automated reminder.

**Do category pages also display article statuses?**

Yes, the article status also applies to category pages.

<a id="preferences"></a>

## Preferences

**Plans supporting for preferences**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## Updating the preferences for an article

To update the preferences in an article from the Knowledge base portal, follow the steps given below.

1. Navigate to any article (Published or Unpublished).
2. Click the **More** (•••) icon at the top right.
3. Click on the **Preferences** tab in the **Article settings**.
4. Select or clear the checkbox next to each option to enable or disable respective preferences.

   * **Allow comments**: Allow readers to comment via Disqus.
   * **Show table of contents**: Display the table of content in your article.
   * **Enable feedback**: Allow end-users to comment on articles within a knowledge base.
5. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Preference%20tab%20overview%20page(1).png)

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="showhide-table-of-contents-for-an-article"></a>

## Show/hide table of contents for an article

**Plans supporting show/hide of content for an article**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You can choose to show or hide the table of contents at two levels. One can show or hide the table of contents for the entire knowledge base or an individual article.

#### Show or Hide the table of contents at Knowledge base site level

1. Navigate to **Settings** () > **Knowledge base site** and select **Article Settings & SEO** in the Knowledge base portal.
2. In the **Article settings** tab, you can toggle on or toggle off the **Show table of contents** under the **Article right** section.

   The changes will be saved. A confirmation pop-up will be displayed at the top right corner.

![1_TOC_artcilesettings.gif](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_TOC_artcilesettings.gif)

#### Show or Hide the table of contents for an individual article

1. Navigate to the desired article.
2. Click the **More** (•••) icon in the top right corner and then choose **More article options**.

   The **Article settings** panel will appear.
3. Click on the **Preferences** tab and select the **Show table of contents** checkbox to show the table of contents.
4. Uncheck the checkbox to hide the table of contents.
5. Click **Save**.

By following the above-mentioned steps, you can show or hide the table of contents at the Knowledge base site level or for an individual article.

![2_Article_TOC.gif](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Article_TOC.gif)

---

### FAQs

**Can I show or hide the table of contents for the entire knowledge base?**

Yes, you can toggle the table of contents visibility at the knowledge base site level.

**How do I show or hide the table of contents at the knowledge base site level?**

Navigate to **Settings** () > **Knowledge base site,** select **Article Settings & SEO**, and toggle the **Show table of contents** option.

**Is it possible to hide the table of contents for an individual article?**

Yes, you can hide the table of contents for an individual article.

**What steps do I need to follow to hide the table of contents for a specific article?**

1. Navigate to the article, click the **More** (•••) icon, select **More article options.**

   The **Article settings** panel will appear.
2. Go to the **Preferences** tab, and deselect the **Show table of contents** checkbox.
3. Click **Save**.

**Does bold text used as headings appear in the table of contents?**

No, bold texts will not appear in the table of contents. Only headings formatted as H2, H3, and H4 will appear in the table of contents.

<a id="marking-articles-as-deprecated"></a>

## Mark as deprecated

**Plans supporting mark as deprecated**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## What is a deprecated article?

In the context of a knowledge base, a deprecated article is flagged as obsolete and may no longer be relevant or valuable for the reader. It is usually replaced by more up-to-date information. Articles may be marked as deprecated for various reasons, such as the core subject being removed, no longer in use, modified, or replaced with a different concept.

For instance, if a product feature is removed or significantly changed, you can mark the related article as deprecated. This helps readers avoid outdated information and redirects them to updated resources or newer articles.

### Mark as deprecated

Previously, the **Mark as deprecated** option was available at the workspace level. Now, this feature is available at the article or page category level, where the article will display a **Deprecated** status tag. Additionally, you can provide a custom deprecation message explaining the reason for deprecation and include hyperlinks to any alternate or updated versions of the article/page if applicable.

---

## Marking an article as deprecated

1. Navigate to the article (published or unpublished) in the Knowledge base portal.
2. Click the **More** (•••) icon and select **More article options**.
3. In the **Article settings** panel, select the **Mark as deprecated** tab.
4. Turn on the **Deprecated** toggle.
5. Enter the reason for deprecating the article in the text field. This message is optional and will be displayed on the Knowledge base site.
6. Use basic text formatting options like Bold (), Italics (), and Underline (), or add Hyperlinks ()if needed.
7. Once done, click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Article_settings_deprecating_An_article.png)

---

## Marking multiple articles as deprecated

To mark multiple articles as deprecated in one instance, follow the steps below:

1. Navigate to the **Documentation** () and select **All articles** in the Knowledge base portal.

   A list of all articles will appear in the **All articles** page.
2. Select the articles you want to mark as deprecated.
3. Click the **More** (•••) icon and select **Deprecate**.

   By default, the **Deprecate** toggle will be enabled.
4. Enter the **Deprecation message** in the text field.
5. Once done, click **Apply**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Deprecating_multiple_article_at_one_go.png)

---

### Knowledge base site view

In the Knowledge base site, a deprecated article will display a **Deprecated** tag and a message at the top in a highlighted format with this icon - .

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-KB_Site_view_of_Deprecated_article.png)

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="updating-article-contributors"></a>

## Update article contributors

**Plans supporting for updating article contributors**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 automatically tracks the project members who have created, updated, or published an article and includes them in the public contributor list.

Readers in knowledge base site can click the avatars within the contributor list to view any other articles that the corresponding project member has contributed.

By default, team members who have taken any action on an article will be added as a contributor. However, project members can be manually added or deleted to the contributor list as well.

---

## Adding or deleting contributors

To update the contributor list:

1. In the desired editor, click the **Article information** () icon next to the article status on the top left to view the contributors list.

> NOTE
>
> If a project member hasn’t uploaded a profile photo, Document360 will display their default avatar.

2. Click **Manage** to open the Manage popup window. You can add and remove contributors from this window.
3. You can delete a contributor by clicking the **Remove contributor** icon provided near the contributor banner.
4. You can add a contributor by searching for a user’s name or email address in the **Add contributors** field from the popup banner.
5. Click the **Add as contributor** () icon to add a project member to the article.

![add contributor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_GIF-Add_delete_contributors.gif)

By following the above-mentioned steps, you can modify the contributors for an article.

> PRO TIP
>
> * If multiple team members collaborate on an article, manually adding contributors ensures that each person’s contribution is acknowledged.
> * If a contributor is no longer part of your team or organization, they will still appear as a contributor as long as their team account remains in the Document360 project. To completely remove them, you’ll need to delete their team account. For more information, refer to our article on [**Managing team accounts**](/help/docs/managing-team-account).

---

### Why does the ‘**This article has no listed contributor. Please assign one**.’ error occur?

This warning message appears in the article editor when no contributors are assigned to an article. During article creation, the creator is automatically assigned as a contributor. If their account is deleted, the association with the article is removed, resulting in the article appearing without any contributors.

To resolve this issue, follow these steps:

1. Open the desired article in the Knowledge base portal.
2. Click the **Article information** () icon next to the article status badge.
3. In the **Contributors** section, verify if any contributors are listed. If none are listed, this confirms the article lacks a valid contributor.
4. Click **Manage** to open the contributor management interface.
5. Search for and select the appropriate contributors. Click the **Add as contributor** () icon next to their names.

   Save the changes. Confirm the contributor's name now appears in the article's **Contributors** section, and the warning message no longer displays.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-No_contributor_error_resolving.gif)

<a id="schedule-publishing"></a>

## Schedule publishing

**Plans supporting schedule publish**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 offers enhanced content management capabilities, including scheduling your drafted articles for publication at specific dates and times. By scheduling publications, you can plan your content calendar effectively, maintain consistency, and avoid last-minute publishing stress.

---

## Setting up schedule publishing

1. Navigate to the article in the Knowledge base portal.
2. Select the dropdown next to the **Publish** button and click the **Publish later** ().

   The **Publish later** panel will appear.
3. Choose the **Date**, **Time** and **Time zone**.
4. Optionally, add comments in the **Comment field** (up to 160 characters).
5. Click **Schedule**.

> NOTE
>
> The **Schedule publishing** feature is applicable for both articles & page categories.

![1_ScreenGIF-Setting_up_schedule_publishing](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Setting_up_schedule_publishing.gif)

---

## Editing a schedule publication

1. Navigate to the desired article in the Knowledge base portal.
2. Click the **Scheduled** dropdown in the top right corner.
3. Click the **Edit** **schedule** () to perform the necessary changes in the publishing schedule.

   The **Edit schedule** panel will appear.
4. Modify the **Date**, **Time** and **Time zone**, and add comments if needed.
5. Click **Schedule** to save the changes.

![2_ScreenGIF-editing_schedule_publishing](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-editing_schedule_publishing.gif)

> NOTE
>
> To immediately publish a scheduled article, click the dropdown next to **Scheduled** and select **Publish now** ().

---

## Cancel schedule publishing

1. Navigate to the article in the Knowledge base portal.
2. Click on the **Scheduled** drop down.
3. Click on **Cancel** () to cancel the schedule publishing.
4. Click **Yes** in the confirmation prompt.

![3_Screenshot-Cancel_schedule_publishing](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Cancel_schedule_publishing.png)

---

## Schedule publishing on multiple article

To schedule multiple articles at once, follow the steps below:

1. Navigate to **Documentation** () > **All articles** in the Knowledge base portal.

   Alternatively, go to any index type category to publish its articles alone.
2. Select the desired articles and click the **Publish later** () or **Publish** () as needed.
3. Choose the **Date**, **Time** and **Time zone** in the **Publish later** panel.
4. Click **Schedule**.

Once scheduled, a **Publish later** () icon will appear next to each article. Hovering over this  icon will display the scheduled publishing date and time.

> NOTE
>
> The publishing process will be initiated at the designated time. However, there might be a delay of a few seconds in publishing the selected articles.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGIF-Schedule_publish_on_multiple_articles.gif)

---

### FAQ(s)

**How to instantly publish an article that is already scheduled for publishing?**

Go to the **Scheduled** dropdown in the top right corner of your Knowledge base portal and click **Publish** now.

**Can I edit an article once it is scheduled for publishing?**

No, an article cannot be edited after scheduling. However, you can cancel the scheduled publishing to make edits. This is similar to forking a draft, except the forked draft has not been published yet.

**Can I publish a scheduled article via the customer API?**

No, scheduled articles in the Knowledge base portal cannot be published via the customer API.

**What happens if I move a scheduled article to a different workspace? Will it remain scheduled?**

No, the scheduled publishing time will be cleared once the article is moved to another workspace.

<a id="article-discussion-feed"></a>

## Discussion feed

**Plans supporting the discussion feed**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Every Article and Category page has a Discussion feed, where you can converse, tag(mention), and collaborate with Team accounts regardless of the roles on your project. Peer reviews, approvals, and conversations can be discussed within the portal using the Discussion feed.

---

## Accessing the discussion feed

1. Navigate to the desired article in the Knowledge base portal, and click on **Discussion feed**(  ) at the top right.

> **NOTE**
>
> In Markdown and WYSIWYG editor, this section is termed as **Discussion**, and in Advanced WYSIWYG editor, it is termed as **Comments**.

1. The Discussion blade appears with the history of conversations (if any).
2. You can type your comments/messages in the text box at the bottom right and hit the **Send** icon.
3. It would be posted as a bubble in the feed with a time stamp and profile name.

> **NOTE**
>
> There is no character limit cap for the comments field.

#### Tag/mention team members in the discussion

5. By using @, you can tag any team account from your project.

6. Choose the intended team account by clicking on their profile.

![Discussion feed](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Overview_page_of_discussion_feedback.png)

> **NOTE**
>
> When you tag or mention a team account, an email notification is sent to their address. The email includes:
>
> * The name of the team account
> * The article name and link to the article
> * The language and version
> * The comment or message
> * A login button to your Knowledge base portal

---

## Delete from feed

You can delete the comment/message you've posted previously in the feed.   
Hover your mouse pointer over the message bubble, and a **Delete** () icon appears. Click on it, and the message is removed.

![Discussion feed](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Deleting_the_feedback_in_feedback_discussion.png)

> **NOTE**
>
> * Only you can delete your comment or message.
> * If you accidentally delete or need to restore a removed message, click the **Undo** option in the deleted bubble. The discussion bubble is restored in the feed.
> * Once the article is published, Discussion feed will disabled.

---

## FAQ (s)

**How can I add comments in the discussion feed, and how does it work in the Advanced WYSIWYG editor?**

You can add comments in the discussion feed using Markdown or the WYSIWYG editor. You can add inline comments in the Advanced WYSIWYG editor, which will be displayed here. For more information, read the article on [Reviewing an article using Inline comments](/help/docs/reviewing-an-article-inline-comments).

**Why is the discussion feed/comment section disabled?**

Once the article is published, you can't add comments directly (the **Discussion feed/comment** section will be disabled). However, you can click **Edit** and add comments to the discussion feed.

A written document on a specific topic in your knowledge base, serving as a unit of organized information.

An end-user with login credentials to access the Knowledge Base portal in Document360. Team accounts manage articles, categories, versions, and languages within the portal.

<a id="revision-history"></a>

## Revision history

**Plans supporting for revision history**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## Article revision

Versioning in a knowledge base ensures accurate, up-to-date content by tracking changes, supporting different product versions, and maintaining a history of edits. It helps teams collaborate, revert to previous versions if needed, and comply with audit requirements. Users can access the right information for their needs while minimizing errors and improving transparency.

In Document360, when a Team account clicks the **Edit** button on a Published article, a new unpublished version of that article is created. The old version is added to the article’s version history but remains available on the Knowledge base site until the new version is published.

![revision history](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734605317771.png)

This article versioning option allows project admins, reviewers, and contributors to compare differences between versions and revert to a previous version at any time.

> **NOTE**
>
> Creating a new article version does not delete existing content. Only a team account can manually delete older article versions.

---

## Creating an article version

There are two ways to create a new version of an article:

#### Method 1: From the Editor

To create a new article revision, follow the steps below:

1. Open a published article in the Knowledge base portal.
2. Click **Edit** on the top right of the editor.

   A new version of the article is created and opened as a draft in the text editor.
3. Update the article content.
4. Click **Publish** and click **Yes** in the confirmation prompt.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Revision_history.gif)

#### Method 2: Fork an older revision to create a new article version

To **restore** an old version of the article:

1. Navigate to the desired article in the Knowledge base portal.
2. Click the **More** () icon and select the **Revision history** ().
3. Click **Fork** on the desired version listed in the history.
4. Click **Yes** in the pop-up.

   This action will create a new version of the article with the content of the selected article version.
5. To edit the new version, click **Open** on the latest version listed in the history.
6. If required, update the article content.
7. Click **Publish** and click **Yes** in the confirmation prompt.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Revision_history.gif)

---

## Article revision actions

The below options are available in **Article revision**:

1. **Fork**: To create a new article version from an existing article version. Here, the article is opened in the Editor mode, where you can make changes to the article content.
2. **Delete****:** To delete the article version. This action cannot be reversed.

> NOTE
>
> You cannot delete a published article version. Only unpublished versions can be deleted.

3. **Open****:** To open the article version in the Editor. This helps you restore any of the previous versions to their published state.
4. **Workflow history****:** View the article version's workflow history. This includes all the Workflow stages, Workflow assignees, comments, and dates.
5. To make any previous version of an article public by opening that version in the editor and clicking **Publish**.

You can also see detailed information about each version, including the version number, contributor, created date, and version visibility.

![revision history](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Workflow_history.png)

---

## Comparing article versions

You can open two versions of an article at any point in **Article revision** and compare them.

To compare two versions of an article:

1. Go to the desired article in the Documentation editor.
2. Click the **More** () icon and select the **Revision history** ().
3. Select the checkbox for the desired versions you want to compare.
4. Click the **Compare** button.

![revision history](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Article_Version_comparision.png)

### Content highlighting criteria:

The compared view of the two versions shows the below details:

**Added content:**

* New content in the compared versions is highlighted in green for easy identification.
* For images, videos, code blocks, PDFs,  and self-closing tags (<br>, <hr>), added content is highlighted with a green badge labeled 'Added.'
* For changes made to tables, the content is highlighted in green.
* Highlights remain visible while scrolling, ensuring added content is easy to spot throughout the article.

**Removed content:**

* Deleted content is highlighted in red with a strikethrough.
* For images, videos, code blocks, PDFs, and self-closing tags (<br>, <hr>), removed content is highlighted with a red badge labeled 'Removed.'
* For changes made to tables, the removed content is highlighted in red.
* Removed content remains visible in the comparison view for clarity and to ensure removed content is easy to spot across the entire article.

**Formatting changes:**

* Changes in formatting (e.g., bold, italic, underline, font size, lists) are highlighted in blue.
* Non-text formatting changes, like table styles or image resizing, are also highlighted in blue with a blue badge labeled ‘Modified.’

> NOTE
>
> Content block movements and multiple formatting changes will not be highlighted when comparing article versions. Multi-formatting changes refer to applying italic, bold, and underline formatting to the same content block.

**Swap versions:**

* The **Swap** button is placed near the version dropdowns at the top for easy access.
* This allows you to reverse the comparison order of two versions, instantly switching the comparisons of the old and new versions.
* This helps you understand changes from both perspectives, such as seeing what was previously added and removed or vice versa.
* The comparison view updates in real time without requiring a page reload, ensuring a seamless experience.
* All existing highlights, filters, and settings are preserved when switching.
* After swapping, the version labels will update to reflect the new order, ensuring clarity on which version is being compared as the new and old.

> NOTE
>
> All highlights for added, removed, and formatting changes will be maintained after the swap. The system will update the highlights to reflect the new comparison.
>
> For example, content previously marked as "added" will appear as "removed" after swap.

**Exit version compare:**

* The **Exit compare** button is located at the top right which you can use to exit from the comparison window.
* Clicking the button will take you back to the main document view without reloading the page.
* You will return to the exact location of the article you were viewing before comparison mode to ensure workflow continuity.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenGif-Revision_history.gif)

---

### FAQs

#### **Why are the updated timeframes of the forked article not in order?**

If the older versions are opened and updated, the recently modified version will be shown with the updated timeframe accordingly.

#### **Can I restore a previous revision of the article?**

If you need to revert an article to a previous state before your recent edits, follow these steps:

* **For published articles:** Delete the forked version that contains your recent edits. This restores the last published version of the article.
* **For draft or new articles:** Create a new version by forking an earlier revision or delete the forked version that includes recent edits.

Forking before making changes preserves the original version, so you can restore it anytime.

#### **How do I discard the current changes and revert to the previous version of the article?**

**Method 1:**

* If the changes have not been published, follow these steps to revert to the previous version:

  + Click on the **Revision history** of the article.
  + **Open** the previous version to view and restore the old content.

**Note:** This option works if the article has been published at least once.

**Method 2:**

* If the article was never published, try the Backup & Restore option in the **Settings** page. This allows you to restore the content of a specific article.

#### Can I change or modify the article's published or last updated date to a past date?

No, the article's published date or last updated date cannot be changed. The last updated date will always reflect the most recent modification date, even if the article version is old.

An end-user with login credentials to access the Knowledge Base portal in Document360. Team accounts manage articles, categories, versions, and languages within the portal.

The public-facing website where end-users can access articles and find answers to their questions.

<a id="article-analytics"></a>

## Article analytics

**Plans supporting article analytics**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Article Analytics in Document360 provides detailed, article-specific insights, unlike standard Analytics that offer a broader overview of your entire knowledge base. With Article Analytics, you can assess individual article performance across metrics like reads, views, likes, dislikes, and link status. Use these insights to optimize your content strategy and enhance user experience.

---

## Accessing article analytics

1. In the editor, navigate to the top-right and click the **More (•••)** icon.
2. Select **Analytics** from the dropdown menu.

   Here, you’ll find detailed metrics on the article's **Reads**, **Views**, **Likes**, **Dislikes**, and **Link Status**.

---

### Understanding article analytics metrics

Each metric gives you actionable insights into article engagement:

* **Reads**: Measures reader engagement based on scrolling, clicking, and time spent on the article. The read count updates daily and is counted once per day per user.

> NOTE
>
> Time spent varies based on user activity. Multiple clicks on the same article are counted as a single read, while time spent can differ for each session.

* **Views**: Represents the number of unique clicks per browser, counted once per browser per user.
* **Likes**: Shows the total number of likes received by the article, providing feedback on content relevance.
* **Dislikes**: Tracks the number of dislikes to help identify areas for improvement.

> NOTE
>
> All metrics start tracking from the time the article is created.

---

### Navigating to project-wide analytics

Click **Go to Analytics** to access the broader project-level analytics for deeper insights into the entire knowledge base’s performance.

![Update-Screenshot-Article_Analytics](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Update-Screenshot-Article_Analytics.png)

---

### Validating links in article analytics

The **Link status** displays the **Total** links within an article, including a breakdown of links that are:

* **Working**: Active and accessible
* **Broken**: Unreachable or incorrect URLs
* **Unknown**: Status could not be determined
* **Ignored**: Links intentionally excluded from validation

The link validation tool helps you maintain active, reliable links within each article. Here’s how to use it:

1. From the Article Analytics page, locate the **Link Status** metric.
2. Click **Validate Now** to automatically check the link status.
3. If any links are broken, identify and copy the link URL.
4. Update the link or set a redirection rule to guide users to the correct destination.

**Example**: If an article link to external documentation is broken, copy the URL, navigate to **Settings > Knowledge base site > Article redirect rules**, and add a new rule.

---

### FAQs

#### How often is the analytics data updated?

Data refreshes in real-time, with reads updating daily based on unique user sessions.

#### Why might my read count differ from views?

Reads factor in user engagement activities like scrolling and clicking, while views simply count unique browser clicks.

#### Can I use article analytics to improve content engagement?

Yes, metrics like Reads, Likes, and Dislikes help you gauge engagement, showing which articles resonate most with your audience.

<a id="article-access-control-knowledge-base-site"></a>

## Security - Article access control

**Plans supporting access to security settings in the knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Add or deny access to the article content for team accounts, team account groups, reader accounts, and reader groups on the Knowledge base portal or Knowledge base site.

---

## Accessing the Article access control

1. Navigate to the desired article in the documentation editor.
2. Click on the **More** () options on the top right of the editor, and select **Security**.
3. There are two options to choose from

   * [Knowledge base portal](/help/docs/article-access-control-knowledge-base-site#knowledge-base-portal)
   * [Knowledge base site](/help/docs/article-access-control-knowledge-base-site#knowledge-base-site)

   An **Assign content access** blade will appear.
4. You can manage access to the article for Team accounts or readers.

![1_Screenshot-Accessing_the_Article_access_control](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Accessing_the_Article_access_control.png)

### Knowledge base portal

To change the article access on the portal, select the **Knowledge base portal access control**.

> **For team accounts & team account groups**   
> Portal access refers to the access through which the article content and article settings are updated or deleted.

The **Assign content access: Knowledge base portal** panel appears with the list of existing team accounts.

1. If no accounts are listed, click **Assign article access** to assign team members.
2. Select the desired team account and click **Apply**.
3. In the **Team account** section, you can perform operations such as **Edit**, **Deny**, and **Remove**.
4. Once done, click **Site access**.

![2_Screenshot-Knowledge_base_portal_access_control](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Knowledge_base_portal_access_control.png)

### Knowledge base site

To change the article access on the site, select the **Knowledge base site access control.**

> **For readers & reader groups**  
> Site access refers to the view access of the published article on the private or mixed knowledge base site.

> **Why is this option Inactive?**  
> This option would be inactive (grayed out) if the knowledge base site access is set as **Public**.

The **Assign content access: Knowledge base site** panel appears with the list of existing readers.

1. If no readers are listed, click **Assign article access** to assign reader accounts.
2. Select the desired reader account and click **Apply**.
3. In the **Readers** section, you can perform operations such as Deny and Remove.
4. Once done, click **Site access**.

![3_Screenshot-Knowledge_base_site_access_control](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Knowledge_base_site_access_control.png)

---

### FAQs

#### **Once Knowledge base portal access is denied for a Team account or group, how can it be restored?**

If access is denied for a team account, the team account will not be listed. To restore access, click **Assign article access** and add the same team account again.

#### **Once Knowledge base site access is denied for a reader or group, how can it be restored?**

If access is denied for a reader account, the read account will not be listed. To restore access, click **Assign article access** and add the same reader account again.

#### **Can I give access to an entire category to a team account and still restrict access to specific articles within that category?**

Yes, in Document360, you can grant access to an entire category to a team account and still restrict access to specific articles within that category.

#### **How do I deny access to a specific article for a team account?**

To deny access to a specific article for a team account, follow these steps:

1. Go to the specific article and click on the **More**() icon in the Knowledge base portal.
2. Navigate to **Security** > **Knowledge base portal**.

   The Team accounts list will appear.
3. Hover over the desired Team account and click the **Deny** () icon.

#### **How do I grant access to a category for a team account?**

To grant access to a category for a team account,

1. Navigate to the category you want to give access to in the Knowledge base portal.
2. Click **More** () icon > **Security** > **Knowledge base portal** > **Assign category access**.
3. Select the desired Team account and click **Apply**.

#### **Can I manage article-level access independently within a category?**

Yes, Document360 allows you to manage article-level access independently within a category. You can grant or deny access to specific articles even if the user has access to the entire category.

#### **What happens if I deny access to an article that is part of a category the user has access to?**

If you deny access to a specific article, the user will not be able to view or interact with that article, even if they have access to the rest of the category. The restrictions applied at the article level will override the category-level permissions for that specific article.

#### **Why can't I see the category and article structure on the Knowledge base site as it appears in the portal?**

If you are unable to see the category and article structure on the knowledge base site, it may be due to JWT access settings. If the reader group doesn’t have access to specific categories, those categories won't be visible to them.

To resolve this, ensure the correct content access is granted to the reader group. If the issue persists, please contact our support team for assistance.

#### How can I configure one article public while keeping all others private in the Knowledge base site?

You can configure a single article as public while keeping all other articles private in a **Mixed project** by following these steps:

**Set the workspace site access to public:**

1. Navigate to **Settings** () > **Users & security** > Site access in the Knowledge base portal.
2. Locate the workspace where the desired article is created.
3. Set the Site access for that workspace to **Public**.

**Configure all other articles as private:**

4. Go to the **Documentation** () section.
5. For each article or category you want to keep private.
6. Hover over the article or category, and click the **More** () icon.
7. Select **Security** > **Knowledge base site**.
8. In the **Assign content access** panel, choose **Private** and click **Close**.

   Ensure that the article you want to make public remains in **Public** access mode.

By doing this, only the specified article will be publicly accessible, while all others remain private.![Configuring one article as public while keeping all others private in the Knowledge base site.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-FAQ_Configuring_one_article_public_other_Articles_As_private.gif)

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The public-facing website where end-users can access articles and find answers to their questions.

<a id="health-check-metrics"></a>

## Health check metrics

**Plans supporting health check metrics**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Health check metrics** help you optimize your article's content and readability. These metrics provide valuable insights into current problems, suggestions for improvement, and aspects where the content is performing well. This feature is only available for articles and category pages in English.

For example, if an article has long sentences or lacks internal links, the tool will flag these issues, allowing you to make improvements and enhance readability and SEO performance.

---

## Accessing health check metrics

To access the Health Check Metrics for an article:

1. Navigate to the desired article in the Knowledge base portal.
2. Click **More** (•••) and select **Health check metrics**.

   The **Health check metrics** panel will appear with two major sections:

   * [SEO metrics](/help/docs/health-check-metrics#seo-metrics)
   * [Readability metrics](/help/docs/health-check-metrics#readability-metrics)

> NOTE
>
> If you update any parameter while the **Health check metrics** panel is open, click **Check now** to view insights on the latest changes.

### Metrics classification

The metrics are classified into three sections,

* **Problems:** Parameters that need immediate action.
* **Suggestions:** Parameters that require improvement.
* **Good Work:** Parameters that are currently optimal.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Health_check_metrics_in_the_Knowledge_base_portal.gif)

---

## SEO metrics

This section displays the SEO metrics for your article, covering the following parameters:

### 1. SEO title length

**SEO title** is the article title text appearing in the search engine results and the browser tabs. This parameter indicates the length of your article's SEO title. If adjustments are needed, the recommended length and an option to update it appear. The ideal SEO title length is between 50-70 characters (including spaces).

* If the SEO title's character length (including spaces) is less than 30 or more than 90, it will appear under **Problems** with a link to update it. Click **Update now** to navigate to the respective section.
* If the length is between 30-49 or 71-90, it will appear under **Suggestions** with a link to update it. Click **Update now** to navigate to the respective section.
* If the length is between 50-70, it will appear under **Good Work**.

### 2. SEO description length

**SEO description** is the summary of an article. It appears in the search engine results as a short article description. This parameter shows the length of your article's SEO description. If adjustments are needed, the recommended length and an option to update it appear. The ideal SEO description length is between 120-160 characters (including spaces).

* If the description length is less than 80 or more than 160 characters, it appears under **Problems**, with a link to update it.
* If the description length is between 80-119 characters, it will appear under **Suggestions**, with a link to update it.
* If the description length is between 120-160 characters, it appears under **Good Work**.

### 3. External links

**External links** are the links used that point to a web location outside your Document360 project. This parameter shows the presence of external links in your article.

* Articles with no external links or more than three will appear under **Suggestions**.
* Articles with one to three external links will appear under **Good Work**.

### 4. Internal links

**Internal links** include article links, category page links, and other relevant links within your Document360 project. Media file links are not considered internal links. This parameter shows the presence of internal links in your article.

* If there are no internal links or more than three, it appears under **Suggestions**.
* If there are one to three internal links, it appears under **Good Work**.

### 5. Featured image

**Featured image** will appear alongside the SEO title and description when the article is shared on social media or other websites. This parameter shows the availability of the featured image in the article.

* If there is no featured image, it appears under **Suggestions**.
* If a featured image is added, it appears under **Good Work**.

---

## Readability metrics

This section displays readability metrics for your article, providing insights into the following parameters:

### 1. Readability score

The readability score indicates how easy your article is to read, on a scale from 0 to 100. A higher score means the content is more readable.

* If the score is below 30, it appears under **Problems**.
* If the score is between 30-59, it appears under **Suggestions**.
* If the score is above 59, it appears under **Good Work**.

> NOTE
>
> For more information, visit the [Readability score](/docs/readability-score) article.

---

### 2. Paragraph length

This parameter shows the length of paragraphs in your article. Long paragraphs can make content harder to follow, so shorter paragraphs are recommended. The optimal length is 150 words or less per paragraph.

* If any paragraph exceeds 150 words, it appears under **Suggestions**.
* If all paragraphs are 150 words or less, it appears under **Good Work**.

> NOTE
>
> Two or more sentences without a break are considered as a paragraph.

---

### 3. Sentence length

This parameter shows the length of sentences in your article. Shorter sentences are easier to read. The recommended sentence length is 20 words or less.

* If any sentence exceeds 20 words, it appears under **Suggestions**.
* If all sentences are 20 words or less, it appears under **Good Work**.

> NOTE
>
> **What is considered a sentence?**
>
> * A sentence is defined as a group of words ending with a period (.).
> * If the ordered and unordered list contains no full stop at the end, it will be considered as a single sentence.

---

### 4. Sub-heading distribution

This parameter shows the use of sub-headings in your article. Sub-headings improve readability and help readers identify different sections.

* If no sub-heading is present, it appears under **Suggestions**.
* If sub-headings are used, it appears under **Good Work**.

In Document360, use Heading tags (H2, H3, H4) to add sub-headings. These are available in the toolbar. If the table of contents is enabled, sub-headings will appear there as well.

> NOTE
>
> Readability metrics do not account for LaTeX expressions or code blocks.

<a id="readability-score"></a>

## Readability score

**Plans supporting Readability score**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The Readability score, found in the Readability metrics section of the [**Health Check Metrics**](/help/docs/health-check-metrics), measures how easy it is to read and understand an article. It is presented as a score out of 100, where a higher score indicates greater readability.

For example, a score between 80 and 100 indicates that the article is very easy to read. If the score is between 60-80, the article is relatively easy to understand. If the score is below 60, the article is more complex, and readers may find it difficult to comprehend.

This score helps you quickly assess an article's readability. It helps you identify areas where readers might struggle without requiring feedback from them.

---

## Checking the readability score

1. Open the desired article in the Knowledge base portal.
2. Click the **More** (•••) icon and select **Health check metrics**.
3. The **Health check metrics** panel will appear with two major sections:

   * SEO metrics
   * Readability metrics
4. Expand **Readability metrics** and find the **Readability score.**

   * If the score is below 30, it appears under **Problems**.
   * If the score is between 30-59, it appears under **Suggestions**.
   * If the score is above 59, it appears under **Good Work**.

> NOTE
>
> If you update any parameter while the **Health check metrics** panel is open, click **Check now** to view insights on the latest changes.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-readability_metrics_in_the_Health_check_metrics.png)

---

### Score classification

The table below outlines the readability score ranges and their corresponding messages. These messages appear next to the score.

| Readability score | Message |
| --- | --- |
| 90-100 | Very easy to read |
| 80-89 | Easy to read |
| 70-79 | Fairly easy to read |
| 60-69 | Easily understood |
| 30-59 | Fairly difficult to read |
| 0-29 | Hard |

For example:

* If the readability score is 84, the message **Easy to read** will appear.
* If the readability score is 35, the message **Fairly difficult to read** will appear.

<a id="sitemap-generator"></a>

## Sitemap

**Plans supporting for sitemap generation**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

A Sitemap is a file that shares detailed information about a website, primarily containing page URLs. Search engines like Google, Bing, and Yahoo use this file to crawl your site more effectively. It communicates the most important pages and files to search engine crawlers. Document360 uses an XML-type sitemap generator.

> NOTE
>
> Sitemap URLs are available only for public projects.

---

## Accessing the Sitemap in Document360

1. Navigate to **Settings** () >**Knowledge base site** > **A****rticle settings & SEO**> **SEO** tab in the Knowledge base portal.
2. Locate the **Sitemap URL**.
3. In the **Select change frequency** field, choose how often your sitemaps should be generated.

> NOTE
>
> Sitemaps are not updated instantly when you add a new article or change an article slug. They are generated based on the selected frequency. It's recommended to choose a frequency that aligns with your article publishing rate. For example, if you publish one or more new articles daily, set the frequency to **Daily**.

4. Click the sitemap URL to view your sitemap.

![Settings page showing SEO options for article management and sitemap configuration.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-New-Accessing_sitemap_in_Document360.png)

---

### FAQs

#### Do I need a sitemap?

A sitemap.xml file is an essential for communicating with search engines. It’s also useful for verifying your website structure for other internal audits.

#### What should I do with the sitemap?

You should submit your sitemap to Google Search Console once it's generated from the Document360 sitemap generator. [Click here](https://developers.google.com/search/docs/advanced/sitemaps/build-sitemap) to learn more about submitting your sitemap to Google Search Console.

#### How does a sitemap look?

```
<?xml version="1.0" encoding="UTF-8"?>
<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">
  <url>
    <loc>http://www.example.com/foo.html</loc>
    <lastmod>2018-06-04</lastmod>
  </url>
</urlset>

```

Plain text

Copy

> Above is a basic sitemap example that includes one URL. It is a misconception that sitemaps have only URLs in them. It can also have metadata added to them.

#### What are the types of sitemaps?

There are three main types of sitemaps

1. **Visual sitemaps**- Used by web project developers.
2. **HTML sitemaps**- Used for sites with large content, with lower impacts on SEO.
3. **XML sitemaps**- Most used commonly used type, performing well in SEO as they are crawler friendly.

<a id="public-comments"></a>

## Public article comments

**Plans supporting discussion/inline comments**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 uses [Disqus](https://disqus.com/), a commenting plug-in, to allow end-users to comment on articles on the Knowledge base site. To enable Disqus, you must first set up and configure the Disqus integration. After configuration, commenting will be automatically enabled on all articles.

> NOTE
>
> For more information, read the article on [Disqus integration in Document360](/help/docs/disqus).

---

## Enabling comments on a public article

> NOTE
>
> If you don’t have the Disqus integration enabled, end-users can’t comment on a public article.

1. Navigate to the desired article in the Knowledge base portal.
2. Click on the **More** (**•••**) icon at the top right and select **More article options**.
3. Go to the **Preferences** tab in the **Article settings** panel.
4. Select the **Enable feedback** checkbox.
5. To disable comments on a public article, deselect the **Enable feedback** checkbox.
6. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Enable_feedback_in_public_articles.png)

> NOTE
>
> Removing the Disqus integration will disable commenting entirely. If you decide to re-enable Disqus later, you'll need to reconfigure the integration by following the steps in the [Disqus](/help/docs/disqus) topic.

### Knowledge base site view

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Enabling_Feedback_Knowledge_base_site_view.png)

---

### FAQ(s)

#### How do I enable comments on a public article?

To enable comments, navigate to the desired article, click on the **More (•••)** icon, go to the **Preferences** tab in the **Article settings** panel, select the **Enable feedback** checkbox, and click **Save**.

#### Can I disable comments on a public article?

Yes, you can disable comments by deselecting the **Enable feedback** checkbox in the **Article settings** panel.

#### Will deleting the Disqus integration disable public comments?

Yes, removing the Disqus integration will disable public comments on all articles.

#### What steps do I need to take to delete the Disqus integration?

To delete the Disqus integration, navigate to Settings () > **Knowledge base site** > **Integrations**, and click **Delete** on the Disqus list item.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="robotstxt"></a>

## Robots.txt

**Plans supporting for Robot.txt**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## What is a Robots.txt file?

A Robots.txt file is a text file used to communicate with web crawlers and other automated agents about which pages of your knowledge base should not be indexed. It contains rules specifying which pages may be accessed by which crawlers.

> For more information, read this [help article](https://developers.google.com/search/docs/crawling-indexing/robots/robots_txt) from Google.

---

## Accessing Robots.txt in Document360

1. Navigate to **Settings** () > **Knowledge base site** > **Article settings & SEO** > **SEO** tab in the Knowledge base portal.
2. Locate **Robots.txt** and click **Edit**.

   The **Robots.txt settings** panel will appear.
3. Type in your desired rules.
4. Click **Update**.

![Screenshot of robot txt page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot_robot_txt_page.png)

---

### Use cases of Robots.txt

A Robots.txt file can block a folder, file (such as a PDF), or specific file extensions from being crawled.

You can also delay the crawl speed of bots by adding crawl-delay in your Robots.txt file. This is useful when your site is experiencing high traffic.

```
User-agent: *
Crawl-delay: 10
```

Plain text

Copy

---

### Restricting the crawler through admin data

```
User-agent: *
Disallow: /admin/
Sitemap: https://example.com/sitemap.xml

```

Plain text

Copy

`User-agent: *` - Specifies that any bot can crawl through the site.  
`Disallow: /admin/:` - Restricts the crawler from accessing admin data.  
`Sitemap: https://example.com/sitemap.xml` - Provides access to bots to crawl the sitemap. This makes the crawl easier as the sitemap contains all the URLs of the site.

---

### Restricting a specific search engine from crawling

```
User-agent: Bingbot 
Disallow: /

```

Plain text

Copy

> The above Robots.txt file is defined to disallow the Bingbot.

`User-agent: Bingbot` - Specifies the crawler from the Bing search engine.  
`Disallow: /` - Restricts Bingbot from crawling the site.

---

#### Best Practices

* **Include links** to the most important pages.
* **Block links** to pages that do not provide any value.
* Add the sitemap location in the **Robots.txt** file.
* A Robots.txt file cannot be added twice. Please check the basic guidelines from [Google Search Central](https://developers.google.com/search/docs/advanced/robots/create-robots-txt#format_location) documentation for more information.

> NOTE
>
> A web crawler, also known as a Spider or Spiderbot, is a program or script that automatically navigates the web and collects information about various websites. Search engines like Google, Bing, and Yandex use crawlers to replicate a site's information on their servers.
>
> Crawlers open new tabs and scroll through website content, just like a user viewing a webpage. Additionally, crawlers collect data or metadata from the website and other entities (such as links on a page, broken links, sitemaps, and HTML code) and send it to the servers of their respective search engine. Search engines use this recorded information to index search results effectively.

---

### FAQs

**How do I remove my Document360 project from the Google search index?**

To exclude the entire project from the Google search index:

1. Navigate to **Settings** ()> **Knowledge base site** > **Article settings & SEO** in the Knowledge base portal.
2. Go to the **SEO** tab and click **Edit** in the `Robots.txt`.
3. Paste the following code:

```
User-Agent: Googlebot 
Disallow: 
```

Plain text

Copy

4. Click **Update.**

**How do I prevent tag pages from being indexed by search engines?**

To exclude the tag pages from the search engines:

1. Navigate to **Settings** ()> **Knowledge base site** > **Article settings & SEO** in the Knowledge base portal.
2. Go to the **SEO** tab and click **Edit** in the `Robots.txt`.
3. Paste the following code:

```
User-agent: *
Disallow: /docs/en/tags/
```

Plain text

Copy

4. Click **Update**.

<a id="read-receipt"></a>

## Read receipt

**Plans supporting read receipt**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Read receipt** feature helps you see who has read and acknowledged an article. This helps ensure important updates are noticed. For example, if your company updates its security policy, employees can be required to acknowledge the article, confirming they have read it. This keeps communication clear and trackable.

> For your information (FYI)
>
> * The Read receipt feature is available exclusively for private and mixed projects in **KB site 2.0**.
> * The Read receipt feature is not available for JWT configured projects.

---

## Managing Read receipts in the Knowledge base portal

You can manage the read receipt feature for articles and category pages in three ways:

Method 1: Bulk management in All articles

Method 2: Individual article settings

Method 3: Accessing read receipt in the Settings

Method 1

Method 2

Method 3

You can enable or disable read receipts for multiple articles at once through the **All articles** () section.

1. Navigate to **Documentation** () > **All articles** () in the Knowledge base portal.

   The **All articles** page will appear with all articles within your workspace.
2. Select the intended articles.
3. To enable the read receipt, click **Enable read receipt**.
4. To disable the read receipt, click **Disable read receipt**.
5. Hover over the **Read receipt** () icon to see the number of readers who have acknowledged the articles.

> NOTE
>
> If the read receipt is configured in the **Settings**, it cannot be changed in the **All Articles** section.

![Enabling the read receipt for selected articles in the All articles section in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-New_Enabling_read_receipt_from_All_articles.png)

To enable read receipts for a specific article:

1. Navigate to the desired article in the Knowledge base portal.
2. Click the **More**() icon and select **More article options**.
3. In the **Article settings** panel, go to the **Read receipt** tab.
4. Turn on the **Enable read receipt for this article** toggle and click **Save**.

![Enabling the read receipt for selected articles in the Articles section in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-New_Enabling_read_receipt_from_Article_settings.png)

You can apply read receipt rules to entire knowledge base categories:

1. Navigate to the **Settings**() > **Knowledge base settings** > **Read receipt** in the Knowledge base portal.

   The **Read receipt** page will display any previously created rules.
2. Click **Create rule**.
3. In the **Create read receipt rule** panel, enter the rule name (up to 50 characters).
4. Choose the visibility option: **Show** or **Hide**.

> NOTE
>
> When creating rules, the order in which they appear determines which rule takes effect. You can create up to 20 rules per project and rearrange them as needed.
>
> For example, if you have two rules for the same category:
>
> * **Rule 1**: Enable the reader acknowledgment feature in Category A.
> * **Rule 2**: Disable the reader acknowledgment feature in Category A.
>
> If Rule 1 is in the second position and Rule 2 is in the third, Rule 1 will take effect first, provided both rules are set to "Show." However, if Rule 1 is set to "Hide," then Rule 2 will take effect, even though Rule 1 has a higher priority.

5. Select the desired categories to apply the read receipt.
6. If needed, assign the rule to specific reader groups.
7. Once done, click **Create**.

![Enabling All articles in the Project settings in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-New_Enabling_Read_receipt_in_the_Settings_page.gif)

> NOTE
>
> * If you have configured in Settings, read receipts cannot be altered at the **Article-level settings**.
> * Read receipts can be added to both draft and published articles.
> * When forking and republishing an article with acknowledgment enabled, readers will need to acknowledge the republished article again.
>
> ![2_Screenshot-publish_confirmation_prompt](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-publish_confirmation_prompt.png)

For articles with reader acknowledgment enabled, the acknowledgment information will be displayed at the top. ![3_Screenshot-acknowledgement_information_at_the_top](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-acknowledgement_information_at_the_top.png)

---

## **Read receipt page**

![Interface showing rules for read receipt settings with highlighted elements for visibility and rules.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-New_Overview_page_of_Read_receipt_in-Settings.png)

The **Read receipt** page provides a detailed view of your configured rules:

1. **Create Rule:** Click to create a new read receipt rule for Knowledge base categories.
2. **Rearrange Rules:** You can rearrange the order of created rules. Rules are prioritized based on their sequence, with the first rule taking precedence.
3. **Name:** Displays the name of each read receipt rule.
4. **Visibility:** Indicates whether the rule is set to Show or Hide.
5. **Rules:** Displays the categories to which the rules are applied.
6. **Dependency viewer:** View and edit the categories where the rule is applied.
7. **Edit:** Hover over the desired rule to edit it.
8. **Delete:** To delete a rule, hover over it, click **Delete**, and confirm the action.

---

## Reader acknowledgement in the Knowledge base site

1. Once the Read receipt configured, navigate to the desired article in the Knowledge base site.

   A small banner will appear at the top, stating **"Your acknowledgement is required upon reading.”**
2. Scroll down to the end of the article, select the checkbox to acknowledge, and then click **Submit**.

   Upon successful acknowledgement, a confirmation message will appear at the top of the article.

![4_ScreenGIF-Reader_acknowledgement_in the KB_site](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGIF-Reader_acknowledgement_in%20the%20KB_site.gif)

---

## Acknowledgement required in the Knowledge base site

![Acknowledgement required in the Knowledge base site](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Acknowledgement_required_in_the_Knowledge_base_site.png)

On the top-right side of the home page, you'll see an Announcement () icon indicating the number of acknowledgements that need to be addressed. Click this to access the **Acknowledgement required** page.

On the left side of the **Acknowledgement required** page, you'll find filter options for workspace and acknowledgement status:

**Workspace**:

* Current Workspace: Filters articles only within the current workspace.
* All Workspace: Filters articles across all workspaces.
* Specific: Allows selection of specific workspaces for filtering.

**Acknowledgement status**:

* Required: Displays a list of articles that have not been acknowledged.
* Acknowledged: Displays a list of articles that have been acknowledged.

---

## Monitoring Read receipt in Analytics

In the **Analytics** () section, you can monitor the read receipt analytics:

1. Navigate to **Analytics** () > **Articles** in the Knowledge base portal.
2. In the **Top articles** section, click **View all**.

The **All Articles** page will appear, showing a field named **Read Receipt**, where you can see the acknowledgment details for each article.

![6_ScreenGIF-Analytics_section_Reader_Acknowledgement](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_ScreenGIF-Analytics_section_Reader_Acknowledgement.gif)

NOTE

Any changes made to the respective articles will reflect in the analytics within 15 minutes.

---

### FAQs

#### What is the maximum number of read receipt rules I can create?

You can create up to 20 read receipt rules.

#### What happens to reader acknowledgment rules when cloning articles or categories across workspaces?

When you clone articles or categories within or across workspaces, reader acknowledgment rules will not be carried over to the new workspace. The rules must be configured separately for the new workspace.

#### Do readers need to acknowledge every time an article is updated?

When forking and republishing an article with acknowledgment enabled, readers will need to acknowledge the republished article again.

<a id="share-articles-via-private-link"></a>

## Share articles via private link

**Plans supporting the sharing of private link**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Share articles with external readers using a private link even before publishing the content. This feature allows you to generate a unique link for any article. With this link, you can grant access to the content to users who do not have access to your knowledge base portal or site. You can share these private links with external users outside your Document360 project (team accounts or reader groups) and disable or regenerate the links at any time to manage access as per your preferences.

> For your information (FYI)
>
> This feature is available exclusively in **KB Site 2.0**, which is accessible for projects created after June 10th.

---

### Creating a private link

1. Navigate to the desired article in the Knowledge base portal.
2. Click on more options (•••) in the category tree next to the article.

   Alternatively, select more options (•••) near the Publish button.
3. Click the **Share link** (  ) icon.
4. In the **Share link** pop-up window,

   a. Click on **Get sharable link (  )** once you have deleted the pre-existing link to generate a new link.

   b. Click on **Copy** (  ) to copy the link to share.

   c. You can choose to click **Delete link** (  ) to delete the existing link.

> NOTE
>
> * When the user has deleted the article, the link will not display the information of the article in the KB site.
> * But once it’s recovered from the recycle bin (or) back up and restored, the same link should allow the user to view the content.

![1_ScreenGIF-Creating_deleting_the_private_link](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Creating_deleting_the_private_link.gif)

---

### FAQs

**What happens if the user deletes the generated link?**

The shared private link will be invalid if the user deletes the generated link in the KB portal.

**How do I regenerate my shareable link?**

After deleting the existing link, navigate to the **More** (•••) option > **Share (  )** icon > click **Get sharable link** to regenerate it.

**How do I share an unpublished article with someone who is not part of the team account?**

In Document360, you can use the Get shareable link feature to share an unpublished article with individuals who are not part of your project’s team account.

<a id="ai-customization"></a>

## Eddy AI customization

**Plans supporting the Eddy AI customization**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

> NOTE
>
> **Current Plan:**
>
> * **Business Plan:** You can customize the response tone and length for AI assistive search.
> * **Enterprise Plan:** In addition to customizing the response tone and length for AI assistive search, you can also customize the AI assistant's name.
>
> **Legacy Plan:**
>
> * If you have purchased AI assistive search, you can customize the response tone and length.
> * **Enterprise Plan:** In addition to customizing the response tone and length, you can also customize the AI assistant's name.

As a Document360 user, you have the flexibility to rename Eddy to fit seamlessly with your company’s identity. Whether your organization has its own advanced AI capabilities or simply wants Eddy to reflect its unique culture and values, customization options are available. This depicts that Eddy not only supports your content needs but also represents your brand in the best possible way.

> NOTE
>
> The users with the access to **View access permissions** > **Portal role** > **Project settings** > **Update (enabled),** can customize the Eddy AI term.

---

## Customizing the Eddy AI

To personalize your Eddy AI,

1. Navigate to Settings ()> **AI features** > **Customization** in the Knowledge base portal.

   The **Customize Eddy AI** page will appear.
2. In the **AI assistant name** text box, enter your desired name for the AI assistant.

   By default, **Eddy AI** will be assigned as the AI assistant name.
3. You can customize the AI Assistive response tone to fit various contexts and situations:

* Default (Select this option for search responses that match the tone of your question or context, offering adaptability for different situations.)
* Professional
* Friendly
* Casual
* Straightforward
* Confident

4. You can customize the response length of AI Assistive search based on how detailed you want the responses to be:

* Default (Select this option for search responses that adjust to your question and the context, varying in length as required)
* Long and detailed
* Short and concise

5. Once done, click **Save.**

> NOTE
>
> **Moderation APIs** verify and filter out inappropriate words in the **AI assistant name** field. If the name doesn’t meet our community standards while saving, a prompt will be displayed. Click **Yes** to proceed, and the moderation API will be overridden.

![Customizing the Eddy AI](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Customizing_the_Eddy_AI.png)

---

### FAQ

#### Is there a character limit for the AI assistant name?

Yes, the AI assistant name should not exceed 15 characters.

<a id="ai-machine-translation"></a>

## AI machine translation

**Plans supporting access to machine translation settings in knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360’s AI machine translation feature enables seamless translation of text within your article. This capability ensures that all aspects of your content can be localized to the languages added to your project, allowing you to easily maintain a multilingual knowledge base.

Key benefits:

* Time-efficient: Easily translates article text, saving you time on manual translations.
* Consistency: Keeps terminology and phrasing uniform across languages, ensuring a cohesive user experience.
* Scalability: Easily handle translations across numerous articles and languages as your knowledge base grows.

> **NOTE**
>
> * When you perform machine translation for a Markdown article, it will be automatically converted to the WYSIWYG editor.
> * If an article is deleted in the main language, it will also be deleted in all other languages. However, if an article is hidden in the main language, it will still be visible on the Knowledge base site in other languages.

## Prerequisites for using machine translation

To perform AI machine translation,

* Ensure you have sufficient machine translation character credits. You can check your available character credits from **Settings**() > **Knowledge base portal** > **Localization & Workspaces** > **Machine translation**. You can also purchase additional credits by clicking the Buy more button on the same page.

> NOTE
>
> Machine translation credits are consumed at a rate of one credit per translated character in the article. Each character translated reduces the available machine translation credits accordingly.

## Using machine translation

You can translate articles using two methods:

1. Machine translation using the **All articles**() section
2. Translating articles from the editor

### Method 1: Machine translation using the **All articles** () section

To translate multiple articles using the **All articles** () section, follow the steps below:

1. Navigate to **Documentation** () >**All articles** () in the Knowledge base portal.
2. From the article list, select the checkbox(s) next to the article(s) you wish to translate.
3. Click **Machine translation**.

   The **Translate to other languages** panel will appear.
4. Select the desired languages (e.g., German and Spanish).
5. Type `Yes` in the confirmation field and click **Yes**.

   > NOTE
   >
   > * The Machine translation feature is only available for WYSIWYG and Advanced WYSIWYG editors. The selected articles will be switched over to the WYSIWYG editor and cannot be reverted.
   > * If you update the content in your main language later, you must repeat these steps to ensure the translated versions reflect the updates.

![Steps to perform bulk machine translation for articles](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-AI_machine_translation.gif)

#### Updating translation status for articles

On the **All articles** () page, after you select one or more articles, you can perform the following translation actions from the toolbar:

1. **Machine translate**: This option is available before an article has been translated for the first time.
2. **Needs translation**: After an article has been translated, you can manually change its status to indicate it requires further translation.
3. **Mark as translated**: When an article is in the translated status, you can manually change it to **Mark as translated** once it's complete.

> **NOTE**  
> The **Need translation** status is only available for secondary languages in your workspace. When a new language is added to a workspace, all articles will appear with the **Need translation** status by default.

### Method 2: Translating articles from the editor

To translate an article from the editor, follow these steps:

1. Navigate to the Knowledge base portal, and from the **Workspace & Language** dropdown, select the desired language.
2. Navigate to the desired article in the editor.
3. Ensure the appropriate content is present in the editor.
4. Click the **Needs translation** dropdown in the top-right corner of the editor to access translation options.
5. Click **Translate** to start the process.

   A progress indicator will appear, and other operations will be restricted until the translation is complete.

![To perform machine translation for individual articles in different language](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGif-AI_machine_translation.gif)

> **NOTE**  
> If a translated article has been updated, and you wish to apply machine translation to the article again, click **✓ Translated** and select **Mark as ‘Needs translation’**. This will change the translation status back to **Needs translation**.

## Understanding machine translation with real-time examples

You can choose between the two methods based on your use case.

1. Scenario 1: Translating articles to existing languages
2. Scenario 2: Adding a new language to the project

Scenario 1

Scenario 2

Assume your main language is English, and your project includes two other languages, such as German and Spanish.

When you create a new article (e.g., **Troubleshooting**) in English, corresponding articles are automatically created in German and Spanish, but they appear without content.

In this scenario, you can use **All articles**() to translate the English content into other languages:

1. Navigate to **Documentation** () > **All articles** () in the Knowledge base portal.
2. Select the **Troubleshooting** article in English.
3. Click **Machine translation**.

   The **Translate to other languages** panel will appear.
4. Select the desired languages (e.g., German and Spanish).
5. Type **Yes** in the confirmation field and click **Yes**.

The content will now be translated from English to German and Spanish.![Translating content from the All articles section in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenGIF-Translating_content_from_all_articles_realtime_example.gif)

If you add a new language (e.g., French) to your project after creating content in English, then the English content will be automatically replicated in the newly added language.

Navigate to the French articles and click **Needs translation** to translate the content.

However, if languages (e.g., German and Spanish) were already added before drafting the English article, the content will not be automatically replicated. In this case, you must manually translate it from the **All articles** () section.

![Translating content from the article editor in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_ScreenGIF-Translating_content_from_editor_real_time_eg.gif)

---

## Managing machine translation credits

To view the available machine translation credits for your project, navigate to **Settings**() > **Knowledge base portal** > **Localization & Workspaces** > **Machine translation**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Machine translate screenshot 1.png)

On this page, you will find the details regarding your used and available machine translation credits.

| Name | Description |
| --- | --- |
| Limit | The total machine translation credits allotted for your project. |
| Usage | The number of credits consumed for machine translation in your project. |
| Remaining | The number of characters remaining from your total machine translation limit. |
| Usage meter | Shows the percentage of translated characters using machine translation from your total limit of 100%. |

> **NOTE**
>
> * An individual article should have fewer than 50,000 characters for machine translation to work. The character count includes all formatting, such as tables, accordions, and other complex elements. Articles with extensive formatting are more likely to exceed this limit. If the character count is too high, consider splitting the article into smaller, manageable sections as a workaround.
> * Machine translation credits are allocated at the project level and apply collectively across all workspaces and languages within that project.

### Machine translation credit limits based on subscription plan

| Plan | Machine translation character limit |
| --- | --- |
| Professional | 1 million characters |
| Business | 2 million characters |
| Enterprise | 5 million characters |

Click **Buy more** to purchase an additional 1 million characters for $50, supporting all three plans: Professional, Business, and Enterprise.

---

## Article translation status indicators

Keep track of the translation status and update it easily as needed. Translation statuses help you identify which articles need updates and which are fully translated, ensuring you’re always informed of your multilingual content's status. The article's translation status indicator is located above the text formatting toolbar in a project workspace that contains multiple languages in both Markdown, WYSIWYG, and Advanced WYSIWYG.

| Status | Indication |
| --- | --- |
| Need translation | The article has not yet been translated or requires additional translation. Initially, the **Need translation** status appears as the default status in all other language articles. The article can either be an existing article created from the base version or a new one.  The options that appear when you click on this status are:   * Translate * Mark as translated   Articles that require translation (with **Needs translation** status) are indicated using the globe (🌐) icon on the left navigation pane. |
| Translated | The article has either been machine or manually translated to the destination language or marked as translated by the team account. |

> **NOTE**  
> The translation status indicator is unavailable on the main language article.

### Filtering articles based on translation status

1. Navigate to **Documentation**() >**All articles** () in the Knowledge base portal.

   The list of articles will appear.
2. Click **Filter** on the right and select the intended filter (**Needs translation** or **Translated**).

From here, you can perform actions such as:

* Changing the translation status
* Machine translate

---

## Troubleshooting

### Encountering error while translating an article

**Error:** Unable to connect the Translate API  
The error message "Error occurred: Unable to Connect the Translate API" appears when attempting to apply machine translation to an article in the editor or from the All articles section. This occurs because the HTML content of the article exceeds the character limit of 50,000 set by the Azure Translation service. Articles with a large number of tables or complex HTML elements are more prone to exceeding this limit, as these elements contribute significantly to the overall character count.

**Steps to resolve:**

1. Open the code view of the article you are trying to translate.
2. Copy the entire HTML content of the article.
3. Use a character counting tool to determine the total number of characters in the HTML content.
4. If the character count exceeds 50,000, split the article content into smaller sections and create multiple articles.
5. Apply machine translation to the smaller articles separately to proceed with the translation.

![Encountering “Error occurred: Unable to connect the Translate API" message while translating an article.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/ScreenGIF-Troubleshooting_Unable_to_connect_the_Translate_API.gif)

### Latest content in the main language not reflected in secondary languages

Updates made to the main language will not automatically reflect in other languages. You must manually initiate the translation process using the Machine translation feature.

When an article is created in the main language, its structure is automatically replicated in secondary languages, but the content itself is not transferred.

**Steps to resolve:** To update the content in secondary languages, follow these steps:

1. Navigate to the **All articles** () section in the main language.
2. Select the article you want to translate into secondary languages.
3. Click **Machine translation**.

   The **Translate to other languages** panel will appear.
4. Select the desired languages.

> **NOTE**
>
> * The translating article(s) will switch to the Advanced WYSIWYG editor and cannot be reverted.
> * Articles in New or Draft status in secondary languages will be overwritten by the latest version from the main language.

5. Type **Yes** in the confirmation field and click **Yes** to proceed.

![Translating content from the All articles section in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenGIF-Translating_content_from_all_articles_realtime_example.gif)

---

### FAQs

#### What languages are supported for machine translation?

Machine translation supports the following languages:

|  |  |  |  |  |
| --- | --- | --- | --- | --- |
| Afrikaans | Dutch | French (Canada) | Korean | Slovenian |
| Arabic | Dutch (Belgium) | Georgian | Latvian | Spanish |
| Arabic - Egypt | English | German | Lithuanian | Spanish (Mexican) |
| Bulgarian | English (Australia) | Greek | Mongolian | Swedish |
| Chinese | English (UK) | he - עִבְרִית | Norwegian | Thai |
| Chinese (Simplified, People's Republic of China) | English (US) | Hungarian | Polish | Türkçe |
| Chinese (Traditional, Taiwan) | Estonian | Icelandic | Portuguese | Ukrainian |
| Chinese (Traditional) | Filipino | Indonesian | Portuguese (Brazil) | Vietnamese |
| Czech | Finnish | Italian | Romanian | Русский |
| Danish | French | Ja - 日本語 | Slovakian |  |

#### Can I manually translate articles instead of using machine translation?

Yes, you can manually translate articles using external translation services. Once you have finished translating, you can mark them as translated.

#### Is there a limit on how many articles I can translate at once?

No, you can translate multiple articles simultaneously as long as you have sufficient machine translation credits.

#### What happens if my article exceeds the character limit for machine translation?

If an article exceeds the 50,000-character limit, machine translation cannot proceed. To enable translation, reduce the character count. Note that the character count is based on the HTML content, ensuring formatting is preserved across all languages during translation.

#### Can I revert back to the original state after machine translation?

Once an article is machine translated, you can change its status back to "Needs translation," but the original content is not retained. Be sure to keep a backup of the original content if needed.

#### Are there additional costs for using machine translation?

Machine translation is included in your subscription plan. However, exceeding your character limit will incur additional charges.

#### What happens to articles in other languages when I create a new article in the main language?

When you create a new article in the main language, corresponding articles are created in other languages (e.g., German, Spanish) but without content. You will need to translate the content using the Machine translation feature in the Knowledge base portal.

#### What happens when I add a new language to the project?

When a new language is added after content has been drafted in the main language, the content from the main language is automatically replicated in the newly added language's articles. To translate these articles, navigate to them and click **Needs translation** to complete the translation.

#### Why are some articles empty in other languages?

If the desired languages were already added to the project before drafting the article in the main language, the content will not be automatically replicated. You must translate the content manually via **All articles**().

#### How do I delete an article in a specific language without affecting other languages?

When you delete an article in any specific language, it will also be deleted in the main language and other languages, as articles are linked across languages.

To avoid this, you can **hide** the article in that specific language:

1. Navigate to the desired article in that language.
2. Use the **Hide** () option to ensure it does not appear in the Knowledge base for users in that language.

   This way, the article will remain available in other languages within your project.

#### How do I delete all articles in one specific language without deleting other languages?

If you want to delete all articles in a specific language but retain the articles in other languages:

1. Navigate to **Settings**() > **Knowledge base portal** > **Localization & Workspaces** >**Localization & Workspaces**in the Knowledge base portal.
2. Hover over the desired workspace and click the **Edit**() icon.

   The **Edit workspace** panel will appear.
3. Navigate to the desired language and click the **More** () icon.
4. Click **Remove**.

> **NOTE**
>
> This action will permanently delete all articles in that desired language across the project. Other languages will remain unaffected.

<a id="eddy-ai-trust-page"></a>

## Eddy AI trust page

**Plans supporting the use of AI tools**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

At Document360, we are committed to transparency with our customers regarding our products and how we use AI to enhance your experience. Below is an overview of Eddy AI's functionality, along with our related security and privacy practices.

---

## Compliance

Eddy AI, our advanced AI-powered tool, adheres to strict compliance standards such as:

* **GDPR**: We follow the General Data Protection Regulation, ensuring robust data protection and privacy for all individuals in the European Union.
* **SOC 2 Type 2**: Our procedures align with the requirements of SOC 2 Type 2, demonstrating our commitment to security, availability, and confidentiality.

---

## Subprocessors

To deliver a high-quality service, Eddy AI leverages a network of trusted subprocessors. These include:

* **MongoDB**: Used as our vector database.
* **OpenAI**: Provides AI capabilities, utilizing their advanced models.
* **Azure**: Our cloud provider ensures a scalable and reliable infrastructure.
* **Stripe**: Facilitates secure payment processing.
* **Segment**: Used for product analytics to enhance the user experience.

---

## Data Security and Privacy

We take facts, safety, and privacy seriously. All facts associated with Eddy AI are securely stored and encrypted. Here’s how we ensure the integrity and confidentiality of your information:

* **Data at rest**: All the information is encrypted using industry-standard encryption protocols.
* **Data in transit**: Data transmitted between your tool and our servers is encrypted to save you from interception and tampering.

Eddy AI is designed to supply steady and dependable overall performance, even under high utilization.

---

## Resources

**1. Cryptography policy**

**Purpose**: The policy aims to ensure the proper and effective use of cryptography to protect the confidentiality, authenticity, and integrity of information.

**Scope**: The policy applies to all information systems developed and/or controlled by Document360 that store or transmit confidential data.

**Policy Owner**: The CEO is responsible for the policy.

**Effective Date**: The policy becomes effective on March 1, 2024.

**Risk Evaluation**: Document360 evaluates risks and implements cryptographic controls to mitigate them where appropriate.

**Encryption Standards**: Strong cryptography with associated key management processes and procedures must be implemented and documented in accordance with industry standards, including NIST SP 800-57.

**Key Management**: Access to keys and secrets is tightly controlled, and there are specific recommendations for the usage of cryptographic keys, including key types, algorithms, and key lengths for various domains such as web certificates, web ciphers, and endpoint storage.

**Exceptions**: Requests for exceptions to the policy must be submitted to the CEO for approval and must be documented.

**Violations & Enforcement**: Known violations should be reported to the CEO and may result in disciplinary action, including termination of employment.

**Version History**: The policy is in its first version, approved by Yasser Elsaid on February 3, 2024.

**Data at Rest**: Confidential data at rest must be encrypted using symmetric encryption with AES-256 bit for a maximum period of 1 year.

**Passwords**: Passwords must be hashed using one-way hash functions like Bcrypt, PBKDF2, scrypt, or Argon2, with a 256-bit key and a 10K stretch, including a unique cryptographic salt and pepper.

**2. Incident Response Plan**

**Purpose and Scope**: The document aims to provide a plan for managing information security incidents and events, covering all such occurrences within the company.

**Definitions**: It clarifies the difference between a security event (an observable occurrence relevant to data security) and a security incident (an event that results in loss or damage to data security).

**Reporting and Documentation**: Employees are instructed to report any suspected incidents immediately using specific communication channels, and all incidents must be documented.

**Severity Levels**: Incidents are categorized into S1 (Critical), S2 (High), and S3/S4 (Medium/Low) severity levels, with clear guidelines for escalation and response.

**Incident Response Team**: The IT Manager or VP of Support leads the incident response effort, with a designated "War Room" for centralized response. Regular meetings are held to update the incident ticket, document indicators of compromise, and perform other response activities.

**Root Cause Analysis**: For critical incidents, a root cause analysis is performed, documented, and reviewed by the CEO, who decides on the need for a post-mortem meeting.

**Response Process**: The response process includes triage, investigation, containment, eradication, recovery, and hardening, with a focus on lessons learned and long-term improvements.

**Physical Security**: The document addresses the physical security of affected systems, including isolation and backup procedures.

**Breach Determination and Reporting**: Only the CEO can determine if an incident constitutes a breach. The company shall promptly notify all relevant parties in accordance with policies and regulatory requirements.

**External Communications**: The company cooperates with customers, data controllers, and authorities as needed, with legal and executive staff determining the approach.

**Roles and Responsibilities**: The document outlines the specific responsibilities of incident responder roles.

**Special Considerations**: It includes handling internal issues, compromised communications, and root account compromises.

**Incident Status and Summary**: A detailed template is provided for documenting incident details, including date, time, location, personnel involved, type of information involved, indicators of compromise, root cause, and actions taken.

**AWS Root Account Compromise Playbook**: Specific guidance is provided for managing Root AWS account usage in the event of a compromise.

**Policy Owner and Effective Date**: The CEO is the policy owner, and the plan becomes effective on March 1, 2024.

**3. Information Security Roles and Responsibilities Policy**

**Objective**: To establish clear roles and responsibilities for protecting electronic information systems and related equipment.

**Policy Owner and Effective Date**: The CEO is the policy owner, and the plan becomes effective on March 1, 2024.

**Applicability**

* Applies to all Document360 infrastructure, network segments, systems, employees, and contractors involved in security and IT functions.

**Audience**

* All employees and contractors involved in the Information Security Program.
* Includes partners, affiliates, temporary employees, trainees, guests, and volunteers.

**Roles and Responsibilities**

1. **Executive Leadership**:

* Approves capital expenditures for security programs.
* Oversees execution and communication of information security and privacy risk management.
* Ensures compliance with laws and standards (e.g., GDPR, CCPA, SOC 2, ISO 27001).
* Reviews vendor service contracts and oversees third-party risk management.

2. **VP of Engineering:**

* Oversees information security in software development.
* Implements and monitors security controls for development and IT processes.
* Conducts IT risk assessments and communicates risks to leadership.

3. **VP of Customer Support:**

* Manages information security tools and processes in customer environments.
* Ensures compliance with data retention and deletion policies.

4. **System Owners:**

* Maintain confidentiality, integrity, and availability of information systems.
* Approve access and change requests for their systems.

5. **Employees, Contractors, Temporary Workers:**

* Act responsibly to protect health, safety, and information resources.
* Identify areas for improved risk management practices.
* Report incidents and adhere to company policies.

6. **Chief Human Resources Officer:**

* Ensures employees and contractors are qualified and competent.
* Oversees background checks, policy presentation, and Code of Conduct adherence.
* Evaluates employee performance and provides security training.

**Policy Compliance**

* Compliance measured through reports, audits, and feedback.
* Exceptions must be pre-approved by the CEO.
* Non-compliance can lead to disciplinary actions, including termination.

**Document Control**

* **Version**: 1.0
* **Date**: February 3, 2024
* **Author**: Yasser Elsaid
* **Approved by**: Yasser Elsaid

**4. Secure Development Policy**

**Policy Owner and Effective Date**: The CEO is the policy owner, and the plan becomes effective on March 1, 2024.

**Purpose:** To ensure that information security is designed and implemented within the development lifecycle for applications and information systems.

**Scope:** Applies to all Document360 applications and information systems that are business critical and/or process, store, or transmit Confidential data.

**Secure-by-Design Principles:**

* Minimize attack surface area.
* Establish secure defaults.
* Apply the principle of Least Privilege.
* Implement defense in depth.
* Fail securely.
* Avoid security by obscurity.
* Keep security simple.

**Privacy-by-Design Principles:**

* Proactive, preventative approach.
* Privacy as the default setting.
* Privacy embedded into design.
* Full functionality without compromising privacy.
* End-to-End Security.
* Full lifecycle protection.

**Development Environment:** Logical or physical segregation of environments: Production, Test/Staging, Development.

**System Acceptance Testing:** Establish acceptance testing programs and criteria for new information systems, upgrades, and new versions. Complete a Release Checklist before deploying code.

**Protection of Test Data:** Test data must be selected carefully, protected, and controlled. Confidential customer data must be protected and not used for testing without explicit permission.

**Change Control Procedures:** Ensure development, testing, and deployment of changes are not performed by a single individual without approval and oversight.

**Software Version Control:** All software is version controlled, with access restricted based on role.

**Policy Compliance:** Measured through reports, audits, and feedback. Non-compliance may result in disciplinary action, up to and including termination.

**5. Code of Conduct Policy**

**Policy Owner**: The CEO is responsible for the policy.

**Effective Date**: The policy becomes effective on March 1, 2024.

**Purpose**: The policy aims to establish and maintain a safe and inclusive environment for all staff members.

**Scope**: This policy applies to all staff members across all professional settings within the organization.

**Culture**: The organizational culture promoted by this policy emphasizes respect, collaboration, and consideration among all employees.

**Expected Behavior**: Staff members are expected to actively participate in creating a respectful and collaborative workplace environment.

**Unacceptable Behavior**: Any form of harassment, violence, discrimination, or inappropriate conduct is strictly prohibited.

**Weapons Policy**: The policy prohibits the possession of weapons on company premises, with strict consequences for violations.

**Consequences**: Non-compliance with this policy will result in immediate corrective actions, including disciplinary measures and the requirement to report violations.

**Responsibility**: The CEO holds the responsibility for ensuring that all staff members adhere to and uphold the principles outlined in this policy.

**6. Access Control Policy**

**Policy Owner**: The CEO is responsible for the policy.

**Effective Date**: The policy becomes effective on March 1, 2024.

**Purpose:** The purpose of this policy is to restrict access to information and systems to authorized individuals in accordance with business objectives.

**Scope:** This policy applies to all systems operated by Document360 that handle confidential data for employees and external parties with network access.

**Access Control and User Management Summary:**

**Identifying Users:** Access privileges are allocated based on specific job roles and competencies required to perform tasks.

**Maintaining Authorization:** All allocations of privileged access are documented and maintained to ensure accountability.

**Enforcing Security Measures:** Multi-factor authentication (MFA) is mandatory for privileged access to enhance security. Generic administrative IDs are prohibited to prevent unauthorized usage.

**Adopting Protocols:** Time-bound access permissions are granted to limit exposure and reduce security risks.

**Logging and Auditing:** All privileged logins and activities are logged and audited to monitor for unauthorized access or misuse.

**User Access Reviews:** Regular reviews ensure that distinct and appropriate identities are maintained for those with privileged access.

**Access Control Policy:** Access is restricted to authorized parties only, ensuring that information remains protected.

**Password Management**: Secure log-on procedures and password policies are implemented to safeguard against unauthorized access.

**User Access Provisioning:** Access permissions are granted based on documented business requirements and validated needs.

**Violations & Enforcement:** Violations of this policy are reported and subject to enforcement measures to maintain compliance and security.

**7. Data Management Policy**

**Policy Owner**: The CEO is responsible for the policy.

**Effective Date**: The policy becomes effective on March 1, 2024.

**Purpose:** To ensure information is classified, protected, retained, and securely disposed of based on its importance to the organization.

**Scope:** Applies to all data, information, and information systems of Document360.

**Data Classification:** Confidential: Highly sensitive data needing the highest protection levels. Examples include customer data, PII, company financials, strategic plans, and technical reports.

**Restricted:** Proprietary information requiring thorough protection. Default classification for all company information unless otherwise stated. Examples include internal policies, legal documents, contracts, and emails.

**Public:** Information intended for public consumption and can be freely distributed. Examples include marketing materials and product descriptions.

**Data Handling:**

**Confidential Data:**

* Restricted access to specific employees or departments.
* Must be encrypted at rest and in transit.
* Should not be stored on personal devices or removable media.
* Requires secure storage and disposal.

**Restricted Data:**

* Access restricted to users with a need-to-know basis.
* Requires management approval for external transfer.
* Secure storage and disposal are mandatory.

**Public Data:** No special protection or handling controls required.

**Data Retention and Disposal:**

* Data retained as long as needed for business, regulatory, or contractual requirements.
* Confidential and restricted data securely deleted when no longer needed.
* PII deleted or de-identified when no longer needed for business purposes.

**Annual Data Review:** Management reviews data retention requirements annually to ensure compliance with the policy.

**Legal Requirements:** Data associated with legal holds or lawsuits is exempt from standard policy requirements and retained per legal counsel’s stipulations.

**Policy Compliance:** Compliance measured through business tool reports and audits.

**Exceptions:** Any exceptions to the policy require CEO approval.

**Violations & Enforcement:** Known policy violations should be reported to the CEO and can result in disciplinary actions, including termination of employment.

**8. Operations security policy**

**Policy Owner**: The CEO is responsible for the policy.

**Effective Date**: The policy becomes effective on March 1, 2024.

**Purpose and Scope:**

* Ensure the secure operation of information processing systems and facilities.
* Applies to all critical Document360 information systems and third-party entities with network access.

**Documented Operating Procedures:**

Technical and administrative procedures must be documented and accessible to relevant users.

**Change Management:**

* Significant changes must be documented, tested, reviewed, and approved before deployment.
* Emergency changes require retrospective review and authorization.

**Capacity Management:**

* Monitor and adjust processing resources and system storage to meet performance requirements.
* Include human resource capacity in planning and annual risk assessments.

**Data Leakage Prevention:**

* Identify and classify information per the Data Management Policy.
* Train users on proper handling of sensitive information.
* Use Data Loss Prevention (DLP) tools based on risk assessment.

**Web Filtering:**

* Implement DNS and IP blocking to restrict access to risky websites.
* Block websites with malicious content or command and control servers unless necessary for business.

**Separation of Environments:**

* Strictly segregate development, staging, and production environments.
* Do not use confidential production customer data in development or test environments without approval.

**Systems and Network Configuration:**

* Follow configuration and hardening standards to maintain system and network security.
* Review production network access configuration rules annually.

**Protection from Malware:**

* Implement detection, prevention, and recovery controls for malware.
* Utilize anti-malware and threat detection software on all company endpoints and emails.

**Information Backup:** Design and implement backup processes for systems and data, ensuring customer data recovery per SLAs.

**Logging and Monitoring:** Implement logging and monitoring to detect and respond to security incidents.

**Control of Operational Software:** Manage the installation and use of operational software according to established rules.

**Threat Intelligence:** Collect and analyze information security threats to produce actionable intelligence.

**Technical Vulnerability Management:** Identify, assess, and address technical vulnerabilities in a timely manner.

**Restrictions on Software Installation:** Establish rules for software installation to ensure security and compliance.

**Information Systems Audit Considerations:** Plan and agree on audit requirements to minimize disruptions to business processes.

**Systems Security Assessment and Requirements:** Include security requirements in the acquisition or significant changes to systems.

**Data Masking:** Implement data masking techniques to protect PII and sensitive data based on risk assessment.

---

## Data Privacy

We prioritize your privateness and cling to strict information dealing with practices:

* Data Privacy Compliance: We have signed a Data Processing Agreement (DPA) with OpenAI, outlining our commitment to data privacy and protection. For more details, refer to [DPA with OpenAI](https://ironcladapp.com/public-launch/63ffefa2bed6885f4536d0fe).
* We utilize OpenAI's ChatGPT 3.5 and GPT-4 models to power Eddy AI, ensuring cutting-edge performance and capabilities.
* This feature adheres to OpenAI's privacy policies by using a form of OpenAI integration.
* We send data to OpenAI via their APIs. An extract from the policy states, "OpenAI will not use data submitted by customers via our API to train OpenAI models or improve OpenAI's service offerings." Any data sent through the API to OpenAI will be retained for analytical purposes for a maximum of 30 days, after which it will be deleted.

> **NOTE**
>
> Read the complete [**OpenAI API data usage policies**](https://openai.com/enterprise-privacy/).
>
> If you have any queries regarding Document360's data policy, please read our [**Privacy policy**](https://document360.com/privacy/).

<a id="ai-writer-suite"></a>

## AI writer suite

**Plans supporting the use of AI writer suite**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The AI writer suite in Document360 is a powerful collection of AI-driven tools designed to streamline your content creation process, enhance the quality of your articles, and ensure your documentation remains engaging and relevant. Available directly within the knowledge base portal, this suite offers features that assist with everything from writing assistance and SEO optimization to generating FAQs and recommending related content, all aimed at boosting productivity and improving the reader experience.

---

## Features in the AI writer suite

1. [**AI writer**](/help/docs/ai-writer)

   1. **Outline creation**  
      Automatically generate a structured outline for your articles, helping you to get started with an article more quickly.
   2. **Make longer/Make shorter**  
      Adjust the length of your content with ease, either by expanding or condensing content based on your needs.
   3. **Change tone/Change voice**  
      Modify the tone or voice of your content to match your audience or brand guidelines.
   4. **Split sentences**  
      Break up long, complex sentences into shorter ones to improve readability.
   5. **Convert speech**  
      Switch between active and passive voice based on your documentation needs.
   6. **Improve it**  
      Enhance your writing by making it clearer, more concise, or more impactful.
   7. **Convert into table**  
      Automatically convert a list or paragraph into a neatly formatted table for easier data presentation.
2. [**AI FAQ generator**](/help/docs/ai-faq-generator)  
   Automatically create frequently asked questions (FAQs) based on the content of your article.
3. [**AI title recommender**](/help/docs/ai-title-recommender)  
   Receive AI-driven title suggestions to make your articles more engaging and easier to find.
4. [**AI SEO description generator**](/help/docs/seo-description-generator)  
   Automatically generate search engine-friendly descriptions to boost the visibility of your articles in the search engine results.
5. [**AI tag recommender**](/help/docs/ai-tag-recommender)  
   Get relevant tag suggestions to help categorize and improve the discoverability of your content within the knowledge base.
6. [**AI related articles recommender**](/help/docs/ai-related-articles-recommender)  
   Suggest relevant articles to users based on the current content, helping them find additional information quickly.
7. [**AI Chart generator**](/help/docs/ai-chart-generator)

   Generate pie charts, flow charts, and tables using Eddy AI based on the selected content.
8. [**AI alt text generator**](/help/docs/ai-alt-text-generator)

   Generate alt text for images and videos while uploading using Eddy AI to enhance user experience, improve accessibility, and boost search rankings.

---

## Multilingual support for Eddy AI writer suite

The Eddy AI writer suite seamlessly integrates with the Knowledge base site, offering support for a wider array of languages.

In addition to English (en, en-US, en-GB, en-AU), Eddy AI writer suite supports 15 other languages, including French (fr), Spanish (es), German (de), Norwegian (no), Dutch (nl), Portuguese (pt), Swedish (sv), Italian (it), Korean (ko), Finnish (fi), Polish (pl), Arabic (ar), Hebrew (he), Danish (da), and Brazilian Portuguese (pt-br).

If a workspace is configured with a language not supported by Eddy AI, such as Chinese, the search suite features will not be available for that workspace.

---

## Plan availability and usage limits

The availability of these features varies depending on your subscription plan. Users on the Professional, Business, and Enterprise plans have full access to all the features listed above, while the Freemium plan does not include the AI Writer Suite.

For most features, there is a soft limit of 5,000 credits per month. Specific features like the **SEO description generator** and **title recommender** have a limit of 1,000 credits per month. If you're approaching your limit, you will be notified within the platform.

Here’s a quick overview of the key credit limits per month:

* **Make longer/Make shorter/Outline creation/Change tone**: 5,000 credits
* **AI SEO description generator/AI Title recommender**: 1,000 credits
* **Other features**: Unlimited usage within Professional, Business, and Enterprise plans

These credit limits apply across the AI writer suite, ensuring you have ample room to use these powerful tools throughout the month.

<a id="ai-writer"></a>

## AI writer

**Plans supporting the use of AI writer suite**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 offers a wide range of AI-powered tools, powered by **Eddy AI**, to help contributors enhance their articles efficiently. Here's a detailed overview of available actions, how to use them, and best practices.

You can quickly launch **Eddy AI** using the keyboard shortcut **Ctrl + Spacebar**.

> NOTE
>
> By default, all the **Eddy AI** features will be enabled for a trial account in the Document360 project.

---

## Prerequisite

Ensure your project subscription supports the AI writer feature, which is turned off by default.

1. Navigate to **Settings**() > **AI features** > **Eddy AI** in the Knowledge base portal.
2. Turn on the **AI writer** toggle.

> NOTE
>
> * To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-writer-suite#multilingual-support-for-eddy-ai-writer-suite).
> * Third-party web browser extensions can affect the smooth working of the Document360 AI writer. If you face any issues, try disabling browser extensions such as ad blockers, password managers, or pop-up blockers before continuing.

---

## Accessing the AI writer actions

The AI writer enables you to perform the following actions on your content:

* Outline creation
* Improve it
* Change tone
* Convert speech
* Change voice
* Make longer
* Make shorter
* Convert into table
* Split sentence
* [AI chart generator](/help/docs/ai-chart-generator)

> NOTE
>
> The AI writer is available only in the Advanced WYSIWYG editor.

To access the AI writer features:

1. Select a piece of text content while writing in the Advanced WYSIWYG editor. The selected text must have at least ten words for Eddy AI to generate a response.

   The bubble menu appears with the available tools.
2. Click the **Eddy AI** option and choose the desired actions.

   **Outline creation**

   This feature generates a structured outline based on your article's content or a prompt.

   **How to use**:

   1. Create a new article with a relevant title.
   2. Click on the **Start writing with Eddy AI** feature.
   3. Ask Eddy AI to write an outline for you with the necessary information.

      Eddy AI will analyze your content and suggest an organized outline.
   4. Review and modify the outline as needed.

   **Benefits**:

   * Ideal for creating clear, logical structures in lengthy articles.
   * Saves time by providing an initial outline that you can refine.

   **Best practices**:

   * Always review the AI-generated outline to ensure it aligns with your goals.
   * Use this when writing complex articles or guides.

   **Improve it**

   This feature refines your text by improving grammar, semantics, clarity, and phrasing.

   **Example**:

   Original:  
   *"The system is highly effective because it works well in most cases."*

   Using **Improve it**:  
   *"The system is very efficient as it performs effectively in the majority of situations."*

   **Best practices**:

   * Use this option for drafts that need polishing before publication.
   * Check the enhanced version to ensure it aligns with your intent.

   **Change tone**

   Allows you to modify the tone of your text to suit different audiences or purposes. The available tone options are Professional, Friendly, Casual, Straightforward, and Confident.

   **Example**:

   Original:  
   *"The team will proceed with the update as soon as possible."*

   Change to **Friendly**:  
   *"The team is excited to get started on the update and will do so as soon as possible!"*

   Change to **Professional**:  
   *"The team will initiate the update at the earliest opportunity."*

   **Best practices**:

   * Use tone changes when targeting different audiences (e.g., casual for blogs, professional for reports).
   * Adjust based on the context and intended reader.

   **Convert speech**

   Document360's AI Eddy AI can change the selected text from direct speech to indirect speech or vice versa.

   **Example**:

   Original (Direct):  
   *"He said, 'I will definitely complete the task by tomorrow.'"*

   Convert to Indirect:  
   *"He said that he would definitely complete the task by the following day."*

   **Best practice**:

   Helpful when rewriting quotes or conversations for formal reports or documentation.

   **Change voice**

   Allows you to switch between active and passive voice.

   **Example**:

   Original (Active):  
   *"The team successfully completed the project within the specified date."*

   Using **Change voice** (Passive):  
   *"The project was successfully completed by the team within the specified date.*

   **Best practices**:

   Use this for stylistic choices or when passive voice is more appropriate (e.g., formal writing).

   **Make longer**

   This option allows you to expand the selected text by elaborating on ideas or providing additional details.

   **Example**:

   If you have a brief introduction like:  
   *"Document360 is a knowledge base platform with several advanced features."*

   Using **Make longer**, you can generate:  
   *"Document360 is a comprehensive knowledge base platform equipped with a wide array of advanced features that cater to the diverse needs of users. It offers a user-friendly interface, robust search functionality, seamless integration capabilities, and customizable branding options. The platform enables teams to create, manage, and share knowledge effectively, facilitating streamlined collaboration and information dissemination. With Document360, organizations can enhance productivity, foster innovation, and drive growth by harnessing the power of knowledge management."*

   **Best practices**:

   * Use this feature to elaborate on key points or when your content feels too brief or lacking depth.
   * Review the expanded text for relevance to avoid unnecessary verbiage.

   **Make shorter**

   This feature condenses text, making it more concise without losing its essence.

   **Example**:

   Original:  
   *"The Document360 platform provides a robust set of features, including version control, multi-language support, analytics, and a powerful AI-assisted search, which helps streamline the knowledge management process."*

   Using **Make shorter**:  
   *"The Document360 platform offers version control, multi-language support, analytics, and a powerful AI-assisted search to streamline knowledge management."*

   **Best practices**:

   * Use this when trying to reduce word count or simplify explanations.
   * Great for summarizing long passages or complex ideas.

   **Convert into table**

   This AI option converts selected content into a well-formatted table. It’s especially useful when dealing with data or lists that would be better presented in a table format.

   **Example:**

   A documentation team has 3 technical writers, whereas a customer support team has 2 technical writers. The documentation team has access to software such as SnagIT while the customer support team has access to software such as Freshdesk and Freshchat.

   Using **Convert into table**, the output becomes:

   | Team | Number of Technical Writers | Software Access |
   | --- | --- | --- |
   | Documentation Team | 3 | SnagIT |
   | Customer Support Team | 2 | Freshdesk, Freshchat |

   **Best practices**:

   * Use this for content that involves comparisons, data, or organized lists.
   * Tables can improve readability, especially for technical or detailed content.

   **Split sentence**

   Splits complex sentences into simpler ones to improve readability.

   **Example**:

   Original:  
   *"Document360 is an advanced platform, and it offers numerous features, including analytics, version control, and AI assistance, making it ideal for managing knowledge bases efficiently."*

   Using **Split sentence**:  
   *"Document360 is an advanced platform. It offers numerous features, including analytics, version control, and AI assistance. These features make it ideal for managing knowledge bases efficiently."*

   **Best practices**:

   * Useful when writing for broader audiences or when clarity is paramount.

   An AI response popup window will appear.
3. You can perform either one or more AI operations in a single window.

   > NOTE
   >
   > A single AI response window can be used to regenerate responses for up to 10 instances.

6. When you click **Regenerate**, the preset action is repeated.
7. Click **Insert** to replace the selected text.
8. Click **More** to view the **Eddy AI** features.

   Team accounts can rate the AI response once below the generated content.

![1_ScreenGIF-Overall_AI_Writer](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Overall_AI_writer.gif)

> NOTE
>
> The outline creation, make longer, make shorter, improve it, convert to table, convert speech, change voice and change tone features have a soft limit of 5000 uses per month. The SEO description generator, title recommender, and article summarizer features have a limit of 1000 uses per month.

---

### FAQs

#### What subscription plans support the use of the AI writer suite?

The AI writer suite is supported by the Professional, Business, and Enterprise subscription plans.

#### How can I activate the Eddy AI feature?

To activate Eddy AI, navigate to Settings > AI features > Eddy AI and turn on the AI writer toggle.

#### What actions can I perform using the AI writer?

You can perform actions such as making text longer or shorter, creating outlines, changing tone, converting speech, improving text, converting content into tables, changing voice, and splitting sentences.

#### Is the AI writer available in all editors?

No, the AI writer is only available in the Advanced WYSIWYG editor.

#### Will my data be secure when using Eddy AI?

* As this feature uses a form of OpenAI integration, we adhere to the privacy policies of OpenAI. We send data to OpenAI via their APIs.
* An extract from the policy states, "OpenAI will not use data submitted by customers via our API to train OpenAI models or improve OpenAI's service offerings."
* Any data sent through the API to OpenAI will be retained for analytical purposes for a maximum of 30 days, after which it will be deleted.

> Read the complete [**OpenAI API data usage policies**](https://openai.com/policies/api-data-usage-policies).  
> If you have any queries regarding Document360's data policy, please read our [**Privacy policy**](https://document360.com/privacy/).

#### Can I use the AI writer features multiple times in a month?

Yes, the content creation, make it longer, make it shorter, and change tone features have a soft limit of 5000 uses per month.

#### What should I do if I encounter issues with the AI writer?

If you face issues, try turning off any third-party web browser extensions that may affect the AI writer's performance.

#### Are there any best practices for using the AI writer features?

Yes, best practices include reviewing generated content for relevance, using features to elaborate or simplify text, and ensuring the tone matches your audience.

#### How many AI credits do my plan support?

5000 AI credits are allocated each month in the Professional, Business, and Enterprise plans. You can contact our customer support if you need to increase this limit.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="ai-faq-generator"></a>

## AI FAQ generator

**Plans supporting the use of AI writer suite**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **AI FAQ Generator** in Document360 is a powerful tool that automatically creates a list of frequently asked questions (FAQs) along with their answers based on the content of your article in the Advanced WYSIWYG editor. This feature is designed to save you time while ensuring that all essential questions are covered.

---

### Prerequisites

To utilize the AI FAQ Generator, ensure you have met the following requirements:

* You must have purchased the **Eddy AI content suite**.
* The **AI writer suite** must be enabled in your Document360 account. This feature is enabled by default upon purchase.

> NOTE
>
> To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-writer-suite#multilingual-support-for-eddy-ai-writer-suite).

---

## AI FAQ generator in Advanced WYSIWYG editor

1. Navigate to the article you wish to enhance in the **Advanced WYSIWYG editor**.
2. Locate and click the **Eddy** icon in the toolbar at the right of the editor.
3. From the dropdown menu, choose **Generate FAQs**.

> NOTE
>
> * The article must contain a minimum of **150 words** for the FAQ generator to function properly.
> * The generated FAQs will automatically be placed at the end of your article, allowing you to add additional content below this section if necessary.

### Customizing generated FAQs

Once the FAQs are generated, you have several options to customize them:

1. You can customize the title of the FAQ section to better fit your article.
2. Click on the **FAQ** section. You will have four options to customize the generated FAQs:

   1. **Settings** (): Click the **Settings** icon to adjust the FAQ template settings for this specific article. Changes made here will apply only to this article.
   2. **Regenerate** (): If you want to create new FAQs based on the current article content, click the **Regenerate** option.
   3. **Expand/Collapse** (): Use the **Expand/Collapse** icon to show or hide the answers to the FAQs.
   4. **Delete** (): If you wish to remove the entire generated FAQ section, click the **Delete** icon.

### Adding custom FAQs

1. Hover between any two FAQs where you want to add a new one.
2. Click the **Add question** ()icon that appears.
3. Fill in your custom question and answer.

To delete a specific FAQ:

4. Click on the FAQ you want to remove.
5. Select the **Delete** () icon that appears above it.

![Adding AI fAQ and FAQ builder in the Advanced WYISYWG editor.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreeenGIF-AI_FAQ_generator_in_the_advanced_WYSIWYG_Editor.gif)

### Locking FAQs

To prevent certain FAQs from being altered during regeneration:

1. Click the Lock () icon next to the FAQ you want to protect.
2. Locked FAQs will be marked with a badge, indicating they are safeguarded from changes.
3. You can still edit these locked FAQs manually if necessary.

If you want to generate additional FAQs while keeping the current ones locked, follow these steps:

1. Lock all existing questions.
2. Click **Regenerate** to create more relevant FAQs based on your article’s content depth.

> NOTE
>
> **FAQ templates** are different from the AI FAQ generator. For detailed information about FAQ templates, refer to the article on the [Advanced WYSIWYG editor](/help/docs/advanced-wysiwyg-editor-basics).

---

## Setting up the FAQ generator

You can customize the FAQ generator settings at the project level by following these steps:

1. Navigate to the Settings ()> **Knowledge base site** > **Article settings & SEO** tab in the Knowledge base portal.
2. In the **Article settings** tab, expand the **FAQ** accordion.

### Customization options

You can customize the FAQ templates as needed from the following options:

1. In the **Expand/Collapse** section, choose your option

   a. **Expand first**: Only the first FAQ will be expanded by default.

   b. **Expand all**: All generated FAQs will be expanded.

   c. **Collapse all**: All generated FAQs will be collapsed.
2. **Style:** For styling the FAQs, choose your desired option:

   a. **With border**: A border will appear around all sides of each FAQ accordion (default option).

   b. **Without border:** Only the bottom border will be displayed on each accordion, except for the last one.
3. **Expand arrow position:** You can select the position of the arrow for expanding FAQs, either right or left. By default, the arrow position is set to right.
4. **Expand/Collapse:** Customize the icons used for expanding and collapsing FAQs. Choose between arrow up/down or plus/minus options.

![Adding AI fAQ and FAQ builder in the Advanced WYISYWG editor.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Setting_page_in_the_Knowledge_base_portal.png)

---

### FAQs

#### What languages does the AI FAQ generator support?

The AI FAQ generator currently supports **English** language only.

#### How do I add a custom FAQ between the generated FAQs?

To add a custom FAQ between the generated FAQs, hover between any two FAQs, click the () icon, and select FAQs from the dropdown.

#### What is the minimum number of questions generated by the AI FAQ generator?

The AI FAQ generator typically produces between **5 and 10 questions**, depending on the content depth of your article.

#### Can I edit the AI-generated FAQs?

Yes, you can edit the AI-generated FAQs by selecting the desired FAQ and making the necessary changes.

#### Is there a usage limit for the AI FAQ generator?

You can use the AI FAQ generator up to 5000 times per month. You can contact our customer support if you need to increase this limit.

<a id="ai-title-recommender"></a>

## AI title recommender

**Plans supporting the use of AI writer suite**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Article Title Recommender** is one of the many AI-powered features available in Document360. This tool helps generate optimized article titles using Natural Language Processing (NLP) to analyze your content and suggest titles that capture the key information while maintaining the original context.

---

### Prerequisites

Before using the Article Title Recommender, ensure that the following prerequisites are met:

* **Preprocessed article content** should contain more than **50 words**.
* **Sufficient Document360 credits**: One title recommendation (three title options) consumes **1 credit**.

> NOTE
>
> To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-writer-suite#multilingual-support-for-eddy-ai-writer-suite).

---

## Using the article title recommender

The **Suggest Title** option is available in the article title section for new articles.

For published or draft articles, follow these steps:

1. Click the article title in the editor to display the **suggest title** feature.
2. Click the **Ask Eddy AI** button.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Title recommender 1.png)

   Three AI-generated title suggestions will appear.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Title recommender 2.png)
3. You can click **Generate more suggestions** for additional options.
4. Choose your preferred title and click **Choose**.
5. If none of the titles meet your needs, click **Cancel** to close the module.

#### Key options:

* **Suggested titles**: Each click on 'Suggest title' generates three title options. Select your preferred title by clicking the radio button beside it.
* **Share feedback**: You can upvote or downvote the suggested titles to provide feedback. This helps improve the feature's performance.
* **Save/Cancel**: After selecting a title, click **Save** or click **Cancel** to exit. **One credit** is consumed each time you click **Suggest title**, regardless of whether you save or cancel.

---

### Credit usage and limits

* Every time you click the **Suggest title**, **one credit** is used, even if you don’t save the suggestion.
* Your subscription plan determines your monthly credit limit.

  > NOTE
  >
  > The soft limit of **1000 credits per month** applies to the **title recommender** feature across the Professional, Business and Enterprise plans. Additional credits can be obtained by contacting customer support.
* **Credits do not automatically renew** each month. For additional credits, contact customer support.

---

### What are preprocessed words in Document360?

**Preprocessing** filters out certain elements from the article content for the purpose of title recommendation. The following elements are **excluded** from the word count:

* HTML tags
* Images
* URLs/links
* Code blocks

For example, if the article word count shown at the bottom of the editor is **220 words**, this includes all elements. After preprocessing, the word count might drop. Ensure your content has more than **50 preprocessed words** for the Title recommender to work.

---

### Data privacy

We prioritize the privacy of your Knowledge base data. The Title Recommender uses OpenAI integration, and we strictly adhere to the **OpenAI privacy policies**. An extract from the policy states: "OpenAI will not use data submitted by customers via our API to train OpenAI models or improve OpenAI's service offerings."

* [Read the full OpenAI API data usage policy here](https://openai.com/privacy).
* For Document360's data policy, refer to our Privacy Policy.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="seo-description-generator"></a>

## AI SEO description generator

**Plans supporting the use of AI writer suite**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The SEO description generator helps streamline the process of creating meta descriptions for your articles and category pages. Automatically generating concise and relevant descriptions ensures that your content is better optimized for search engines, enhancing visibility and click-through rates. This tool saves time while maintaining alignment with your content's focus and SEO best practices.

---

## Prerequisites

Before generating an SEO description for your article or category page, ensure that the following prerequisites are met:

1. **Sufficient credits**: You must have enough credits to generate an SEO description. Credits are consumed per description generated.
2. **Preprocessed content**: The article’s preprocessed word count (excluding HTML tags, images, URLs, and code blocks) must exceed 200 words. Keep in mind that the word count displayed at the bottom of the Document360 editor includes all elements, including those that do not count toward the meta description generation. Make sure the content exceeds 200 words after preprocessing.

   Example: If an article shows 250 words, but contains images, HTML, and links, the preprocessed count may drop below 200, making it ineligible for SEO description generation.
3. **Access permissions**: The **Ask Eddy AI** button will only be available to team members with the relevant permissions. If disabled, contact your administrator to gain access.

> NOTE
>
> To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-writer-suite#multilingual-support-for-eddy-ai-writer-suite).

---

## Using the SEO description generator

For individual articles or category pages,

1. In the Knowledge base portal, go to the desired article/category page.
2. Click on the More () icon at the top-right corner and select **SEO.**

   The **Article settings** panel will appear.
3. Expand the **SEO** section and click the **Ask Eddy AI** button.

   The meta description is generated by Eddy AI based on the article/category page content.
4. Review the generated description and click **Save**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/SEO.png)

> PRO TIP
>
> Always double-check the generated meta description to ensure it aligns with the intent of your article. Although AI-generated descriptions are efficient, manual review ensures the content is accurate and relevant to your audience.

---

## How to generate SEO descriptions for multiple articles/category pages?

You can generate meta descriptions for multiple articles/category pages in the same version and language.

1. Navigate to the Documentation () > **Content tools** > **Documentation** > **SEO description**.
2. Select the desired workspace from the project workspace dropdown.
3. Ensure that the selected language is **English.**
4. All the articles and category pages in the selected workspace and language appear.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/SEO Description.png)

> NOTE
>
> The preprocessed word count appears next to the article/category page name. You can generate meta descriptions only for the articles and category pages with a preprocessed word count of more than 200.

5. Use filter options to narrow down articles by SEO description availability, category, contributor, tags, or last updated date.

   **Example:** If you want to generate descriptions for articles that haven’t been updated recently, filter by "Date" to prioritize older articles.
6. Select the checkbox next to each eligible article (those with a preprocessed word count of over 200). Click **Ask Eddy AI** to generate meta descriptions for multiple articles at once.
7. Review the descriptions and click **Yes** in the confirmation prompt to save.

> PRO TIP
>
> Prioritize generating meta descriptions for high-traffic or cornerstone content first, as improving SEO for these pages can have the biggest impact on your overall search engine visibility.

---

### Best practices for writing SEO meta descriptions & titles

Creating effective meta descriptions and titles is crucial for improving your search engine rankings. Here are some best practices to help you craft strong meta descriptions and titles:

#### Best practices for SEO meta descriptions

1. **Keep it concise (around 155-160 characters):** Meta descriptions should be brief yet informative. They are snippets that appear in search engine results, so ensure they’re clear and concise.
2. **Include relevant keywords:** Incorporate primary and secondary keywords naturally, reflecting the core topic of the article to improve discoverability.
3. **Align with user intent:** Ensure the meta description answers what your target audience might be looking for. This helps increase click-through rates by attracting the right audience.
4. **Make it actionable:** Use calls to action like “Learn more,” “Discover,” or “Get started” to encourage users to click on your link.
5. **Unique for every page:** Ensure every page on your website has a unique meta description to avoid duplicate content issues.
6. **Avoid keyword stuffing:** Overloading the meta description with too many keywords can make it seem unnatural and may negatively impact SEO.

> **PRO TIP**
>
> Focus on clarity and relevance. Even though meta descriptions don’t directly impact rankings, they play a significant role in improving click-through rates.

#### Best practices for SEO titles

1. **Optimal length (50-60 characters):** Keep your title under 60 characters to ensure it doesn’t get cut off in search results.
2. **Include primary keywords:** The title should include your primary keywords, preferably at the beginning, to improve relevance for search engines.
3. **Reflect the article’s content:** The title should accurately represent the article’s subject matter to avoid misleading users or increasing bounce rates.
4. **Make it engaging:** Write compelling titles that spark interest. Use power words or questions to attract user attention.
5. **Avoid redundancy:** Ensure your title is clear, straightforward, and free from unnecessary repetition of words.
6. **Brand inclusion (optional):** You can add your brand’s name at the end of the title to improve brand visibility, but only if space allows without truncating essential keywords.

---

### FAQs

#### Why is an SEO description generator essential?

Use the SEO description generator to generate the meta descriptions for your articles and category pages effortlessly. This AI (Artificial Intelligence) powered feature will generate the best meta description for your articles and category pages based on the content.

#### What is a meta/SEO description?

A meta description or SEO description summarizes an article/category page. The meta description appears as snippets in the search engine results. Adding meta descriptions will improve your SEO, discoverability, and increase organic traffic.

#### How are credits associated with the SEO description generator?

Credits are required to generate SEO descriptions with the SEO description generator. One credit is consumed when you generate a meta description for an article/category page. For example, if you want to generate the meta description for 50 articles, you need 50 credits.

#### Does Document360 offer free credits for generating meta descriptions?

Yes, we offer ten free credits for all paid projects. You cannot avail free credits in the Trial plan.

#### Why the article word count shown in the editor varies from preprocessed word count?

The preprocessed word count excludes content elements such as HTML tags, Images, URLs/links, and Code blocks. The article word count includes all the elements in the content.

#### What happens when I generate an SEO description for an article which already has an SEO description?

* One credit would be consumed to generate the meta description.
* The generated meta description will replace the current meta description.

#### Can I generate different meta descriptions with the same article content?

No, the meta description changes only if the content is modified. Suppose you generate the meta description for the same content. In that case, the same meta description will be generated again, and one credit will be consumed.

#### Can I manually update the SEO title and SEO description?

You can manually update the SEO title and SEO description on the SEO description overview page or in the individual article settings.

#### Can I generate SEO descriptions for articles in languages other than English?

Currently, we support the SEO description generator only for the English language. However, you can manually add SEO descriptions for articles in other languages.

#### Do search engines crawl SEO descriptions of private articles?

No, search engines cannot crawl private articles.

#### What is the validity of the credits?

The credits are valid for the lifetime of the project.

#### Do the credits get affected by a change in the subscription plan?

No, the credits are not affected by a subscription plan change.

#### Does Document360 provide a refund for unused credits?

No, we don't provide a refund for unused credits.

#### Can I generate an SEO title with the SEO description generator?

You can only generate meta descriptions with the SEO description generator. As the article's title is considered an SEO title for an article without an SEO title, you can use Document360's AI title recommender feature.

#### Can I switch between languages in the SEO description module?

Yes, you can switch between languages in the SEO description module. This option lets you update the meta description for multiple articles in one place. However, the SEO description generator can be used only in English.

#### How many SEO descriptions can I generate?

Here’s a breakdown of the soft limits for the SEO description generator based on the pricing plans:

* **Professional**: 1000 descriptions/month
* **Business**: 1000 descriptions/month
* **Enterprise**: 1000 descriptions/month

#### Is my data security maintained?

We understand that your Knowledge base data is sensitive. As this feature uses a form of OpenAI integration, we adhere to the privacy policies on OpenAI. An extract from the policy states, "OpenAI will not use data submitted by customers via our API to train OpenAI models or improve OpenAI's service offerings."  
Read the complete [**OpenAI API data usage policies**](https://openai.com/policies/api-data-usage-policies)  
If you any queries regarding Document360's data policy, please read our [**Privacy policy**](https://document360.com/privacy/)

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="ai-tag-recommender"></a>

## AI tag recommender

**Plans supporting the use of AI tag recommender**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The AI tag recommender is a powerful tool that leverages Artificial Intelligence (AI) to suggest relevant tags for your article or category page content. By analyzing the content and identifying common keywords and topics, the AI recommends a set of tags. These tags help categorize and organize your content, making it easier for both team members and readers to find the right information within your Knowledge base.

---

### Prerequisites

* **Preprocessed article content** must be more than 50 words.
* You must have the relevant access permissions to generate tags.

> NOTE
>
> To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-writer-suite#multilingual-support-for-eddy-ai-writer-suite).

---

## Accessing the recommended tags for an article

1. Go to the desired article in the {{glossary.Knowledge base portal}}.
2. Click **More** (•••) at the top right of your editor next to the Publish button.
3. Select **Tags** to open the **Article settings** page.
4. Click the **Ask Eddy AI** button.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/AI tag recommender 1(1).png)

   You will find a set of AI-suggested tags based on the article content in the **Eddy AI recommends** section.

   > NOTE
   >
   > To use the AI tag generator, your article must have a word count of at least 200 words.
5. Click to choose the suitable tags to add them to the article and click **Save**.
6. Reopen the article settings to regenerate tags.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/AI tag recommender 2.png)

> NOTE
>
> The recommended tags also appear in the confirmation prompt when publishing an article. In the **Publish confirmation** prompt. Expand the **Configure article settings** section and click **Ask Eddy AI** in the **Tags** section for tag recommendations. Select the suitable tags to add it before publishing the article.

---

### What does preprocessing mean?

Preprocessing refers to the filtering of specific elements in the article or category page content. The following elements are excluded when generating tags:

* HTML tags
* Images
* URL/links
* Code blocks

For example, if your article shows 80 words at the bottom of the Document360 editor, this number includes HTML tags, links, and code blocks. After preprocessing, the word count might be reduced. Ensure the preprocessed article contains more than 50 words to generate tags.

---

**Why is tagging important?**  
Adding tags to your articles is essential for effective content management, especially when dealing with a large volume of information. Tags categorize articles based on themes or topics, making them easier to locate through searches. Proper tagging improves search precision, enhances content discoverability, and ensures that related articles are grouped together, benefiting both your internal team and external users.

---

## Best practices for content management

To make the most out of tagging, follow these best practices to ensure your knowledge base is well-organized and easy to navigate:

1. **Create a consistent tagging structure**: Establish clear guidelines for how tags should be used across all articles. Consistency is key to making sure similar content is grouped appropriately. For instance, decide in advance whether to tag articles based on topics, products, or user roles and follow this approach throughout.
2. **Use specific and relevant tags**: Avoid broad or vague tags that don't provide enough context. Focus on tags that directly relate to the article's core content. For example, instead of using a general tag like "Update," specify "Security Update" or "Feature Update."
3. **Limit the number of tags**: While tags are important, applying too many can be counterproductive. Aim to use 3-5 key tags per article that best describe the content. This keeps searches focused and avoids cluttering the tagging system.
4. **Review and update tags regularly**: As your content evolves, review and update your tags to ensure they remain relevant. Retire or modify tags that are outdated or no longer applicable to ensure efficient content retrieval.
5. **Group content using tags**: Tags allow you to group related content, improving navigation. For example, you could tag all articles related to "Onboarding," "Troubleshooting," or "Product Features" to create clusters of related content, helping users easily find what they need.
6. **Leverage the AI tag recommender**: Use the AI Tag Recommender feature to ensure consistent and relevant tagging across your articles. The AI's suggestions will help maintain uniformity, which is especially useful when different team members are managing content.

---

### FAQs

#### Who can generate the Tags?

Team accounts with the following permission combinations can generate the tags:

* Update article settings + Manage Tags
* Publish article + Manage Tags
* Update article settings + Publish article + Manage Tags

#### Can I generate the tags for multiple articles in one go?

Currently, you can generate the tags for one article at a time.

#### Does using the AI tag recommender feature spend credits?

No, the AI tag recommender feature does not consume any Eddy AI credits. This feature currently offers unlimited usage without any credit limitations.

#### Can I still add the Tags manually?

Yes, you can add the Tags manually.

#### Can I turn off the Tag recommendations?

No, you cannot turn off the Tag recommendations.

<a id="ai-related-articles-recommender"></a>

## AI related articles recommender

**Plans supporting the use of AI related articles recommender**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360's AI-powered related articles recommender enables team accounts to automatically associate relevant related articles based on the content of your current article. This feature enhances the user experience by ensuring that readers have quick access to additional information related to their queries.

---

### Prerequisites

* Preprocessed article content must be more than 200 words.
* You must have the relevant access permissions and credits to generate related articles.

> NOTE
>
> To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-writer-suite#multilingual-support-for-eddy-ai-writer-suite).

---

## Accessing the AI related article recommender

You can add related articles using Eddy AI by following the below steps:

1. Navigate to the **Documentation** in the Knowledge base portal.
2. Select any published or unpublished article.
3. Click on the **More** (•••) option and select **Related articles**.

   If related articles have already been added, you can view the list below the search bar.
4. Click **Ask Eddy AI**, and Eddy AI will recommend the related articles.

   > NOTE
   >
   > To use the AI related article recommender, your article must have a word count of at least 50 words.
5. Click the **Add** () icon to include the desired articles in the related articles list.
6. Turn on the **Auto relate this article to all related articles** toggle, if needed.

   > NOTE
   >
   > When **Auto relate this article to all related articles** is enabled, if Article-A is added as a related article in Article-B, then Article-B will appear as a related article in Article-A. Save time by using this toggle for adding related articles.
7. Once you have made changes, click **Save**.

   > NOTE
   >
   > To add related articles to your entire Knowledge base in one instance, read the article on [**Dynamic related article recommendation**](/help/docs/ai-dynamic-related-articles-recommendation) article.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Adding_related_articles_manually_KBsite_1_0.gif)

---

### Accessing the AI related article recommender in the publish checklist

You can also use the Related articles recommender when publishing an article by following these steps:

1. Click **Publish** on any desired article.

   The **Publish confirmation** prompt will appear.
2. Expand the **Configure article settings** section.
3. Scroll down to view the **Related articles** section.
4. Click **Ask Eddy AI**, and Eddy AI will recommend the related articles.
5. Click the **Add** () icon to include the desired articles in the related articles list.
6. Once done, click **Yes.**

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screengif-Adding_related_articles_in_publish_checklist.gif)

---

### Viewing related articles in the knowledge base site

In the knowledge base portal, related articles are generated by Eddy AI and can be found in the **Related articles** section at the bottom of each article. Readers can click on a related article to navigate directly to it, making it easy to explore additional resources and information relevant to the current reading.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Related articles in KB site.png)

---

### FAQs

#### How many related articles can Eddy AI generate at one time?

Eddy AI can generate a maximum of 3 related articles at one time.

#### Can I manually add related articles in addition to those recommended by Eddy AI?

Yes, you can manually add articles, and Eddy AI’s recommendations will complement your selection.

#### Will previously added related articles be overwritten when I use Eddy AI?

No, Eddy AI will suggest additional articles. You can choose to add them without affecting your existing related articles.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="ai-chart-generator"></a>

## AI Chart generator

**Plans supporting the use of AI chart generator**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **AI Chart generator** in Document360 allows you to automatically convert text into various visual formats, such as pie charts and flow charts. This feature streamlines the process of creating charts, eliminating the need for third-party tools and saving time in generating visual aids directly within your articles.

## Prerequisites

To use the AI Chart generator, you must meet the following requirements:

* You must have an active subscription to the Eddy AI content suite.
* The AI writer suite must be enabled in your Document360 account.
* Ensure that the text or table you want to convert is within the main body of your article. Text within comments or image captions cannot be used for chart generation.

> NOTE
>
> To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-writer-suite#multilingual-support-for-eddy-ai-writer-suite).

---

## Creating charts from text

1. In the Advanced WYSIWYG editor, highlight the content you want to turn into a chart.
2. Click the Eddy AI option in the floating bubble menu and select the **Generate** option from the dropdown menu.
3. Choose the type of chart you want to generate. Available options include **Pie chart**, **Flow chart**, and **Table**.
4. The system will create a chart of the highlighted text based on your selection. If the generated chart is not satisfactory, you can regenerate it up to 10 times. Regenerations are tracked and displayed in tabs, allowing you to review previous versions and select the best one.
5. Once you are satisfied with the generated chart, you can either replace the selected text or insert the chart below the selected text as an image within your article.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_GIF-Create_flow_chart_from_text.gif)

> NOTE
>
> If the system fails to generate the chart, an error message will be displayed: "No results found. Please revise the content or add more context and try again." You can dismiss the error message by clicking elsewhere on the screen or the close button.

## Creating charts from tables

1. Highlight the table you want to convert into a chart.
2. Click the Eddy AI option in the floating bubble menu and select the **Generate** option from the dropdown menu.
3. Choose the type of chart you want to generate. Available options include **Pie chart**, **Flow chart**, **Table**.
4. The system will create a chart of the highlighted text based on your selection. If the generated chart is not satisfactory, you can regenerate it up to 10 times. Regenerations are tracked and displayed in tabs, allowing you to review previous versions and select the best one.
5. After generating the chart, you can either replace the table or insert the chart below the table as an image.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_GIF-Create_piechart_from_table.gif)

> NOTE
>
> The final generated chart which you use in your article is saved in the Document360 Drive, allowing you to reuse it in other articles if needed.

## Customizing charts

After generating a chart, you can customize its appearance using the editing options available for images in Document360:

* **Alignment and positioning**: Use the bubble menu to adjust the alignment or inline positioning of the chart.
* **Edit chart**: You can edit the chart using the image editing options in the editor, such as cropping, resizing, or adding annotations.

> NOTE
>
> Although the chart cannot be edited directly once inserted into the article, you can undo the action, update the content, and generate a different result, or regenerate the chart using the same text but with a different chart type.

* **Undo option**: If you accidentally replace content with a generated chart and want to revert, use the Undo (Ctrl+Z) option to restore the original content.

## Supported chart types

Document360 currently supports the following chart types:

* **Pie charts**

  + **Use case**: Show the distribution of parts within a whole. Useful for visualizing proportions, such as categories, percentages, or data segments.
  + **Example**: Display the percentage of tasks completed by different team members.
* **Flow charts**

  + **Use case**: Map out processes, workflows, or decision sequences. Ideal for illustrating step-by-step procedures or decision trees.
  + **Example**: Outline the steps involved in a document approval process or a user onboarding workflow.
* **Tables**

  + **Use case**: Present structured data for easy comparison. Ideal for displaying data sets, such as comparisons or performance metrics.
  + **Example**: Compare product features, service levels, or user feedback across different categories.

## File naming convention

All generated charts will follow a standardized naming convention. The file name will be AI generated based on context, or the selected content. The file name will be appended with the chart type. For example - **sales\_data\_pie\_chart.png**.

---

### FAQs

#### Can I edit a generated chart?

No, once a chart is generated, it cannot be edited directly. However, you can regenerate the chart with updated content or switch to a different chart type.

#### What are the possible reasons for chart generation to fail, and how can I fix it?

Chart generation may fail due to:

1. Insufficient or incomplete data.
2. Unsupported content (e.g., comments, captions).
3. Formatting issues or exceeding data limits.

To resolve this, provide more context by using structured lists, numeric data, or grouping information logically (e.g., by region, product type). These text types are ideal for generating accurate charts. If generation fails, revise the content and try again.

#### Where are the generated charts saved?

The final generated charts used in the article are saved in the Document360 Drive, allowing you to reuse them in multiple articles. The generated charts will be saved to **Images** > **Documentation** in the Document360 Drive.

#### How many times can I regenerate a chart?

You can regenerate charts type up to 10 times. This includes switching between chart types.

#### Are all versions of generated charts saved?

No, only the final chart that you choose to insert or replace in the document will be saved in the Document360 drive. Charts generated during the regeneration process are not saved unless they are inserted into the article.

#### Is there an undo option after replacing content with a chart?

Yes, you can use the Undo (Ctrl+Z) option to restore the original content if you are not satisfied after replacing content with a generated chart.

#### Does the AI Chart generator consume Eddy AI credits?

Yes, each chart generated using the AI Chart generator consumes credits from your monthly Eddy AI credit limit. This includes generating charts from text or tables, as well as regenerating charts to try different types or updated visuals. Each generation or regeneration counts as one credit deduction from your monthly credit allowance under the Eddy AI content suite.

<a id="ai-alt-text-generator"></a>

## AI alt text generator

**Plans supporting the use of AI alt text generator**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

> NOTE
>
> For users on the Legacy plans, AI alt text generation will be available if you have purchased Eddy AI content suite add-on.

Writing alt text for images can be time-consuming but is vital for accessibility and discoverability. Alt text, also known as alt tags, appears when an image fails to load and comes to the help of visually impaired users when they choose the read out loud option in the KB site. With 20% of Google searches being image-based, optimized alt text enhances user experience, improves accessibility, and boosts search rankings.

To address this challenge, Document360 offers the Eddy AI alt text generation feature. This tool automatically suggests alt text for your images, helping you adhere to best practices like keeping descriptions concise while ensuring accessibility compliance. You can easily edit or use these suggestions as they are, saving time and effort.

Document360’s Eddy AI alt text generation feature streamlines this process by providing concise, accessible suggestions. For instance, it might describe a software interface as **Document360’s settings dashboard with configuration options**. This ensures compliance, saves time, and enhances discoverability.

By combining accessibility and search optimization, the Eddy AI alt text generation feature empowers businesses to make their visual content more impactful while delivering a seamless user experience.

> NOTE
>
> * This feature is enabled by default if the AI writer is enabled.
> * You can generate up to 5000 alt texts per month. Each API call deducts one soft limit, so one project can use it across various articles.
> * Eddy AI can only generate alt text for images smaller than 20 MB in JPEG, JPG, PNG, and WEBP formats.
> * Eddy AI Alt text generator feature supports only in **English** language.
> * Eddy AI Alt text generator may have accuracy limitations with panorama images, fisheye view images, and icons with monochrome colors.
> * To know more about the languages supported by Eddy AI,  [click here](/help/docs/ai-writer-suite#multilingual-support-for-eddy-ai-writer-suite).

---

## Generating AI alt Text in the Advanced WYSIWYG Editor

To generate alt text while uploading an image in the Advanced WYSIWYG editor, follow these steps:

1. Navigate to the article in the Advanced WYSIWYG editor.
2. Use the slash command `/image` or go to **Insert > Image**.

   The **Insert Image** panel will appear.
3. Insert images using one of the following methods:

   * **Upload from my device**:  
     Select an image from your local device. Eddy AI will automatically generate alt text in the **Alt Text** field.
   * **Choose from Drive**:  
     Select an image from the Drive.

     + If the image already has alt text from the Drive, it will persist.
     + To update or regenerate the alt text, click the inserted image, then click the **Alt text** () icon in the floating menu.
   * **Drag and drop**:  
     Drag and drop the desired image in the panel. Eddy AI will automatically generate alt text in the **Alt Text** field.
   * **External URL**:  
     Enter the image’s URL. Eddy AI will automatically generate alt text in the **Alt Text** field.
4. To regenerate alt text, remove the existing text and click  **Generate**.
5. **For multiple images**, Eddy AI will generate alt text for all images. To regenerate, remove the existing alt text and click  **Generate** for each image individually.
6. Review and edit the generated alt text as needed.
7. Once done, click **Insert** to add the image to your article.

> NOTE
>
> For more information on adding images, read the article on [Inserting images in the Advanced WYSIWYG editor](https://docs.document360.com/docs/adding-images-to-articles#inserting-an-image-advanced-wysiwyg-editor).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGIF-Adding_Alt_Text_for_pasted_images.gif)

---

### Generating AI alt text while copy-pasting images in the Advanced WYSIWYG editor

To generate AI alt text while copy-pasting images in the Advanced WYSIWYG editor:

1. Drag and drop or paste the desired image into the Advanced WYSIWYG editor.
2. Click on the pasted image, and the floating menu will appear.
3. Select the **Alt text** () icon.
4. In the **Image alt text** field, either:

   * Enter the alt text manually.

     Alternatively, click  **Generate** to create alt text using Eddy AI.
5. Click the  icon to save the alt text.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGIF-Adding_Alt_Text_for_pasted_images.gif)

---

## Generating AI alt text while uploading an image in Drive

To generate an alt text while uploading an image to the Drive:

1. During the image upload process, either:

   * Manually enter the alt text.

     Alternatively, click  **Generate** to create Eddy AI-generated alt text.
2. For multiple images:

   * Click  **Generate** next to each image to create alt text individually.

     Alternatively, click  **Generate for all images** to generate alt text for all uploaded images in one go.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Adding_alt_text_for_multiple_images_in_drive.gif)

### Generating AI alt text for an uploaded image in Drive

To generate alt text for an image already uploaded in the Drive:

1. Navigate to the **Drive** () in the Knowledge base portal.
2. Click the desired image, and the **File details** panel will appear.
3. In the **Alt text** section:

   * Click  **Generate** to create alt text using Eddy AI.
   * To regenerate, remove the existing alt text and click  **Generate** again.
4. Once done, click **Update** to save the changes.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Generating_AI_alt_text_for_an_uploaded_image_in_Drive.gif)

## Try this feature

Explore this feature with an interactive demo below and see how it works in real time.

---

### FAQs

#### How many AI alt texts can I generate per month?

You can generate up to 5000 alt texts per month per project.

#### Is the AI alt text generation feature enabled by default?

Yes, this feature is enabled by default if the AI writer is enabled.

#### Can I review and edit the generated AI alt text?

Yes, you can review and edit the generated alt text before accepting it.

#### How do I generate AI alt text when uploading an image to Drive?

When uploading an image to Drive, simply click the  **Generate** button next to the alt text field to create AI-generated alt text.

#### How do I regenerate AI alt text for an image?

To regenerate the alt text, delete the existing alt text, the  **Generate** button will appear to help you regenerate using Eddy AI.

#### What happens if the Generate button is disabled?

If the  **Generate** button is disabled, it means your monthly AI credit balance has been exhausted. You can contact your admin/Document360 support.

#### What happens if I try to upload multiple images but don't have enough credits?

If your available credit balance is insufficient for all images in a single upload, the **Generate all** button will be disabled.

For example, if you upload 10 images but only have 5 credits, the  **Generate all** option will not be available. However, you can manually select up to 5 images (or as many as your credits allow) and click  **Generate** to create alt text for the selected images.

#### Can AI generate alt text for all image formats?

AI can only generate alt text for images smaller than 20 MB in JPEG, JPG, PNG, and WEBP formats.

#### What if I copy-paste an image in an article? How can I add alt text?

If the article is in Advanced WYSIWYG editor, you can generate the AI alt text for the image. Click the pasted image in the article and a floating menu will appear. Click on the **Alt Text** () icon and then **Generate** to create the alt text. Click the  icon to save.

#### Are KB customization images included in the alt text generation count in Drive?

No, only images from published articles with dependencies, as well as those from templates, snippets, and glossary, are counted.

<a id="ai-search-suite"></a>

## AI search suite

**Plans supporting the use of AI search suite**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The AI search suite enhances the user experience by integrating AI-powered tools that streamline search and content discovery. The suite includes three key features: Ask Eddy AI assistive search, Ask Eddy AI API, and an AI article summarizer, all designed to improve knowledge base navigation and content summarization.

---

## Features in the AI search suite

1. [**Ask Eddy AI assistive search**](/help/docs/ai-assistive-search-ask-eddy)

   This feature provides an intelligent search experience, allowing users to ask questions directly and receive relevant, AI-curated answers. By leveraging machine learning, it enhances the accuracy and speed of content retrieval, making knowledge base navigation more efficient.
2. [**Ask Eddy AI API**](/help/docs/ask-eddy-ai-api)

   This API gives you a flexible, customizable solution, allowing you to seamlessly integrate GenAI search directly into your product's UI. With this integration, your users can access the Ask Eddy feature without needing to navigate through product documentation, providing a more streamlined and efficient experience.
3. [**AI article summarizer**](/help/docs/ai-article-summarizer)

   The AI article summarizer is integrated into the Knowledge base site to help users quickly get the gist of lengthy documents. This tool scans articles and condenses them into shorter summaries, providing users with key takeaways without having to read through the entire content.
4. [**Text to voice functionality**](/help/docs/text-to-voice-functionality)

   The text-to-voice feature on your Knowledge base site allows users to listen to articles instead of reading them, saving time. This functionality is beneficial for multitasking, allowing users to absorb information while performing other activities.

---

## Multilingual support for Eddy AI search suite

The Eddy AI search suite seamlessly integrates with the Knowledge base site, offering support for a wider array of languages.

In addition to English (en, en-US, en-GB, en-AU), Eddy AI search suite supports 15 other languages, including French (fr), Spanish (es), German (de), Norwegian (no), Dutch (nl), Portuguese (pt), Swedish (sv), Italian (it), Korean (ko), Finnish (fi), Polish (pl), Arabic (ar), Hebrew (he), Danish (da), and Brazilian Portuguese (pt-br).

If a workspace is configured with a language not supported by Eddy AI, such as Chinese, the search suite features will not be available for that workspace.

---

## Plan availability and usage limits

1. **Ask Eddy search**: This feature is included with 2,000 credits per month for the **Business** plan and 5,000 credits per month for the **Enterprise** plan, with each search query consuming 1 credit. It is tailored to support businesses with high AI-driven search needs. To purchase additional credits, please contact support.
2. **Ask Eddy AI API**: This feature is included with 2,000 credits per month for the **Business** plan and 5,000 credits per month for the **Enterprise** plan, with each call consuming 1 credit. This enables enterprises to scale AI-powered search functionality seamlessly.
3. **AI article summarizer**: This feature is included with 1,000 credits per month for the **Business** and **Enterprise** plans, with each summarization task consuming 1 credit. It enhances content summarization efficiency for improved workflow management.

The AI search suite's flexible credit system ensures businesses can tailor their usage to their specific needs, providing scalable solutions to meet growing demands for AI-enhanced search and content management tools. For more information on pricing, click [here](https://document360.com/pricing/).

<a id="ai-assistive-search-ask-eddy"></a>

## AI assistive search (Ask Eddy AI)

**Plans supporting the use of AI assistive search**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The Ask Eddy AI feature is available on your home page and the Knowledge base site's search bar. This AI assistant provides more contextual answers to reader queries and prompts. This helps the user avoid having to search and read through multiple articles. Instead, it provides answers from your existing Knowledge base.

> NOTE
>
> * By default, Eddy AI assistive search retrieves answers from the main workspace. To access information from a different workspace or across all workspaces, switch to the desired workspace using the filter on your knowledge base site.
> * After updating content in the published article, Eddy AI assistive search will take approximately 15 minutes to fetch the updated information in the knowledge base site.
> * To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-search-suite#multilingual-support-for-eddy-ai-search-suite).

The Ask Eddy AI will extract all information in your knowledge base, including the textual content, code blocks, tables, content reuse elements, and LaTeX.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Eddy_fetching_Code_block_information.png)

---

## Enable Ask Eddy AI for your Knowledge base site

1. Navigate to **Settings** () > **AI features** > **Eddy AI** in the Knowledge base portal.
2. Turn on the **AI assistive search** toggle.

   The AI assistant **Eddy AI**now starts indexing your Knowledge base content and this process takes a while. Once done, the Ask Eddy AI button will be available on your Knowledge base site search bar and the Home page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-AI_assisstive_search.png)

* The **KB site** checkbox will be the default selection which enables Eddy AI for searches on the Knowledge base site.
* The **KB widgets & extensions** checkbox enables Eddy AI for widgets and third-party tool integrations with Document360.
* The **Public API** checkbox activates Eddy AI for all API endpoints using a single API token.

---

## Accessing Ask Eddy AI

> For your information
>
> The Conversational Eddy AI enhancement is available exclusively in **KB site 2.0.** To explore KB site 2.0 without impacting your existing Knowledge base, go to **Settings** () **> Customize site**. For more details, read the article on [KB site 2.0 migration](/help/docs/kb-site-20-migration).

1. Click on the **Search bar** or press `Ctrl + K` on the Knowledge base site.
2. Start typing the keyword, and the general search results will appear.

> NOTE
>
> If Ask Eddy AI is not enabled in the Knowledge base portal, only the search bar will be available in the Knowledge base site.

3. Hit Enter and Ask Eddy AI will generate results along with the source articles.
4. Click the **Copy** () icon to copy the generated content if needed.
5. Provide feedback by clicking the **Like** () or **Dislike** () icon for the generated result.
6. Click **Source articles** to refer to the articles based on which the **Eddy AI** fetches information.

   The source URLs will be listed and numbered in the **Source articles** section. The same numbers will be used in the AI response to help you identify which parts of the response are fetched from each source article.
7. Hover over the number to find additional information, such as, if it’s an external source, you can find the title of the web page and a short description of the source article. Click on the number or the **Open in a new tab** () icon to open the source article in a new tab.
8. Click on the desired source article, to open the article in a new tab.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-External_sources.gif)

   **Eddy AI** will provide answers in the language the question is asked.
9. Choose the desired workspace or all workspaces from the filter dropdown to fetch results from **Eddy AI**.

> NOTE
>
> * If you filter workspaces during an Ask Eddy AI conversation, the generated results will be reset.
> * Eddy’s response will be contextual and will be based on the last five queries.

9. After the first query and answer, click the **Continue conversation with** **Eddy AI** text field to enter your next query and press Enter or click the **Send** icon.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Conversational_Eddy_AI.gif)

---

### Customize the Eddy AI Localization variables

1. Navigate to **Settings** () > **Localization & Workspaces**in the Knowledge base portal.

   By default, the **Localization & Workspaces** tab will appear.
2. Navigate to the **Localization variables** tab.
3. In the **Eddy AI** accordion, update the variable values according to your desired language.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenShot-AI_assisstive_search.png)

---

## Integrating Eddy AI in KB Widget with multi-lingual support

You can access Eddy AI within your knowledge base as a widget, in various languages including English (en-US, en-GB), French (fr), Spanish (es), German (de), Norwegian (no), Dutch (nl), Portuguese (pt), Swedish (sv), Italian (it), Korean (ko), Finnish (fi), Polish (pl), Arabic (ar), Hebrew (he), Danish (da), ensuring a seamless user experience.

> For more information, read the article on [Integrating Eddy AI in KB widget](/help/docs/knowledge-base-widget-getting-started).

---

## Enabling Eddy AI credits notification

You can configure notifications for Ask Eddy AI credit balance. To enable Credit usage alert toggle,

1. Navigate to **Settings** () > **Knowledge base portal**> **Notifications**.

   By default, the **Notification channels** tab will appear.
2. Go to the **Notification mapping**tab.
3. In **Eddy AI notifications**accordion, turn on the **Credit usage alert**toggle.

Once enabled, Document360 will send reminders to the configured notification channels when the credit balance drops to 20%, 10% of the total allotted balance, and when the balance expires.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_ScreenShot-AI_assisstive_search.png)

---

NOTE

Document360's "Ask Eddy AI" utilizes OpenAI APIs in its backend operations. Data is transmitted to OpenAI through their APIs. OpenAI adheres to a privacy policy that prohibits the use of customer-submitted data via our API for training OpenAI models or enhancing OpenAI's service offerings. Both Document360 and OpenAI comply with GDPR regulations. Additionally, Document360 is SOC 2 compliant.  
An extract from the policy states, "OpenAI will not use data submitted by customers via our API to train OpenAI models or improve OpenAI's service offerings."

> Read the complete [**OpenAI API data usage policies**](https://openai.com/policies/api-data-usage-policies)**.**  
> If you any queries regarding Document360's data policy, please read our [**Privacy policy**](https://document360.com/privacy/)**.**

---

### FAQs

#### What data or information does Ask Eddy AI collects?

Ask Eddy AI does not collect any Personal Identifiable Information (PII). We collect prompts (questions), **Eddy AI**'s response, citation articles, and feedback; This collected data is available as part of Eddy AI Search Analytics.

#### What technology does Ask Eddy AI use?

Ask Eddy AI utilizes OpenAI APIs under the hood for its functionality. We send data to OpenAI via their APIs. According to OpenAI's privacy policies, data sent via their APIs will not be used to train their GPT models.

#### Does Ask Eddy AI use any external source other than our knowledge base?

No, Ask Eddy AI does not use any other sources. It solely relies on your knowledge base content to generate responses. If there is insufficient information or context available in your knowledge base to answer a specific question, Ask Eddy AI will respond with "I do not know."

#### How do my readers use the AI-powered assistive search feature?

Your Knowledge base site users click the Ask Eddy AI button, and a prompt input popup opens. They can type in any prompt or query to get tailor-made answers.

#### How does Ask Eddy AI protect your data?

We know that privacy and security is critical for many organizations. We are committed to protecting your organization’s and user’s data and privacy. We use industry-standard security practices, reputable sub processors with SOC 2 compliance, and provide the controls needed for organizations to meet their own data protection requirements.

#### What does credit mean for Ask Eddy AI?

One credit equals one question (prompt) asked. As part of our standard offering, Ask Eddy AI can be used to ask 1000 questions per month. Please contact our support team or your customer success manager if you wish to purchase additional credits.

#### How does Ask Eddy AI work on private knowledge base?

Ask Eddy AI utilizes the access controls you have set to generate an appropriate response based on the user's access control and permissions. If a logged-in user lacks access to a specific article but asks a question where the restricted article holds the answer, Ask Eddy AI will respond with "I do not know."

#### How quickly does Eddy AI's response reflect new content?

After updating an article, it generally takes around 15 minutes for **Eddy AI**'s response to align with the changes if a question is posed regarding the updated content. Similarly, when deleting an article, **Eddy AI** typically takes about 15 minutes to stop referencing the content from the deleted article.

#### Does Ask Eddy AI search within attachments?

Currently, Ask Eddy AI does not search within attachments. This means any content within your PDF and Word document which you have attached or embedded within your knowledge base article, is not indexed by Ask Eddy AI. However, we will support this functionality in future release updates.

#### Does Eddy AI read Excel file data to provide answers if I upload a file?

No, Eddy AI does not fetch or read information from files uploaded in articles.

#### What happens if I select French as the workspace language but ask questions in English?

If you set French as your workspace's preferred language but ask questions in English, Eddy AI will respond in English.

> NOTE
>
> Eddy AI responds in the same language as the query, regardless of the workspace language.

#### How do I check my Eddy AI credit balance?

The admin/owner can view the remaining credits for using AI Assistive search feature from  **Settings** () > **AI features** > **Eddy AI** .

Document360 will send reminders to the configured notification channels when the credit balance drops to 20%, 10% of the total allotted balance, and when the balance expires.

#### How can I purchase additional credits for the Eddy AI assistive search?

You can purchase additional credits by navigating  **Settings** () > **AI features** > **Eddy AI**, and the Buy moreoption in the Document360 portal. If you are in trial version, you cannot purchase add-ons.

#### How do I configure email domain for Eddy AI credit notification?

To receive **Eddy AI** credit notifications via email, you need to configure your email domain. Go to **Settings** () > **Knowledge base portal**> **Notifications** > **Email domain**. By default, emails will be sent from [support@document360.com](mailto:support@document360.com) if the email domain is not configured.

#### What are the various notification channels for receiving Eddy AI credit notifications?

You can receive **Eddy AI** credits notifications in English from various notification channels such as webhook, Microsoft Teams, Slack, and email if you have set up the configuration. For more information of configuring notifications, read the article on [Notifications](/help/docs/notifications).

#### How do I configure the desired email address for receiving Eddy AI credit notifications?

After enabling the **Eddy AI** credits notification toggle, to receive **Eddy AI** credit notifications, configure your email address in  **Settings** () > **Knowledge base portal**> **Notifications**.

1. In the **Notification channels** tab, click on **New channel** and select SMTP.
2. Click **Next**.
3. Enter the channel name and the desired email address to receive notifications.
4. If required, you can add CC and **BCC**.

   For more information, read the article on [SMTP notification channel](/help/docs/smtp-email-notification-channel).

#### Why is Eddy AI not available in my API documentation?

**Eddy AI** is available only on the Knowledge base site and is not implemented for API documentation.

#### Can Eddy AI answer questions that require user login or involve restricted articles?

No, **Eddy AI** answers questions based on the user’s access control and permissions. If a logged-in user does not have access to a specific article, but they ask a question related to that article, **Eddy AI** will respond with *No results found.*.

#### Why is the Ask Eddy AI button greyed out?

The **Ask Eddy AI** button becomes greyed out or disabled when your Eddy AI credit limit has been reached. To continue using this feature, you will need to renew your credits.

The public-facing website where end-users can access articles and find answers to their questions.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="ai-dynamic-related-articles-recommendation"></a>

## AI dynamic related articles recommendation

**Plans supporting AI dynamic related articles recommendation**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The dynamic related articles recommendation feature allows you to effortlessly enhance your knowledge base site by automatically linking relevant articles across all content. This ensures that readers always find additional information related to their queries, improving navigation and overall user experience. In one instance, you can apply these related articles to your entire knowledge base.

> NOTE
>
> To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-search-suite#multilingual-support-for-eddy-ai-search-suite).

---

## Dynamic related articles recommendation

> For Your Information (FYI)
>
> The Dynamic related articles recommendation is available exclusively in **KB site 2.0**. To explore KB site 2.0 without impacting your existing Knowledge base, go to **Settings** () > **Customize site**. For more details, read the article on [KB site 2.0 migration](/help/docs/kb-site-20-migration).

You can dynamically add related articles to your Knowledge base site for all articles.

1. Navigate to **Settings** () > **AI features** > **Eddy AI**in the Knowledge base portal.
2. Turn on the **Dynamic related article recommendation** toggle.

   Now, **Eddy AI** will automatically add related articles to all the articles in your knowledge base site.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Dynamic_related_articles_recommendation.png)

Additionally, you can manually add more related articles by following these steps:

1. Navigate back to **Documentation** () and select the article to which you want to add related articles.
2. Click the **More** () option and select **Related articles**.
3. Click Ask Eddy AI, and **Eddy AI** will recommend the related articles.
4. Click the **Add**() icon to include the desired articles in the related articles list.
5. Turn on the **Auto relate this article to all related articles**  toggle, if needed.
6. Once you have made changes, click **Save**.

> NOTE
>
> When **Auto relate this article to all related articles** is enabled, if Article-A is added as a related article in Article-B, then Article-B will appear as a related article in Article-A. Save time by using this toggle for adding related articles.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Adding_related_articles_manually_KBsite_2_0.gif)

> NOTE
>
> The following scenarios apply if you have not yet enabled the **Dynamic related article recommendation** toggle:
>
> * If you have permission to enable the toggle, a banner will appear with the option to **Enable recommendations**. Clicking this will redirect you to the **Eddy AI** settings page, where you can turn it on.
> * If you do not have permission, you'll see an **I'm Interested** button. Clicking this will send an email to your team account owner, notifying them of your interest in enabling the feature.

### Knowledge base site view

After enabling the Dynamic related article recommendation feature, all articles recommended by this feature in the Knowledge Base will display relevant related articles, marked with an  icon next to the article name.

> NOTE
>
> **Eddy AI** recommends up to three articles. If manually curated articles are the same as Eddy's recommendations, the number of recommended articles may vary.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-Knowledge%20base%20view%20of%20dynamically%20added%20related%20articles.png)

---

### FAQs

#### What is the Dynamic related articles recommendation feature?

The Dynamic related articles recommendation feature automatically links relevant articles across all content in your knowledge base, enhancing navigation and user experience.

#### How can I enable the Dynamic related articles recommendation feature?

To enable it, navigate to **Settings** () > **AI features** > **Eddy AI** in the Knowledge base portal and turn on the Dynamic related article recommendation toggle.

#### Why are related articles not appearing for certain articles?

The dynamic related articles recommendation feature uses an algorithm to assess article relevance. Only articles that meet a specific relevance threshold will appear as related. If no similar articles are found, recommendations cannot be generated.

#### How do I identify articles recommended by the Dynamic related articles feature?

Articles recommended by the Dynamic related articles feature are marked with a  icon next to the article name in the Knowledge base site. However, if you manually add related articles or use the Ask Eddy AI feature to add them, the  icon will not appear.

The public-facing website where end-users can access articles and find answers to their questions.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="ai-chatbot"></a>

## AI Chatbot

**Plans supporting AI chatbot**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

> NOTE
>
> If you're on a **Legacy plan**, this feature is available only if you've purchased the AI assistive search add-on for your project.

In Document360, you can interact with the Eddy AI Chatbot to quickly get answers to your questions without having to search through Knowledge base articles. The Eddy AI Chatbot helps you find relevant information faster and more easily.

> NOTE
>
> * The Eddy AI Chatbot will be available exclusively for KB site 2.0 projects.
> * To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-search-suite#multilingual-support-for-eddy-ai-search-suite).

---

## Configuring the Eddy AI Chatbot

To enable Eddy AI in the Knowledge base widget:

1. Navigate to **Settings** () > **AI features** > **Eddy AI** in the Knowledge base portal.
2. Turn on the **AI assistive search** toggle.
3. Select the **KB widgets & extensions** checkbox.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Turn_on_KbWidget_in_Settings.png)

To configure the Eddy AI Chatbot in the Knowledge base portal:

1. Navigate to **Widget**() in the Knowledge base portal.
2. Click **Add widget**.
3. Enter your desired name for the Eddy AI Chatbot in the **Widget name** field (up to 30 characters).
4. By default, the **Configure & connect**tab will be selected.

#### **Connection**

5. In the **Widget JavaScript** accordion, find the **Widget key** and its JavaScript code.
6. Click the **Regenerate** () icon to regenerate the **Widget key**.
7. In the **Connect domains** accordion, find the domains where the widget displays.
8. In the **JWT** accordion, implement an authentication configuration for the Eddy AI Chatbot using JWT, ensuring a secure environment for private and mixed projects.

> NOTE
>
> For more information, read the article on [Securing Chatbot authentication using JWT](/help/docs/securing-chatbot-authentication-using-jwt).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot_Connection_section_in_Chatbot_AI.png)

#### **Customize the experience**

9. Select **Chatbot** as the widget type.

> NOTE
>
> Once a widget type is selected and saved, it cannot be changed.

10. In the **Style widget**accordion, customize Eddy AI chatbot’s styles and themes.

> NOTE
>
> For more information, read the article on [Styling the Eddy AI Chatbot](/help/docs/styling-the-chatbot).

11. In the **Content access** accordion, select the content level access for your readers, such as **Project**, **Workspace**, or **Category**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Customize_the_experience_in_the_Chatbot.png)

#### **Set controls**

12. In the **Widget security**accordion, enter your desired domain to ensure the widget is displayed exclusively on that specific domain.

> NOTE
>
> * Once a domain is added to the **Widget security** list, any project member who wants to install the Eddy AI Chatbot on a different domain must add that domain in the Widget security section.
> * If no domains are added to the list, the Eddy AI Chatbot can be integrated into any SaaS application or public website.
> * Please note, the **www.** is not considered part of your domain. Only add what follows **www.** in your URL.
>
>   Example: [document360.com](http://document360.com)

13. Preview the Eddy AI Chatbot on the right side of the page.
14. Once configured, click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Set_controls_in_Chatbot.png)

To display the created Eddy AI Chatbot on your Knowledge base site:

1. From the Knowledge base widget page, hover over the desired widget and click the **Copy script** () icon.
2. Go to **Settings** () > **Knowledge base site** > **Integrations**.
3. Scroll down to **Custom HTML** blade and click **Add**.

   The **Add new integration** panel will appear.
4. Enter the desired description.
5. Select the intended option in the **Insert code** field.
6. Paste the copied script and click **Add**.

Now, the Eddy AI Chatbot will appear on your Knowledge base site.

> NOTE
>
> To integrate the Eddy AI Chatbot into your custom site, paste the copied script into the appropriate HTML file.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Pasting_the_code_in_HTML_Integration.gif)

---

## Accessing the Eddy AI Chatbot in the site

To access and interact with the Eddy AI Chatbot on your site:

1. Click the Eddy AI Chatbot icon to open the chatbot.
2. Type your question and click the **Send**() icon or press **Enter**.

   Eddy AI will retrieve information from your Knowledge base to answer your query.
3. Hover over any generated answer to **Copy** (), **Like** (), or **Dislike** () the response.
4. Click the **Clear** () icon to clear the conversation.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGIF-Exploring_Chatbot_AI.gif)

---

### FAQs

#### How can I view the feedback (likes and dislikes) received from the Eddy AI Chatbot?

To view the Eddy AI Chatbot feedback,

1. Navigate to the **Analytics**() > **Eddy AI** in the Knowledge base portal.
2. Filter the desired Eddy AI Chatbot using the **Application** filter at the top of the page.

   In the **Feedback** section, you will see the number of likes and dislikes received.

#### What is the difference between a Widget and an Eddy AI Chatbot?

A **Widget** allows manual navigation through articles or search functions, while an **Eddy AI Chatbot** engages users in a conversation, offering immediate, direct answers without the need to manually navigate through content.

<a id="securing-chatbot-authentication-using-jwt"></a>

## Securing Chatbot authentication using JWT

**Plans supporting AI chatbot**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

JSON Web Token (JWT) is an open standard used to securely transmit information between parties as a JSON object. It allows for authentication and information exchange, ensuring that the data sent is verified and trusted. By implementing JWT for the Eddy AI Chatbot, you can create a secure environment for your private and mixed projects, protecting sensitive information from unauthorized access.

> NOTE
>
> To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-search-suite#multilingual-support-for-eddy-ai-search-suite).

You can implement an authentication configuration for the Eddy AI Chatbot using JWT, ensuring a secure environment for Private and Mixed projects.

1. Navigate to Knowledge base widget () in the Knowledge base portal.
2. Click **Add widget** to create a new widget.

   Alternatively, hover over the desired widget and click the **Edit** (✎) icon to modify an existing widget.
3. Select the widget type as **Chatbot** to configure JWT for Eddy AI Chatbot.
4. In the **Configure & connect** tab, go to the **JWT** accordion and **enable** the JWT toggle.

1. **Client ID:** The client ID will be your project’s ID.
2. **Widget ID:** Since multiple widgets may exist, a widget ID is provided for their unique purposes.
3. **Token endpoint:** This is the HTTP endpoint used to obtain an access token using an authorization code.
4. **Client secret:** Click **Regenerate** to generate the client secret. Ensure you save this for future use, as it will apply to all widgets created moving forward.

> NOTE
>
> The **Client Secret** is required for all future JWT-enabled widgets. It will not be stored within Document360, so keep it securely.

   e. **Authorize URL:** Paste the authorized URL from your knowledge base widget webpage.

5. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Securing_Knowledge_base_widget_authentication_using_JWT(1).png)

Embed the authorized URL within your code and paste it into the **Script section** of your webpage to implement a secure, authenticated Chatbot. This setup will prevent unauthorized third-party access. By following these steps, you can successfully implement JWT authentication for the Eddy AI Chatbot, ensuring a secure environment for your projects. After configuring your chatbot, test the setup thoroughly to ensure that everything functions correctly.

> NOTE
>
> For more information on implementing the auth endpoint, read the article on [Managing the Knowledge base widget](/help/docs/managing-the-knowledge-base-widget).

---

### FAQs

#### What should I check if I encounter issues during authentication?

If you experience authentication issues, ensure the following:

* The client secret and token endpoint are correctly configured.
* The user is authenticated before making a request to the endpoint.

#### What are common pitfalls to avoid when implementing JWT?

Here are a couple of common pitfalls to watch out for:

* **Failing to save the client secret** after regeneration can lead to authentication failures.
* **Misconfiguring the token endpoint** can prevent successful token retrieval.

#### What should I do if I lose my client secret?

You will need to regenerate a new client secret and update your configuration accordingly.

#### How can I verify that JWT authentication is working?

Test the authentication flow by attempting to access the Eddy AI Chatbot and checking for the correct access token response.

<a id="styling-the-chatbot"></a>

## Styling the Chatbot

**Plans supporting AI chatbot**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Styling the appearance and behavior of your Eddy AI chatbot can significantly enhance the user experience. Customizing your Eddy AI Chatbot’s colors and icons to match your brand can create a seamless experience, making it easier for users to engage with the Eddy AI chatbot and get timely information.

> NOTE
>
> To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-search-suite#multilingual-support-for-eddy-ai-search-suite).

---

## Styling the Eddy AI Chatbot

To style the Eddy AI chatbot, follow the steps below:

1. Navigate to Knowledge base widget () in the Knowledge base portal.
2. Hover over the desired widget and click the **Edit** (✎) icon.
3. In the **Configure & connect** tab, expand the **Style widget** accordion.

#### Widget color

4. Click **Change icon** to replace the icon with an image or select one from the available icons.

   a. Choose any icon from the **Icon set** tab.  
   **(or)**  
   b. Click the **Insert image** tab.

   1. To use an image URL, paste or type the URL and click **Insert**.
   2. Alternatively, to upload an image from Drive, click **Upload an image** and select the desired file.

> NOTE
>
> Click **Default** to revert to the default icon and color.

5. Click **Change color** to update the Eddy AI Chatbot’s background color.

   The color palette will appear.
6. Select a color using the color picker or enter a hex, RGB, or HSL code for specific color values.

#### Widget position

7. Select **Left** or **Right** to position the widget icon on either side of your site.
8. Enter the desired pixel values in the **Side spacing** and **Bottom spacing** fields to adjust the Eddy AI Chatbot's placement.

#### Hide widget

9. Turn on the **Hide widget** toggle if you want to hide the widget on your site.
10. After making your changes, click **Save**.

> NOTE
>
> The **autosave** feature is enabled when navigating between the Knowledge base widget tabs, ensuring your changes are automatically saved.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Styling_the_Knowledge_base_widget.gif)

<a id="eddy-ai-federated-search"></a>

## Adding external sources for AI Assistive search

**Plans supporting addition of external sources in AI assistive search**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

> NOTE
>
> For **Legacy** plan users, this feature is available only if you have purchased the AI assistive search add-on for your project.

The Adding external sources for AI assistive search feature allows you to configure it to retrieve information from multiple external sources, simplifying the process and delivering more comprehensive answers to users.

Imagine a support agent for a software company using Document360 to resolve customer issues. Previously, they could only search for solutions within their internal Knowledge base articles. With this feature, the agent can now pull information from external resources like the company's public documentation site, blogs, and product release notes. This helps the agent deliver accurate and comprehensive answers quickly without leaving the platform, improving both response time and customer satisfaction.

> NOTE
>
> To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-search-suite#multilingual-support-for-eddy-ai-search-suite).

---

## Adding external sources

To access and manage external sources:

1. Navigate to **Settings** () >**AI features** >**Manage source****s** in the Knowledge base portal.

   The **Manage source** page will display a list of already configured external sources (if any).
2. Click **Add new** to add a new external source.

   The **Add source** panel will appear.
3. Choose the desired source type, either **Webpage** or **Sitemap**.

> NOTE
>
> You can add up to 50 **Webpage****s** and 1 **Sitemap**.

4. Enter the desired source name.
5. Enter a valid URL.

> NOTE
>
> The webpages must be in HTML5 format and should include `<article>` or `<main>` tags.

6. Once done, click **Add source**.

![Adding new external sources in AI Assistive search in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Adding_External_sources.gif)

---

## Manage source overview page

The **Manage source** page will list all indexed external sources.

![Manage sources for AI search, including content access and external source options.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Manage_source_over_view_page.png)

Below is a breakdown of the available options:

1. **Content access:** Restrict Eddy AI’s access to specific workspace and language. Two options are available: **All** and **Allow** selected.
2. **Filter:** Filter sources based on type such as **All, Sitemap, Webpage, or Failed Sources**. Failed sources will display all sources that encountered errors.
3. **Sync:** By default, sources are synced every 24 hours, and to sync manually, you can click **Sync** up a source up to four times per day.
4. **Add new:** Click **Add new** to add a new source for indexing.
5. **Search:** Use the search bar to locate a source by its name.
6. **Type:** Displays the type of the source, either **Webpage** or **Sitemap**.
7. **Last sync:** Shows the last sync date. Hover to view the exact time.
8. **Status:** Toggle to enable or disable a source. If disabled, Eddy AI will stop fetching information from that source.
9. **Error:** To denote an external source where the URL has encountered some error.
10. **Delete:** Click the **Delete** () icon to remove a source.
11. **Edit:** Click **Edit** () to modify the source name or URL.

### Enabling Eddy AI for specific workspaces, languages, and categories

This feature allows you to configure Eddy AI to selectively enable or restrict support for specific workspaces, languages, and categories in your Knowledge base. On the **Manage sources for AI assistive search** overview page, you can manage the content access and restrict AI access to specific workspaces, languages, and categories for more focused assistance.

1. Click the **All** dropdown and you have two selections,

   * **All** - lists all the workspaces in your knowledge base.
   * **Allow selected** - allows you to select the workspace, languages, and categories.

   If you select **Allow selected** from the dropdown, a **Manage workspace & category popup** appears.
2. Select the workspace, languages, and categories you want to allow the assistive search to fetch data from.

   A Manage button appears with the Allow selected dropdown selection.
3. Click **Manage** to select and manage the sources and click **Save**. The Save button is enabled only when changes are made.

   Once any modifications are made, you will get a confirmation popup saying, ‘*AI search sources updated*.’
4. Click **Cancel** or hit Esc to close the popup.

![Manage workspaces and categories with language options of the external sources in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Enabling_Eddy_AI_for_specific_workspaces_languages_and_categories.png)

> NOTE
>
> If you switch from **Allow selected** to **All** dropdown selection, and then again switch to **Allow selected**, the selections made will be retained.

The **Enabling Eddy AI for specific workspaces, categories, and languages** feature is applicable across all areas where AI Assistive Search is enabled.

---

### Handling errors in external sources

If errors such as unsupported HTML formats, unsupported languages, or HTTPS issues occur on a webpage, Eddy AI will stop fetching information from that page until the error is resolved. However, if errors occur on one or more web pages within a sitemap, Eddy AI will continue fetching data from the remaining valid URLs in the sitemap.

1. Click the **Error** () icon next to the status toggle.

   The **Edit** panel will display the URLs and their errors.
2. Hover over a URL and click the **Open site** () icon to view the external source.
3. Click **Remove** to delete a specific URL from the list in the Sitemap.
4. Click **Remove all** to delete all URLs with errors.

> NOTE
>
> * If the webpage source link has bot detection or similar detection mechanisms enabled, Eddy AI search will be unable to crawl the content. As a result, the source will not be added, and a forbidden error will occur.
> * Eddy AI supports only Server-Side Rendered (SSR) webpages. Client-side rendered webpages may not be indexed properly, leading to empty search results. To ensure accurate embedding and search functionality, please use server-rendered content.

![Handling errors of the external sources in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGIF-Handling_GIF_in_External_sources.gif)

---

## Knowledge base site view

When Eddy AI fetches results from external sources:

1. The source URLs will be listed and numbered in the **Source articles** section. The same numbers will be used in the AI response to help you identify which parts of the response are fetched from each source article.
2. Hover over the number to find additional information, such as, if it’s an external source, you can find the title of the web page and a short description of the source article. Click on the number or the **Open in a new tab** () icon to open the source article in a new tab.
3. Click on the desired source article, to open the article in a new tab.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-External_sources.gif)

---

## Troubleshooting

This section provides step-by-step guidance to address common issues that you may encounter when adding external sources to your Eddy AI Assistive search. To configuration errors, each solution is tailored to help you quickly identify and resolve potential roadblocks.

### Unsupported format while adding sitemap

**Error:** Unsupported format

The error message **Unsupported format** occurs when attempting to add a sitemap to the **Manage sources** section if the sitemap contains nested sitemaps with the `<sitemapindex>` tag, exceeds the 1 MB file size limit, or is in an unsupported format.

**Steps to resolve:** To resolve this error, follow the steps below:

* Use only the direct sitemap URL without the `<sitemapindex>` tag, as nested sitemaps are not supported.
* Ensure the sitemap file size is less than 1 MB.
* Verify that the sitemap is in a supported format, such as XML.

### Forbidden error while adding webpage

**Error:** Forbidden

The error message **Forbidden** will appear when attempting to add a web page to the **Manage sources** section. This error arises if the web page source has bot detection or other security mechanisms enabled, preventing Eddy AI search from crawling the content.

**Steps to resolve:** To resolve this error, follow the steps below:

* Check if the source link has bot detection mechanisms enabled. If so, you may need to contact the website administrator to allow crawler access.
* Use a different source that does not restrict crawling.

### Only HTML5 documents with `<article>` or `<main>` tags are supported while adding webpage

**Error:** Only HTML5 documents with `<article>` or `<main>` tags

The error **Only HTML5 documents with** `<article>` **or** `<main>` **tags** will occur when adding a web page that does not meet the HTML5 format or lacks the required `<article>` or `<main>` tags.

**Steps to resolve this issue:** To resolve this, follow the steps below:

* **Verify the HTML5 format:** Check the doctype declaration of the web page. HTML5 pages should have `<!DOCTYPE html>` as the declaration.
* **Check for required tags:** View the page source (`Ctrl + U` / `Cmd + U`) and ensure it contains `<article>` or `<main>` tags.
* **Update the web page:** If the page is not in HTML5 format or lacks the required tags, update the page to meet these requirements.

By addressing these common errors and their solutions, you can ensure a smoother experience when adding external sources to your Eddy AI Assistive search.

---

### FAQs

#### **How do I perform a manual sync for external sources?**

To perform manual sync for external sources, follow steps below:

1. Navigate to **Settings** **(****)** > **AI features**>**Manage source****s** in the Knowledge base portal.
2. Click **Sync** at the top of the **Manage source** page.
3. You can manually sync external sources up to four times per day.

> NOTE
>
> The system automatically syncs every 24 hours.

#### **How do I delete an external source?**

To delete any external sources from the Manage source page:

1. Navigate to **Settings** **(****)>** **AI features** **>** **Manage source****s** in the Knowledge base portal.
2. Hover over the desired source and click the **Delete** () icon.
3. To delete multiple sources at once, select the checkboxes for the desired sources and click **Delete** at the top.

#### **How do I view analytics for external sources?**

To view the search metrics analytics for external sources:

1. Navigate to **Analytics**() > **Eddy AI** in the Knowledge base portal.
2. In the **Most referenced articles** section, external sources will be listed alongside Knowledge base articles.

#### **Can I disable external sources temporarily without deleting them?**

Yes, you can turn off the **Status** toggle next to any external source to temporarily disable it. Eddy AI will stop fetching information from that source until it’s re-enabled.

<a id="ai-article-summarizer"></a>

## AI article summarizer

**Plans supporting the use of AI article summarizer**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Article summarizer** is one of the many Artificial Intelligence (AI) powered features in Document360. This feature comes in handy when readers want to save time by not reading lengthy articles. Instead, they can read a piece of condensed article information as a **summary**.

Document360 uses natural language processing (NLP) to locate the vital information in the article content while maintaining the original context to generate an optimal summary.

> NOTE
>
> To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-search-suite#multilingual-support-for-eddy-ai-search-suite).

### Prerequisites

* **Preprocessed article content** should be more than **250 words.**
* The AI feature is supported in your subscription plan.

> NOTE
>
> The article summary is available (depending on your subscription plan) in new/existing articles published on or after May 27, 2023.

---

## Enabling article summarizer

To enable the article summarizer, follow the steps below:

1. Navigate to **Settings** ()> **AI Features** > **Eddy AI** in the Knowledge base portal.
2. Turn on the **Article summarizer** toggle.

When enabled, the **Summary** is available at the article top in the Knowledge base site. Click on 'Summary' to expand and read it.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Enabling_Summarizer.png)

---

---

#### What is 'Preprocess' or 'Preprocessed words' in Document360 articles?

**Preprocess** refers to filtering specific article/category page elements. The below elements are not considered for meta description generation's word count:

* HTML tags
* Images
* URL/links
* Code blocks

  > If you have an article word count shown as 220 words at the bottom of the Document360 editor, this includes the HTML tags, links, code blocks, and more. When preprocessing content is considered, the word count would be less. Ensure the preprocessed article content is more than 250 words for the AI article summarizer to work.

---

#### Data privacy

We understand that our customer's Knowledge base data is sensitive. As this feature uses a form of OpenAI integration, we adhere to the privacy policies on OpenAI. An extract from the policy states, "OpenAI will not use data submitted by customers via our API to train OpenAI models or improve OpenAI's service offerings."

> Read the complete draft of [**OpenAI API data usage policies**](https://openai.com/policies/api-data-usage-policies)

> If you any queries regarding Document360's data policy, please read our [**Privacy policy**](https://document360.com/privacy/)

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="ask-eddy-ai-api"></a>

## Ask Eddy AI API

**Plans supporting the use of Ask Eddy AI API**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The Eddy AI Public API is an invaluable feature designed to enhance the functionality and flexibility of our Eddy AI search feature. The Eddy AI Public API is particularly useful for businesses looking to deeply integrate AI-driven search capabilities directly into their own platforms or services. By embedding Eddy AI into your product, you provide users with the ability to access powerful search functionality without needing to visit your documentation site.

This API offers greater flexibility in customizing the user interface, allowing you to tailor aspects like color, naming, and placement to align with your brand and user experience. With this seamless integration, Eddy AI becomes a natural extension of your product, enhancing user interactions and improving search efficiency. By exposing the API endpoints, you can incorporate them into your platforms, effortlessly extract answers from Eddy AI and build a customized search experience.

> NOTE
>
> To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-search-suite#multilingual-support-for-eddy-ai-search-suite).

---

## Using the Public API

1. Navigate to the Settings () > **AI Features** > **Eddy AI** in the Knowledge base portal.
2. In **AI assistive search**, select the **Public API** checkbox.

![1_Screenshot-ENabling_Ask_Eddy_API](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-ENabling_Ask_Eddy_API.png)

> NOTE
>
> 1. Ensure at least one of the checkboxes is selected. Otherwise, the AI assistive search toggle will be automatically disabled.
> 2. If the Public API is not enabled, you'll receive a ‘500 response code error’ or a ‘400 API access disabled error’ while using Ask Eddy AI API.
> 3. Each API call will reduce your total credit count by one.

3. Create authorization API token.

> NOTE
>
> 1. In the Knowledge Base portal, navigate to Settings () > **Knowledge Base Portal** > **API Tokens**.
> 2. Click **Create API Token**, enter the token name, and specify the POST method.
> 3. Click **Create** and **copy** the generated API token.

4. You can find the API structure at the [API hub](https://apihub.document360.io/index.html).

---

## Try the Eddy AI Public API in our API docs

1. Navigate to the Document360 [API documentation](https://apidocs.document360.com/apidocs/perform-ai-assistive-search-ask-eddy-within-project-version).
2. On the right side of the page, click the **Try it** section.
3. In the **Token** field, field, enter the API token generated from your Document360 project.
4. Enter the desired values in the **Body** section. The default request box will appear as follows:

   1. **Prompt**: Enter the question or query.
   2. **Version ID**: Obtain the current version ID.
   3. **Language Code**: Specify the desired language code for the input.
5. Click **Try it & see response** and the response will be generated.

![5_Screenshot-Ask_Eddy_in_API_Documentation](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Ask_Eddy_in_API_Documentation.png)

---

## Try the Eddy AI Public API in Swagger

1. Navigate to the Swagger [API hub](https://apihub.document360.io/index.html). Under project versions, you can find the Ask Eddy AI API.
2. In the top right of the Swagger API hub and click **Authorize**.
3. The **Available authorizations** panel will appear, prompting you to enter the API token.
4. Paste the API token into the **Available Authorizations** window and click **Authorize**.
5. Once authorized, navigate to **Project versions** > `/v2/ProjectVersions/ask-Eddy AI` and click **Try it out**.
6. The default request box will appear as follows:

* **Prompt**: Enter the question or query.
* **Version ID**: Obtain the current version ID from the `/v2/ProjectVersions` endpoint.

  ![6_Screenshot-Updating_Getting_Project_version](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Updating_Getting_Project_version.png)
* **Language Code**: Specify the desired language code.

7. Click **Execute** to receive a successful response containing all required information.

> NOTE
>
> If you receive a service unavailable message, ensure the Public API is enabled in the settings.

![4_ScreenGIF-Using_Eddy_API_Token_in_Swagger](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGIF-Using_Eddy_API_Token_in_Swagger.gif)

---

### FAQ

#### **Why is there a discrepancy in the source articles between the Ask Eddy public API and Eddy AI search on the user site?**

The discrepancy in source articles may occur if you're retrieving details using the `articleID` for an article that is of type "Pagecategory." In such cases, fields like `article_id`, `article_title`, and `article_slug` will return null in the API response.

For "Pagecategory" articles, the details should be fetched using the `categoryID` instead of the `articleID`. Here's an example of what the API response would look like for a "Pagecategory" article:

```
{
  "category_id": "_categoryid",
  "category_title": "Title",
  "category_slug": "slug",
  "version_name": "v1",
  "version_slug": "v1",
  "article_id": null,
  "article_title": null,
  "article_slug": null,
  "version_display_name": null
}
```

JSON

Copy

To resolve this issue, ensure that you're using `categoryID` to retrieve information for "Pagecategory" articles when using the Eddy API.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="text-to-voice-functionality"></a>

## Enhancing accessibility with our read out loud feature

**Plans supporting read out loud feature on the Knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The read out loud feature on your Knowledge base site allows users to listen to articles instead of reading them, saving time. This functionality is beneficial for multitasking, allowing users to absorb information while performing other activities. This feature is particularly useful for users who want to listen to content while performing other activities or for those who prefer auditory learning.

Available exclusively on the Knowledge Base site 2.0, this feature enhances engagement by offering a flexible alternative to reading.

> NOTE
>
> For customers on the old pricing plan, the read out loud functionality is available under Enterprise plan with the AI assistive search add-on.

## Using the read out loud feature

Here are some of the key highlights of the read out loud feature,

* The read out loud feature begins reading from the article heading and continues with the body content.
* It does not cover the article summary.
* The feature reads the alt text of images and videos. If the image or video does not contain alt text, the audio just indicates their presence in the respective language.
* The **Listen** button is located in the article header below the article heading. Once playback begins, the button label updates to **Listening**, and the Player window opens.

> **NOTE**  
> To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-search-suite#multilingual-support-for-eddy-ai-search-suite).

#### Player option

The player controls are located at the bottom right of the screen. Here’s how to use them:

* Play () icon - to start listening to the content.
* Pause () icon - to stop audio play.
* Forward () icon - to skip ahead by ten seconds.
* Backward () icon - to rewind by ten seconds.
* Close (**x**) icon - to close the player window.

  ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Text_to_voice_kb_site.png "image(169).png")

#### Enable or disable player option

You can enable or disable the player option at the project level.

1. Navigate to Settings () > **Knowledge base site** > **Article settings**.
2. Under the **Accessibility** section, turn on the **Enable** **read out loud** toggle.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Read_out_loud_settings.png "image(169).png")

> NOTE
>
> The **Enable read out loud** feature will be disabled by default for customers on the trial plan.

---

## FAQs

**What all does the feature read from the article content? Is there any content it doesn’t cover?**

In addition to the textual content, the feature reads out the contents from the following content blocks of the article,  
Glossary, Snippets, Variables, Headings (H2, H3, H4), Numbered lists, Checklists, Bullet lists, Callouts, Private notes, Accordions, FAQ, Link text, emojis.

The Enable read out loud feature only indicates the presence of the following without actually reading its contents - Tables, Inline code, code blocks, images, videos, Latex, and files attached to the article using insert menu.

**Can I choose to read an article from in between?**

Yes, you can navigate the audio player using the seek option.

<a id="ai-premium-suite"></a>

## AI premium suite

**Plans supporting the use of AI premium suite**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **AI premium suite** elevates the user experience by automating key business processes and improving workflow efficiency through advanced AI-powered tools.

---

## Features in the AI premium suite

1. [**AI-automated business glossary generation**](/help/docs/ai-glossary-generator)

This feature helps companies streamline the creation and management of industry-specific glossaries. This feature allows businesses to maintain consistent terminology across teams, enhance communication, and ensure accuracy in documentation.

> **NOTE**
>
> The Eddy AI premium suite is available in English (en) only.

<a id="ai-glossary-generator"></a>

## AI glossary generator

**Plans supporting the use of AI premium suite**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Different departments within an organization may use similar business terms, but the underlying definitions and assumptions may differ. This knowledge is only known to those within each department. Therefore, defining business terms is crucial for a shared understanding, consistent data collection practices, and the right business logics applied to compute reliable business metrics.

Document360's AI Glossary generator helps organizations communicate and collaborate by clearing ambiguity in terminology. It helps you to create a complete collection of business terms used in an organization, providing clarity and a shared understanding of ambiguous terms. It aids in data collection, team collaboration, communication, and database design.

---

## Enabling the AI Glossary generator

![1_Screenshot-Enabling_Automated_business_glossary](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Enabling_Automated_business_glossary.png)

1. Navigate to **Settings () > AI Features > Eddy AI** in the Knowledge base portal.
2. Scroll down to find the **AI Glossary generator** option.
3. Toggle the switch to enable this feature.

---

## Accessing AI Glossary generator

You can access the **AI Glossary generator** using the following steps:

1. Navigate to **Documentation** ()> **Content tools** > **Content reuse** and select **Glossary.**
2. Click **Take action** on the Eddy AI banner in the center of the page.

   By default, the **Open suggestion** section appears as the default view under the **Eddy AI glossary suggestions.**

> NOTE
>
> The AI Glossary Generator will show suggestions only if the articles are published. Otherwise it shows 0 suggestions.

1. On the left navigation bar:

   * You'll find a list of Eddy AI recommended glossary terms.
   * Use the **Search bar**, if you have multiple terms to search.
   * Use the **Sort** option to organize the terms.
2. At the top center, you can view the number of times that each term is repeated.

> For example, Backup is used 1 time(s) in 1 article(s).

6. In the **Definition** text box, Eddy AI will suggest the relevant definition of the term, and you can edit it using the formatting tools.

> NOTE
>
> Glossary definition can be up to 500 characters.

7. Under the **Add to** drop down menu, **English** will be selected as default.
8. Enable the **Update in articles (n)** check box to update the glossary in the articles.

> NOTE
>
> You can create a glossary without implementing it in the article by unchecking the **Update in articles** check box.

9. Click **Show Articles** to view the list of articles where the glossary terms will be used.

> NOTE
>
> Only articles that you have access are displayed here.

10. Once the changes are done, click **+ Add to glossary**.
11. After adding the term to the glossary, it will be moved to the glossary list.
12. If you need to ignore it, click **Ignore term**, and it will be added to the **Ignored suggestions** section.
13. Anytime, you can go to **Ignored suggestions** and click **Move to open list**.
14. Click **Continue later** to close the blade.

![2_ScreenGIF-Accessing_Automated_Business_Glossary](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Accessing_Automated_Business_Glossary.gif)

You can perform the AI Glossary generator Scan every 7 days.

![3_Screenshot-Scan_Again_of_that_specific_eddy_box](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Scan_Again_of_that_specific_eddy_box.png)

---

### Using AI Glossary generator in the advanced WYSIWYG editor

![4_ScreenGIF-Automated_Business_Glossary_in_the_Editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGIF-Automated_Business_Glossary_in_the_Editor.gif)

1. Navigate to the Advanced WYSIWYG editor and click **Insert**.
2. Select **Glossary**, and Eddy AI will provide glossary suggestions based on that specific article.

> NOTE
>
> In the Editor, **AI Glossary generator** scan will occur every time you open it. At one instance, it can scan up to the first 50 terms

3. Click **Take action** to open the **Eddy AI glossary suggestions** window, with the Open suggestions section as the default view.

### Shortcuts for AI Glossary generator

You can use the following shortcuts in the **Edit glossary suggestions** window.

* Use the ARROW keys to navigate suggestions.
* Press ENTER to add the current glossary term.
* Press BACKSPACE to ignore the current glossary term.

---

## FAQs

**Does the AI Glossary generator recognize singular and plural business terms as one?**

No, the Document360's AI Glossary generator considers two identical terms, one being singular and the other being plural, as two individual and specific terms.  
For example, the term **Team Accounts** and **Team Account** are evaluated as two distinguished terms.

**Does the AI Glossary generator recognize synonymous terms as one term?**

The synonymous terms will be considered as two individual and separate terms.  
For example, the words Routine and Daily are synonymous with each other. However, they are considered as two different terms or words.

**How often can you perform a rescan and why?**

The system recommends an interval of 7 days between each scan which will be notified in the user interface. Some quantifiable content in the documentation is necessary to scan the content and provide new suggestions.

**Is the rescan manual or automated?**

The Rescan is a manual process and not an automated action.

**What happens post a rescan?**

After the rescan, new suggestions are updated in the **open suggestions** list and the users will be notified with an email notification regarding the same.

A powerful Document360 editor with rich text editing and Markdown support, offering a visual, flexible experience compared to the Markdown and basic WYSIWYG editors.

<a id="how-to-write-genai-friendly-content"></a>

## How to write GenAI friendly content

To write AI-friendly content for your articles, it's important to structure your information in a way that improves clarity, readability, and searchability. Here are some best practices to follow:

### 1. **Use clear and concise headings**

* **Headings (H1, H2, H3)**: Organize content using clear and descriptive headings. This helps AI understand the hierarchy and structure of your article.
* **Keyword-rich headings**: Ensure your headings reflect the content of the section. For example, instead of "Introduction," use "Introduction to Cloud Storage Solutions."

### 2. **Write short and focused paragraphs**

* **Keep sentences short**: Aim for sentences of 15-20 words. Avoid complex sentences as they can confuse AI processing.
* **One idea per paragraph**: Ensure each paragraph covers one idea to make it easy for AI to extract key information.

### 3. **Include tables for structured data**

* **Well-labeled tables**: Use tables to present structured data, making it easier for AI to scan and interpret. Clearly label rows and columns with descriptive headers.
* **Consistent formatting**: Ensure the table is formatted consistently for better AI recognition (e.g., avoid merged cells or irregular formatting).

### 4. **Incorporate code snippets carefully**

* **Use clean and well-commented code**: When including code snippets, use standard formatting and comment on key sections. AI can use comments to understand the context.
* **Use appropriate syntax highlighting**: This helps AI differentiate code from regular text.

### 5. **Use bullet points and numbered lists**

* **Break up information**: Bullet points and lists help organize content and make it easier for AI to break down and extract key points.
* **Limit list length**: Keep lists concise, ideally under 5-7 points, to avoid overwhelming the AI and readers.

### 6. **Include descriptive alt text for images**

**Alt text and captions**: Always include descriptive alt text and captions for images. This allows AI to understand and process the context of the image.

### 7. **Provide clear, contextual links**

* **Internal links**: Link to relevant internal articles using clear anchor text. Avoid generic phrases like “click here.”
* **Anchor text**: Use descriptive anchor text that informs AI of the linked content, such as “Read more about cloud storage security best practices.”

### 8. **Ensure SEO best practices**

* **Keyword optimization**: Use keywords naturally within headings, subheadings, and content. Avoid keyword stuffing.
* **Meta descriptions**: Write clear, relevant meta descriptions with keywords to help AI rank the content effectively.

### 9. Use business glossary terms consistently

* **Consistent terminology:** Make sure to use terms from your business glossary consistently throughout your articles. This helps AI identify and relate key terms across your content, improving searchability and comprehension.
* **Define key terms:** If a term might be unfamiliar to readers, include a brief definition or link to your business glossary. This ensures both AI and users understand the context of specialized terms.
* **Standardize abbreviations:** Always use standardized abbreviations or acronyms from your business glossary. This ensures AI correctly identifies and categorizes key terms.

### 10. **Write for humans first**

* **Conversational tone**: AI tends to perform better with content that is written in a human-friendly tone, as it improves engagement and contextual understanding.
* **Natural language**: Use natural, everyday language. Avoid jargon or overly complex terms unless absolutely necessary, and provide definitions for technical terms.

### 11. **Monitor AI-generated content**

**Review and revise**: If you're using AI tools like AI writers or content generators, always review the output to ensure it meets your quality standards and reads naturally.

---

#### Recommendations for optimizing your experience as a contributor with Eddy AI

Writing documentation that is easily understood by AI (Eddy AI) involves incorporating clear language, structured formatting, and adherence to specific guidelines.

1. **Use clear and focused language**

   Express ideas in a straightforward manner, avoiding unnecessary complexity.

   Break down complex concepts into simpler, digestible parts.

   Define technical terms or provide links to detailed explanations.
2. **Structured formatting**

   Use clear headings and subheadings to organize information.

   Employ bullet points and numbered lists to present step-by-step instructions.

   Highlight key points using bold or italics for better parsing by bots.
3. **Consistent terminology**

   Maintain consistency in the use of terminology to facilitate understanding.

   Use the Glossary feature in Document360 to achieve this.

   Avoid ambiguity by using specific and standardized terms.
4. **Avoid jargon overload**

   Minimize the use of industry-specific jargon unless essential.

   If technical terms are necessary, provide brief explanations or context.
5. **Elaborative text content**

   Elaborate the content and clearly specify the content's intent.

   If you use multimedia content, ensure that you provide a text explanation of what the media is trying to convey.

   Break down information into shorter paragraphs for better readability.

   Provide explicit answers to questions in the form of FAQs to minimize inaccurate answers by "Eddy AI." AI bots tend to hallucinate when the content is not elaborate or explicitly mentioned.
6. **Provide context and example**

   Offer real-world examples to illustrate technical concepts.

   Provide context to help the reader understand the purpose and application of the information.
7. **Use descriptive headings**

   Craft descriptive headings that accurately represent the content.

   Headings should act as a guide, summarizing the content beneath.

   Avoid repetitive heading text in the same article.
8. **Test with "Eddy AI"**

   Utilize "Eddy AI" to analyze your content for clarity and coherence.

   Make adjustments based on feedback from these tools.

By implementing these recommendations, you can create and manage documentation that is not only comprehensible to humans but also easily processed and understood by AI and NLP bots like "Eddy AI".

<a id="prompt-engineering-tips"></a>

## Prompt engineering tips

In Document360, Eddy AI provides various AI-driven functionalities that help streamline content creation and enhance the overall knowledge base experience. Leveraging prompt engineering with Eddy AI can improve accuracy, efficiency, and relevance in generating content tailored to your needs. This guide will help you make the most of Eddy AI’s capabilities when interacting with your knowledge base.

---

## Best practices for prompt engineering with Eddy AI

**1. Be clear and specific in your prompts**

When working with Eddy AI, the more precise your instructions, the better. For example, instead of asking for a “brief summary,” be specific about what you want, such as, “Generate a 100-word summary about the benefits of Document360’s knowledge base.”

If your content involves complex technical details, break it into smaller, more manageable requests. This helps Eddy AI deliver focused, relevant outputs.

**2. Ask for step-by-step instructions**

Eddy AI can be very effective in generating procedural content when you clearly specify the task. Instead of just saying, "Explain how to publish an article," a more refined prompt would be, "List the steps to publish an article in Document360, including where to click and how to configure settings."

**3. Structure your prompts for comparisons**

Structure your prompt accordingly if you need content that compares features or options. For example, “Compare the key differences between Document360’s private and public knowledge base setups” will guide Eddy AI to focus on generating a detailed comparison.

**4. Focus on article summaries**

When summarizing articles, especially longer ones, ask Eddy AI to create summaries based on specific sections or categories. For instance, “Summarize the benefits and limitations section of the article on Document360’s multi-language support.” This will help generate more concise and useful summaries.

**5. Include context for recommendations**

Context is critical when asking Eddy AI to generate recommendations or suggestions. For example, instead of saying, “Recommend improvements,” you could say, “Recommend improvements to the onboarding process in a knowledge base article for new users.”

---

#### **Recommendations for optimizing your experience as a reader with Eddy AI**

1. **Converse naturally**

   **Why**: Speak to "Eddy AI" as you would to a human.

   Example: Instead of "Search for articles on templates," try "Eddy AI, find me articles explaining Document360 templates."
2. **Provide detailed context**

   **Why**: Enhance understanding by setting the stage and providing context.

   **Example**: Instead of "Errors in the documentation," try "Eddy AI, help me identify and resolve errors in the Document360 user guide."
3. **Customize persona**

   **Why**: Instruct "Eddy AI" to adopt a specific identity for personalized responses.

   **Example**: Instead of "Search for software updates," try "Eddy AI, imagine you're our IT expert and update me on the latest software changes."
4. **Embrace creativity**

   **Why**: Encourage experimentation and creativity in your queries.

   **Example**: Instead of a standard search like "Knowledge base structure," try "Eddy AI, let's play! Imagine you're a content strategist and suggest an ideal knowledge base structure."

By following these recommendations, you harness the power of Eddy AI’s capabilities and make your interactions more engaging and tailored to your specific needs. Feel free to experiment, instruct Eddy AI creatively, and watch as your queries yield more insightful and personalized results.

---

## Tips for enhancing knowledge base articles with Eddy AI

**1. Use Eddy AI for content categorization**

When organizing content, ask Eddy AI to help categorize or label articles. For example, “Suggest categories for an article that discusses API integration and customization in Document360.” This will help streamline your knowledge base’s structure.

**2. Generate error message documentation**

If your knowledge base deals with troubleshooting or technical content, you can ask Eddy AI to document common error messages. For example, “Generate explanations for common error messages users may encounter when integrating third-party tools in Document360.”

**3. Request best practices**

Eddy AI can also assist in compiling best practices. For instance, you can ask, “List best practices for writing comprehensive how-to articles for a knowledge base aimed at developers.”

**4. Create troubleshooting guides**

Suppose your knowledge base includes a troubleshooting section. In that case, you can instruct Eddy AI to generate content like, “Create a troubleshooting guide for resolving common login issues in Document360,” which ensures the AI focuses on step-by-step solutions.

---

## Use cases

Eddy AI is a versatile tool that can streamline content creation across various industries, whether you’re building an LMS, maintaining a customer support knowledge base, or generating compliance documentation. By tailoring prompts to your specific needs, you can harness the full potential of Eddy AI to improve efficiency, accuracy, and engagement across your platform.

### 1. Building a Learning Management System (LMS) with Eddy AI

**Course creation and structuring**

* **Outline generation:** You can use Eddy AI to quickly generate course outlines by specifying your learning objectives. For example, ask Eddy AI, “Create an outline for a beginner’s course on cloud computing,” and it will draft a structured plan with topics and subtopics.
* **Content segmentation:** For educational materials, Eddy AI can divide long-form content into smaller, digestible modules. For instance, “Split this article on cybersecurity fundamentals into 5 lessons, each with a title and brief summary.”
* **Quiz and FAQ generation:** Request, “Generate quiz questions for each module in a cloud computing course,” or “Create FAQs for the module on cloud security,” and Eddy AI will produce interactive learning assessments and clarification points.

**Enhancing user engagement**

* **Adaptive learning paths:** Based on learner performance, you can ask Eddy AI to recommend follow-up content. For example, “Suggest advanced articles for learners who have completed the beginner’s cloud computing course.”
* **Knowledge retention aids:** Eddy AI can help create summaries and quick revision guides. You might ask, “Generate a revision guide summarizing the key points of the data privacy module.”

---

### 2. Streamlining content for customer support knowledge base

In customer support, having a well-structured knowledge base is essential for quick and effective problem resolution. Eddy AI can assist by creating and organizing relevant content for customer support teams and self-service portals.

**Creating troubleshooting guides**

* You can prompt Eddy AI with specific support cases like, “Generate a step-by-step troubleshooting guide for common login issues in an e-commerce platform.”
* For technical support, ask for explanations on error messages. For example, “Create documentation explaining the causes and fixes for error code 403 in web hosting.”

**Organizing FAQs for support agents**

* Use Eddy AI to generate frequently asked questions based on customer interactions. For example, “Create a list of FAQs for common billing issues faced by customers on our platform.”
* It can also assist in updating existing FAQs by analyzing new data or customer queries. Ask, “Update our current FAQ section with recent questions about product integration.”

---

### 3. Accelerating compliance documentation in regulated industries

For industries like healthcare, finance, or manufacturing, maintaining up-to-date compliance documentation is crucial. Eddy AI can simplify the creation and maintenance of this content.

**Generating compliance checklists**

* Ask Eddy AI to generate specific checklists based on industry standards. For instance, “Generate a checklist of mandatory compliance requirements for healthcare data privacy regulations (HIPAA).”
* Compliance content often requires updates. Eddy AI can help with prompts like, “Update the checklist with the latest changes to GDPR regulations.”

**Creating Standard Operating Procedures (SOPs)**

* In regulated environments, SOPs need to be clear and detailed. Eddy AI can assist in drafting these. You could ask, “Draft a Standard Operating Procedure for handling customer data in compliance with GDPR.”

---

### 4. Supporting product development documentation in tech companies

Maintaining up-to-date product documentation is key to smooth operations and customer satisfaction for software and tech companies. Eddy AI can help streamline the process.

**API documentation**

* Ask Eddy AI to generate API usage examples or explanations. For example, “Generate a step-by-step guide on how to integrate our API with third-party services.”
* It can also assist with documentation updates. You can request, “Update the API documentation to reflect the changes in the latest version.”

**Release notes and feature documentation**

* With new product updates, use Eddy AI to create concise release notes. For instance, “Generate release notes for version 4.2 of our software, highlighting the new features and bug fixes.”
* It can also help generate user guides for new features. For example, “Create a user guide for the new reporting dashboard feature in our SaaS platform.”

---

### 5. Automating knowledge base content for retail and E-commerce

In retail and e-commerce, a comprehensive knowledge base is critical for ensuring smooth customer support and product understanding. Eddy AI can help keep your content updated and relevant.

**Product documentation**

* Use Eddy AI to automatically generate product guides. For instance, “Create a product guide for a smart home security system, covering setup, troubleshooting, and usage tips.”
* It can also generate comparison content. Ask, “Compare the features of three smart home security systems available on our platform.”

**Order and return procedures**

* Create customer-facing content that simplifies processes. For example, ask, “Generate a step-by-step guide for returning a product purchased on our e-commerce site.”

---

### FAQs

**How can I ensure Eddy AI gives me specific content?**

Be as detailed as possible in your prompt. If you're asking for an explanation, specify the length, tone, and focus. For example, “Provide a formal, 200-word explanation of how to create custom categories in Document360.”

**What should I do if the output is too broad?**

Rephrase the prompt to narrow the focus. Break down the request into smaller steps, such as “Generate a summary of Document360’s version control feature,” followed by “List the key benefits of version control in a knowledge base system.”

**Can Eddy AI assist with writing FAQs based on my content?**

Yes, you can request FAQs based on specific sections or topics. For instance, ask, “Generate FAQs related to article categorization and tagging in Document360.”

**How can I use Eddy AI to create technical content?**

For technical content, make sure your prompts include relevant technical details. For example, “Generate a step-by-step guide for integrating Google Analytics with Document360’s knowledge base.”

<a id="drive"></a>

## File management

**Plans supporting the use of Drive**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 Drive is a centralized, cloud-based storage solution designed to help Document360 customers store, organize, and manage files efficiently.

> NOTE
>
> Plan storage limits are as follows:
>
> * **Free:** 1 GB
> * **Professional:** 50 GB
> * **Business:** 100 GB
> * **Enterprise:** 500 GB

## Document360 Drive

Document360 Drive is a centralized, cloud-based storage repository designed for Document360 customers. It allows you to store and manage all your files efficiently, ensuring easy access and seamless collaboration across your team.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Document360_drive_overview.png "image(134).png")

To access the Document360 drive, click the Drive () icon on the left navigation bar.

### Drive management features

1. [Adding folders and files](/help/docs/adding-folders-and-files)
2. [Folder actions in Drive](/help/docs/folder-actions-in-drive)
3. [File actions in Drive](/help/docs/file-actions-in-drive)
4. [All files overview](/help/docs/all-content-overview)
5. [Recent, Starred, and Recycle bin files](/help/docs/recycle-bin-recent-and-starred-files)

<a id="adding-folders-and-files"></a>

## Adding folders and files

**Plans supporting the use of Drive**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 Drive enables you to create and manage folders and subfolders, ensuring that your file structure aligns with your Knowledge base categories for better navigation and accessibility. This article will walk you through the steps to manage system folders, add new folders, subfolders, and files, making your document management more organized and intuitive.

---

## System folders

Every Document360 project includes **System folders**, which are built-in folders that come by default. These folders are essential for the core functionality of your project and cannot be deleted, moved, reordered, or renamed. However, users can perform certain actions within these folders, including adding files or setting a default folder.

When you navigate to the **Drive** page, you will see a category tree on the left navigation pane listing all your files and folders. System folders are easily identifiable by the **shield icon** next to their name.

> NOTE
>
> While files within system folders can be deleted (though not recommended), the folders themselves have several restrictions.

For example, **Images** is a system folder which contains subfolders such as Home page builder, Settings, Documentation, and Glossary.

![Drive interface displaying system folders like Settings, Documentation, and Home page builder.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-System_folders_in_Drive.png)

### Folder actions

#### Restricted actions

* **Delete**: System folders cannot be deleted.
* **Move/Reorder/Rename**: You cannot move, reorder, or rename system folders.

#### Allowed actions

* **Add Files/Folder**: You can freely add files or create new subfolders within system folders.
* **Change color**: Customize folder colors to help visually organize your Drive.
* **Set default folder**: You can set any system folder as the default for easy access.

![Document360 interface showing file management options and folder structure in the drive.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-More_options_in_system_folder.png)

---

## Adding a new folder

Here are the methods to create a new folder in your Drive.

**Method 1:** Using the ‘New folder’ option  
**Method 2:** Using the ‘+’ option

Method 1

Method 2

### Using the '+' option

Use the Folder Manager navigation pane on the left to add a root-level folder. This process is similar to adding a category using the "Category Manager" in the Documentation section.

1. Navigate to **Drive** () from the left menu in the knowledge base portal.

   Existing Folders and Subfolders will be displayed in a tree-view style on the left navigation pane.
2. In the left navigation bar, hover the mouse pointer over the space between the folders until the **Flywheel** (**+)** icon appears.
3. Click the **+** icon, and a **New folder** popup will appear.
4. Enter the desired folder name.
5. The default location is 'Root level.' You can add a new root-level folder from anywhere in the Drive using the folder location dropdown and clicking on the **Reset** option.
6. Click **Create**.

![Creating a new folder named 'Artifacts related to Release notes' in the drive.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Adding_a_new_folder_using_flywheel_icon.png)

### Using the 'New folder' option

1. Navigate to **Drive** () from the left menu in the knowledge base portal.

   Existing Folders and Subfolders will be displayed in a tree-view style on the left navigation pane.
2. Click the **New folder** option on the top left.

   A **New folder** popup will appear.
3. Enter the **Folder name**.
4. The folder location is 'Root level' by default.

   Using the **Folder location** dropdown, you can select the desired folder.
5. Click **Create**.

![Creating a new folder named 'Artifacts related to Release notes' in Document360.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Adding_a_new_folder_using_New_folder_option.png)

> PRO TIP
>
> When you create folders for your knowledge base s, it is easier to navigate and maintain if the folders are in-sync with the Category and Subcategory of your knowledge base.

---

## Adding subfolders

You can add subfolders once you have more than one root-level folder.

**Method 1:** Using the ‘More’ option  
**Method 2:** Using the ‘+’ option

Method 1

Method 2

### Using the 'More' option

1. Navigate to **Drive** () from the left menu in the knowledge base portal.

   Existing Folders and Subfolders will be displayed in a tree-view style on the left navigation pane.
2. Click the More () icon next to the folder, select **Add folder**.

   The **New folder** popup appears.
3. Enter the **Folder name**.
4. The folder location by default is the folder you click on the More () icon.

   You can add a subfolder anywhere in the Drive using the location dropdown.
5. Click **Create**.

![Creating a new folder named 'AI Writer artifacts' in the document management system.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Adding_a_subfolder_using_More_option.png)

### Using the '+' option

1. Navigate to **Drive** () from the left menu in the knowledge base portal.

   Existing Folders and Subfolders will be displayed in a tree-view style on the left navigation pane.
2. In the left navigation bar, hover the mouse pointer over the space between the folders until the '+' icon appears.
3. Click the '**+**' icon.

   A **New folder** popup will appear.
4. Enter the desired folder name.

   The default location is the folder where you clicked the '+' icon.

   Using the location dropdown, you can add a subfolder from anywhere in the Drive.
5. Click **Create**.

![Creating a new folder named 'Artifacts related to Release notes' in the drive.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Adding_a_new_folder_using_flywheel_icon.png)

> NOTE
>
> Ensure the root level folder is expanded (The arrow on the left side of the folder points downwards); if not, a new folder will be created at the same level.

> **CAUTION**
>
> Deleting a root-level folder in the Drive also deletes its subfolders and files. This can cause broken images and file links in articles referencing any deleted file.

---

## Adding files

You can add files to folders in drive using two methods:

**Method 1:** Using drag and drop in Empty folders  
**Method 2:** Using the 'More' option

Method 1

Method 2

### Using drag and drop in Empty folders

You can add individual or multiple files to folders or subfolders using the drag and drop feature. If your folder is empty, you can use the drag and drop area in the center or click the **Upload** button.

1. Drag one or more files from your device's local storage and drop them into the designated area.

   Alternatively, click the **Upload from my device** button and use the file explorer to select your files.
2. Specify the **Folder location** where you will store the files.

   The Folder that is selected in the Folder manager is set as the default location for file upload.
3. Upon completing the selection of images, in the **Tags** field, you can select pre-existing tags or choose to create tags, which will be saved to the available list of tags.
4. If a single image is being uploaded, define the **Alt-text**, and if multiple images are being uploaded, define the **Common alt-text** for the set of images selected for upload.
5. Click **Upload** to confirm.

![Adding files using the local file explorer option in the Drive](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Adding_files_drag_and_drop.gif)

### Using the 'More' option

To add files to a subfolder, use the left navigation pane:

1. Click the **More** () icon next to the folder.
2. Select the **Add file** option.
3. You can upload your files in two ways:

   1. Click **Upload from my device** and select your files from local file explorer.
   2. Drag and drop the desired file.
4. Add **Tags** and **Common alt text** if required.
5. Click **Upload**.

![Adding files using the More icon in the Drive](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_ScreenGIF-Adding_files_using_more_option.gif)

> NOTE
>
> * File names should not contain the characters +, %, #, or =.
> * You can view the list of acceptable file formats in the bottom left. To know more about acceptable formats, read [How can I add file type restrictions](/help/docs/adding-folders-and-files#how-can-i-add-file-type-restrictions)?
> * When uploading multiple images, you can add both tags and alt text. However, if you upload a combination of images and other file formats, or if you upload only file formats other than images, you can only add tags. Both Tags and Alt text fields are optional fields.

---

## File limits and file type restrictions

The file limits and file type restrictions are as follows:

* Each folder can contain up to 5000 files.
* Subfolders are treated as separate folders.
* **Single file upload**: The maximum file size is 150MB per file.
* **Multiple files upload**: The maximum combined size of all selected files is 160MB.

### Adding file type restrictions

You can restrict the file types you and other team members can upload. For example, if you want to restrict uploads to only .png files, follow these steps:

1. Navigate to **Settings**() > **Knowledge base portal** > **General** > **Drive settings**.

   By default, the **Allow all media types** option is selected.
2. Click **Choose allowed media formats** and click **Add**.
3. Enter the **Media type** and **Extension** fields.

   > NOTE
   >
   > * **Media type** - Type in the media you want to restrict. You must enter the following format: `media type/extension`. Refer the [basic media format types](https://en.wikipedia.org/wiki/Media_type#Common_examples_%5B10%5D) for better understanding
   > * **Extension** - Type in the extension type. This is a case-sensitive field. Ensure that you enter the lowercase alphabet in this field. (For example, .png, .svg, .jpg)
4. Click **Add media type** to add the more allowed file formats.
5. Click **Save** to confirm.

![Adding file restrictions to the project](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_ScreenGIF-Adding_file_type_restrictions.gif)

## Troubleshooting

### **Folder file limit reached**

**Error:** This folder has reached its maximum file limit. Please upload your file(s) to another folder.

This error occurs when a folder exceeds the **5000-file limit** in Document360 Drive. This includes:

* Files uploaded directly into a folder.
* Images copied and pasted into the article editor, which are automatically saved in the default folder by **Set default folder**.
* Images from imported **Docx files**, which are stored in the **default folder** on the drive.

**Steps to resolve:**

* Upload new files to a **different folder** or change the default folder on the drive.
* Remove **unused files** from the current folder to free up space.
* If the issue persists, **clear the browser cache** and try again.

![Folder storage limit reached notification in Document360 interface with file list displayed.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Troubleshooting_Folder_files_limit_reached.png)

---

### FAQs

#### What is alt text in Document360 Drive and how is it used?

Alt text (alternative text) in Document360 Drive is a brief description of an image's content. It is used primarily for accessibility purposes, helping visually impaired users understand the context of images embedded in articles. Alt text should be descriptive yet concise, providing meaningful information about the image.

* Specify alt text for each image to ensure accessibility compliance and improve user experience.
* Alt text can be set during the upload process or edited later through image properties in Document360 Drive.
* Each alt text can be up to 140 characters long.

#### Why are certain files and images not uploading to Google Drive and showing a 'File type not supported' error?

This may be due to file type restrictions. To check and adjust the allowed file formats, follow these steps:

1. Navigate to **Settings** ()> **Knowledge base portal**> **General** > **Drive settings** in the Knowledge base portal.

   By default, the **Allow all media types option** is selected.
2. If this option is enabled, try re-uploading your files or images.
3. If specific file formats are selected to restrict, you must remove these restrictions to upload your desired files.

> NOTE
>
> Ensure that file names in uploaded files do not include the characters **+**, **%**, **#**, or **=**."

A centralized, cloud-based storage repository in Document360 for storing and managing all files.

A type of category in Document360 used to organize articles without creating a separate knowledge base page.

A secondary folder in the Document360 drive that is created within a primary folder to further organize files and content.

A type of category in Document360 used to organize articles without creating a separate knowledge base page.

A secondary folder in the Document360 drive that is created within a primary folder to further organize files and content.

Organizes related articles under a common theme in the knowledge base.

A secondary category in Document360 used to organize and display groups of related articles. Subcategories act as folders within a primary category, helping structure similar topics for better organization and navigation.

A type of category in Document360 used to organize articles without creating a separate knowledge base page.

A secondary folder in the Document360 drive that is created within a primary folder to further organize files and content.

A type of category in Document360 used to organize articles without creating a separate knowledge base page.

A secondary folder in the Document360 drive that is created within a primary folder to further organize files and content.

<a id="folder-actions-in-drive"></a>

## Folder actions in Drive

**Plans supporting the use of Drive**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In Document360, you can organize your files efficiently using folders and subfolders. You can manage individual folders or use bulk actions to handle multiple folders at once, making it easier to maintain and retrieve your knowledge base assets.

> NOTE
>
> For effective file management, it is recommended to organize your folders and subfolders similarly to your documentation categories and subcategories. This ensures that storing, maintaining, and retrieving files is straightforward and intuitive.

---

## Setting a folder as Default folder

To set a folder as a Default folder, follow the below steps:

1. Click the Drive () icon on the left navigation sidebar.
2. Click on any folder from the left navigation pane.
3. Click the More () icon next to the desired folder and then click the **Set default folder** option.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Default_folder.png)

* The selected folder will be set as the default folder on a project level.
* Once done, you will get a popup saying *Editor folder updated*.
* The **Default folder** on the Drive can be identified by the Edit () icon that appears next to the folder icon.

  > NOTE
  >
  > + If a category has already been mapped to a Drive folder, the mapped Drive folder setting is chosen over the Default folder. All the images added to any article in that category are uploaded to the mapped Drive folder.
  > + But if the category is not mapped to any Drive folder, the images added directly would be saved in the Default folder.

---

## Renaming a folder

You can change or update the existing name of a folder or a subfolder.

1. Click the Drive () icon on the left navigation sidebar.
2. You can view the existing Folders and Subfolders in tree-view style on the left navigation pane.
3. Click the More () icon next to the desired folder.
4. Click **Rename**.
5. Enter the new name and click the **Rename** button.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Rename_drive.png)

   > NOTE
   >
   > You cannot rename a **System folder**.

---

## Moving a folder

You can move your folders and subfolders within the Drive.

> NOTE
>
> You cannot move a **System folder** in the Drive.

There are two ways to execute the **Move** function.

### Using the More option

1. Click the Drive () icon on the left navigation sidebar.
2. Hover over the folder you want to move and click the **More (****)** icon.
3. Select **Move**.

   Alternatively:

   1. Select one or more folders by checking the boxes next to their names.
   2. Click the **Move** option that appears above the list.
4. In the **Move files** window, select the destination folder.
5. Use the search field to quickly find the destination folder by typing keywords.
6. Click **Move**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGif-Moving_drive_folder.gif)

The category with its subfolder and files will be moved to the new location.

### Using drag and drop

You can also use the left navigation panel to move your folders into other main folders and subfolders.

1. Click and hold the folder you want to move.
2. Drag the folder to the desired location on the left navigation pane.
3. Drop the folder onto another folder to move it inside.

![54_Screenshot-Drive-Moving_drag_and_drop_moving](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1729155724024.png)

---

## Starred folders

You can add your main folder or subfolder as a Starred entity. This means the folder marked as starred appears when you click on the **Starred** option on the left navigation pane, irrespective of the folder’s location in the Drive.

1. Click the Drive () icon on the left navigation sidebar.
2. Hover over the desired folder and click the star (☆) icon.

   The starred folders will be indicated with a star (★) icon next to the folder name.
3. Click on the "★" icon next to the folder name to remove the folder from the **Starred** list of folders.

   You can perform the same action from the "Starred" overview folder.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenShot-Starred_drive_folders.png)

---

## Change folder color

You can change the folder color to any given or custom color. This is handy when you want to differentiate one folder from another or color-code it. The default folder color is Gray.

1. Hover over the desired folder on the left navigation pane and click the More () icon.
2. Click **Change color**.

   You can choose from the color palette with all the most common colors. If you want to add any custom color, enter the required Hex code or use the color picker.

![32_Screenshot-Drive_Folder_actions-Change_folder_color](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/32_Screenshot-Drive_Folder_actions-Change_folder_color.png)

---

## Removing or deleting a folder

You can remove or delete folders and subfolders from the Drive using the Remove and Delete options.

1. Click the Drive () icon on the left navigation sidebar.
2. Click the More () icon next to the desired folder.
3. Click **Remove**.

   Alternatively:

   Select the checkbox of the desired folder and the **Remove** option will appear above the folder list.
4. Click **Remove**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenShot-Remove_drive_folder.png)
5. A **Delete** confirmation prompt will appear.
6. Click **Yes**.

> NOTE
>
> * Once deleted, all the corresponding reference links of the media files will be broken. Please note that clearing the CDN cache will take up to 1 minute.
> * You cannot remove or delete the System folders. You can identify these folders by the shield symbol on the folder icon.
> * If you have accidentally removed or deleted any folder from the Drive, you can always retrieve it from the **Recycle bin** (up to 30 days from deletion) of the Drive.

---

## Bulk folder actions

You can perform different actions on more than one folder at a time. This saves time when you want to perform these actions for a larger number of folders in your Drive.

1. Click the Drive () icon on the left navigation sidebar.
2. Select one or more folders (in list view and grid view) from the list of folders.

   At the top, you can view the bulk actions possible:

   * **Move**: Relocate the selected folders to another folder.
   * **Copy**: Create a copy of the folders.
   * **Add tags**: Organize folders with tags for better categorization.
   * **Download**: Download the selected folders to your local storage.
   * **Remove**: Delete the folders and move them to the Recycle bin.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenShot-Bulk_folder_action.png)

---

## Folder breadcrumb

The folder **Breadcrumb** at the top of the Drive window helps you navigate within the folder hierarchy. It shows the path from the root directory to the current folder you’re viewing.

Click on any level of the breadcrumb to navigate back to that folder.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1729167349844.png)

---

### FAQ

#### What happens if I click on the Set default folder option for a folder that is already set as the default?

A drive folder can be set as the default multiple times. If you select the **Set default folder** option for a folder that is already the default, no changes will be made.

#### What happens when I change the name, copy, move, or reorder a folder?

Changing the name, copying, moving, or reordering a folder does not affect the file URLs of the files within it keeping the images linked to articles intact.

A type of category in Document360 used to organize articles without creating a separate knowledge base page.

<a id="file-actions-in-drive"></a>

## File actions in Drive

**Plans supporting the use of Drive**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## Performing file actions in Drive

To manage files in Document360 Drive, follow these steps:

1. Navigate to **Drive** () from the left menu in the knowledge base portal.
2. Click the desired folder in which the required file is available.
3. Click the list view/grid view () icon on the top right of the **Drive** page.

   * **List view:** Click the **More** () icon next to the file name.

     By default, the list style appears. You can view the files along with information such as name, dependencies, updated on, updated by, file size, and tags. It is visible in columns only when the view is in List style. You can adjust the length of each of the columns containing file information.

     ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Drive page - List view(1).png "Drive page - List view(1).png")
   * **Grid View:** Hover over the file and click **More** and select the file action.

     Alternatively, hover over the file(s) and select the checkbox to view the file actions, such as actions **Move**, **Copy**, **Add tags**, **Download**, and **Remove** at the top menu.

     ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Drive page - Grid view(2).png "Drive page - Grid view(2).png")

---

### Move

You can **move** files between folders without changing its link structure. This is similar to performing cut and paste action.

1. Select the required file in your drive.
2. Click **Move** in the top menu bar.

   The **Move files** popup window appears.
3. Select the desired folder by searching the destination folder in the search bar or by navigating to the desired folder manually from the list.
4. Click **Move**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/File actions in Drive - Move.png "File actions in Drive - Move.png")

   > NOTE
   >
   > The image link does not change when it is moved from one folder to the other folder in Drive. This helps the images linked to the articles stay intact.
   >
   > `https://cdn.document360.io/project-id/Images/Documentation/image name.image_type`

---

### Copy

You can duplicate the file in another destination folder. This is similar to performing copy and paste action.

1. Select the required file in your drive.
2. Click **Copy** in the top menu bar.

   The **Copy files** popup window appears.
3. Select the desired folder by searching the destination folder in the search bar or by navigating to the desired folder manually from the list.
4. Click **Copy**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/File actions in Drive - Copy.png "File actions in Drive - Copy.png")

---

### Add tags and alt-text

You can add tags and alt-text to your file for easy discoverability and grouping. The article tags and file tags are from the same tag library. Adding tags makes it easier for you to identify or search and retrieve a particular set of files.

1. Select the required file in your drive.
2. Click **Add tags**, in the top menu bar.

   The **File details** blade appears.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/File actions in Drive - Add tags & alt-text(1).png "File actions in Drive - Add tags & alt-text(1).png")
3. Add the tags in the **Tags** field.
4. Add the alternative text in the **Alt text** field.
5. Click **Update**.

You can also add tags to multiple files simultaneously.

1. Selecting the required files from the drive.
2. Click **Add tags** in the top menu.

   The **Add tags** pop-up window appears.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/File actions in Drive - Add tags - multiple files(2).png "File actions in Drive - Add tags - multiple files(2).png")
3. In the **Tags** field, enter the relevant tags.

   You can either add existing tags or create new tags.
4. Click **Add**.

---

### View details

To view and manage file details, click the **More** () icon next to the file name and select **View details** from the dropdown menu. This will open the **File details** blade, where you can view a thumbnail of the file and access various actions such as move, copy, replace, download, and delete, which are available through icons located below the thumbnail.

Additionally, you can view important file information, including the file's location, size, type, uploaded date, and the name of the user who uploaded the file. You can also view and edit the tags associated with the file, as well as the alt text for image files.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/File actions in Drive - View details.png "File actions in Drive - View details.png")

---

### View file dependencies

**File dependency** indicates the number of instances a particular file has been added/attached to articles/category pages in the knowledge base.

1. Navigate to the Drive (  ) icon in the **Knowledge base portal**.
2. Browse through the folders to locate the intended file.
3. In the Dependencies column, click on the number (e.g., 6) displayed next to the file. This number represents the count of related areas with dependencies.

   * **Files with Dependencies**: If a file has dependencies, the Dependencies field will show the number of dependencies.
   * **Files without Dependencies**: If a file has no dependencies, the Dependencies field will be indicated by a '-'.

   Be cautious when handling folders, as they may contain files with dependencies. Always review individual file dependencies before making changes to a folder.
4. Upon clicking the number, the **File dependencies** panel will appear. This panel provides information about the file's associations in various areas, such as Articles, KB Customization, and Content Reuse.
5. In **Articles**, expand the listed articles to view details such as the article status, article version, Open site () icon, team account, and date.
6. In **KB Customization**, the homepage details associated with the file will be displayed.
7. In **Content reuse**, expand the desired content tool, and you can view the languages and the content reuse (variable, snippet, glossary) name.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/File actions in Drive - File dependencies(1).png "File actions in Drive - File dependencies(1).png")

To identify files with or without dependencies in your drive,

1. Click the **Filter** () in the top right corner.
2. Expand the **Dependencies** tab and choose the necessary option to filter the files based on filtering options.
3. Click **Apply** to view your desired results.   
   This will help to keep the drive free from outdated images or files with no dependencies.

   ![Image showing dependencies filter in drive](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1735730861622.png)

---

### Download

You can download single or multiple files from the drive to your local storage.

1. Select the file(s) you want to download.
2. Click the **Download** button on the top menu bar. The file(s) will be downloaded as a .zip file.

Alternatively, you can download a file from its details page:

1. Open the **File details** blade.
2. Click the **Download** () icon. The selected file will be downloaded as a .zip file.

Alternatively, click the **More** () icon next to the file name and select **Download** from the dropdown menu. The specific file will be downloaded as a .zip file.

---

### Remove

You can delete single or multiple files from the drive to your local storage.

1. Select the file(s) you want to delete.
2. Click the **Remove** button on the top menu bar. The file(s) will be moved to the Recycle bin folder.

Alternatively, you can delete a file from its details page:

1. Open the **File details** blade.
2. Click the **Remove** () icon. The selected file will be moved to the Recycle bin folder.

Alternatively, click the **More** () icon next to the file name and select **Remove** from the dropdown menu. The specific file will be moved to the Recycle bin folder.

> NOTE
>
> Once deleted, all corresponding media file reference links will be broken, and the CDN cache will be cleared shortly.
>
> You can choose to retrieve files from the recycle bin in case of accidental deletion.

---

### Replace

You can update a file by replacing it with another file of the same type. This allows you to update your files without changing the file name or URL. This helps in retaining the file path in any locations where the file is used without breaking the links. The file change will be updated in the article within 20 minutes.

![15_Screenshot-File_actions_in_Drive_File_replace](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1731493359282.png)

#### Method 1

1. Click the Drive () icon on the left navigation sidebar.
2. Navigate to the folder where the file you want to replace is located.
3. Hover over the desired file and click the More () icon.
4. Click **Replace**.

   Your local file manager will open.
5. Select the new file to replace the existing one and click **Open**.

   The new file will be updated in the Drive.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-File_replacement.png)

#### Method 2

1. Click the Drive () icon on the left navigation sidebar.
2. Navigate to the folder where the file you want to replace is located.
3. Hover over the desired file and click the More () icon.
4. Click **View details**.
5. A **File details** blade will open on the right side of the window.
6. Click the Replace () icon.
7. On the **Replace file** popup, click **Replace file**.

   Your local file manager will open.
8. Select the new file to replace the existing one and click **Open**.

   The new file will be updated in the Drive.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGif-File_replacement.gif)

> NOTE
>
> When a file is replaced on the Drive, the old file content is overwritten. The old file content cannot be restored in any way possible (unless there is an offline backup of the same file). Unlike the deleted files, the overwritten files are not available in the Recycle bin of the Drive to restore.

---

## Troubleshooting

### Resolving file replacement error

**Error**: You can’t replace files with a different style type.

This error occurs when you try to replace a file with another file of a different type, which is not allowed. For instance, if you are trying to replace a jpg file with a pdf file, you might encounter this error.

**Steps to resolve**:

1. **Verify file types:**

   1. Navigate to **Drive ()** in the **Knowledge base portal**.
   2. Click the **More** () icon to view the file details and click **Replace.**
   3. Ensure the selected and destination files are of the same type.

2. **Clear your browser cache:**

   1. After confirming the file types, clear your browser cache and try again.
   2. Use the steps below based on your browser:

      * Google Chrome: Click on **Menu** () > **Settings** > **Privacy and security** > **Clear browsing data**.
      * Mozilla Firefox: Click on **Menu** ()  > **Settings** > **Privacy & Security** > **Clear Data**.
      * Microsoft Edge: Click on **Menu** ()  > **Settings** > **Privacy, search, and services** > **Choose what to clear**.
      * Safari (Mac): Go to **Safari** > **Preferences** > **Privacy** > **Manage Website Data** > **Remove All**.
      * Safari (iPhone/iPad): **Settings** > **Safari** > **Clear History and Website Data**.
      * Opera: **Menu** > **Settings** > **Advanced** > **Privacy & Security** > **Clear browsing data**.

        > NOTE
        >
        > It may take some time for the updated settings to take effect.

3. **Test in different environments:**

   1. Open the file replacement workflow in an incognito window.
   2. Try the process in different browsers to confirm the issue is resolved.

4. If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

   Provide the following details:

   * Screenshots of the error message.
   * Details of the affected files.
   * A HAR file for further analysis.

---

### FAQs

#### Is there a way to see the file's history or previous versions before replacing it?

Currently, Document360 does not provide version history of files in the Drive. It's recommended to keep backups of important files before making replacements.

#### What happens to the old file after I replace it?

The old file's content is permanently overwritten and cannot be restored. Make sure to back up important files before replacing them.

A folder in the Document360 drive where deleted files and folders are temporarily stored. It allows users to recover accidentally deleted items if needed. Deleted items are stored for 30 days before they are deleted permanently.

A folder in the Document360 drive where deleted files and folders are temporarily stored. It allows users to recover accidentally deleted items if needed. Deleted items are stored for 30 days before they are deleted permanently.

A folder in the Document360 drive where deleted files and folders are temporarily stored. It allows users to recover accidentally deleted items if needed. Deleted items are stored for 30 days before they are deleted permanently.

A centralized, cloud-based storage repository in Document360 for storing and managing all files.

A folder in the Document360 drive where deleted files and folders are temporarily stored. It allows users to recover accidentally deleted items if needed. Deleted items are stored for 30 days before they are deleted permanently.

<a id="all-content-overview"></a>

## All files overview

**Plans supporting the use of Drive**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **All Files** overview page in Document360 Drive compiles all the files in your project in one place. This feature is particularly helpful for performing bulk operations, allowing you to manage files across all folders and subfolders from a single location. Whether you need to move, copy, or delete files in bulk, the All Files page saves you time and effort by centralizing your file management.

## All files overview page

Navigate to Drive () > **All files** on the Knowledge base portal.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Drive_all_files_page_overview.png)

The **All files** overview page will display, listing the files in your project. By default, the page shows 20 files per page. To navigate through the list of files, use the pagination buttons at the bottom of the list to move between pages.

The following options are available on the **All files** page:

* **Storage used**: You can view both the used and total available storage in your Document360 Drive. If you need additional space, you can purchase more storage by selecting the **Buy more** option.
* **Grid view**: Files and folders in Drive are displayed in list view by default. You can switch to **Grid view** to display files and folders in a grid format.
* **Filter**: Use the **Filter** option to narrow down files based on specific criteria. The following filters are available in Drive:

  + **Dependencies**: Shows files without any dependencies, meaning these files haven't been used in articles, content reuse elements, or knowledge base customizations.
  + **Uploaded**: Filters files by their upload date.
  + **Uploaded by**: Filters files by the team account that uploaded them.
  + **Type**: Filters files by their format.
  + **Tags**: Filters files by user-added tags.

### Bulk operation on files

The **All files** page allows you to perform bulk operations, streamlining file management across the entire Drive. Here's how to select files and use these operations effectively:

* Click on the checkbox next to each file to select it individually.
* To select all files on the current page (up to 20), click the **Select all** checkbox at the top of the list.

> NOTE
>
> If you want to select all files in the Drive, click **Select all {N} items**, where **N** is the total number of files in your project. This will select all files, not just the 20 displayed on the current page.

Once you have selected the files you wish to manage, you can choose from the following bulk actions:

* #### **Move**

  + Relocate selected files to any folder or subfolder, including categories.
  + Use this feature when reorganizing your Drive to keep files well-structured.
* #### **Copy**

  + Duplicate files and paste them into a different folder or subfolder in the Drive.
  + Copy files when you need the same content in multiple locations without affecting the original file.
* #### **Download**

  + Download the selected files to your local storage.
  + Use this feature to back up important files or to work on them offline.
* #### **Remove**

  + Delete files from the folder and move them to the Recycle bin (includes categories).
  + Once in the Recycle bin, files can be restored or permanently deleted.

If your project contains more than 20 files, use the pagination buttons at the bottom of the All Files page to move between pages. Here’s how to navigate:

* **Next/Previous buttons**: Click these to move forward or backward through the list of files.
* **Page numbers**: Jump to a specific page by clicking the page numbers displayed at the bottom of the file list.

  ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Drive_all_files_bulk_actions.png)

---

### Best practices for file management

* **Regular cleanup**: Use the **All files** page to periodically review and clean up unnecessary files. This ensures your Drive stays organized and clutter-free.
* **Use categories**: When moving or copying files, categorize them appropriately to improve searchability and file management.
* **Check dependencies**: Before removing files, verify their dependencies to ensure they are not linked to other important content.

<a id="recycle-bin-recent-and-starred-files"></a>

## Recent, Starred, and Recycle bin files

**Plans supporting the use of Drive**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Managing a large number of files and folders can sometimes lead to intentional or accidental deletions. To help recover deleted content, Document360 provides a Recycle bin. When a file or folder is deleted, it is temporarily moved to the Recycle bin, allowing users to easily restore it if needed.

> NOTE
>
> Document360 also provides a dedicated **Recycle bin** for the categories and articles deleted from your Documentation.

## Recycle bin operations

1. Click the Drive () icon on the left navigation sidebar.

   You can view the existing Folders and Subfolders in tree-view style on the left navigation pane.
2. Click **Recycle bin**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Recycle_bin.png)

> NOTE
>
> Hover over the file and click the eye () icon to view its dependencies. A blade with the list of article(s) where the file is associated will appear.

### Restore from recycle bin

#### Bulk restore

In case of accidental file/folder deletions in the Drive, follow the below steps to restore all the files and folders.

1. On the Recycle bin window, select the checkbox of the files/folders you want to restore.
2. If you wish to select all the items in the Recycle bin, check the Select all checkbox at the top (only the first 20 items will be selected).
3. To select all the files in your Recycle bin, click **Select all {N} items**, where N is the total number of files in the Recycle bin.

   This option will appear only when at least one file is selected.
4. Click **Restore**.

   The selected files/folders will be restored to their original location in the Drive.

#### Restore individual files or folder

For individual files/folders,

1. Hover over the desired file/folder and click on the More (•••) icon.
2. Click **Restore**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGif-Restore_drive.gif)

### Permanently deleting files from the Recycle bin

If you are confident that you do not need the files/folders in the recycle bin,

1. On the Recycle bin window, select the checkbox of the desired files/folders.
2. If you wish to select all the Recycle bin items, check the Select all checkbox at the top (only 20 items will be selected).
3. To select all files, click **Select all {N} items**.
4. Click **Delete forever** located above the list of files/folders.
5. Alternatively, for individual files/folders, hover over the desired file/folder and click on the More (•••) icon next to the file/folder.
6. Click **Delete forever**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Delete_forever_drive.gif)

#### Empty recycle bin

If you want to eliminate all the files/folders in the Recycle bin in one go, click the **Empty recycle bin** button at the top right. All the files/folders will be permanently deleted from the Recycle bin.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenShot-Empty_recycle_bin.png)

> NOTE
>
> The deletion of files/folders from the **Recycle bin** is an irreversible action. Once the file/folder is removed from the Recycle bin using the **Delete forever** or the **Empty recycle bin** option, it cannot be retrieved (unless you have an offline backup of the same file/folder).

---

## Recently uploaded files and folders

The **Recent** folder in the Drive window helps you to access the latest uploaded files/folders. This is a dynamic folder populated with files and folders based on the latest addition or upload. This comes in handy as you do not have to look for the latest files uploaded into any of the folders. To access this folder,

1. Click the Drive () icon on the left navigation sidebar.
2. From the left navigation pane, click on the **Recent** folder.

   You will see the list of files/folders that are uploaded latest based on the time of upload.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenShot-Recent_drive.png)

---

## Starred folder and files

You can add your main folder or subfolder as a Starred entity. This means the folder marked as starred appears when you click on the **Starred** option on the left navigation pane, irrespective of the folder’s location in the Drive. Starred files and folders help you quickly access important content by marking them for easy reference.

1. Click the Drive () icon on the left navigation sidebar.
2. On the left navigation pane, click the **Starred** folder.

   All the files/folders that you have starred will be listed here with a star (★) icon next to the folder name.
3. Click on the star (★) icon again to remove it from the **Starred** folder.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenShot-Starred_drive_folders.png)

---

### FAQs

#### What happens to a file/folder in the Recycle bin if I do not perform any action on it?

The file/folder would be automatically deleted permanently after 30 days.

#### Can I recover permanently deleted files or folders from the Recycle Bin?

No, once files or folders are permanently deleted using the "Delete forever" option, they cannot be recovered. It’s important to be certain before selecting this option. If you need additional backups, consider creating an offline backup before permanently deleting files.

A type of category in Document360 used to organize articles without creating a separate knowledge base page.

A centralized, cloud-based storage repository in Document360 for storing and managing all files.

<a id="workflow-designer"></a>

## Workflow designer

**Plans supporting workflow designer**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

A workflow in Document360 is a crucial tool designed to streamline the management of knowledge base documentation. It enables you to establish an internal business process for creating, editing, reviewing, and publishing articles or category pages.

## Why use workflow?

Workflow management facilitates collaboration among team members, including writers, editors, illustrators, and subject matter experts. Organizations can ensure consistency, accountability, and efficiency throughout the documentation cycle by implementing a structured workflow.

### Using workflow in Document360

Workflow functionality in Document360 consists of two main modules:

**1. Workflow designer**  
**2. Workflow assignments**

Here's a quick guide to using the **Workflow designer** efficiently.

---

## Workflow designer

The **workflow designer** feature helps project team members to create and maintain a step-by-step stage for any new or existing documentation. This makes collaboration easier between the writers, editors, illustrators, subject matter experts, and other project team members.

The workflow feature allows the admins or project owners to design a workflow that best suits their business requirements.

### Accessing the Workflow designer

To access the workflow designer page, follow the below steps.

Navigate to **Documentation**() > **Content tools** > **Workflow designer** in the Knowledge base portal.

You can view the existing built-in workflow (Draft – In review – Published). You can create additional workflow statuses here. You can also edit the existing statuses (including system status) and reorder/delete the custom statuses anytime.

![1-Screenshot-Accessing_the_workflow_designer.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1-Screenshot-Accessing_the_workflow_designer.png)

---

## Workflow status

A **Workflow Status** represents a checkpoint or stage in the documentation cycle within Document360. There are two types of statuses:

* **System Status**: These are predefined start and end statuses (e.g., Draft and Published) that **cannot be deleted or reordered**.
* **Custom Status**: These are user-defined statuses that offer flexibility in creation, editing, reordering, and deletion at any time. You can also turn on the **read-only** toggle for the statuses you added. This restricts the other team members from editing the article(s) or category page(s). They can only view and comment on it.

---

## Adding a new status

1. Navigate to **Documentation**() > **Content tools** > **Workflow designer** in the Knowledge base portal.
2. Click the **Create workflow status** button at the top-right.  
    Alternatively, click the **(+)** button found between the statuses to create the workflow status.

![2-Screenshot-Create_workflow_status.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2-Screenshot-Create_workflow_status.png)

4. Type in a **Name** (required) and **Description** (optional) for your status.
5. Turn on/off the **Read-only** toggle to allow or restrict editing the article when it is set to the specified status.

   > NOTE
   >
   > If the Read-only toggle is enabled, team members will not be able to edit the article or category page content when the article is set to the specified workflow status. Additionally, team members will not be allowed to publish the article. However, they can still add comments on the articles or category pages.
6. Click on the **Add** button at the bottom.

   The workflow status will be added in the intended section of the workflow.

![3-Screenshot-Create_workflow_status](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3-Screenshot-Create_workflow_status.png)

### Editing an existing status

1. Navigate to **Documentation**() > **Content tools** > **Workflow designer** in the Knowledge base portal.  
    The existing statuses in the workflow will be listed.
2. Click on the **Edit** () icon and an **Update status** panel will appear.

   ![4_Screenshot-Editing_a_new_workflow_status](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Editing_a_new_workflow_status.png)
3. You can edit the **Name**, and **Description** and update the **Read-only** option (for statuses you have created (or) statuses for which the **Read only** is turned off).
4. Click the **Update** button at the bottom once you are done.

#### Reorder status

You can reorder the custom statuses dragging and dropping them within the workflow. The reorder icon is available on the left adjacent to each status.

![6_Screenshot-Reordering_a_new_workflow_status](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Reordering_a_new_workflow_status.png)

> NOTE
>
> You cannot reorder system workflow statuses.

### Deleting an existing status

1. Navigate to **Documentation**() > **Content tools** > **Workflow designer** in the Knowledge base portal.  
    The existing statuses in the workflow would be listed.
2. Click on the **Delete** () icon.

![5_Screenshot-Deleting_a_new_workflow_status](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Deleting_a_new_workflow_status.png)

4. Click **Yes** to confirm.

> NOTE
>
> * The workflow status cannot be recovered once deleted. All the due dates and assignee data would also be lost.
> * Users cannot delete the two system statuses (Start\* and end\*) provided.

---

## Troubleshooting

### Cannot edit article due to read-only workflow status

**Error:** You can't edit this article as the current workflow status is marked as read-only.

This warning appears because the article's workflow status is currently set to a custom read-only mode. When an article's workflow status is read-only, editing is restricted to maintain content integrity for specific workflow stages.

Your admin may have set this status for a specific purpose. If you have the appropriate permissions, you can modify the status. Otherwise, please contact your admin to make the necessary changes.

**Steps to resolve:**

Follow the steps below to enable editing for the article:

1. Navigate to **Documentation**() > **Content tools** > **Workflow designer** in the Knowledge base portal.
2. Locate the workflow status causing the warning message. You can identify it by the **lock** () icon, which indicates that the **Read-only** option is enabled.
3. Click the **Edit**() icon next to the workflow status.

   The **Update status** panel will appear.
4. Turn off the **Read-only** toggle.
5. Click **Update**to save the changes.

Once the read-only status is disabled, you can edit the article as needed.

![Encountering "You can't edit this article as the current workflow status is marked as read-only" message while editing an article.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/ScreenGIF-Troubleshooting_You%20can't_edit_this_article.gif)

---

## eBook

### Guide to Setup Documentation Workflow

Our eBook will show you how to produce quality documentation!

#### You'll learn,

* *A step-by-step guide to creating documentation workflows*
* *Documentation best practices that improve content quality*
* *How to produce content that meets your customer expectations*

![ebook-documentation-workflow-mockup](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/ebook-documentation-workflow-mockup.png)

[![2022-02-02_08-23-42](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2022-02-02_08-23-42.png)](https://document360.com/ebook/guide-to-setup-documentation-workflow/#eBook-Form)

---

<a id="managing-workflow-status"></a>

## Managing workflow status

**Plans supporting for Managing workflow status**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You can manage workflow statuses from the Documentation editor. Additionally, they can assign these statuses to team members directly within the editor.

---

## Workflow status actions

The **Workflow status** option is available at the top right of the Documentation editor, next to the **Publish**/**Edit** button.

![Image showing workflow status of a article](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/18_ScreenShot-Workflow.png)

#### View the current status

The active workflow status of an article will be displayed as a tag below the **Workflow status** option above the editor.

For more information about the current or other status in the workflow, follow the below steps:

1. Click the **Workflow status** dropdown at the top right of the editor.
2. The list of available statuses and supporting information (due date, approved status, assignee) will be displayed.
3. If the article is in any status, the preceding statuses will be struck through.
4. If the article is *Published*, then all the statuses will be struck through.

#### Setting a due date

You can set due dates for both active/current and upcoming statuses in an article workflow.

1. Click the **Workflow status** dropdown at the top right of the editor.
2. Hover over the status for which the date has to be set.
3. Click the **Set due dates** () icon.
4. A calendar selection assistant will appear, and you can select the desired date.
5. To clear any existing due date, click the **Clear due date** option below the calendar.

#### Setting an assignee

1. Click the **Workflow status** dropdown at the top right of the editor.
2. Hover over the status for which the team member has to be assigned.
3. Click the **Assign owner** () icon.

   The list of project team members will be displayed.
4. You can also use the **Search by email** bar at the top to find the desired team member.
5. Click the **Assign** () icon.

   The team member will be assigned a particular status, and a notification will be sent to the team member’s Email.

   Removing an assignee can also be done by following the same steps. Hover over the team account and click the (**x**) icon next to it.

   > NOTE
   >
   > A single team member account can be assigned to multiple workflow statuses for an article. However, multiple team accounts cannot be assigned to a single workflow status.

#### Activate a workflow status

You can activate the next status if they have completed the assigned workflow status.

1. Click the **Workflow status** dropdown at the top right of the editor.
2. Hover over the next status and click on it.

   An expanded view of the status will appear along with the comment box.
3. If needed, use the comment box to provide any information to the next assignee by tagging them.
4. Click the **Set status** button and the next workflow status will be activated.

#### View workflow history

Users can view the entire workflow history with all the supporting information for an article.

1. Click the **Workflow status** dropdown at the top right of the editor.
2. Click the **View history** option above the workflow status list.
3. An expanded view with all the workflow status history will be displayed.

   This provides an overview of the entire workflow cycle that an article has gone through.

   Each version of the article revision can have its workflow history and comments.

![To set and manage workflow status of an article](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/19_ScreenGif-Workflow.gif)

---

### FAQ

**What steps should I take to ensure that team accounts receive notifications when I assign a workflow?**

The email will be sent to the team account to whom the workflow status is assigned, provided they have enabled the workflow events in the notification mapping. To ensure that team accounts receive notifications when assigning a workflow, they need to enable the relevant events in the notification section. Follow these steps:

1. Navigate to **Settings** () > **Knowledge base portal** > **Notifications**.
2. Go to the **Notification mapping** tab and expand the **Documentation editor** accordion.
3. Turn on the following toggles:

   * Article Workflow Status Updated
   * Article Workflow Due Date Updated
   * Article Workflow Assignee Updated
4. Additionally, to enable notifications for page category types, turn on the following toggles:

* Category Workflow Status Updated
* Category Workflow Due Date Updated
* Category Workflow Assignee Updated

---

## **eBook**

### **Guide to setup documentation workflow**

Our eBook will show you how to produce quality documentation!

**You’ll learn,**

* *A step-by-step guide to creating documentation workflows*
* *Documentation of best practices that improve content quality*
* *How to produce content that meets your customer expectations*

![ebook-documentation-workflow-mockup](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/ebook-documentation-workflow-mockup.png)

[![2022-02-02_08-23-42](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2022-02-02_08-23-42.png)](https://document360.com/ebook/guide-to-setup-documentation-workflow/#eBook-Form)

<a id="workflow-assignment"></a>

## Workflow assignment

**Plans supporting workflow assignment**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 enables you to manage and assign workflow statuses to team members directly from the editor. This feature streamlines the documentation process by providing clear visibility and control over each stage of an article's lifecycle.

---

## Assign an article to a team member

1. Navigate to the desired article from the Knowledge base portal.
2. Click the workflow status dropdown on the top right corner of your editor.
3. Hover over the desired status and click the **Assign owner** () icon.
4. Select the appropriate team member and click () to assign.

   Assigned team member will receive a notification email.

   > NOTE
   >
   > A single team member can be assigned to multiple workflow statuses in an article, but multiple members cannot be assigned to a single workflow status.
5. To remove an assignee, hover over the team member's name and click the (x) icon.
6. Click the **Set due dates** () icon to select the desired due date.
7. Click the status again to add any necessary comments (optional). Use the @ command to tag your team members and notify them regarding the updated workflow status.
8. Click **Set status** to complete the workflow assignment.

![4-Screenshot-Assign_workflow_to_team_member.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4-Screenshot-Assign_workflow_to_team_member.png)

---

## Workflow assignments overview

The Workflow assignments overview page gives a bird’s eye view of the articles/category pages available on the selected version and language of the knowledge base project. The articles that assigned information to the team account’s profile are available.

From the Knowledge base portal, navigate to Documentation () > **Workflow assignments**.  
![1-Screenshot-Workflow_assignments.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1-Screenshot-Workflow_assignments.png)Team accounts can view the number of articles/category pages in each workflow status at any given point in time along with the due date and workflow status. You can also view the articles that are assigned to you from the left navigation menu.

---

## eBook

### Guide to Setup Documentation Workflow

Our eBook will show you how to produce quality documentation!

#### You'll learn,

* *A step-by-step guide to creating documentation workflows*
* *Documentation best practices that improve content quality*
* *How to produce content that meets your customer expectations*

![ebook-documentation-workflow-mockup](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/ebook-documentation-workflow-mockup.png)

[![2022-02-02_08-23-42](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2022-02-02_08-23-42.png)](https://document360.com/ebook/guide-to-setup-documentation-workflow/#eBook-Form)

---

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="article-templates"></a>

## Templates

**Plans supporting content reuse**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 article templates are pre-designed article structures that you or any team member can use while writing articles for your Knowledge base. These templates provide design consistency and style for your brand, whether you're creating a User guide, FAQ, Release notes, or any custom document.

In Document360, you can create new articles from any basic system templates or create a new article template that you can reuse any number of times in your project.

---

## Creating an article from an existing template

1. From the left navigation pane, hover over the desired category and click on the () icon.
2. Click **Article from template** and enter the article name in the **Name** field.
3. Choose the category location from the **Nest category under…** dropdown.
4. Select one of the available templates.

   A preview will be available in the right frame.
5. Once done, click **Create**.
6. If you don’t find a suitable template in the preloaded list, click **Manage templates** next to the the **Template name**.

   ![Creating a template from existing article](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGIF-Creating_an_article_from_an_existing_template.gif)

---

## Creating a new template

1. From the Knowledge base portal, Navigate to Documentation() > **Content tools** > **Content reuse** > **Templates** in the Knowledge base portal.

   The **Manage templates** overview page appears.

   You can view the system templates and the templates you have previously added.

> NOTE
>
> Default templates will be created automatically based on your onboarding use case selection. These templates can be edited, copied, or deleted as per your requirements.
>
> ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-New_system_templates.png)

2. Click **Create template** on the top right of the page.

   The **Create template** window will appear.
3. Enter the desired template name.
4. Select the editor type for the template.
5. Enter the description of the templates.
6. Click **Create.**

   A new article is created, and you can start making the necessary changes.
7. Once done, click **Save** or **Save & close** from the Save dropdown.

   Your new template will be added to the list of templates.

   ![2_ScreenGIF-Creating_a_new_template_from_scratch](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Creating_a_new_template_from_scratch.gif)

### Editing a template

1. Hover over the desired template and click the **Edit** () icon.

   The selected template will appear.
2. On the top, next to the template name, click the  icon.

   A popup will appear.
3. Update the name and the description of the template in their respective fields.

   Note that the character limit for the description is 250 characters (including space).
4. Once done, click **Save**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Templates.gif)

---

## Saving an existing article as a template

You can add an existing article as a template regardless of its status (Published, Draft, New, Review, Hidden).

1. In the **Documentation editor**, click the More (•••) icon next to an article name.
2. Select **Save as template** and click **Yes** in the **Save** confirmation prompt.
3. You can also find the **Save as template** option under the More (•••) icon on the top-right of the article editor.

   A template has been added, which you can use when creating new articles from a template.
4. Go to the **Manage templates** page to view, edit, and delete the saved template.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Templates.gif)

---

## FAQs

#### Can I clone templates and use them to create a new template?

On the Templates page, you can clone templates to create new ones by hovering over the template and clicking on the **Clone** () icon. This saves time by allowing you to derive aspects from existing templates.

#### What happens if I delete a template that I no longer need?

Deleting a template removes it from the library but doesn't affect articles already created using that template. Your existing content remains unaffected.

#### Is the template I create available for other team members to use?

Once you create or save an article as a template, other team members can view and use the template in the Template library.

#### Does updating a template affect the article created from it?

Updating a template does not affect articles that were created from that template. When you create an article from a template, a local copy of the content is saved in the article. It is isolated from the template content.

#### Can I clone templates used in articles to other languages?

No, templates cannot be cloned to different languages in Document360. Currently, templates can only be cloned within the same language.  
If you need to use a template in a different language:

1. Manually recreate the template in the desired language by copying its structure and content.
2. Translate the content into the desired language.
3. Save the new template in the respective language workspace.

<a id="variables"></a>

## Variables

**Plans supporting content reuse**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You can reuse variables when you use the same text-based content in multiple places that may change over time (like field names, contact numbers, addresses, disclaimers, etc.). A **Variable** in Document360 is a reusable element that helps maintain consistency and efficiency across various documentation sections. By employing variables, contributors to your articles can easily update information in one place, and it automatically reflects throughout the entire documentation, ensuring accuracy and reducing redundant efforts.

For example, you want to add your contact information in multiple instances, which might change over time. In this case, you can add a variable for contact information. If a change is required, you can update the variable alone instead of updating it in all instances.  
 (**Contact: +1 897564231/support@serverless.com**)

---

## Creating a variable

To create a variable,

1. Navigate to Documentation () > **Content tools** > **Content reuse** > **Variables** in the knowledge base portal.

   The **Variables** page appears. If you have added any variables earlier, you can see them listed here.
2. Click **Create variable** at the top to select language-specific variables (Global, English, French, etc.) added to your project.
3. Enter the **Name** for your variable.

> NOTE
>
> The variable **name** can include letters, numbers, hyphens, and underscores, with a maximum length of 30 characters.

6. The **Merge code value** will be the variable name that appears with the variable tag in your editor.

> For example, if your variable name is **Disclaimer**, your Merge code value would be ***{{variable.Disclaimer}}.***

7. In the **Language** selection dropdown, the default selection is **Global** (Available across all languages). However, if needed, you can choose a desired available language to create a language-specific variable.
8. In the **Content** field, enter the variable's content.

> NOTE
>
> The variable content's character limit is 100 characters with spaces. If you want to add longer texts, expressions, media, tables, or code blocks, use **Snippets**. For more information, read the article on [Snippet](/help/docs/snippets).

#### Formatting options

Use the following text formatting options to style your variable content

a. Basic text formatting:  
 • **Bold**  
 *•* ***Italic***  
 • **~~Strikethrough~~**  
 • **Underline**  
 • **Font size** (8 to 36)

b. Additional formatting:

Click the **More text** icon to access:  
 • **Font Family** (Choose from the list of fonts)  
 • **Text color** (Color picker or HEX code)  
 • **Background color** (Color picker or HEX code)  
 • **Subscript**  
 • **Superscript**  
 • **Clear Formatting**

c. **Insert Link** - To add a hyperlink.

* Click on the **Insert link** icon.
* Type the **URL** and add text to the link.
* If needed, select **Open in new tab.**
* Click **Insert.**

9. Click the **Create variable** button.

The newly created variable will appear on the **Variables** page, where it can be edited or deleted as needed.

![Creating a new variable in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Creating_a_variables.gif)

---

## Using variable in an article/category page

You can add a variable to your article/category page using two methods.

#### Method 1: Using the syntax (Markdown editor)

In the Markdown editor, type a **variable.MergeCodeValue** between closed double curly brackets.

> **Example**: *{{variable.Disclaimer}}*

You must know the exact merge code value to add the desired variable. The variable will not work even if a single letter changes.

> NOTE
>
> Typing in *variable.Merge\_Code\_Value* will only work in the Markdown editor. If you are using Advanced WYSIWYG editor, you can insert variable using the toolbar.

#### Method 2: From the toolbar (Markdown, WYSIWYG, and Advanced WYSIWYG)

1. Click the Content reuse **()** icon for Markdown and WYSIWYG editor.   
   **(or)**  
   From the Advanced WYSIWYG editor, click **Insert > Variables** or use the slash "**/**" command to access variables.
2. Select the variable or use the **Search variables** bar to narrow down the variable name.

> In the Advanced WYSIWYG editor, the **Variables** pane appears on the right for variable selection. Hover the pointer on the variable name to preview its content.

3. Select the intended variable to insert**.**

> NOTE
>
> In Markdown and WYSIWYG editor, you can select multiple variables in one go.

![Inserting the variables in the Advanced WYSIWYG editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Using_variables_in_advanced_WYSIWYG_method2.gif)

---

## Variables overview page

You can view, edit, or delete a variable on the **Variables** page.

1. Navigate to Documentation () > **Content tools** > **Content reuse** > **Variables** in the knowledge base portal.

   The **Variables** page appears where you can find the list of variables you have already added.

![Overview page of Variables in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-overview_of_Variables_page.png)

1. **Languages**: To filter the variables in Global or a specific language.
2. **Search variable**: Search the variable list based on the name.
3. **Used in**: If a variable is not added to any article/category page, the status would be `-`. If a variable is added to any article/category page, you can click the **View** button to see the list of articles/category pages containing the variable.
4. **Language**: The desired language of each variable.
5. **Last modified**: The last time the variable content was updated.
6. **Preview**: Click on the variable name, and you can view the variable's content.
7. **Progress**: Click the globe icon to view the variable’s progress in multiple languages.
8. **Edit** () icon: To edit the variable content.
9. **Delete** () icon: To remove the variable.

---

### View article/category page dependency

In the **Variables** page, you can find the **Used in** column.

1. In the **Used in** column, click on the **View** button.

   The **View references** panel will appear, where you can view the list of articles/category pages to which the variable has been added.
2. Click on the article to expand the section.
3. You can find the following information:

   * The article version.
   * The project workspace and language.
   * The team account name and profile picture who has added the variable.
   * The article states (Published, Draft, New Article).
   * The time/date information when the variable was inserted in the article/category page.

![Viewing the dependency of variables](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGIF-Viewing_the_dependency_of_variables.gif)

---

### Editing an existing variable

1. Navigate to Documentation () > **Content tools** > **Content reuse** > **Variables** in the knowledge base portal.

   The **Variables** page appears. You can find the list of variables you have already added.
2. Hover over the desired variable and click the Edit **()** icon.

   You can edit the content of the variable. The Name and Merge Code Value cannot be edited.

> NOTE
>
> **Editing a link added in a variable**
>
> Click the link, and you can find the following options:
>
> * **Open link** (): The link will open in the tab. This helps in checking the link.
> * **Style** (): Style has two options.
>
>   + Green: To change the link text color to green.
>   + Thick: To increase the thickness of the link text.
> * **Edit** (): To edit the URL, link text, and change open in the new tab option.
> * **Unlink** (): To unlink the URL and change it to standard text. The URL will be unlinked, and only the URL text will appear.

3. After you complete the content edit, click the **Update** button.

> NOTE
>
> When you edit the content of an existing variable in the library, the content change will reflect in all the articles/category pages that contain the respective variable.

![Editing the existing variables in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenGIF-editing_an_existing_variables.gif)

---

### Deleting a variable

1. Navigate to Documentation () > **Content tools** > **Content reuse** > **Variables** in the knowledge base portal.

   The **Variables** page appears. You can find the list of variables you have already added.
2. Hover over the desired variable and click the **Delete** () icon.
3. Click **Yes** in the confirmation prompt.

#### To bulk delete multiple variables

Select multiple intended variables from the **Variables** page and click the **Delete** option at the top of the list.

![Deleting the variables in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_ScreenGIF-Deleting_a_variable.gif)

---

## Translating variables

You can create and manage variables in multiple languages. This ensures that when your articles are translated, the variables match the language of the article, providing a consistent and localized user experience.

#### **Translating new variables**

1. Navigate to the Documentation () > **Content tools** > **Content reuse** > **Variables** in the knowledge base portal.
2. Click **Create Variable**.
3. In the **Language** dropdown, select the intended language (except global).
4. Enter the variable **name** and the content for the variable in English (or your default language).
5. To translate the content into other languages, click the **Translate to other languages** dropdown.
6. Select the desired language(s) from the dropdown menu and click **Translate**.

   > NOTE
   >
   > * The default language will be marked as **Main**.
   > * Translated languages will be indicated with a green tick to show that the translation is complete. If needed, you can navigate to untranslated languages and complete their translation.
7. Once the translations are complete, click **Create Variable** to save the variable along with its translations.

> For example, if you create a variable for a welcome message in English, you can use the translation feature to add the same message in French, Spanish, German, etc.

![Translating the new variables in other languages in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_ScreenGIF-Translating_new_variables.gif)

#### Translating existing variables

> NOTE
>
> Global variables cannot be translated.

1. Click on the desired existing variable you wish to translate.
2. Navigate to **Translate to other languages** and select the desired language that the variable needs to be translated.
3. Click **Translate**.
4. If needed, you can navigate to other languages and translate them.
5. To retranslate the content, click **Translate again**, which will overwrite the existing translation with the new one.
6. If you need to remove the translated variable for a specific language, click **Remove language**.

   You can retranslate the content at any time if needed.

![Translating the existing variables in other languages in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_ScreenGIF-Translating_existing_variables.gif)

---

## FAQ(s)

**How do Variables work?**

Variables allow you to define specific content elements, such as product names or version numbers, in one place. Updating the variable automatically reflects the change across all relevant sections when this content changes, ensuring uniformity.

**What's the benefit of using Variables in my documentation?**

By using Variables, you ensure consistency in your documentation while minimizing the need for manual updates. This saves time, reduces errors, and maintains accuracy, especially when dealing with frequently changing information.

**Can I create my Variables in Document360?**

Document360 empowers you to create custom Variables tailored to your documentation needs. This allows you to adapt the feature to the specific terminology and elements relevant to your content.

**How do I use Variables in my articles?**

Insert the variable into the article content using the editor's toolbar or the merge code value, and it will dynamically pull the information you've defined, ensuring uniformity across your documentation.

**Can Variables be updated across multiple articles at once?**

When you update a Variable, the change is automatically reflected throughout all instances where that variable is used, making it easy to maintain consistent information across your entire knowledge base.

**Are Variables limited to specific types of content?**

Yes, Variables can be used for limited text, number, or link-based content, from product names and version numbers to URLs and contact information.

**How do Variables enhance collaboration among team members?**

Variables streamline the collaboration process by ensuring everyone is using the same accurate information. Changes to a variable are instantly updated across all articles, preventing discrepancies.

**Is using Variables a best practice in technical documentation?**

Using Variables is a best practice that improves technical documentation efficiency, consistency, and accuracy. It's particularly valuable when working with dynamic information that requires frequent updates.

**Can I translate variables into any language?**

You can translate variables into any of your project’s languages.

**Is the definition of a variable term created in the Knowledge base site indexed in search and by Google?**

Yes, the definition of a variable term created in the Knowledge Base (KB) site is indexed in both the site's search and by Google. Once the term is added, it becomes searchable on the website and will also be crawled and indexed by Google.

A powerful Document360 editor with rich text editing and Markdown support, offering a visual, flexible experience compared to the Markdown and basic WYSIWYG editors.

<a id="snippets"></a>

## Snippet

**Plans supporting content reuse**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Snippets** is a predefined set of content blocks the content manager or author uses as reusable content. The Snippet's content can vary from simple text or phrases to lengthy paragraphs, tables, images, and more. In Document360, the snippets are stored in a library, and you can easily insert them into articles during editing with just a click of a button.

> NOTE
>
> The Snippet will appear as regular content to the reader on the Knowledge Base site. The reader will not know that the content was rendered through Snippet.

---

## Creating a snippet

To create a snippet,

1. Navigate to **Documentation** () > **Content tools** > **Content reuse** > **Snippets** in the knowledge base portal.

   The **Snippets** page appears. If you have added any snippets earlier, you can see them listed here.
2. Click **Create snippets** at the top to select language-specific snippets(Global, English, French, etc.) added to your project.
3. Enter the **Name** for your snippet.

   > NOTE
   >
   > The snippet **name** can include letters, numbers, hyphens, and underscores, with a maximum length of 30 characters.
4. The **Merge code value** will be the snippet name that appears with the snippet tag in your editor.

   **For example,** if your snippet name is **Disclaimer**, then your Merge code value would be ***{{snippet.Disclaimer}}.***
5. In the **Language** selection dropdown, the default selection is **Global** (Available across all languages). However, if needed, you can choose a desired available language to create a language-specific snippet.
6. In the **Content** field, enter the snippet's content.

   By default, the snippet editor will be WYSIWYG (HTML). However, you can switch to the Markdown editor if required.

> NOTE
>
> Switching to Markdown:
>
> 1. Click **Switch to Markdown**.
> 2. Click **Proceed** in the **Change confirmation** prompt.
>
> **You will lose the WYSIWYG content when you switch to Markdown.**

7. Once done, click **Create snippet**.

![Adding a new snippet in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Adding_a_Snippet.gif)

#### **Formatting options**

**WYSIWYG**

The below formatting options are available for snippet content in WYSIWYG:

![1_Screenshot-Formatting_options_available _in_snippet](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1724477524068.png)

* Basic text formatting options such as **Bold**, **Italic**, **Strikethrough**, and **Underline** are available.
* Additional formatting options include **Font size, Font Family, Text color, Background color, Subscript, Superscript, and Clear Formatting**.
* You can create **Ordered** and **Unordered Lists** for listing items.
* **Insert Image** allows you to insert an image from a URL, local storage, or Drive.
* **Insert Link** lets you add a hyperlink from a provided URL or link to a knowledge base article.
* You can use **Insert callouts** such as Info, Warning, Error, and Success.
* **Insert latex** lets you add expressions and equations:

  + Click the **Insert latex** option, and an **Insert latex expression** panel will appear.
  + Type your desired Latex syntax and click **Insert.**
  + [Read this article](http://docs.mathjax.org/en/latest/input/tex/macros/index.html) for basic Latex commands used in Latex syntax.
* **Insert table** allows you to create a table by selecting the required number of rows and columns.
* **Insert codeblock** lets you add codeblocks.

  + Click **Insert codeblock** and select the language of the desired code from the dropdown.
  + Add code in the **Insert your code** field and click **Insert.**
* You can preview the Snippet in **Code view** (HTML). Click **Code view** to view the preview. If you want to switch back to the editor view, click **Code view** again.

---

**Markdown**

Markdown is handy when significant text and minimal media are involved in the Snippet. You can use Markdown syntax manually while writing or formatting text using the Markdown toolbar.

**For example**, you can make a text appear bold by writing the respective syntax or using the Bold () icon in the Markdown toolbar.

![13_Screenshot-Makdown_options_available _in_snippet](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1724478140496.png)

* Basic text formatting options such as **Bold**, **Italic**, **Strikethrough** are available.
* **Block quote** lets you add block quotes.
* **Line** lets you insert a horizontal line.
* **Ordered List** and **Unordered List** are available for listing items.
* **Insert Table** allows you to create a table by selecting the required number of rows and columns.
* **Insert Image** allows you to insert an image from a URL, local storage, or Drive.
* **Insert Codeblock** lets you add code blocks:

  + Click **Insert Codeblock** and type the desired code inside the code block.
  + Example: ``code``.
* You can use **Insert callouts** such as Info, Warning, Error, and Success.
* **Insert latex** lets you add expressions and equations.

  + Click the **Insert latex** option, and a sample latex syntax () will appear.
  + Type your desired syntax.
  + The syntax must start and end with `$`.

> NOTE
>
> When adding latex, do not include a space between `$` and syntax. For more information, [read this article](http://docs.mathjax.org/en/latest/input/tex/macros/index.html) for basic latex commands.

* **Insert Link** allows you to add a hyperlink from a provided URL or link to a knowledge base article.
* **Glossary** lets you add glossary terms to your Snippet.

---

## Using snippet in the article

There are **two methods** by which you could add a snippet to your article.

#### Method 1: Using the syntax (Markdown editor)

In the Markdown editor, type a **snippet.MergeCodeValue** between closed double curly brackets.

> **Example**: *{{snippet.Disclaimer}}*

You must know the exact merge code value to add the desired snippet. The snippet will not work even if a single letter changes.

> NOTE
>
> Typing in *snippet.Merge\_Code\_Value* will only work in the Markdown editor. If you are using Advanced WYSIWYG editor, you can insert snippet using the toolbar.

#### Method 2: From the toolbar (Markdown, WYSIWYG, and Advanced WYSIWYG)

1. Click on Content reuse **()** for Markdown and WYSIWYG editor.   
   For the Advanced WYSIWYG editor, click on **Insert >** **Snippets****,** or using the slash "**/**" command you can access snippets.
2. Select the snippet or use the **Search snippets** bar to narrow down the snippet name.

> In the Advanced WYSIWYG editor, the **Snippets** pane appears on the right for snippet selection. Hover the pointer on the snippet name to preview its content.

3. Select the intended snippet to insert.

> NOTE
>
> If the **Insert as local copy** toggle is on, the snippet content added to the article will remain unchanged. The snippet in the article will not be affected if the selected snippet's content is modified or removed in the future.

![Inserting snippets in the article in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Inserting_Snippet__in_an_article.gif)

---

## Snippet overview page

You can view, edit, or delete a snippet on the **Snippets** page.

1. Navigate to **Documentation** () > **Content tools** > **Content reuse** > **Snippets** in the knowledge base portal.

   The **Snippets** page appears where you can find the list of snippets you have already added.

![Explaining the Snippet overview page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Snippet_overview_page.png)

1. **Languages**: To filter the snippet in Global or a specific language.
2. **Search snippets**: Search the snippet list based on the name.
3. **Used in**: If a snippet is not added to any article/category page, the status would be `-`. If a snippet is added to any article/category page, you can click the **View** button to see the list of articles/category pages containing the snippet.
4. **Language**: The desired language of each snippet.
5. **Last modified**: The last time the snippet content was updated.
6. **Preview**: Click on the snippet name, and you can view the snippet's content.
7. **Progress**: Click the globe icon to view the snippet’s progress in multiple languages.
8. **Edit** () icon: To edit the snippet content.
9. **Delete** () icon: To remove the snippet.

---

### View article/category page dependency

In the **Snippets** page, you can find the **Used in** column.

1. In the **Used in** column, click on the **View** button.

   The **View references** panel will appear, where you can view the list of articles/category pages to which the snippet has been added.
2. Click on the article to expand the section.
3. You can find the following information:

   * The article version.
   * The project workspace and language.
   * The team account name and profile picture who has added the snippet.
   * The article states (Published, Draft, New Article).
   * The time/date information when the snippet was inserted in the article/category page.

![Viewing the dependencies of snippets](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGIF-View%20article_Snippet_dependency.gif)

---

### Editing an existing snippet

1. Navigate to **Documentation** () > **Content tools** > **Content reuse** > **Snippets** in the knowledge base portal.

   The **Snippets** page appears. You can find the list of snippets you have already added.
2. Hover over the desired snippet and click the **Edit ()** icon.
3. After you complete the content edit, click on the **Update** button.

> NOTE
>
> When you update a snippet in the library, the changes are automatically reflected in all articles and category pages that use it. This includes published articles, which will be updated without needing to republish them.

![Editing the existing snippets](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Edit_snippet.png)

---

### **Deleting a snippet**

1. Navigate to **Documentation** () > **Content tools** > **Content reuse** > **Snippets** in the knowledge base portal.

   The **Snippets** page appears. You can find the list of snippets you have already added.
2. Hover over the desired snippet and click the **Delete** () icon.
3. Click **Yes** in the confirmation prompt.

#### **To bulk delete multiple snippets**

Select multiple intended snippets from the **Snippets** page and click the **Delete** option at the top of the list.

![Deleting the snippets in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_ScreenGIF-Deleting_a_Snippet.gif)

---

## Translating snippets

You can create and manage snippets in multiple languages. This ensures that when your articles are translated, the snippets match the language of the article, providing a consistent and localized user experience.

> NOTE
>
> Global snippets cannot be translated.

#### Translating new snippets

1. Navigate to the **Documentation** () > **Content tools** > **Content reuse** > **Snippets** in the knowledge base portal.
2. Click **Create snippet**.
3. In the **Language** dropdown, select the intended language.
4. Enter the snippet **name** and the content for the snippet in English (or your default language).
5. Click **Switch to markdown** to change the content editor from WYSIWYG to the Markdown editor.
6. To translate the content into other languages, click the **Translate to other languages** dropdown.
7. Select the desired language(s) from the dropdown menu and click **Translate**.

> NOTE
>
> * The default language will be marked as **Main**.
> * Translated languages will be indicated with a green tick to show that the translation is complete. If needed, you can navigate to untranslated languages and complete their translation.

7. Once the translations are complete, click **Create snippet** to save the snippet along with its translations.

> For example, if you create a snippet for a welcome message in English, you can use the translation feature to add the same message in French, Spanish, German, etc.

![Translating the snippets in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_ScreenGIF-Translating_snippets.gif)

#### Translating existing snippets

1. Click the desired existing snippet you wish to translate.
2. Navigate to **Translate to other languages** and select the desired language that the snippet needs to be translated.
3. Click **Translate**.
4. If needed, you can navigate to other languages and again translate into those languages.
5. To translate the content again, click **Translate again**. This will overwrite the existing translation with a new one.
6. If you need to remove the translated snippet for a specific language, click **Remove language**.

   You can retranslate the content at any time if needed.

![Translating the existing snippets](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_ScreenGIF-Translating_existing_snippets.gif)

---

## FAQs

**How many snippets can be created in one project?**

You can create up to 200 snippets in a single project. If you need more, additional snippets can be purchased as an add-on.

**Can I change the name of a snippet after it has been created?**

While you can edit the contents of a snippet, its name cannot be changed after creation.

**Why is a snippet inserted in a new line?**

Snippets are designed as new blocks of content, allowing for multiple lines to be added within them. As such, they will always start from a new line to maintain structure and clarity.

One of the three editors in Document360, WYSIWYG (What You See Is What You Get) is a content editing tool that shows the final output as writers create and format content.

A powerful Document360 editor with rich text editing and Markdown support, offering a visual, flexible experience compared to the Markdown and basic WYSIWYG editors.

<a id="glossary"></a>

## Glossary

**Plans supporting content reuse**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

A glossary helps readers easily understand frequently used terms, such as words, phrases, acronyms, or abbreviations. By adding a glossary to your knowledge base, you provide quick, convenient access to definitions, making your content more user-friendly and informative.

Glossary terms are visually marked with a dotted underline in your articles and category pages. Readers can hover over these terms to view the definition, ensuring they stay informed without navigating away from the page. You can reuse glossary terms throughout your content as needed. For example, when adding the acronym *GDPR*, you can define it as "General Data Protection Regulation," and the term will be consistently used across all relevant articles.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1.%20Glossary%20-%20View%20in%20site.png)

> NOTE
>
> Glossary terms are available in both the Knowledge Base and Knowledge Base Assistant.

---

#### Why add a glossary to your Knowledge base?

Including a glossary in your documentation improves both the reader experience and the accuracy of your content. Here’s how:

1. **Improved readability**: Glossary terms allow readers to get instant definitions for complex terms without leaving the page, reducing confusion and ensuring better comprehension.
2. **Consistency**: Once a term is added to the glossary, it can be reused across multiple articles, ensuring that terminology is defined consistently across your entire knowledge base.
3. **Time-saving for writers**: Technical writers no longer have to define terms in each individual article, which reduces redundancy and speeds up the content creation process.
4. **Product-specific education**: You can use the glossary to define product-specific terms or industry jargon, helping readers get familiar with your terminology and enhancing their understanding of your product.

---

## Managing glossary terms

Accessing and managing your glossary is straightforward. Navigate to **Content tools** > **Content reuse** > **Glossary** to view your existing glossary terms. Here’s a breakdown of the key features for managing glossary terms:

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2.%20Glossary%20-%20Overview%20page.png)

1. **Languages**: Use the language filter to sort glossary terms by specific languages. Terms marked as "Global" represent glossary terms available across all languages in your knowledge base.
2. **Create**: Add new glossary terms individually or import multiple terms in bulk to streamline content creation.
3. **Export CSV**: Export selected glossary terms as a CSV file for external use, enabling easy sharing or backup.
4. **Search term**: Search for glossary terms by name. Hover over the **Preview** () icon to see a quick definition.
5. **Used In**: If a glossary term is linked to any articles or category pages, the **View** option appears.

   Click **View** to open the **View references** pop-up showing all associated articles or categories. The pop-up also displays the workspace and language of each article.

   Use the dropdown next to each article/category name to see detailed information such as article status, version, a link to view the article in the knowledge base portal, contributor profile image, name, and last updated date.
6. **Language**: Displays the language in which the glossary term is available.
7. **Last Modified**: Shows the most recent time and date the glossary term was updated.
8. **Edit**: Update the glossary term or its content. Note: The term’s language cannot be changed.
9. **Delete**: Remove the glossary term from the knowledge base.
10. **Items on Page/Total Items**: Displays the number of glossary terms shown per page and the total number of terms in the glossary.
11. **Use Eddy AI for glossary generation**

    Leverage **Eddy AI’s glossary generation** to automate the process of creating glossary terms for key phrases and acronyms in your knowledge base. This AI-powered feature analyzes your content and suggests terms that can be defined, saving you time and ensuring your documentation is thorough. For large projects, this feature is especially helpful, as it ensures that all relevant terminology is consistently captured. For more information, read [AI glossary generator](/help/docs/ai-glossary-generator).

---

#### SEO and search benefits of glossary terms

By defining industry-specific terms in your glossary, you’re not only helping your readers but also improving your knowledge base’s SEO. Glossary terms can increase the relevance of your documentation in search engine results by associating definitions with keywords, making it easier for users to find your content online

---

## Quick navigation for glossary management

### Adding glossary terms

* [How to add a glossary term?](/help/docs/adding-glossary-term)
* [How to add a glossary term in articles?](/help/docs/adding-glossary-term-in-articles)
* [How to import the glossary?](adding-glossary-term#importing-glossary-terms)

### Managing glossary terms

* [How to edit a glossary term?](/help/docs/editing-and-deleting-glossary-term#editing-a-glossary-term)
* [How to delete a glossary term?](/help/docs/editing-and-deleting-glossary-term#deleting-a-glossary-term)
* [How to delete multiple glossary terms?](/help/docs/editing-and-deleting-glossary-term#deleting-multiple-glossary-terms)

### Navigation links for glossary

* [How to add the glossary overview page link in the header?](/help/docs/glossary-overview-page#how-to-add-the-glossary-library-page-link-in-the-header)
* [How to add the glossary overview page link in the footer?](/help/docs/glossary-overview-page#how-to-add-the-glossary-overview-page-link-in-the-footer)
* [How to add the glossary overview page link in the menu?](/help/docs/glossary-overview-page#how-to-add-the-glossary-overview-page-link-to-the-menu)
* [How to add the glossary overview page link on the Home page?](/help/docs/glossary-overview-page#how-to-add-the-glossary-overview-page-link-on-the-home-page)

---

### FAQs

#### How do I add a glossary term to my articles?

You can add glossary terms by navigating to **Content tools > Content reuse > Glossary**, then create a new term. Once added, the term can be used in your articles, and readers can hover over it to view the definition.

#### Can I import multiple glossary terms at once?

Yes, you can bulk import glossary terms using the import option in the Glossary section. This is useful for large projects where multiple terms need to be added quickly.

#### What happens if I delete a glossary term?

When a glossary term is deleted, it is removed from all articles where it was used. The term will no longer display as a hoverable definition for readers.

#### Can glossary terms be filtered by language?

Yes, you can filter glossary terms by language. Terms marked as "Global" will be available across all languages in your knowledge base.

#### How can I track where glossary terms are used?

You can click on the **View** option next to any glossary term to see a list of articles or categories it is associated with, including details like article status, version, and contributors.

#### Does the glossary setting change when I switch between workspaces?

No, glossary settings, along with other content tools such as snippets, templates, variables, and tags, are configured at the project and not at the workspace level. This means that when you switch between workspaces, the glossary and other content tool configurations remain unchanged. Each project retains its unique settings regardless of the workspace you are in.

<a id="adding-glossary-term"></a>

## Adding glossary terms

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In Document360, you can easily add glossary terms at any time, making it a quick process that takes just a few seconds.

---

## Adding a glossary term

1. Log in to the ****Knowledge base portal**** and navigate to your project.
2. Select the ****Documentation**** tab and click on ****Content tools**** from the left navigation list pane.
3. Navigate to ****Content tools**> **Content reuse** > **Glossary****. Here, you’ll see a list of existing glossary terms (if any have been added).
4. Click **Create** to create a new glossary term.

   Alternatively, click the dropdown to import terms as a CSV file. For detailed instructions on importing terms, refer to [Import Glossary Terms](adding-glossary-term#importing-glossary-terms).
5. Enter the desired term in the provided field.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Create%20glossary%20-%20English.png)

   When adding a glossary term, you will encounter four fields: **Name**, **Language**, **Term**, and **Content**.

   1. **Name:**

      * This field allows you to give a specific name to the glossary term, which will be used for reference.
      * The character limit for the Name is **100 characters**.
   2. **Language:**

      * Choose the appropriate language for the glossary term from the dropdown menu.
      * If you select a language other than **Global**, the option to translate the term into other languages will be enabled.
   3. **Term:**

      * This field is where you enter the actual term or phrase you want to define.
      * The character limit for the Term is also **100 characters** including spaces. Acceptable inputs include letters, numbers, spaces, and special characters such as () - \_ & : ; ? / . , [ ] @ # ! \*.
   4. **Content:**

      * In this field, you can provide a detailed definition or explanation of the term.
      * The character limit for the Content is **500 characters**.
   > NOTE
   >
   > When translating a term into another language, you can use the name for reference across all languages.

6. Once completed, click **Create glossary** to finalize the addition.

   > NOTE
   >
   > When translating an article into other languages, machine translation credits are consumed based on the number of characters.

### Formatting options

Basic text formatting options include:

* Bold
* *Italic*
* Underline
* ~~Strikethrough~~

You can also access additional formatting features, such as:

* Font size
* Font family
* Text color
* Background color
* Subscript and superscript
* Clear formatting

For item lists, you can use Ordered list and Unordered list options.

To insert images, use the **Insert image** feature to upload from a URL, local storage, or Drive. You can also view the snippet in **Code view (HTML)** and switch back to **Editor view** as needed.

> NOTE
>
> If a glossary term is added under "All," it cannot be added at the language-specific level. For example, if you want to define "TXT record" in multiple languages, create a glossary term in English and translate it to other languages. Use the Name field to identify the term across all languages. A term designated as Global cannot be language-specific.

For a better understanding of how a business glossary can help your Knowledge base, read our blog: [**Importance of business glossary in knowledge management**](https://document360.com/blog/knowledge-management-business-glossary/)**.**

---

## Importing glossary terms

You can also effortlessly import multiple glossary terms using the **Import glossary** option. Before importing, you need to prepare a CSV file with glossary terms and their corresponding definitions.

### Import glossary template

You can create a CSV file matching the required template or download a sample to populate your data.

#### Sample CSV format

| Term | Definition |
| --- | --- |
| First term | First term definition |
| Second term | Second term definition |
| Third term | Third term definition |

#### Download sample CSV file

You can download one of the following templates for local use:

* **With data** - Includes sample terms and definitions.

Import glossary - With data

761 Byte

* **Without data** - Contains only row headers.

Import glossary - Without data

20 Byte

> NOTE
>
> Use software like Microsoft Excel, OpenOffice Calc, or Google Docs to open and edit the CSV file.

### Importing glossary terms using the CSV file

Once your CSV is ready, upload it to the platform and start using the glossary terms in your articles and category pages.

1. Navigate to ****Content tools** > **Content reuse** > **Glossary**** in the Knowledge Base portal.
2. Click **Create > Import terms**, and the import popup will appear.
3. Drag and drop the CSV file or use the **Upload** option to select the file from your device.

   Wait a few seconds for validation. The system will display the number of valid and invalid terms.

   If any terms are invalid, click **Download** next to the error count to review the errors, such as "Already associated term" or "Definition exceeds 500 characters."
4. Click **Import**, and the newly added terms will appear in the Glossary overview.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Import%20glossary%20terms.png)

This feature streamlines the glossary management process, saving you time when handling large sets of terms and definitions.

---

## Troubleshooting

### CSV upload error

If you encounter an error message like *"Please make sure the CSV follows the sample template"* when uploading a glossary CSV file, it may be due to the language settings in your Excel application.

**Cause:** The headers in the template file may have been altered if your Excel language is set to anything other than English. The system cannot detect modified headers, leading to upload failure.

**Resolution:** Follow these simple steps to fix the problem:

* Check and change Excel regional settings (Office 365 Web Application)

1. Open the glossary CSV template in Excel.
2. If you are using **Excel in Office365 (Web Application):**

   1. Go to **File > Options > Regional Settings** in Excel.
   2. In the **Change Regional Format Settings** pop-up, select *English (United Kingdom)* from the dropdown in the **Select your preferred regional format for Excel for the web** field.

* Change regional format in Windows:

1. Open Settings in Windows.
2. Navigate to **Time & Language** > **Language & Region**.
3. Change the regional format to **English (United Kingdom)**.

   Once done,
4. Close and reopen the glossary CSV template in Excel.
5. Ensure the headers match the sample template exactly.
6. Save the file again to ensure the correct headers remain intact.
7. Retry uploading the CSV file.

If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

---

### FAQs

#### Can I add images to the glossary while importing glossary terms from a CSV file?

Only web images can be imported through definitions. Use the tag `<img src="Image_URL"/>` in your definition cell to add images.

For example, to include an image for "JSON Web Token," add the definition in the CSV as: `JSON Web Token <img src="https://jwt.io/img/logo-asset.svg"/>`

Imported images are stored in the Glossary folder in **My Drive** > **Images** > **Glossary**.

#### How do I add a hyperlink inside a glossary?

You can embed a hyperlink within a glossary definition using HTML tags in the **Code view** of the Glossary editor.

**Example:** If you want to hyperlink the word "Google" to `google.com` in the glossary definition, follow these steps:

1. Navigate to the desired glossary and click **Edit** ().
2. In the editor section, click the **Code view** () icon.
3. Add the hyperlink in HTML format as shown below.

```
<p><a href="https://google.com/">Google</a></p>
```

HTML

Copy

4. Click **Update** to save your changes.

Now, when users hover over this glossary term on the Knowledge base site, they can click "Google" to navigate to `google.com`.

<a id="adding-glossary-term-in-articles"></a>

## Inserting glossary term in an article

**Plans supporting content reuse**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Glossary terms are essential for improving your readers' understanding of frequently used terms, abbreviations, acronyms, and industry-specific jargon. By incorporating glossary terms into your articles and category pages, you ensure that readers can easily grasp complex concepts without leaving the content. Glossary terms are visually marked with a dotted underline, allowing users to hover over them for instant definitions. Here's how you can add glossary terms across different editors in Document360.

---

### How to add glossary terms in the Markdown editor?

The Markdown editor allows you to seamlessly add glossary terms to enhance your articles. You can do this using two methods:

#### Method 1 - Using the menu option

1. Open the desired article in the Markdown editor.
2. In the toolbar, click on the **Glossary** icon.
3. The **Insert glossary term(s)** menu will appear, displaying a list of all available glossary terms.
4. Click the checkbox next to the term(s) to select the term(s) you want to insert into your article.
5. Click **Insert**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Glossary%20in%20markdown%20editor.png)

Your selected glossary terms will now be added to the article, enriching the reader's experience.

#### Method 2 - Using the Markdown syntax

If you prefer to use the Markdown syntax or need to manually input a term, follow this method:

1. Open the desired article in the Markdown editor.
2. Enter the following syntax:  
   `{{glossary.Term_name}}`
3. Replace `Term_name` with the exact name of the glossary term you want to add.

> NOTE
>
> Glossary terms are case-sensitive and must match exactly, including any spaces. To find the exact term name, refer to the Glossary section in your Document360 portal.

### How to add glossary terms in the WYSIWYG editor (HTML)?

If you’re working in the WYSIWYG editor, adding glossary terms is simple and efficient. Follow these steps:

1. Open the desired article in the **WYSIWYG editor**.
2. Click on the **Glossary** option in the toolbar.
3. The Insert glossary term(s) pop-up window will appear with a list of available glossary terms.
4. Click the checkbox next to the term(s) to select the term(s) you want to insert into your article.
5. Click **Insert**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Glossary%20in%20WYSIWYG%20editor.png)

The glossary terms will now be embedded within your article, improving clarity and reader engagement.

### How to add glossary terms in the Advanced WYSIWYG editor?

For more advanced formatting or content management needs, the Advanced WYSIWYG editor also supports glossary terms. Here’s how to do it:

1. Open the article in the **Advanced WYSIWYG editor**.
2. Click on the **Insert** menu in the toolbar.
3. From the dropdown, select **Glossary**.
4. A blade will appear, displaying all available glossary terms.
5. Use the search function to find the specific term you want.
6. Click on the term to insert it into the article.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Glossary%20in%20Advanced%20WYSIWYG%20editor.png)

The merge code value will appear in the article: `{{glossary.Term_name}}`

> NOTE
>
> While in the editor, you won’t see a live preview of the glossary term. To see how the glossary will appear to readers, click the **View preview** button in the toolbar. This will allow you to view the article with the glossary terms fully rendered, ensuring they are correctly placed.

<a id="editing-and-deleting-glossary-term"></a>

## Managing glossary terms

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## Translating glossaries

You can create and manage glossaries in multiple languages, ensuring a consistent and localized user experience when your articles are translated.

1. Navigate to the ****Documentation****() > ****Content tools**** > ****Content reuse**** > ****Glossary**** in the knowledge base portal.
2. Click **Create**.
3. In the **Language** dropdown, select the intended language (except global).
4. Enter the Glossary **Name, Term** and **Content** in English (or your default language).
5. Click the **Translate to other languages** dropdown to translate the term and content into other languages.
6. Select the desired language(s) from the dropdown menu and click **Translate**.

> NOTE
>
> * The default language will be marked as **Main**.
> * Translated languages will be indicated with a green tick to show the complete translation. If needed, you can navigate to specific languages and complete their translation.

7. Once the translations are complete, click **Create glossary** to save the glossary along with its translations.

![Translating the glossaries in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Translating_the_glossary.gif)

---

## Editing a Glossary term

You can edit glossaries in Document360 by following these steps:

1. Navigate to Documentation () > **Content tools** > **Content reuse** > **Glossary** in the knowledge base portal.

   The **Glossary** page appears. If you have added any glossaries earlier, you can see them listed here.
2. Hover over the desired glossary and click the Edit **()** icon.
3. You can update the term and definition of the glossary.
4. Navigate to **Translate to other languages** and select the desired language in which the glossary needs to be translated.
5. Click **Translate**.
6. If needed, you can navigate to other languages and translate them.
7. To retranslate the content, click **Translate again**, which will overwrite the existing translation with the new one.
8. If you need to remove the translated glossary for a specific language, click **Remove language**.
9. Once you have made changes, click **Update**.

> NOTE
>
> Global glossaries can be translated.

![Translating, editing a glossary in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Editing_the_glossary.gif)

---

## Deleting a Glossary

To delete a glossary term,

1. Navigate to Documentation () > **Content tools** > **Content reuse** > **Glossary** in the knowledge base portal.

   The **Glossary** page appears. You can find the list of glossaries you have already added.
2. Hover over the desired glossary and click the **Delete** () icon.
3. Click **Yes** in the confirmation prompt.

#### To bulk delete multiple terms

Select multiple intended glossaries from the **Glossary** page and click the **Delete** option at the top of the list.

![Deleting a glossary in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3-ScreenGIF-Deleting_the_glossaries.png)

> **NOTE**
>
> When deleting a term with dependencies, please follow the below instructions to avoid glossary content loss in articles:
>
> 1. Navigate to the desired glossary term and click on the **View** option.
>
>    The **View references** panel will appear, where you can view the list of articles/category pages to which the glossary has been added.
> 2. Click on the Open in new window () icon and open the article in the portal.
> 3. Manually remove the glossary term.
> 4. Navigate back to the glossary page and click **Delete**.

---

## Exporting glossary terms

You can easily export the glossary terms from your knowledge base project as a CSV (Comma Separated Values) file. This feature allows you to back up your glossary data or share it with your team for further analysis.

To streamline the export process, you can download glossary terms specific to a particular language within your project.

To export your glossary terms,

1. Navigate to **Documentation** > **Content tools** > **Content reuse** > **Glossary**.
2. Select the desired language from the **Languages** dropdown at the top.  
    The default selection is **Global**.
3. Click the **Export CSV** button at the top right.
4. Wait for a few seconds to let Document360 compile the terms.
5. A file with a (.csv) extension is downloaded to your local device storage.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Glossary%20-%20Export%20CSV%20option.png)

> NOTE
>
> To open the exported CSV file, you can use Microsoft Excel, OpenOffice Calc, Google Docs, or other CSV tools.

### What data is included in the exported file?

The exported CSV file contains the following information:

* **Glossary Name:** The name of each glossary term.
* **Glossary Definition:** The definition associated with each term.
* **Dependencies:** The number of articles or categories linked to each glossary term.
* **Updated By:** The name of the user who last updated the term.
* **Updated On:** The date when the term was last modified.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Glossary%20-%20Export%20as%20CSV.png)

By exporting your glossary terms, you ensure easy access to important definitions and enhance collaboration within your team. If you have any questions about this process, feel free to consult our support resources for further assistance.

<a id="glossary-overview-page"></a>

## Managing the glossary landing page

**Plans supporting content reuse**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Readers can access all the glossary terms in the selected language knowledge base on the glossary overview page. You can find the alphabetical list of words at the top, where you can navigate to the desired alphabet glossary. Here's your glossary overview page link:

> `https://yourdomain/docs/glossary-overview`  
>  Replace the <yourdomain> with your Knowledge base site domain

---

### Adding the Glossary library page link in the header

1. Navigate to **Settings** > **Knowledge base site** > **Customize site** from the Knowledge base portal.
2. Select the **Customize site** and select the **Header** dropdown menu.
3. Select **Primary navigation**, and click **Add new item** under left side or right side.

   An **Add new item** panel appears.
4. Select **Glossary** in the dropdown.
5. Add the desired text in the Glossary definition. This text appears on the Knowledge base site.
6. If you want the glossary overview page to appear in a new tab, enable the **Open link in new tab** toggle next to the glossary definition.
7. Click **Save**.

![Portal_Screenshot-Update_Add_glossary_in_header](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Portal_Screenshot-Update_Add_glossary_in_header.png)

#### Outcome

![Outcome_Screenshot-Update_Add_glossary_in_header_outcome](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Outcome_Screenshot-Update_Add_glossary_in_header_outcome.png)

### Adding the glossary overview page link in the footer

1. Navigate to **Settings** > **Knowledge base site** > **Customize site** from the Knowledge base portal.
2. Select the **Customize site** and select the **Footer** dropdown menu.
3. You can either configure with **Basic footer** or **Custom footer**.

**Basic footer**  
 If you're using the Basic footer option, follow the below steps:  
 \* Select **Basic footer**, and click the **Add new link** button.  
 \* Add the Link name as Glossary (You can change it as per your requirement).  
 \* Type in your glossary overview page URL \*`https://yourdomain/docs/glossary-overview`.  
 \* Once done, click **Add**.  
 \* Click on the **Save** icon > **Publish** to publish the changes in the KB site.

**Custom footer**  
 If you're using the custom footer option, add the glossary overview page URL  
`https://yourdomain/docs/glossary-overview` in the desired code location and click **Save**.

![Portal_Screenshot-Update_Add_glossary_in_footer](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Portal_Screenshot-Update_Add_glossary_in_footer.png)

#### Outcome

![Outcome_Screenshot-Update_Add_glossary_in_footer_outcome](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Outcome_Screenshot-Update_Add_glossary_in_footer_outcome.png)

---

### Adding the glossary overview page link to the Secondary navigation

1. Navigate to **Settings** > **Knowledge base site** > **Customize site** from the Knowledge base portal.
2. Select the **Customize site** and select the **Header** dropdown menu.
3. Select **Secondary navigation**, and click **Add new item**.

   Make sure the **Show in home page** check box is enabled.
4. You can either configure with **Single level**, **Multiple level** or **Ticket deflector**.
5. Add the desired **title** and type in your glossary overview page URL `https://yourdomain/docs/glossary-overview` in the **link** field.
6. Click **Add**.

![Portal_Screenshot-Update_Add_glossary_in_mrng](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Portal_Screenshot-Update_Add_glossary_in_mrng.png)

#### Outcome

![Outcome_Screenshot-Update_Add_glossary_in_the_Menu](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Outcome_Screenshot-Update_Add_glossary_in_the_Menu.png)

You can also add a glossary overview page link in any other section on the Home page as per your requirement.

<a id="feedback-manager-overview"></a>

## Feedback manager

**Plans supporting feedback manager**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The Feedback manager is a content tool in Document360 designed to help you track, evaluate, and respond to feedback from readers on your knowledge base. It is a powerful tool for addressing user concerns and identifying areas where your content may need improvement.

---

## Feedback manager overview

### Accessing the Feedback manager

To access the Feedback manager in Document360,

1. Navigate to **Documentation** () > **Content tools** > **Documentation** > **Feedback manager** in the Knowledge base portal.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Feedback_manager_overview(1).png)

### Features of the Feedback manager

The Feedback manager includes two tabs, each serving a specific purpose in managing reader feedback. Both tabs share similar features, such as filtering, assigning feedback, setting feedback status, and exporting feedback data for further analysis.

#### Article feedback tab

The **Article Feedback** tab compiles feedback directly related to individual articles or categories within your knowledge base. This includes reader comments, positive or negative ratings, and any specific concerns raised about the content.

Readers indicate whether an article was helpful by selecting the  **Yes** or  **No** options at the end of each article. If they select  **Yes**, they can add an optional comment. If they select  **No**, they can choose from options like “Need more information” or *“*Difficult to understand” and may add additional feedback. All responses appear in the **Article feedback tab**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Feedback_manager_article_feedback.png)

#### No search results feedback tab

The **No search results feedback** tab captures feedback from readers who did not find results for their search queries. This feedback is useful for uncovering gaps in content or identifying keywords to improve search relevance.

When a reader does not find any results for a particular search query or keyword, they can share their feedback. All feedback is compiled in the **No search results feedback** tab.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Feedback_manager_no_search_results_feedback.png)

---

## Managing feedback in the Article feedback tab

The feedback in the **Article feedback** tab are user feedback related to articles in your knowledge base. You can use this tab to understand the satisfaction of readers with your articles and find opportunities for improvement.

### Reader actions

At the end of each article, readers can show if the article was helpful or not by,

* **Selecting Yes**: Readers can optionally add a comment about why they found the article helpful.
* **Selecting No**: Readers can choose from reasons (like "Need more information" or "Difficult to understand") and add more comments if needed. If the reader wishes to be informed if you reply to their feedback, they can select the **Notify me about updates** checkbox.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Article_feedback_reader_actions.png)

### Responding to article feedback

To respond to feedback in the **Article feedback** tab, follow these steps:

1. **Select feedback**: Choose an item from the list in the **Article feedback** tab.
2. **Review the feedback**: Read through the reader’s comments to understand their input.
3. **Open the associated article**: The article linked to the feedback is displayed in the top right corner. Click the  icon to open the article in the editor in a new tab.
4. **Assign the feedback**: If necessary, assign the feedback to a team member by selecting their name from the **Assignee** dropdown.
5. **Discussions & history**: Update the feedback with any comments/responses related to the feedback in the **Discussions & history** field.

6. **Update the Feedback Status**: Select a status from the **Status** dropdown to indicate the feedback’s progress. The available statuses are:

   1. **Open**: Feedback is assigned the **Open** status by default, indicating it is yet to be addressed.
   2. **Planned**: The **Planned** status shows that the feedback has been reviewed and scheduled for future action.
   3. **In progress**: Set to **In progress** when a team member actively works on the feedback.
   4. **Complete**: When the feedback has been addressed, assign it the **Complete** status. You can still add comments to feedback marked as **Complete** if needed.
   5. **Closed**: The **Closed** status indicates that the feedback is no longer active, and no further actions can be performed.

> NOTE
>
> If the reader has requested a response for their feedback, enable the **Notify end user/reader** toggle after adding your response in the **Discussions & history** field. When you post a response with this toggle enabled, the feedback status will automatically change to **Closed**.

By addressing feedback in this tab, you can enhance the quality and relevance of your articles, ensuring a better experience for your readers.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Article_feedback_steps.png)

---

## Managing feedback in the No search results feedback tab

The **No search results feedback** tab collects feedback from readers who couldn’t find results for their search queries. You can use this feedback to identify content gaps in your knowledge base or adjust keywords to improve search results.

### Reader actions

If a search yields no results, readers can submit feedback to let you know what information they seek. If the reader wishes to be informed if you reply to their feedback, they can select the **Notify me about updates** checkbox.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Search_results_feedback_reader_actions.png)

### Responding to No search results feedback

To respond to feedback in the *no search results feedback* tab, follow these steps:

1. **Review the search query**: Check the search query provided by the user. This information helps you understand what the reader was looking for but couldn’t find.
2. **Understand the feedback**: Read any additional comments from the user to gain more context about their needs.
3. **Assign the feedback**: Use the **Assignee** dropdown to assign the feedback to a relevant team member.
4. **Take action**: Decide the necessary steps to address the feedback, such as creating new content, updating existing articles, or adding relevant keywords to improve search results.
5. **Discussions & history**: Update the feedback with any comments/responses related to the feedback in the **Discussions & history** field.
6. **Update the status**: Use the same status options as in the **Article feedback** tab (Open, Planned, In Progress, Complete, and Closed) to track the feedback’s progress.

> NOTE
>
> If the reader has requested a response for their feedback, enable the **Notify end user/reader** toggle after adding your response in the **Discussions & history** field. When you post a response with this toggle enabled, the feedback status will automatically change to **Closed**.

By addressing feedback in this tab, you can close content gaps and improve the search experience for your readers.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Search_results_feedback_steps.png)

---

## Additional features

Both feedback tabs include tools to make feedback management easier:

* **Filters**: Filter feedback by status, date, assignee, or other options to quickly find what you need.
* **Bulk actions**: Apply actions to multiple feedback entries simultaneously, like assigning feedback or updating statuses.
* **Export to CSV**: By default, feedback data from the past 90 days will be exported for analysis or record-keeping.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Feedback_manager_additional_features.png)

---

### FAQs

**What is the difference between "Complete" and "Closed" in the Feedback Manager?**

In the Feedback manager, the status **Complete** indicates that the feedback has been fully addressed, while **Closed** signifies that all actions related to the feedback are resolved. Once the feedback is closed, it cannot be reopened, whereas feedback in **Complete** status can be set to **Open** if needed.

**For example**:  
Let's say a user submits feedback about an issue with a feature. Once the team reviews and addresses the feedback, they mark it as **Complete** to show the work is done. However, if the user later reports that the issue isn't fully resolved, the team can change the status from **Complete** back to **Open** to continue working on it.

On the other hand, if the feedback is not in scope or the team finishes all related actions, such as updating the documentation and informing the user, they mark the feedback as **Closed**. Once feedback is **Closed**, it cannot be reopened for further changes.

**Can I export the data from the Feedback manager?**

Yes, you can export data from the feedback from the Feedback manager for a maximum of up to 90 days.

<a id="custom-pages"></a>

## Custom pages

**Plans supporting Custom pages**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Custom pages** featurein Document360 allows you to create dedicated, standalone pages for your Knowledge base site. Custom pages are separate from standard articles and provide the flexibility to add content like Terms & Conditions, Privacy policies, Copyrights. With options for customization, multilingual support, and navigation configuration, Custom pages can enhance the user experience of the Knowledge base site and keep your content organized.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Custom_pages_overview.png "Custom page overview - figma(1).png")

> NOTE
>
> This feature is exclusively available for **KB site 2.0** projects.

## Creating a Custom page

Users with Draft writer, or Editor content roles can create a custom page in the Knowledge base portal. You can also create custom roles with exclusive permissions for custom pages.

To create a custom page,

1. Navigate to **Documentation** () > **Content tools** > **Custom pages** in the knowledge base portal.
2. Click on the **Create page** button to open the **Create custom page** popup.
3. In the Create custom page popup, enter the page name and optional description for the custom page. Select the language for the Custom page from the language dropdown.
4. Click **Create** to open the editor.
5. In the editor, enter the desired content for your Custom page.

> NOTE
>
> Users with **Draft writer**, or **Editor** content roles can create a custom page in the Knowledge base portal. You can also create custom roles with exclusive permissions for custom pages.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_GIF-Creating_custom_page.gif "Create custom page - figma.png")

The editor provides Advanced WYSIWYG options, allowing you to format text, add images, and structure content as needed.

* **Add and format content**: Add content, images and use other formatting and insert options to organize the content as needed.
* **Set SEO details**: Navigate to **More** () > **SEO**, and enter the **Meta title**, **URL slug**, and **Description** for your custom page.
* **Collaborate with team members**: Add inline comments directly on the content, allowing others to provide feedback and suggestions.

Once you have finished creating your custom page, click **Publish** to go live.

> NOTE
>
> To keep a custom page in draft mode, save your content without selecting **Publish**. This keeps the page hidden from the live site until it’s ready to be published.

---

## Managing a Custom page

You can easily manage your custom pages from the **Custom pages** list in **Content tools**.

### Editing a custom page

To edit an existing custom page,

1. In **Content tools** > **Custom Pages**, select the page you wish to edit, and click **Edit** ().
2. Make the desired updates in the editor, such as changing text, images, or page details.
3. **Save** any changes to keep your draft updated or **Publish** to make it live immediately.

### Deleting a custom page

To delete a custom page,

1. In **Content tools** > **Custom Pages**, select the page you wish to delete, and click **Delete** ().
2. Once you click Delete, the **Delete confirmation** popup will open.
3. Click **View dependencies** to see the articles and KB Customizations that use the custom page.
4. Click **Delete** to permanently delete the custom page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_GIF-Deleting_custom_page.gif "Delete custom page dependencies - figma.png")

> NOTE
>
> Deleted pages cannot be restored, so ensure the page is no longer needed before deleting.

### Cloning a custom page

In **Content tools** > **Custom Pages**, select the page you wish to clone, and click **Clone** (). A duplicate custom page will be created with the prefix **“Clone -”**.

For example, if a clone a custom page titled *Terms and Conditions*, the duplicate custom page will be titled *Clone - Terms and Conditions*.

---

## Multilingual custom pages

Custom pages support machine translation, enabling you to provide content in multiple languages. To translate the custom pages to another language,

1. Click the language dropdown from the top right of the editor to view the available languages.
2. Select the desired language from the dropdown to enable the **Translate** dropdown.
3. Expand the Translate dropdown to view the number of characters to be translated, and the number of characters available for machine translation.
4. Click Translate to translate the contents of your custom page to the desired language.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_GIF-Translating_custom_page.gif "Translate custom page - figma.png")

---

## Try this feature

Once created, custom pages can be added to your Knowledge base site’s navigation. You can integrate a custom page into the site’s [**header**](/help/docs/header-primary-navigation)or [**footer**](/help/docs/footer-navigation), making it visible across your knowledge base.

To add a custom page to the header or footer, go to **Customize Site** in the **Knowledge Base Site** settings, where you can choose the location and display options.

* To add a custom page to a header, select **Custom page** from the list of navigation menus under **Primary navigation**.
* To add a custom page to a footer, enter your desired title, and a link to the Custom page while adding a new link to the footer.

To see custom pages in action, explore the interactive demo below, which showcases how to create and integrate a custom page seamlessly into your Knowledge Base site:

---

### FAQs

**How many custom pages can I create?**

Each project allows up to 5 custom pages by default, with options to add more depending on your plan.

**Can I make a custom page private?**

Yes, you can restrict access to custom pages based on user roles in your knowledge base settings.

**Where will custom pages appear?**

They can be included in the left navigation or placed in the header or footer for quick access across the site. If a custom page is publishing, but not included in the header or footer, only users with a link to the custom page can access it.

**What can I do if I accidentally delete a custom page?**

Deleted pages cannot be restored, so always double-check before deleting.

<a id="tags"></a>

## Tags

**Plans supporting tags**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Tags in Document360 help you easily identify, filter, navigate, and group related articles, category pages, or files within your knowledge base.

---

## What are tags?

A tag is a simple label made up of letters, numbers, words, or phrases that describe the content of an article, category page, or file.

For example, if an article covers software installation, you can apply the tag *Installation*. When readers see this tag next to the article, they’ll instantly know what to expect.

### How tags improve your experience

* Simplify team and reader navigation (via identification, filtering, and browsing)
* Group similar articles or files for easier access
* Improve keyword searches within your knowledge base
* Boost visibility on third-party search engines by generating unique URLs for tags

> NOTE
>
> Try the [AI Tag recommender](/docs/ai-tag-recommender) to automatically generate and apply relevant tags to your content.

### Best practices for using tags

| Do’s | Don’ts |
| --- | --- |
| Keep tags concise | Overuse tags on a single page |
| Use broad category terms | Assign irrelevant or redundant tags |
| Ensure tag consistency across your knowledge base | Make spelling or semantic errors in tag names |

---

## FAQs

**Can I assign multiple tags to a single article or file?**

Yes, you can assign various tags to a single article, category page, or file. This capability enables you to capture the multiple aspects and topics covered within the content.

**What's the advantage of using tags for grouping content?**

Using tags for grouping allows you to create thematic collections of content. For instance, you can group articles from different categories related to a common theme under a specific tag, making it easier for users to explore comprehensive information.

**Do tags have any impact on search functionality?**

Yes, tags enhance search functionality. When users search for specific topics, content with relevant tags will be more accurately identified and presented in search results, helping users find pertinent information faster.

**Can I search for content using tags?**

Yes, you can use tags to refine your search results. Document360 will display a list of content items tagged with that keyword or label when you search for a specific tag.

**Is there a limit to the number of tags I can assign to an item?**

There's no strict limit, but Document360 recommends using a reasonable number of tags to maintain clarity. Assign tags that accurately represent the main themes or topics of the content.

**Is there a limit to the number of tags I can add in a project?**

Yes, you can add up to 1000 tags in a single Document360 project.

**Can I bulk-import tags into my Document360 project?**

No, with the current implementation, you cannot bulk-import tag.

<a id="tag-manager-overview-page"></a>

## Manage tags page overview

**Plans supporting tags**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Manage tags** page in Document360 is your central hub for managing tags within your knowledge base. Here, you can assign tags to articles, category pages, and files stored on Drive. This page also allows you to organize tag groups, helping you consolidate related tags and view their dependencies across all articles, categories, and files.

To access the Tags Overview page, go to **Documentation** > **Content tools** > **Documentation** > **Tags**.

---

## Key features of the Manage tags page

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1.%20Manage%20tags%20page.png)

1. **Create tag**: Easily add new tags to your project, which can be later associated with articles, category pages, and files.
2. **Search tags**: Use this field to quickly filter and search for existing tags in your project. Simply type in the keyword, and relevant results will be displayed below.
3. **Created by**: View the contributor’s name who created each tag, providing transparency and accountability within your tagging strategy.
4. **Date**: Check the creation date for each tag, helping you track updates and changes over time.
5. **Tag dependency**:

   View how many instances each tag has been associated with across:

   * Articles
   * Page category
   * Files in drive
   > NOTE
   >
   > You cannot delete a tag if it has dependencies, meaning it is associated with any articles, category pages, or files. Please remove the tag’s dependencies first before deleting it from the tag library.
6. **Edit options**:

   Access various actions to manage your tags:

   * Edit: Click the edit icon to modify the tag name and description.
   * Move: Easily relocate tags to different categories or groups.
   * Merge tags: Combine similar tags to reduce redundancy.
   * Remove references: Detach tags from specific articles, categories, or files.
   * Delete: Remove tags from your project, ensuring your tagging system stays organized.
7. **Export**: Export all tags in your project to a CSV file for external use or analysis.
8. **Filter**:

   Use the "Filter" option at the top-right to narrow down the displayed tags by various criteria, such as:

   * Tag associations
   * Creation on
   * Created by

---

## FAQs

**Can I view the list of all Tags used in my knowledge base?**

Yes, the **Manage tags** overview page *(****Content tools*** *>* ***Documentation*** *>* ***Tags****)* displays all the tags available in your knowledge base project. This page helps you manage and maintain a consistent tagging strategy across your content.

**Can I view which is associated with which article or file?**

The tag references in articles, categories, and files can be viewed from the **Manage tags** overview page. Click on the number in the consequent columns and View dependencies for the tags.

**Can I edit or remove Tags?**

Yes, you can easily edit or remove Tags at any time. Navigate to the **Manage tags** overview page *(****Content tools*** *>* ***Documentation*** *>* ***Tags****)* select the tag, and the Edit and Delete option appears at the page top.

**Can I merge two or more tags?**

You can merge similar tags by selecting them in the **Manage tags** overview page and clicking on the **Merge tags** option at the top.

**Can I remove tag dependencies?**

You can remove tag dependencies one article/file at a time or use the bulk dependency remove. Select the tags in the **Manage tags** overview page and click on the **Remove dependencies** option at the top.

<a id="adding-a-new-tag"></a>

## Adding a new tag

**Plans supporting tags**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Team accounts in Document360 can create tags to organize articles, page categories, and files in Drive. Tags help classify and manage content efficiently across the project, while also enhancing search functionality by making content easier to find.

> NOTE
>
> Use the [**AI tag recommender**](/help/docs/ai-tag-recommender) feature in Document360 to analyze article content and recommend relevant tags. If no suitable tag exists in your tag library, the recommender can also help you create new tags.

---

## Adding tags to the library

There are **four** methods to add tags to your project's Tag library.

1. From the **Manage tags** overview page
2. From **More article options** in the editor
3. Adding tags to files in **Drive**
4. Adding tags to the articles in the **All articles** page

### Adding tags from the Manage tags overview page

To add tags from the **Manage tags** overview page,

1. Log in to the **Knowledge base portal** and select the **Documentation ()** tab from the left navigation sidebar.
2. Navigate to **Content tools > Documentation > Tags**.
3. On the **Manage tags** overview page, click the **Create tag** button at the top-right.
4. Enter the tag name and description in the respective fields.
5. Select the group you want to associate the tag with (the individual tag is the default selection).
6. Click the **Create** button to add the tag to your project's tag library.

![1_Screenshot-Creating_a_new_tag_method1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Add_tags_content_tools.png)

### Adding tags from More article options in the editor

To add tags in the editor,

1. In the documentation editor, click the **More ()** icon.
2. From the menu, select **Tags** to open the **Article settings** window.
3. In the **Tags** field:

   * Click the field to open a dropdown showing existing tags.
   * Type in the field to search for matching tags. The dropdown will filter results as you type.
   * If the tag you typed does not exist, the dropdown will show an option to create a new tag. Select this option to add the tag to your library.
4. After selecting or creating the desired tags, click **Save** to apply the changes.

![2_ScreenGIF-Creating_tags_in_documentation_editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_GIF-Add_tags_editor.gif)

### Adding tags to files in Drive

To add tags to files in Drive,

1. Navigate to the **Drive** and click on the desired file name.
2. Click the **More ()** icon next to the file name and select either **Add tags** or **View details** to open the **File details** side panel.
3. In the **File details** side panel, locate the **Tags** field.
4. In the **Tags** field:

   * Click the field to open a dropdown showing existing tags.
   * You can type in the field to search for matching tags. The dropdown will filter results based on your input.
   * If the tag you typed does not exist, you will see an option to create a new tag.Click this option to add the new tag.
5. After selecting or creating the desired tags, click the **Update** button to save the changes.

![3_Screenshot-Adding_tags_in_drive_method_3](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Add_tags_drive.png)

### Adding tags to articles from the All articles page

1. From the Knowledge base portal, go to Documentation > All articles.
2. Select one or more articles from the list.
3. Select **Create tags** from the toolbar. This opens the **Create tags** window.
4. In the **Create tags** window:

   * Use the **Tags** field to select existing tags from the dropdown or type to search for tags.
   * If the tag you typed does not exist, select the option to create a new tag.
5. After selecting or creating the desired tags, click **Save** to apply the changes.

![4_Screenshot-Method4_Adding_tags_in_All_articles](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Add_tags_all_articles.png)

## Tag limitations and details

Below are some of the details and limitations of tags in Document360.

### **Number of tags in a project**

Team members can add up to **1,000 tags** to a single project. Tags are listed on the **Manage tags overview** page, with pagination at the bottom for easier navigation.

### **Tag character limit**

* **Tag name**: The maximum character limit, including spaces, is **30**.
* **Tag description**: The maximum character limit, including spaces, is **100**.

### **Tag description**

* When you hover over a tag in the **Knowledge base portal** or **Knowledge base site**, the tag's description appears as a tooltip.
* On the dedicated **Tags page** in the **Knowledge base site**, the tag description appears below the tag title.

## **Tag naming guidelines**

Tags can include:

* Uppercase and lowercase characters (with multi-language support)
* Numbers
* Spaces
* Selective special characters: **\_ + - @ # % ^ & ! ()**

> NOTE
>
> Tag name cannot contain the following special characters: **\ / : \* ? " <> |**.

<a id="tag-groups-overview"></a>

## Tag groups page overview

**Plans supporting tag groups**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Tags in Document360 help you organize articles, page categories, and files in Drive. But managing a large number of tags can get complicated. To make it easier, Document360 allows you to group related tags into **Tag groups**. Tag groups help you keep your tags organized and easier to manage. Within each group, you can see the tags it contains and their dependencies, making it simple to maintain a clear and organized tag library.

---

## Creating a tag group

To create a tag group,

1. Log in to the **Knowledge base portal** and select the **Documentation ()** tab from the left navigation sidebar.
2. Navigate to **Content tools > Documentation > Tags**.
3. Select the **Groups** tab. You can view the list of Tag groups if you have any.
4. Click on the **Create group** to add a new tag group.
5. Add the **Tag group** name and description and click **Create**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_GIF-Creating_tag_groups.gif)

## Adding tags to tag groups

There are two methods for adding tags to tag groups.

* **Method 1**: Assign a tag to a group while creating it by selecting the desired group from the **Select group** dropdown.
* **Method 2**: In the tag library, select multiple tags, click **Move** in the toolbar, and assign them to the desired group.

## Deleting tag groups

To delete a tag group, go to the **Tag groups** page, select the group you want to delete, and click **Delete** in the toolbar.

> NOTE
>
> Deleting a tag group will remove all dependencies of the tags in the group from associated articles, page categories, and files. Additionally, the tags themselves will be deleted from the project.

---

### FAQs

#### **Can I add tags to tag groups after creating them?**

Yes, you can add tags to tag groups either while creating the group or later by selecting multiple tags in the tag library and moving them to the desired group.

#### **What happens if I delete a tag group?**

Deleting a tag group will remove all dependencies of the tags in the group from associated articles, page categories, and files, and the tags themselves will be deleted from the project.

#### Is it possible to add tag groups to articles?

No, tag groups cannot be added to articles. They are designed to help organize your tags and provide a way to view all articles associated with the tags in a specific tag group.

<a id="tag-dependency-viewer"></a>

## Manage tag dependencies

**Plans supporting tags**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Tag dependencies allow you to view and manage where tags have been applied in your project, such as articles, page categories, and files in Drive. This ensures you can track and clean up tag usage across your project efficiently.

## Viewing tag dependencies

To view tag dependencies,

1. Navigate to **Documentation** > **Content tools** > **Documentation** > **Tags**.
2. Click the number displayed under the **Articles**, **Page category**, or **Files in drive** columns to open the **Tag dependencies** window and view detailed information.
3. Review the detailed information about the selected tag's usage in the **Tag dependencies** window.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-View_tag_dependencies.png)

### Information available in the Tag dependencies window

In the **Tag dependencies** window, you can view detailed information about where the tag is applied:

* **For articles**: Article title, status (new article, draft, published), workspace, language, article creator, and the article's date of creation.
* **For page categories**: Page category title, status (new article, draft, published), workspace, language, article creator, and the page category's date of creation.
* **For files**: File name.

---

## Removing tag dependencies

You can remove tags from articles, page categories, or files directly from the **Tag dependencies** window by following these steps:

1. Select the desired items (articles, page categories, or files) using the checkboxes.
2. Click **Remove dependencies** to remove the tag from the selected items.
3. To remove the tag from all listed items, click **Select all** and then **Remove dependencies**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Remove_tag_dependencies.png)

<a id="find-and-replace"></a>

## Find and replace

**Plans supporting find and replace**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Find and replace** allows you to search and replace a keyword/phrase across your project's articles and category pages.

You can search only words and numbers and you can replace those with words, numbers, and selective characters.

![4b_Screenshot-Find_and_replace-Text_fields](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4b_Screenshot-Find_and_replace-Text_fields.png)

---

## Performing the find and replace operation

1. Go to the Documentation () icon > **Content tools** > **Documentation** > **Find and replace**.  
   ![1b_Screenshot-Accessing_find_and_replace](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1b_Screenshot-Accessing_find_and_replace.png)
2. Enter the desired keyword/phrase you want to search in the **Find** field.

   * A list of articles and category pages which has the keyword/phrase appears.
   * You can use the available filter options by clicking on **Filter** available on the top-right to narrow down the results.
   * Select the **Match whole words** checkbox to find and replace a specific word/phrase.
   > For example, when you replace `page` with `article`, all occurrences of `page` will be replaced with `article` but only when it is a separate word. The word `homepage` will be ignored for this action.

   > NOTE
   >
   > The number of times the term is mentioned in the article is fetched by the **Find** field and displayed as occurences. The occurrences are displayed at the top of the article preview pane.
   >
   > ![2_Screenshot-Find_and_replace-Article_preview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Find_and_replace-Article_preview.png)

3. Select the articles and category pages in which you want to replace the text.

   * To replace the text in the desired article, select the adjacent checkbox.
   * If you want to replace it in all instances, select the check box adjacent to the **Articles/Category pages** column header.
4. Enter the desired keyword/phrase you want to replace in the **Replace with** field.
5. Click **Replace**.

> NOTE
>
> The **Replace** button is enabled only when you select at least one article/category page.

6. Select the desired article status after replacement.

   * **Publish** - To publish the article after replacing the keyword/phrase.
   * **Draft** - To keep the article in the draft after replacing the keyword/phrase.
7. Click **Apply**.
8. To view the full article on a new tab, click on the open article in new tab () icon near the **Article preview**.  
    ![6b_Screenshot-Find_and_replace-Confirmation_prompt](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6b_Screenshot-Find_and_replace-Confirmation_prompt.png)

### Filter options

The following filter options are available:

* **Workspace/Language** - To filter the search results by workspace and language.
* **Visibility** - To filter the search results by visibility status (Visible/Hidden).
* **Status** - To filter the search results by article status (New article/Draft/Published).
* **Contributors** - To filter the search results by contributors. You can search by team account name, and multiple selections are allowed.
* **Tags** - To filter the search results by tags.
* **Updated on** - To filter the search results by last updated date range.

![5d_Screenshot-Find_and_replace-Filters_available](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5d_Screenshot-Find_and_replace-Filters_available.png)

## Find and replace in editor

1. You can also use the **Find and replace** tool within the Editor.
2. Navigate to the desired editor and click the find and replace () icon.  
   ![New_Screenshot-Find&Replace_in_editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/New__Screenshot-Find&Replace_in_editor.png)

   > NOTE
   >
   > When the tool is used from the editor, it finds and replaces the text only in the respective article.

---

## FAQ(s)

**Who can access the Find and replace?**

Find and replace is available only for team accounts with Content role as **Editor** (or) custom content role with the Perform **Find and replace** permission.

**Can I perform Replace without entering anything in the 'Replace with' field?**

* You can perform Replace without content in the **Replace with** field. The keyword/phrase entered in the **Find** field will be removed from the selected articles and category pages.
* When you enter nothing in the **Replace with** field and click **Replace**, the 'Replace content is not provided' message appears in the 'Confirm replace' prompt.

**Does the 'Replace with' change the Markdown or HTML syntax entered in the editor?**

No, it does not replace the Markdown or HTML syntax entered in the editor. It replaces the text that appears in the Knowledge base article.

> For example, to replace the keyword "Set up" with "Install" in an article with Markdown syntax, enter as : Find - `Set up`; Replace - `Install`.

**Do the search results return the articles in the Recycle bin?**

No, the articles and category pages dumped in the Recycle bin will not be covered in the search.

**How many replacement events can be performed?**

The occurrences in a maximum of 1000 articles can be replaced in a single event.

A tool in Document360 used by writers to draft and format content. Document360 offers three types of editors: Markdown, WYSIWYG, and Advanced WYSIWYG.

Permissions assigned to a team account in Document360 that define the actions they can perform on knowledge base content, such as creating, editing, or managing articles and categories.

![8_Screenshot-Content_role_view permission](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Content_role_view%20permission.png)

A folder in the Document360 drive where deleted files and folders are temporarily stored. It allows users to recover accidentally deleted items if needed. Deleted items are stored for 30 days before they are deleted permanently.

<a id="seo-descriptions"></a>

## SEO descriptions

**Plans supporting SEO description**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

SEO descriptions can be added for individual articles in the article settings. To manage or generate SEO descriptions for multiple articles or page categories, use the SEO description tool in the Content tools section.

## Generating SEO descriptions

To manage the SEO descriptions for multiple articles or page categories,

1. Log in to the Knowledge base portal and choose the desired project.
2. Choose a workspace from the Workspace dropdown menu. Make sure the workspace language is set to English.
3. Navigate to **Content tools** > **Documentation** > **SEO description** in the Documentation tab.
4. Select the checkbox next to each article for which you want to generate SEO descriptions.

> NOTE
>
> Articles with fewer than 200 words are ineligible for SEO description generation, and their checkboxes will be disabled.

5. Click **Ask Eddy AI** in the top-right corner to generate SEO descriptions for the selected articles.
6. Review the generated descriptions in the SEO description column:

   1. If you are satisfied with all generated descriptions, click **Save**.
   2. If you are not satisfied with any description, click **Cancel**.
   3. For partially satisfactory results, click **Save** or **Cancel** individually for each article in its respective row.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_GIF-Content_tools_seo_description.gif)

### Filters in the SEO description tool

You can use the Filter dropdown to quickly identify the articles for which you want to generate SEO descriptions.

The following filters are available in the **Filter** dropdown:

* **SEO description**

  + **Available**:Filter the articles with existing SEO description.
  + **Not available**: Filter the articles without an existing SEO description.
* **Category**: Filter the articles by category or subcategory.
* **Contributor**: Filter the articles by contributors.
* **Tags**: Filter the articles with the tags.
* **Updated on**: Filter the articles updated within a time frame or a specific range of dates.

---

### FAQs

#### **What happens when I use the “Select all” option and try to generate SEO descriptions for articles with fewer than 200 words?**

When using the **Select all** option, all articles on the page are selected, including those with fewer than 200 words. If you proceed to generate SEO descriptions, a confirmation prompt will notify you that descriptions cannot be generated for these articles. To continue generating descriptions for eligible articles, type "yes" in the field and confirm by clicking **Yes**.

#### How do I generate the SEO description for individual articles from the editor?

You can generate the SEO description for individual articles from the editor using the [**AI SEO description generator**](/help/docs/seo-description-generator).

#### What are some best practices while draft SEO titles and descriptions?

#### Best practices for SEO descriptions

1. **Keep it concise (around 155-160 characters):** Meta descriptions should be brief yet informative. They are snippets that appear in search engine results, so ensure they’re clear and concise.
2. **Include relevant keywords:** Incorporate primary and secondary keywords naturally, reflecting the core topic of the article to improve discoverability.
3. **Align with user intent:** Ensure the meta description answers what your target audience might be looking for. This helps increase click-through rates by attracting the right audience.
4. **Make it actionable:** Use calls to action like “Learn more,” “Discover,” or “Get started” to encourage users to click on your link.
5. **Unique for every page:** Ensure every page on your website has a unique meta description to avoid duplicate content issues.
6. **Avoid keyword stuffing:** Overloading the meta description with too many keywords can make it seem unnatural and may negatively impact SEO.

#### Best practices for SEO titles

1. **Optimal length (50-60 characters):** Keep your title under 60 characters to ensure it doesn’t get cut off in search results.
2. **Include primary keywords:** The title should include your primary keywords, preferably at the beginning, to improve relevance for search engines.
3. **Reflect the article’s content:** The title should accurately represent the article’s subject matter to avoid misleading users or increasing bounce rates.
4. **Make it engaging:** Write compelling titles that spark interest. Use power words or questions to attract user attention.
5. **Avoid redundancy:** Ensure your title is clear, straightforward, and free from unnecessary repetition of words.
6. **Brand inclusion (optional):** You can add your brand’s name at the end of the title to improve brand visibility, but only if space allows without truncating essential keywords.

<a id="export-documentation-as-zip"></a>

## Exporting your Document360 project as a ZIP file

**Plans supporting import and export of project**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Using the **Export** option in Document360, you can export and download the contents of your project as **ZIP** file.

The exported Document360 ZIP file contains the following:

* Articles and category pages
* Media files hosted in Drive (Exporting media files is optional)

The exported project ZIP file can be easily imported onto another project in Document360.

---

## Exporting a project

To export a Document360 project as a ZIP file,

1. Navigate to **Documentation ()** > **Content tools** > **Import & Export** > **Import & Export project**.
2. Click the **Export** button to open the **Export project** popup.
3. In the **Export project** popup, select the **Article modified on** option that matches the articles you want to export. Choose **All** to export all articles, **7 days**, **30 days**, or **90 days** to export articles modified within the selected timeframe, or **Custom date** to specify a custom date range.
4. Select the workspace you wish to export by checking the box next to the workspace name. Selecting a workspace includes all languages and categories within that workspace.
5. To export specific languages and categories within a workspace, click the arrow next to the workspace name to view the available languages. Then, click the arrow next to each language to display its categories. You can select specific languages and categories as needed.

> NOTE
>
> As you make the selections, the total categories selected for export are displayed at the top-right of the frame.

6. Check the **Include media files** box to include related media files in the exported ZIP file.
7. Click **Export** to begin exporting the project contents.

> NOTE
>
> Depending on the size of the content selection, the time taken to export may vary.
>
> For example, the typical sample project content provided by Document360 is usually exported in 60 seconds or less.

![Screengif-Updated_Exporting_your_Document360_project_as_a_ZIP_file](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_GIF-Export_project_file.gif)

The export process is initiated, and you will get a notification popup at the top-right when the export is complete and ready for download. You can navigate to other modules while the export is in progress.

---

## Downloading the ZIP file

To download the exported Document360 project ZIP file,

1. Navigate to **Documentation ()** > **Content tools** > **Import & Export** > **Import & Export project**. The latest exported file will be available under **Recent files** (The date and time of export will be available in the file).
2. Click **Download** to save the file in your local storage (or)Click **Copy link** to generate a downloadable link for the export file.

![Screenshot-Updated_Import_and_Export_projects-Download_the_exported_file](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Download_exported_project_zip_file.png)

## Export project API endpoint

* To use the export project API endpoint, you should be on the **Business** or **Enterprise** plan. You can use it up to 2 times per day.

> NOTE
>
> Once you perform a new export operation, the previously exported ZIP available for download is overwritten.

---

### FAQ

**In what format are the articles available in the exported ZIP file?**

If you select a single language while exporting your Document360 project:

* Articles created in the **Markdown editor** will be in **.md** format.
* Articles created in the **WYSIWYG/Advanced WYSIWYG editor** will be in **.html** format.

If you select multiple languages while exporting your Document360 project:

* All articles will be downloaded in **.json** format.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="import-a-documentation-project"></a>

## Importing a Document360 project ZIP file

**Plans supporting import and export of project**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Once you complete exporting the **Document360** **ZIP files**, they can be imported to any project. This is useful when you need to migrate your knowledge base from one project to another, or if you need to restore your knowledge base from a backup ZIP file.

Importing a **Document360** ZIP file includes:

* Articles and category pages
* Media files included in the exported ZIP file

> NOTE
>
> To import a **Document360** project, the team account must have the **Editor** content role. For custom content roles, the account must have **Update** and **Publish access** to the **Project Import & Export** feature.

---

## Importing a project ZIP file

To import a **Document360** project ZIP file,

1. Navigate to **Documentation**() > **Content tools** > **Import and export** > **Import and export project** in the Knowledge base portal.
2. Click the **Import**  button to open the **Import project** panel.
3. Drag and drop the project ZIP file from your local storage or use the **Upload** option to select the ZIP file.

   Document360 will upload and validate the ZIP file.
4. If you need to choose a different ZIP file, click **Replace**.
5. After successful validation, a confirmation message will display details about the ZIP file, such as:

   * **Languages**
   * **Number of categories**
   * **Number of articles**
6. Select the **Set article status to publish** checkbox if you want all the imported articles to be published. If the checkbox is not marked, all the imported articles remain in the **Draft** state.
7. Click **Import**  to finalize the process.

Once the ZIP file is successfully imported into your desired project, all articles and media files will become available within the project.

![Screenshot-Updated_importing_document360_successfull](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_GIF-Import_zip_file_process.gif)

---

### Importing projects with the same workspace slug

When importing a project ZIP file into another project with the same workspace slug:

* The imported articles and categories will merge with the existing articles and categories within the same workspace.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Importing_Document360_project_within_same_workspace.png)

If the workspace slug of the destination project differs from the slug in the imported ZIP file:

* A **new workspace** will be created with the workspace name and slug from the imported project. All imported data will be added to this new workspace.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Importing_Document360_project_as_seperate_workspace.png)

---

### Importing a project ZIP file into a specific workspace without overriding existing content

To import a project ZIP file into a specific workspace while avoiding conflicts with existing articles or workspace slug:

1. Export the desired categories from your **Document360** project as a ZIP file.
2. Extract the ZIP file in your local file explorer.

   The extracted folder contains two main directories: **Media** and **workspace\_slug**.

   * **Media**: Contains all media files of the project.
   * **workspace\_slug**: Contains two folders and a JSON file:  
     a) **Articles**: List of articles in the project.  
     b) **Categories**: List of page categories in the project.  
     c) **workspace\_slug\_category\_articles**: A source file with workspace and article data.
3. Open the **workspace\_slug\_category\_articles** file in a code editor.
4. Modify the workspace name and slug to match the destination workspace name and slug.
5. Save your changes and rename the JSON file using the destination workspace slug format: `workspace_slug_category_articles`.

   **Example:** `v2_category_articles`
6. If needed, update the slugs of articles or categories, and the language code in the extracted folders.
7. Compress the modified files into a new ZIP file and name it using the destination workspace slug.
8. Return to your **Document360** project and import the newly created ZIP file.

In this example, we are importing a project ZIP file with the workspace slug **v1** into a project with the workspace slug **v2**. To match the target workspace **v2**, we update the workspace name and slug in the **v1** ZIP file.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGIF-Importing_steps_of_Document360_project.gif)

The above screen recording demonstrates how to change the workspace slug and name from **v1** to **v2** in the extracted files, re-compress the modified files into a new ZIP file, and successfully import them into the **Document360** project with the workspace slug **v2**.

---

### FAQs

#### What happens to my existing content when I import Document360 project data from a ZIP file?

Importing project data from a **Document360** ZIP file behaves differently based on the workspace slug:

* If the workspace slug in the ZIP file matches the destination project’s workspace slug, the imported articles and categories will merge with the existing articles and categories within the same workspace.
* If the workspace slug in the ZIP file differs from the destination project’s slug, a new workspace will be created using the workspace name and slug from the imported project. All imported data will be added to this new workspace.

Importing the ZIP file does not affect your project’s settings. Be sure to back up any important data before proceeding with the import.

#### What happens if I import a ZIP file into the same project it was exported from?

If you import a ZIP file into the same project from which it was exported, any articles in the ZIP file that match existing articles in the project will be overwritten with the version from the ZIP file. Articles that do not exist in the ZIP file will remain unchanged.

#### How do I find the Workspace slug URL for my project?

1. Navigate to the desired **Document360** project.
2. Go to **Settings**() > **Knowledge base portal** > **Localization & Workspaces**.
3. In the **Localization & Workspaces** tab, hover over the desired workspace and click the **Edit**() icon.

   The **Edit workspace** panel will appear.
4. In the **Slug URL** field, locate the slug URL for the workspace.

#### Can I import only ZIP files for Document360 projects? Are ZIP files from other platforms supported?

No, ZIP files from other platforms are not supported. Only project export ZIP files generated in **Document360** can be used while importing content to a project.

#### What is the maximum size for Document360 project ZIP files I can upload?

**Document360** project ZIP files can be uploaded up to a maximum size of 1 GB.

#### Why did my Document360 export file fail to import?

There are several reasons why your **Document360** export file may fail to import:

1. **Unsupported features**  
   If the export file contains workspaces, languages, or other features not supported in your current Document360 plan, the upload will fail. Hover over the info icon for details on unsupported features.
2. **Mismatched slugs and workspace names**  
   The workspace names and slugs in the source and destination projects do not match. Ensure these align before attempting the upload.
3. **Incorrect file format**  
   The imported file must follow the required format for the import process. Verify the structure and ensure it meets the necessary guidelines.
4. **Missing languages in destination**  
   If the import file contains languages that are not available in the destination workspace, the upload will not proceed. Add the required languages to the destination workspace before uploading.

![Screenshot-Updated_importing_document360_successfull](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Import_zip_file_error.png)

<a id="migrating-documentation-from-another-knowledge-base-platform"></a>

## Migrating documentation from other platforms

**Plans supporting content migration**

| Professional | Business | Enterprise |
| --- | --- | --- |
| **✓** | **✓** | **✓** |

Document360 supports migration from 100+ Knowledge base platforms. Document360 provides migration support as an add-on in the Business and Enterprise plans.

Migrating documentation from one knowledge base platform to another platform can be tricky and overwhelming. With Document360, it is just a simple process.

The Document360 migration team has helped customers migrate from other platforms such as

* Zendesk
* Freshdesk
* HelpDocs
* WordPress
* KnowledgeOwl
* GitHub
* Intercom
* Drift
* Confluence  
   and many more.

![4_Screenshot-Migration-Platforms_supported](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1731245595890.png)

### Initiating a migration request

Get the latest information on migration to Document360 on the [**Migration page**](https://document360.com/migration-request/) on our website. You can initiate a migration request from the website through the [**Migration request form**](https://document360.com/migration-request/#MigrationForm).

If you're currently using a trial version of Document360, to migrate your existing knowledge base content to Document360, follow these steps.

1. Navigate to **Documentation** ()> **Content tools** > **Import & Export** > **Migrate content**.

![Screenshot-Updated_Migration-Accessing_migration_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1731245662452.png)

2. Click the **Initiate migration** button and a popup appears.
3. Enter the hyperlink to your existing external knowledge base or product documentation site in the **External knowledge base link** field.

   This refers to the link at which your content is currently hosted.  
   For example, docs.yourcompany.com
4. Enter the knowledge base platform used in the **Current platform** field.

   This refers to the platform currently hosting your documentation.  
   For example, Zendesk, Intercom, Confluence, etc.
5. Click the **Submit** button.

![Screenshot-Updates_Migration-Accessing_migration_page_request](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1731245721164.png)

Once you submit the information, one of Document360's migration experts will contact you to help with the migration process.

---

## Document360 migration - What happens next?

![Screenshot-Updated_Migration-Process](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1731245759014.png)

### Step 1: Kick-off

Document360's migration expert will contact you to understand your current knowledge base system and provide an estimate. We can migrate from pretty much any existing knowledge base system or platform.

### Step 2: Migrate

The migration team then uses automated tools and manual processes to migrate your knowledge base. This will be an iterative process with regular updates and sync-ups.

### Step 3: Test

We perform a thorough QA (Quality Assurance) process, set redirection rules, and make sure your new Document360 knowledge base is live without losing any of your existing SEO (Search Engine Optimization) traffic.

### To set up a redirect rule for the subfolder URL path

When you migrate from another platform to Document360, you must set up a redirect rule at the subfolder level. This will enable any URLs from your previous platform to redirect to documentation in your current knowledge base in Document360.

Follow the below steps to set up a redirect rule for the subfolder URL path:

1. Go to **Settings** > **Knowledge base site** > **Article redirect rules** > **New redirect**.
2. Select Redirect type as **Replace with**.
3. Enter the old subfolder path in the **Source path** field.
4. Enter the subfolder path you want to redirect in the **Destination URL** field.
5. Click **Save**.

> **For example**, you want to redirect the subfolder path `/help/customer/` to `/docs/en/` in the URLs `https://docs.churn360.com/help/customer/article_slug`.
>
> * Enter `/help/customer/` in the **Source path** field.
> * Enter `/docs/en/` in the Destination URL field.
>
> With the above redirect rule, all the URLs with subfolder path `/help/customer/` in the configured knowledge base domain (`https://docs.churn360.com/`) will be redirected to the subfolder path `/docs/en`.

---

### FAQ

**Why should I set up a redirect rule when I change the subfolder path?**

Your readers would have bookmarked the articles in your old knowledge base. Your articles would be backlinked in internal and external articles as references. So, when you do not set up a redirect rule for these URLs, it will lead to a 404 error page. 404 error pages play a negative role in google search index which will pull down google search results and mainly cause a bad reader experience.

<a id="pdf-design-templates"></a>

## Designing a PDF template

**Plans supporting export to PDF**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

PDF templates (previously "Design templates") define the PDF's design, styling, and text formatting aspects ready to be exported. Templates help maintain brand consistency for the different PDFs generated.  
 PDF templates are chosen along with other settings when the Team account initiates a new **Export to PDF**.

Team accounts can choose the existing system template (Default) or create a new one.

---

## PDF templates overview page

Users can access the PDF templates in the Knowledge base portal.

1. Go to the Documentation () icon > **Content tools** > **Import & Export** > **Export to PDF**.
2. Select the **PDF template** tab at the top.
3. You can find the list of PDF templates available (both system templates and custom templates).

   The information available here is the Template name and the last modified time/date. The data can be sorted in ascending or descending order.
4. The template name is the name of the respective project (If this feature is being accessed for the first time and no custom template is added).
5. You can add and manage all PDF templates from this page.  
    ![1_Screenshot-Accessing_the_PDF_templates_overview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Accessing_the_PDF_templates_overview.png)

   ### Template actions on the overview page

   You can perform the following action on the PDF templates on the overview page. The individual template controls are visible when the user hovers the mouse pointer over each template.

* **Clone**: Create a duplicate template similar to the original. Clicking on the clone button would open the PDF template settings page. ‘Clone’ will be added to the original template name. The user can make the necessary changes and click **Save**.
* **Edit:** Users can click on the **Edit** button and edit all the previously saved settings on the template. Once the changes are done, click on the **Save** button. Click on the **Back** button to return to the overview page.
* **Delete**: Click the Delete option to remove any design template from the list. A delete confirmation prompt is displayed. Click **Yes**.  
   The delete option is disabled for the default template. Also, if only one template is available in the list, that is considered a default template.
* **Create new template**: Unlike the other actions, this action has a dedicated button at the top of the page. Users can click this button to create and add new PDF templates to the list.

![4_Screenshot-Updated_PDF_templates_create_new_template](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Updated_PDF_templates_create_new_template.gif)

---

## New PDF template

On the design template overview page, click on the **Create new template** button at the top. A design settings window appears. Specify the following settings in each section.

---

### Template name

Add a name for the new design template. This is a mandatory field. The name can be a maximum of 250 characters with space. Letters, numbers, spaces, and special characters (- and \_) can be added.

![5_Screenshot-PDF_templates_create_new_template_overall_settings](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-PDF_templates_create_new_template_overall_settings.png)

There are three main design segregations for creating the PDF template.

### **1.  Design options**

#### Layout style

Select the page orientation of the template (Portrait or Landscape). Choose between **Portrait** (Height > Width)

or \*\* \*\* (Height < Width).

![6_Screenshot-PDF_templates_create_new_template_display_settings](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-PDF_templates_create_new_template_display_settings.png)

#### Margin

You can choose from the four different system margins or a custom margin.

![7_Screenshot-PDF_templates_create_new_template_display_settings_Margins](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-PDF_templates_create_new_template_display_settings_Margins.png)

* **Normal** - Top: 50px, Bottom: 50px, Left: 60px, Right: 60px
* **Moderate** - Top: 30px, Bottom: 30px, Left: 40px, Right: 40px
* **Narrow** - Top: 10px, Bottom: 10px, Left: 15px, Right: 15px
* **Wide** - Top: 70px, Bottom: 70px, Left: 80px, Right: 80px
* **Custom margins** - The margins can be set from a minimum of 10 pixels to 80 pixels

![8_Screenshot-PDF_templates_create_new_template_display_settings_Custom_margins](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-PDF_templates_create_new_template_display_settings_Custom_margins.png)

#### Cover page

You can add a cover page to the PDF template by turning on the toggle. The cover page is the first page in the PDF file. The cover page is applied only if the checkbox is selected.  
You can preview the cover page on the right.

![1_advancedPDFtemplate](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_advancedPDFtemplate.png)

**a.  Title:** The title text that appears on the Cover. The title must be less than or equal to **15 characters**. It can comprise letters, numbers, spaces, and special characters.

**b.  Description:** Provide a short description of the PDF document. The description must be less than or equal to **500 characters**. It can comprise letters, numbers, spaces, and special characters.

**c.  Color:** Specify the text color of the Title and description on the cover. Use the color picker or the hex code to specify the color.

**d.  Logo:** Upload any logo image to appear on the cover page. Click on the **Click to upload logo or image** button, select the image from the local storage file explorer, and click the **Open** button.  
You can select the three standard square sizes available **Small**(150px), **Medium**(200px), **Large**(250px), or choose a **Custom size** in pixels. The canvas size can be between 20 and 350 pixels in width and height.

**e. Image:** Upload any image to appear on the cover page. Click on the **Background color / image** to select the background color. Choose the color from the pop-up color palette. Click image and click **Click to upload** to upload an image.

#### Terms & conditions

Click on the checkbox to insert any article or custom text into the exported PDF document.

![10_Screenshot-PDF_templates_create_new_template_display_settings_Terms_and_conditions](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-PDF_templates_create_new_template_display_settings_Terms_and_conditions.png)

* **Link existing article**- You can choose any one of the existing articles from the project to be included as default in the PDF template.
* **Custom** - You can use the text formatting options to draft custom content to appear in the PDFs.  You can add text, numbers, special characters, and links to the field.

  > NOTE
  >
  > There are no character limits for the Terms & Conditions.

#### Table of content

Select the checkbox to enable the table of contents in your PDF document.  The table of contents helps in easy navigation to the section of the PDF documents.

![11_Screenshot-PDF_templates_create_new_template_display_settings_Table_of_contents](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/11_Screenshot-PDF_templates_create_new_template_display_settings_Table_of_contents.png)

You can select the checkbox(s) of the heading(s) to make them visible in the table of content in the PDF.  When you choose a subheading, all the higher-level headings are automatically selected.

For example, when you select H4, H2 and H3 are automatically selected.

The page numbers are added to the heading on the Table of Contents page.

**Using Table of contents in a document**  
 A table of contents serves two primary functions:

* It's a straightforward way to show every topic your PDF covers at a glance
* It makes document navigation a breeze by clearly showing the page on which each subject is explained

#### Watermark

Turn on the **Enable watermark** available at the bottom.  
 You can choose a text or image watermark on your PDF document.

> **What is a watermark?**  
>  A **watermark** is a text or image behind the document's main text.  It is usually a lighter shade than the text to read the document easily.
>
> Text watermarks are often used to categorize or show a document's purpose with words such as DRAFT, CONFIDENTIAL, etc.
>
> Image watermarks add brand identity, visual attention, and a professional look with imagery such as logos.

![12_Screenshot-PDF_templates_create_new_template_display_settings_watermark](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/12_Screenshot-PDF_templates_create_new_template_display_settings_watermark.png)

* **Text watermark** - A simple text can be added as a watermark using the text field.  The character limit is maximum of 65 characters including spaces
* **Image watermark** - If an image watermark is required, select an image, click on the **Click to upload logo or image**, and select an image from your local storage file explorer to continue.  
   You can select the three standard square sizes available **Small**(150px), **Medium**(200px), **Large**(250px), or choose a **Custom size** in pixels.  The canvas size can be between 20 and 350 pixels in width and height.

### 2.  Header & footer

#### Header image

Set a header image for the PDF doc template using this section.  This acts as a logo (or any image) placeholder on all the pages except for the cover.  
 Click on the **Click to upload logo or image** option and select the required image from the local storage file explorer.

![13_Screenshot-PDF_templates_create_new_template_Header_and_footer](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/13_Screenshot-PDF_templates_create_new_template_Header_and_footer.png)

* **Alignment** - You can select the position of the header image in the document.  The selections available are **Left, Center,** or **Right**.
* **Image size** - Users can select the three standard sizes available **Small**(50x60px), **Medium**(70x80px), **Large**(80x95px), or choose a **Custom size** in pixels. The canvas size for **Height** and **Width** can be between 20 and 85 pixels.

#### Page numbers

Click on the checkbox to enable page numbers on each page.

![14_Screenshot-PDF_templates_create_new_template_Page_number](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/14_Screenshot-PDF_templates_create_new_template_Page_number.png)

* **Page number type** - Users can select from the three types of page numbers provided

  > + Page 1 of 10, Page 2 of 10, ...
  > + Page 1, Page 2, Page 3....,
  > + 1,2,3...
* **Text alignment** - Choose the position of the page number in the document, **Left, Center or Right**

#### Footer text

Click on the checkbox to enable the footer text in your document.  The footer text has no character limit and can comprise letters, numbers, spaces, and special characters.

![15_Screenshot-PDF_templates_create_new_template_Footer_text](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/15_Screenshot-PDF_templates_create_new_template_Footer_text.png)

* **Content** - Type in the content that appears in the document's footer section
* **Font size** -The font size (10 to 16) can be customized based on the requirement.
* **Font color** - Specify the text color of the footer content.  Use the color picker or the hex code to specify the color.

> NOTE
>
> As the footer space in the PDF page is dynamic based on the text and font size, the text does not appear truncated in the final document.

### 3.  Text Settings

Specify the Heading and paragraph font-related settings for the PDF text in this section.

![19_Screenshot-PDF_templates_New_template_Text_settings](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/19_Screenshot-PDF_templates_New_template_Text_settings.png)

#### Heading text settings

* **Font family** - Select the font family for the Headings in the PDF document

  For example, Arial, Calibri, Verdana, etc.
* **Heading color** - Specify the text color of the Heading tags (H2, H3, H4). Use the color picker or the hex code to specify the color

#### Paragraph text settings

* **Font family** - Select the font family for the Headings in the PDF document

  For example, Arial, Calibri, Verdana, etc.
* **Font size** - Choose the font size(10 to 24) in the PDF design template
* **Font color** - Specify the text color of the paragraph content.  Use the color picker or the hex code to specify the color
* **Disable links** - Turn on or off the hyperlinks in the PDF that you want to export.  When you turn on the toggle, other than the table of contents and direct URL, the hyperlinks in the PDF are disabled

  For example, when you turn on the **Disable links** toggle and export a PDF, the hyperlinks in the exported PDF are disabled.  However, the hyperlinks of the table of content and direct URL work.
* **Links color** - Specify the color of the links that appear in the document.  Use the color picker or the hex code to specify the color

  > **Pro tip** - Choose the color that aligns with your brand or the Heading color for a more visual appeal

---

## Default template

Any created PDF template can be set as a **Default** template.  The default template is available without selection in the "Select PDF template" when you initiate an Export to PDF.

![16_Screenshot-PDF_templates_create_new_template_Set_as_default](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/16_Screenshot-PDF_templates_create_new_template_Set_as_default.png)

Click on the **Set as default setting** on the design template page before you **Save** any template. A **Default** tag appears next to the template name on the design template overview page.

![17_Screenshot-PDF_templates_default_template](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/17_Screenshot-PDF_templates_default_template.png)

> NOTE
>
> The default design template cannot be deleted.

---

## FAQ(s)

**What are PDF templates?**

PDF design templates are pre-designed layouts or formats that can be used as a starting point for creating professional-looking PDF documents. They provide structured and design elements, such as fonts, colors, and graphics, that can be customized with specific content.

**How can the PDF templates benefit me?**

PDF templates save time and effort by providing a ready-made framework for your documents. They ensure consistency in branding and visual appeal, making your PDFs look polished and visually appealing. Templates also streamline the design process, allowing you to focus on content compilation rather than starting from scratch.

**Can I customize PDF templates to fit my needs?**

Yes, PDF templates are meant to be customizable. You can modify the text, images, colors, and layout of the template to align with your specific requirements. This allows you to maintain your brand identity while tailoring the design to suit your content and purpose.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="compliling-content-for-pdf"></a>

## Compiling content for PDF

**Plans supporting export to PDF**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Create a new PDF (customizing the content you want in your PDF) and add PDF attributes like file name, choosing templates, and choosing the content. The exported PDF can also be password-protected if the user chooses to add a level of access security.

---

## Export to PDF

Go to **Documentation**() > **Content tools** > **Import & Export** > **Export to PDF**, and the Content templates tab is the default selection.

> NOTE
>
> You can only export **published articles** and **category pages**. All the hidden articles/categories are will not be available for export.

### Create new PDF

Follow the below steps to create a new PDF.

1. In the **Export to PDF** page, click the **Create new PDF** button on the top right corner.   
   The **Start export** page opens.
2. Enter the **Name** for the PDF.
3. Enter a **Password** if you want to password-protect your PDF.
4. In the **Select PDF template** field, choose the required PDF template from the dropdown menu.   
   The design template is used to style the PDF content template. Users can configure the visual aspects like the cover page, table of contents, watermark, layout, header & footer, and font settings.   
   To learn more about creating PDF templates, read the article on Designing a PDF template.
5. Select the required **Workspace**.
6. Select the required **Language**.   
   ![2-Screenshot_Start-Export](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2-Screenshot_Start-export.png)You can view the preview of the selected template on the right side. You can navigate between Cover, Terms, ToC, and Content previews.
7. In the **Categories & articles** section, click **Select category articles** to choose the categories.
8. In the **Add categories & articles** popup window, select the sub-categories and articles that you want to export.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3-Screenshot_Add-categories-and-articles_1.png)

8. Click **Done** to confirm selection.
9. Click **Export** to initiate export to PDF.  
   The **Export Status** will be updated as *Success* on completion.

> NOTE
>
> You can now download multiple articles from one or more categories on your knowledge base site as PDFs.

---

## Other actions on PDF

You can perform the following actions on the exported PDF.

1. **Download**: Save the generated PDF in your computer.
2. **Regenerate**: Perform the export function again. Clicking on this option exports the latest content available to the PDF.
3. **Clone**: Create a duplicate of the content template with all the attributes similar to the original template.
4. **Edit**: Make changes to the attributes of the content template.
5. **Export details**: View the file name, version, language, categories and articles in the exported PDF.
6. **Delete**: Remove the content template from the template library. This action cannot be reversed.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4-Screenshot_Export-to-PDF-actions_1.png)

---

### FAQs

#### How can I share draft articles with members outside my project team?

In the Advanced WYSIWYG editor, you can share draft articles with members who are not part of your project team by using the "Export PDF" option.

1. Navigate to the desired article in the Advanced WYSIWYG editor.
2. Select the More (•••) options > **Export PDF**
3. Download a PDF version of the draft article.

   You can then share this PDF with the relevant members.

#### Why are SVG images not visible in my exported PDFs?

SVG images may not appear in exported PDFs due to a limitation of the SelectPDF plugin, which is used for converting HTML to PDF. When SVGs are included using the `<img>` tag, they are not rendered in the PDF. This is a known limitation of the SelectPDF plugin.  
As a workaround, you can:

1. Convert the SVG file into a supported image format such as PNG or JPG.
2. Re-upload the converted file.

<a id="analytics"></a>

## Analytics

**Plans supporting analytics**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Analytics** section in Document360 provides a comprehensive overview of your Knowledge base's performance, offering insights to help you optimize content and enhance user engagement. It is categorized into several detailed reports:

* [Articles analytics](/help/docs/articles-geography-and-performance)
* [Eddy AI assistive search analytics](/help/docs/eddy-ai-search-analytics)
* [Search analytics](/help/docs/analytics-search)
* [Reader analytics](/help/docs/reader-analytics)
* [Team accounts analytics](/help/docs/analytics-team-accounts)
* [Feedback analytics](/help/docs/feedback)
* [Links status analytics](/help/docs/links-status)
* [Page not found analytics](/help/docs/page-not-found-analytics)
* [Ticket deflector](/help/docs/ticket-deflector-overview)

### Plan availability

The following analytics features are available based on your subscription plan:

* **Professional plan only**:

  + Eddy AI assistive search analytics
  + Links status analytics
  + Page not found analytics
  + Ticket deflector analytics
* **Professional and Business plans**:

  + Article analytics
  + Search analytics
  + Reader analytics
  + Team account analytics
  + Feedback analytics

### Analytics based on workspace and language

The analytics in Document360 are specific to the active workspace and language of your Knowledge base portal. If you switch to a different workspace or language, the analytics will update to reflect data for the selected workspace and language.

To view analytics for a specific workspace or language:

1. Click on the Workspace Dropdown.
2. Select the desired **Workspace** and **Language** from the available options.

The displayed analytics will now correspond to your chosen workspace and language. All data in analytics displayed is based on the UTC time zone.

<a id="articles-analytics"></a>

## Articles analytics

**Plans supporting article analytics**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Articles**analytics page in Document360 offers detailed insights into the performance of your articles, including overall article data, geographic distribution, and top-performing categories and articles. This valuable data can help you understand user engagement, identify popular content, and make data-driven decisions for improving your Knowledge base.

---

## Accessing Articles analytics

To access the Articles analytics page:

1. From the Knowledge base portal, navigate to **Analytics** ()>**Articles**.

   The **Articles** analytics page opens with an overview of article data. This data is specific to the current workspace and language.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Article_analytics.png)

### Using filters to customize data

By default, the data shows metrics for the **last week**. You can adjust this using filters:

1. Click the **Date** filter dropdown.
2. Select a predefined range (e.g., **This month**, **Last month**) or choose **Custom** to specify a date range.
3. Click on the **All users** dropdown to filter analytics data based on **Team accounts** or **Readers**. This filter applies only to private and mixed projects.
4. If using the **Knowledge base widget**, use the top-right dropdown to switch between **Knowledge base** and **Widget analytics**.
5. Select the JWT widget to track and analyze user interactions and engagement of Feedback analytics within private and mixed projects secured by JWT authentication.

   For more information on Knowledge base widget JWT authentication, read the article on [Managing the Knowledge base widget](https://docs.document360.com/docs/managing-the-knowledge-base-widget).

![Updated_Screenshot-JWT_for_reader_Analytics_June_release](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Updated_Screenshot-JWT_for_reader_Analytics_June_release.png)

> NOTE
>
> Article analytics data can take up to 15 minutes to reflect in the portal.

---

### Article performance

The following performance information of the articles is available in this section as tiles based on the filters applied. Total views, total reads, total likes and total dislikes here in this section are cumulative metrics which include the total including the deleted articles.

| Field | Description |
| --- | --- |
| **Total articles** | Total number of unique articles that were published in the date range based on the applied filters. The deleted articles are not considered. |
| **Total views** | The number of times an article is accessed is counted once per browser session.   * A view is recorded when an article loads in the browser, regardless of user interaction. * Multiple visits to the same article within a session count as one view, even across tabs or windows or when a user closes and opens the same article within that particular browser session. * Alternatively, if a user opens the same article in a different browser, device, clears the cache & reopens the article or refreshes the browser, they will count as another view. * A browser session resets every 24 hours. Accessing the article after this period will count as another view. |
| **Total reads** | An article read is recorded when a user engages through clicking, scrolling, and spending time on the page. The user has to perform all these three actions to count as one read.   * **Scrolling**: At least a single scroll is needed for a valid read. * **Time spent**: Time is tracked only after 40 seconds spent on the article. If a user becomes idle (e.g., stops interacting) for some time or switches tabs, the timer pauses and resumes upon return. * **Session tracking**: Time spent revisiting the same article within 24 hours in the same browser session is added to the previous session's total.   Reads reflect meaningful interaction, distinguishing them from simple page loads. |
| **Total likes** | The total number of likes an article has received. |
| **Total dislikes** | The total number of dislikes received. |

The aggregated data for **Views**, **Reads**, **Likes**, and **Dislikes** within the selected date range is presented in both a numeric format and graphs. You can interact with the graphs by clicking on the legends at the bottom to view individual data points. Click **Export image** ( ) to save the section as a PNG image.

![3_Screenshot-Article_performance_part](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734677856131.png)

---

### Most read articles

This section displays the top-performing articles based on total read time (in hours or minutes). The **Article name**s are listed on the left, and the **Duration** is displayed on the right. Click on the **Export image** () icon to save the section as a PNG image.

![4_Screenshot-Most_read_analytics](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734677884298.png)

---

### Top articles list

The top five articles are listed with information such as **Article name**s, **Contributors**, **Views**, **Reads**, **Likes**, **Dislikes**, and **Feedback**. These articles are ranked by views. Click **View all** to see all the articles in your knowledge base, along with additional information such as time spent and the last updated date. This list does not contain the deleted articles.

![5_screenshot-Top_Articles_part](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734677909945.png)

To analyze specific articles, select one from the list to view detailed analytics. Filters are available to sort readers by:

* **All readers**
* **Self-registration**
* **JWT**
* **Invited readers**

![10_Screenshot-JWT_filter_updation](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1732612581614.png)

* You can filter the following article type, contributors, and date.
* Click **Export CSV** to export the articles in the list.
* Click the **Download** () icon to download the last exported file.
* Click on the back arrow on the top-left to navigate back to the **Articles** page.

![6_Screenshot_All_article_entire_view_part](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734677936708.png)

---

### Location-based views

This section displays a world map highlighting countries based on article views. The data is derived from the IP addresses of users who accessed the articles. A table beside the map lists the top 5 countries, showing the total number of views for each of them (here the cumulative views are shown including those that were garnered by deleted articles as well). These locations are ranked by views. The rest of the countries are grouped under Others.

![7_Screenshot-Location_based_view](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734677969019.png)

* Click on **View all** to view detailed country-based information.

  > NOTE
  >
  > The View all list has tiles representing the number of total views, reads, likes, and dislikes. This count, however, unlike the main page does not include the deleted articles.
* All the countries with at least one view are available. Scroll to view the list of countries on the left side. You can also search for the countries by name.
* The article names, views, reads, likes, dislikes, and average time spent are available as a list.
* You can filter the location data based on article type and date.
* Click on the **Export CSV** button to export the articles in the list.
* Click **Download** () icon to download the last exported file.
* Click the Close (**X**) icon on the top right to navigate back to the **Articles** page.

---

### Top categories

This section displays the top category name and total views. These categories are ranked by views (here the cumulative views are shown including those that were garnered by deleted articles as well).

* Click on **View all** to view the entire list of categories. The category name, number of articles in the category, views, reads, likes, dislikes, and time spent (in minutes) in the categories. This count, however, unlike the main page does not include the deleted articles.
* You can filter the data based on the category type (*All*, *Folder*, *Page,* or *Index*).
* Click on the **Export CSV** button to export the categories in the list.
* Click the Download () icon to download the category list.
* Click on the back arrow on the top-left to navigate back to the **Articles** page.

![8_Screenshot-detailed_Location_based_view](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734678085925.png)

---

### FAQs

#### **Why do my most-read articles and top articles sections differ?**

The Most read articles section lists the top 5 articles with the longest read times during the selected period. In contrast, the Top articles section lists the top 5 most viewed and read articles on your knowledge base, consolidated for the selected period.

#### **Which team account roles in Document360 can access the Analytics section? Is it limited to Admins and Owners?**

In Document360, Admins, Owners, and Contributors can access the Analytics section if their content role is Editor or draft writer.

If you want to restrict team accounts from accessing the Analytics section, you can create a custom portal and content role and uncheck the "Analytics" permission. This will prevent specific users from accessing Analytics.

When creating a new team account or modifying an existing one, assign this custom content role to ensure users with this role can't access the Analytics section.

> For more details on creating a custom content role, read the [Roles and permissions](/help/docs/roles) article.

#### **How can I find the file size I am trying to export?**

Currently, Document360 does not display the file size before export. After downloading the file, you can check the size on your local device.

#### How does the analytics track read counts for smaller articles that do not require scrolling?

For shorter articles where scrolling is not necessary, a read is counted if a user clicks on the article and spends at least 60 seconds engaging with the content. Even without scrolling, this interaction is recognized as a valid read based on the read time shown in the article.

A chart legend represents data series in a chart, using colors or symbols to differentiate them. For example, each column of data in a chart is shown in a unique color, with the colors and series names displayed as the legend

<a id="eddy-ai-search-analytics"></a>

## Eddy AI search analytics

**Plans supporting Eddy AI analytics**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Eddy AI assistive search analytics empowers you to understand and optimize the performance of AI search in your Knowledge base. The **Eddy AI - Assistive Search** analytics page provides information on the overall Eddy AI performance and search metrics, including unanswered searches of your knowledge base site. Also, you can visualize search analytics through charts and graphs for better understanding.

> NOTE
>
> To know more about the languages supported by Eddy AI, [click here](/help/docs/ai-search-suite#multilingual-support-for-eddy-ai-search-suite).
>
> The Conversational Eddy AI related metrics are available only in **KB site 2.0** projects.

---

## Accessing Eddy AI search analytics

1. Navigate to **Analytics** () >**Eddy AI**in the Knowledge base portal.

   The **Eddy AI - Assistive Search** page will appear.

   You can view a comprehensive overview of article performance for the past week by default, but the filter allows you to select a different date range.

### Using filters to customize data

By default, the data shows metrics for the **last week**. You can adjust this using filters:

1. Click the **Date** filter dropdown.
2. Select a predefined range (e.g., **This month**, **Last month**) or choose **Custom** to specify a date range.

---

### Eddy AI search analytics page overview

> NOTE
>
> If multiple chatbots are deployed, the data from all chatbot instances will be merged and reflected in the results.
>
> Similarly, if multiple knowledge base widgets are in use, data from all widget instances will be combined into the results.

You can view the following article performance metrics as tiles based on the filter applied:

| Field | Description |
| --- | --- |
| **Total conversations** | Total number of conversations in Eddy AI, where one or more Eddy queries count as a conversation. This metric will be available only for Knowledge base site 2.0 where Eddy AI is conversational. A single message is also counted as a conversation. |
| **Total queries** | Total number of queries performed in Eddy AI. Queries are individual questions included in the conversation. |
| **Answered queries** | Total number of queries that returned a result. |
| **Unanswered queries** | Total number of queries that did not produce any results. |

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_ScreenShot-Eddy_AI_analytics.png)

---

### Query analysis

You can interact with the graph to learn more information on query analysis:

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734687587539.png)

1. **Date-wise metrics**: Hover over the graph to find the metrics on a specific date.
2. **Date**: The metrics are shown in month/date format. To view metrics of a different month, click the **This month** dropdown at the top right and make a selection of your choice.
3. **All**: Represents the comparison of answered queries, unanswered queries, and conversations in a single graph.
4. **Answered (green line)**:  Click to view the graph of queries that returned a result.
5. **Unanswered (red line)**: Click to view the graph of queries that did not produce any result.
6. **Conversations (violet line)**:Click to view the graph of conversations. It is available only for KB site 2.0projects. Scroll down to the last section to export **Conversations** in CSV format.
7. **Export image**: To export the Query analysis as an image in .png format.

> NOTE
>
> Try to maintain the **Unanswered** searches as low as possible compared to the **Answered** searches to ensure your readers find the right content when they perform a Knowledge base site search. Unanswered searches typically occur when there is a lack of relevant information in the documentation, causing the Eddy AI to be unable to fetch data for specific search queries. Keeping your documentation up-to-date can help minimise such queries.

---

### Conversation depth metrics

The conversation depth metrics display the graph illustrating the total number of queries per conversation alongside the total number of conversations. Conversation depth metrics are available only for **KB site 2.0** projects.

1. Hover over each bar to see the exact number of conversations.

   The graph tracks conversations ranging from 1 to 5 queries, with conversations exceeding 5 queries grouped under 6+.
2. Click the **Export image** () icon to export Conversation depth metrics as an image in .png format.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734687695576.png)

---

### Feedback chart

The feedback charts display the data illustrating the total number of Likes and Dislikes, along with the percentage information. The total percentage of feedback is represented inside the color chart.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734687719524.png)

Click the **Export image** () icon to export the Feedback as an image in .png format.

---

### Popular queries

This section showcases the top five popular search themes, along with their frequency counts for the selected month. Queries are grouped by keywords, highlighting the most popular topics of the month and the frequency of related questions asked by readers.

> NOTE
>
> The Popular queries metric is generated only if at least one month of data is available.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734687745810.png)

---

### Unanswered queries

This section showcases the top five popular search themes, along with their frequency counts for the selected month. Each keyword represents a popular topic with unresolved searches.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734687764606.png)

> NOTE
>
> Post-processing occurs monthly, where 30 days of data is analyzed. The data is sent to OpenAI, which identifies the most common keywords and groups them into 10 primary topics. Any remaining data that does not fit into these categories is grouped under "Others." This helps to organize and highlight the most frequent topics efficiently. This is done for all the answered and unanswered queries.

---

### Most referenced articles

This section lists the five most-referenced source articles for the selected month, along with how often each has shown as a source in Eddy AI search results.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734687787606.png)

---

### Conversations

This section offers a detailed view of user interactions in a tabular form showing queries, response status, and feedback.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Conversation_table_in_Eddy_AI_Analytics.png)

1. **Search field:** Enter a query to search for a specific conversation or query.
2. **Conversations:**The conversation will appear. By default, only the first question of each conversation is visible, with the other questions collapsed. Click on a desired query to open a pop-up that displays the entire conversation.

   > NOTE
   >
   > If a conversation started last month and continues into this month, the conversation will be included in last month's analytics.
3. **Query topic:** Query topics are fetched from the list of popular queries. A minimum of 30 days of data is required to generate a query topic.
4. **Response:** Indicates the response status, such as answered () or unanswered queries ().
5. **Feedback**: Displays the feedback, such as likes or dislikes.
6. **Filter**: Filter by query topic, response status, feedback type, or application.

   * **Response Status**: Filter the response status by three options: All, Answered, or Unanswered.
   * **Feedback**: Filter the feedback types by four options: All, None, Liked, or Disliked. By default, **All** is selected.
   * **Query type**: Filters queries from previous months. This filter is unavailable for the current month.
7. **Export**: Export the data as a CSV file based on the applied filters.

---

### FAQs

#### **Why am I unable to filter the data on a weekly basis?**

Popular queries and unanswered search keywords are derived from algorithmic grouping methods. These methods require sufficient data to categorize keywords based on the frequency of responses generated.

#### **How do I resolve queries for which no response is generated?**

To address queries that receive no responses, identify the relevant articles based on the keywords derived from unanswered search prompts raised by readers. Update the content of these articles accordingly.

#### **How does Eddy AI conversation analytics fetch information if the conversation is in multiple languages?**

If a conversation includes multiple languages, the conversation will be updated in the conversation table for each language used. However, specific metrics like total searches, answered queries, unanswered queries found, and feedback received will only be updated for the language in which they occurred.

#### **How does Eddy AI conversation analytics fetch information if the conversation is in multiple workspaces?**

If a conversation includes multiple workspaces, it will be updated in the conversation table for each workspace used. However, specific metrics such as total searches, answered queries, unanswered queries, and feedback will only be updated for the languages used within the respective workspace.

#### **How are queries different from conversations?**

Queries are individual questions included in the conversation. One or more queries contribute to a conversation.

<a id="analytics-search"></a>

## Search analytics

**Plans supporting search analytics**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Use Search Analytics to track reader behavior, optimize your content, and identify gaps in your documentation. This page provides metrics on search trends, successful queries, and no-result searches, helping you enhance the search experience for your users.

---

## Accessing the Search analytics page

To access Search analytics, from the Knowledge base portal, navigate to **Analytics** () and then select **Search**.

### Using filters to customize data

By default, the data shows metrics for the last week. You can adjust these using filters:

1. Click the **Date** filter dropdown.
2. Select a predefined range (e.g., **This month**, **Last month**) or choose **Custom** to specify a date range.
3. For private and mixed projects, you can filter the search analytics by All users, Team accounts and Readers. For mixed projects, All users will include Team accounts, private readers and public readers data. The readers filter however will only show the private readers data.
4. If using the **Knowledge base widget**, use the top-right dropdown to switch between **Knowledge base** and **Widget analytics**.
5. Select the JWT widget to track and analyze user interactions and engagement of reader analytics within private and mixed projects secured by JWT authentication.

   For more information on Knowledge base widget JWT authentication, read the article on [Managing the Knowledge base widget](/help/docs/managing-the-knowledge-base-widget).

![Updated_Screenshot-JWT_for_Search_analytics_June_release](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Updated_Screenshot-JWT_for_Search_analytics_June_release.png)

> NOTE
>
> Search analytics data can take up to 15 minutes to reflect in the Knowledge base portal.

---

### Search analytics page overview

The **Search** analytics page shows the below four metric tiles that are also represented graphically in the Search analysis tile.

| Field | Graph color | Description |
| --- | --- | --- |
| **Total searches** | Purple line | The number of searches users perform on the selected project workspace in the Knowledge base site. |
| **Successful searches** | Green line | The searches that returned at least one result. |
| **No result found** | Red line | The total number of searches that did not produce any result. |
| **Bounced** | Yellow line | The searches that returned results, but the user did not click on any of the results. |

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenShot-Search_Analytics.png)

You can interact with the graphs by clicking on the legends at the bottom to view individual data points. Click **Export image** ( ) to save the section as a PNG image.

> NOTE
>
> Aim to keep **No result found** searches as low as possible to improve the overall search success rate.

---

### Search success rate

The **Search success rate** pie chart distinguishes successful and unsuccessful results. The total number of searches is available in the middle of the chart.

* **Successful** refers to the searches that returned results.
* **Failed** refers to the searches that returned no results.

Click **Export image** ( ) to save the section as a PNG image.

![5_Screenshot-Updated_Search_analytics-Search_success_rate](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734687879593.png)

---

### Search and No result found list

#### Searches

This section lists the most searched keywords and provides the following information:

| **Field** | **Description** |
| --- | --- |
| **Search keyword** | The exact term searched by users. |
| **Search count** | Number of times the keyword was searched. |
| **Views** | Number of views associated with search results. |
| **Reads** | Number of reads triggered by the search. |
| **Bounced** | Searches that returned results but were not clicked by users. |

You can sort data using numeric values for better analysis.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734687860119.png)

#### No result found

Displays keywords that did not return any results. The following fields are available:

| **Field** | **Description** |
| --- | --- |
| **Search keyword** | Keyword users searched for. |
| **Search count** | Number of times the keyword was searched. |

---

### Export Search analytics data

1. Click **Export CSV** to download the search analytics.

   Wait for a few seconds. Once the file is ready, a Download icon appears next to the **Export CSV** button.
2. Click on the Download () icon, and the file is saved to your local device storage.

   The downloadable file remains available until a new CSV is generated.

   Hover over the Download () icon to see the last export date and time.

---

## Knowledge base site view

This is how your reader would view the search terms that do not return any results. The reader can provide their feedback similar to the Article feedback on their recent search term. They can provide their email (optional) and choose to be notified of any change.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenShot-Search_analytics.png)

To know more about No search results feedback, read the article on [Feedback manager](/help/docs/feedback-manager-overview).

---

### FAQs

#### **How can Search Analytics help me identify gaps in documentation?**

You can review the list of **No Results Found** search terms, highlighting topics users are searching for but not finding results. This information helps pinpoint areas where documentation may be lacking or unclear.

#### **How does understanding popular search terms benefit my knowledge base?**

Understanding popular search terms helps identify the topics your readers are most interested in or frequently searching for. By analyzing these terms, you can optimize your Knowledge base content, create new articles to address common queries, and ensure your Knowledge base is aligned with your user’s needs.

#### **What is meant by bounced search?**

The Bounced search refers to a situation where search results are displayed to the user, but they do not click on any of the results. This term is used to describe such instances.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The public-facing website where end-users can access articles and find answers to their questions.

A chart legend represents data series in a chart, using colors or symbols to differentiate them. For example, each column of data in a chart is shown in a unique color, with the colors and series names displayed as the legend

<a id="reader-analytics"></a>

## Reader analytics

**Plans supporting readers analytics**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Reader** analytics page provides an overview of reader activity in your Private or Mixed access project. Use this tool to track user engagement and optimize your content strategy.

---

## Accessing the Reader analytics page

To view reader analytics, from the Knowledge base portal, navigate to **Analytics** () and then select **Reader**.

### Using filters to customize data

By default, the data shows metrics for the **last week**. You can adjust this using filters:

1. Click the **Date** filter dropdown.
2. Select a predefined range (e.g., **This month**, **Last month**) or choose **Custom** to specify a date range.
3. If using the **Knowledge base widget**, use the top-right dropdown to switch between **Knowledge base** and **Widget analytics**.
4. Select the JWT widget to track and analyze user interactions and engagement of reader analytics within private and mixed projects secured by JWT authentication.

   For more information on Knowledge base widget JWT authentication, read the article on [Managing the Knowledge base widget](https://docs.document360.com/docs/managing-the-knowledge-base-widget).

![Updated_Screenshot-JWT_for_reader_Analytics_June_release](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Updated_Screenshot-JWT_for_reader_Analytics_June_release.png)

4. To filter readers by their registration type, use the dropdown menu to select All readers, Self-registration, SSO, JWT, and Invited readers.

> NOTE
>
> Reader analytics data can take up to 15 minutes to reflect in the Knowledge base portal.

---

### Reader Analytics page overview

The **Reader** page shows the below three metric tiles, each representing absolute data points reflecting the overall reader analytics. These metrics remain unaffected by any filters applied to the data.

| Field | Description |
| --- | --- |
| **Total readers** | Number of readers added to your project who can access the Knowledge base. |
| **Self-registered readers** | Readers who registered themselves on your Knowledge base site. |
| **Frequent readers** | Readers who frequently access your articles, calculated based on views and reads.If a reader is searched in the reader table using the search field, the reader gets updated in the frequently modified list. |

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Reader_analytics.png)

---

### View reader analytics data

The Reader analytics section displays data for the for the selected duration, including the following fields:

| Field | Description |
| --- | --- |
| **Name** | The profile picture and name of the Reader is available here. This is a clickable field.  Click the reader’s name to view detailed information, including total views, reads, likes, dislikes, and a list of articles they've accessed, along with the average time spent and the last viewed date. |
| **Email** | Displays the email of the reader. |
| **Reader type** | Displays the type of reader based on their mode of registration like Self-registration, SSO, JWT, or Invited readers. |
| **Views** | The number of times an article is accessed is counted once per browser session.   * A view is recorded when an article loads in the browser, regardless of user interaction. * Multiple visits to the same article within a session count as one view, even across tabs or windows or when a user closes and opens the same article within that particular browser session. * Alternatively, if a user opens the same article in a different browser, device, clears the cache & reopens the article or refreshes the browser, they will count as another view. * A browser session resets every 24 hours. Accessing the article after this period will count as another view. |
| **Reads** | An article read is recorded when a user engages through scrolling, clicking, or spending time on the page.The user has to perform all these three actions to count as one read.   * **Scrolling**: At least a single scroll is needed for a valid read. * **Time spent**: Time is tracked only after 40 seconds spent on the article. If a user becomes idle (e.g., stops interacting) for some time or switches tabs, the timer pauses and resumes upon return. * **Session tracking**: Time spent revisiting the same article within 24 hours in the same browser session is added to the previous session's total.   Reads reflect meaningful interaction, distinguishing them from simple page loads. |
| **Last login** | Displays the login date of the reader’s most recent login. Click a reader's name to view their detailed login activity. |

---

### Reader individual contributions

1. Click on a reader to view more detailed information about their contributions:

* **Profile** - Team account name, Image, Email, Portal role, and Last login date and time (UTC time zone).
* **Contribution performance - Total views**, **Total reads**, **Total likes**,and **Total dislikes**.
* **Articles** - Displays a list of **Article names** to which the user has contributed, along with details such as **Views**, **Reads**, **Likes**, **Dislikes**, **Created on**, and **Last updated** date. This table can be exported as a CSV file for download to your local system.

2. Click the **Filter** button at the top to filter the analytics data based on **Article type** (*All*, *Page*, *Article*) and **Date** (*7 days*, *30 days*, *Custom date*).
3. Once done, click **Apply**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-Reader_analytics.png)

---

### Export reader analytics data

1. Click **Export CSV** to download the reader analytics.

   Wait for a few seconds. Once the file is ready, a Download icon appears next to the **Export CSV** button.
2. Click on the Download () icon, and the file is saved to your local device storage.

   The downloadable file remains available until a new CSV is generated.

   Hover over the Download () icon to see the last export date and time.

Single Sign-On - A method that allows users to access multiple applications with one set of login credentials.

<a id="analytics-team-accounts"></a>

## Team accounts analytics

**Plans supporting team accounts analytics**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Team accounts** analytics overview page provides a detailed view of each team member’s account type, the articles or category pages they create or access, their contributions, and last login details.

---

## Accessing the Team accounts analytics page

To view Team accounts analytics, from the Knowledge base portal, navigate to **Analytics** () and then select **Team accounts**.

### Using filters to customize data

By default, the data shows metrics for the **last week**. You can adjust this using the filter:

1. Click the **Date** filter dropdown.
2. Select a predefined range (e.g., **This month**, **Last month**) or choose **Custom** to specify a date range.

> NOTE
>
> Team account analytics data can take up to 15 minutes to reflect in the Knowledge base portal.

---

### Team account analytics page overview

The **Team accounts** page shows the below three metric tiles:

| Field | Description |
| --- | --- |
| **Total team accounts** | Number of team accounts in the project in your Knowledge base excluding the deleted team accounts. |
| **Articles published** | Number of articles published based on the **Date** filter you have chosen. |
| **Top performers** | Profile images of top-performing team members, ranked by the number of articles contributed, are displayed here. |

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Team_account_analytics.png)

---

### View Team account analytics data

The Team account analytics displays data for the selected duration, including the following fields:

| Field | Description |
| --- | --- |
| **Name** | The profile picture and name of the Team account along with its type (normal or SSO) are available here. This is a clickable field.  Click the Team account name to view detailed information, including total views, reads, likes, dislikes, and a list of articles they've accessed, along with the date the articles were created and last updated. |
| **Email** | Displays the email of the reader. |
| **Portal role** | Displays the portal role that is assigned to the Team account (Owner, Contributor, Admin, and more). |
| **Contributed** | Displays the total number of articles contributed by the Team account during the selected time frame. |
| **Last contributed** | The time of the last contribution made by a team account is displayed relative to the current time, such as "4 minutes ago" or "This Monday." For contributions older than a week, the exact date ("Nov 16, 2024") is shown. |

---

### Team account individual contributions

1. Click on a team account to view the detailed information about their contributions:

* **Profile** - Team account name, Image, Email, Portal role, and Last login date and time (UTC time zone).
* **Contribution performance -** Four tiles displaying **Articles created**, **Total views**, **Total likes**,and **Total dislikes**. These metrics exclude the count of deleted articles.
* **Articles** - Displays a list of **Article names** to which the user has contributed, along with details such as **Views**, **Reads**, **Likes**, **Dislikes**, **Created on**, and **Last updated** date. This table can be exported as a CSV file for download to your local system.

2. Click the **Filter** button at the top to filter the analytics data based on **Article type** (*All*, *Page*, *Article*) and **Date** (*7 days*, *30 days*, *Custom date*).
3. Once done, click **Apply**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenShot-Team_accounts_analytics.png)

---

### Export Team account analytics data

1. Click **Export CSV** to download the team account analytics.

   Wait for a few seconds. Once the file is ready, a Download icon appears next to the **Export CSV** button.
2. Click on the Download () icon, and the file is saved to your local device storage.

   The downloadable file remains available until a new CSV is generated.

   Hover over the Download () icon to see the last export date and time.
3. To export the analytics of individual team accounts, click on the team account name and then click **Export CSV** available above the list of article performance details.
4. Click the Download () icon, and the file is saved to your local device storage.

<a id="feedback"></a>

## Feedback analytics

**Plans supporting feedback analytics**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Feedback analytics track total comments, likes, and dislikes for each article/page category. You can find the analytical representation of the feedback data in charts and graphs.

---

## Accessing the Feedback analytics page

To view Feedback analytics, from the Knowledge base portal, navigate to **Analytics** () and then select **Feedback**.

### Using filters to customize data

By default, the data shows metrics for the **last week**. You can adjust this using filters:

1. Click the **Date** filter dropdown.
2. Select a predefined range (e.g., **This month**, **Last month**) or choose **Custom** to specify a date range.
3. If using the **Knowledge base widget**, use the top-right dropdown to switch between **Knowledge base** and **Widget analytics**.
4. Select the JWT widget to track and analyze user interactions and engagement of Feedback analytics within private and mixed projects secured by JWT authentication.

   For more information on Knowledge base widget JWT authentication, read the article on [Managing the Knowledge base widget](https://docs.document360.com/docs/managing-the-knowledge-base-widget).

![Updated_Screenshot-JWT_for_reader_Analytics_June_release](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Updated_Screenshot-JWT_for_reader_Analytics_June_release.png)

> NOTE
>
> Feedback analytics data can take up to 15 minutes to reflect in the portal from the time the feedback is given.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Feedback_analytics.png)

---

### **Feedback analysis**

The graphical representation of the Feedback analysis is shown below.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734801406078.png)

The **Feedback** page shows the below four metric tiles:

| Field | Description |
| --- | --- |
| **Total article** | The number of articles that received some feedback (Like, dislike, or comment) from the readers. |
| **Total feedback** | The number of comments logged. |
| **Total likes** | The number of likes received, that are accompanied by comments from the readers. |
| **Total dislikes** | The number of dislikes received, that are accompanied by comments from the readers. |

![1_Updated_Screenshot-Feedback_analytics-Overview_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734802023945.png)

---

The Feedback analysis displays the following metrics:

| Field | Description |
| --- | --- |
| **Date-wise metrics** | The metrics on a specific date when you hover over the graph. |
| **All** | The graph of all feedback, including articles, likes, and dislikes. |
| **Articles** | The graph of article feedback. |
| **Feedback** | The number of feedback submitted. |
| **Likes** | The graph of likes received. |
| **Dislikes** | The graph of dislikes received. |
| **Export image** | To export the Feedback analysis graph as an image in .png format. |

---

### Feedback metrics

This section displays a graphical representation of reader’s dislike responses, including the specific reasons selected by readers for their feedback. The dislike responses are:

* Need more information
* Difficult to understand
* Inaccurate or irrelevant content
* Missing or broken link
* Others

![4_Screenshot-Updated_Feedback_analytics-Filters_metrics](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734802120667.png)

#### Custom feedback messages

The dislike responses mentioned above are the default system responses. You can change the response on the **Localization variables** page and also view the total count for each type of dislike response selected by readers.

Navigate to **Settings**()> **Knowledge base portal** > **Localization & Workspaces** > **Localization variables**.

For more information, read the article on [Localization variables](/help/docs/localization-variables).

---

### Feedback list

Here, the list of articles, along with the feedback information, is displayed. The information available in this section are

* Article name
* Proportion (Likes vs. Dislikes out of 100)
* The total article views in the selected time frame
* Likes received with feedback or comments
* Dislikes received with feedback or comments
* Feedback or comments received

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734802145188.png)

The actions you can perform from this section are:

* **View in Knowledge base**: This appears next to the article name when you hover over it. Click on this, and the article opens the Knowledge base site in a new browser tab.
* **View feedback**: This appears at the end of the row when you hover your pointer over the article. Clicking **View feedback** redirects you to the **Feedback manager**.
* **Filter**: You can filter the list based on articles, page categories, or both.
* **Export CSV**: Click **Export CSV** to download the reader analytics.

  Wait for a few seconds. Once the file is ready, a Download icon appears next to the **Export CSV** button.

  Click on the Download () icon, and the file is saved to your local device storage.

  The downloadable file remains available until a new CSV is generated.

  Hover over the Download () icon to see the last export date and time.

---

### FAQ

#### **Are feedback submissions without comments included in the metrics displayed on the Feedback Manager tiles?**

No, Any feedback without a comment will not appear in the metrics reflected on the Feedback Analytics tiles. Only feedback submissions that include both a thumbs up/thumbs down response and a comment are counted in the **Feedback analytics** data.

The public-facing website where end-users can access articles and find answers to their questions.

<a id="links-status"></a>

## Links status analytics

**Plans supporting analytics on link status**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Links status** is a sub-feature under the Analytics section of Document360. This feature is a broken link checker that helps validate and monitor all internal, external, and media file links on the knowledge base. It allows you to fix bad/broken links to improve Search Engine Optimization (SEO) and enhance the reader experience.

With the following validations, you can run the link validation at a workspace and language level.

1. **Scheduled validation**
2. **Manual validation**
3. **Article level validation**

> NOTE
>
> For manual and scheduled validation, all the links at the project level are analyzed to check for broken, unknown, or working links.

---

## Accessing the Links status analytics page

To view the Link status analytics, from the Knowledge base portal,

1. Navigate to **Analytics** () and then select **Link status**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Link_status_analytics.png)

---

## Links status overview page

This page contains all the necessary data regarding the links used in your Knowledge base (selected workspace and language). You have two sections on the page: **Links status tiles** and **Links list**.

### 1. Links status tiles

![Image showing links status overview page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Link_analytics.png)

#### Links classification

| Field | Description |
| --- | --- |
| **Total links** | The total number of URLs and files (both internal and external) linked in the different articles on your Knowledge base. |
| **Internal** | The total number of Internal URLs including article links and media file links within your Document360 project. |
| **External** | The total number of External URLs including article links and media file links outside your Document360 project. |
| **Ignored** | The links you want to ignore in the current validation or upcoming validation. |

#### Current state

| Field | Description |
| --- | --- |
| **Redirect URL** | When the link has been temporarily or permanently routed to a different URL. |
| **Working** | The link works fine and points to an intended webpage or file (Internal and External). |
| **Broken** | A broken or dead link is a hyperlink in the article that no longer works because it's encountering one or more issues like URL changes, incorrect URL, page or item removed, or restricted/private knowledge base article URL. Broken status applies to URLs and media files. |
| **Unknown** | The link that does not return a status. |

#### Broken link/image

When a broken link or an image file is accessed:

* **Link** – When the reader clicks on a broken link, a 404-page error or similar message showing that the webpage is unavailable is displayed.  
  ![8_Screenshot-Links_status_404_error_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Links_status_404_error_page.png)
* **Media files** – In the case of an image or video file, a broken image thumbnail icon would be displayed in place of it in the article.  
  ![9_Screenshot-Links_status_Broken_media_file](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Links_status_Broken_media_file.png)

---

### 2. Links list

The list of all links used in the entire workspace is displayed below the Links status section. You can find the following information about the links used.

![Image showing list of links used in a workspace](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Link_analytics.png)

| Field | Description |
| --- | --- |
| **Article name** | The article name in the Knowledge base that contains the link. |
| **Link type** | **Links**: Internal link, External link, Secured link, Unsecured link **Media files**: Internal file, and External file. |
| **URL** | The actual web link (destination URL) |
| **Redirect URL** | If the existing source path has been redirected to a new destination. |
| **Status** | Indicating the status of the link. **Working**, **Broken**, **Redirected**, or **Ignored**. |

> NOTE
>
> If you have deleted an article after the validation and the report has been generated, the article is grayed out. A trash icon appears next to the article name.

---

### Filters for Links list

The **Filter** button at the top of the Links list section is useful when you have a greater number of links. You can filter links based on four parameters: the **Source**, **Visibility**, **Link type**, and **Status**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734802570175.png)

Once you have selected the filter, click **Apply**.

You can also apply filters directly by clicking on the Link status tile that you prefer to view. For example, when you click on the **Broken** or **External** link status tile, the respective links with the link type or status are displayed in the list.

---

### Export Links list analytics data

1. Click **Export CSV** to download the Link analytics.
2. Click on the Download () icon next to the **Export CSV** button, and the file is saved to your local device storage.

   The downloadable file remains available until a new CSV is generated.

   Hover over the Download () icon to see the last export date and time.

---

## Actions and controls

Above the Links status sections, you can find the controls and data regarding the link analytics.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734802611737.png)

#### a. Validation type

The validation types are **Scheduled**, **Manual**, and **Article level**.

#### b. Report date

* The date of the reports generated will be loaded here. The validation reports are named as per the generation date.
* When you hover over the info () icon adjacent to the **Report data** dropdown, you can view the next or upcoming Scheduled link validation date.

  > NOTE
  >
  > Scheduled link validation runs every 7 days hence only the latest weekly data is shown.

#### c. Manage links

* This button opens the **Manage links** window.
* This window contains information about all the links used, and also those which are **Ignored** or **Included** in the validations under respective tabs.

#### d. Validate links

* This button initiates the Manual link validation at the project level.
* When you click **Validate links,** a confirmation prompt pops up to alert you with the number of manual validations left for the month.
* To proceed, click **Confirm**.

#### e. Manual validation usage

* This status bar shows your project's available Manual validation limit as per your project plan. The limit resets every month.
* The link status validation limit applies to both internal and external links.
* Customers of all price tiers can opt for an increase in the link validation limit anytime based on their requirement for a nominal charge.
* For additional information, contact our [**support team**](https://document360.com/contact-us/).

#### f. Link analytics usage

This status bar shows the stats of the link limit used out of the total limit for your project.

> NOTE
>
> The link validation limit for the plans that support analytics on link status are:
>
> Business plan - 5000 links
>
> Enterprise plan - 10000 links

### Links analytics limit exceeded

When the links count is higher than the total count of links limited for your project, the **Links analytics limit exceeded** text appears instead of the **Link analytics usage**.

* When the link analytics limit is exceeded, and the links validation (both Scheduled and Manual validation) takes place, only the links under the total given limit are validated.
* The extra links that exceed the limit are not validated. Article-level validation is also not possible for those links.

  For example, your total link limit is 10000, but the total link count in your project is 10500. Only the first 10000 links are validated when you perform the links validation. The recently added 500 links are not validated.
* To validate all the links in your project, contact our [**support team**](https://document360.com/contact-us/) to increase the limit for your project.

---

## Link validation

You can perform link validation at a workspace and language level in the below ways,

1. Scheduled validation
2. Manual validation
3. Article level validation

> NOTE
>
> For manual and scheduled validation, all the links at the project level are analyzed to check for broken, unknown, or working links.

### 1. Scheduled validation

This is an automated link validation that runs on a **Schedule**, based on your plan tier.

#### Steps to perform schedule validation

1. On the Knowledge base portal, click on the Analytics () icon on the left navigation sidebar.
2. Click **Links status** on the left navigation pane.
3. The Links status overview page appears.
4. From the **Validation type** drop-down at the top, select the **Scheduled** validation (which is the default selection for your projects).
5. You can find the recently generated Scheduled link validation.
6. If you want to look into any previous reports, from the **Report date** drop-down select the report date you wish to view.

### 2. Manual validation

#### Steps to perform manual validation

1. On the Knowledge base portal, click on the Analytics () icon on the left navigation sidebar.
2. Click **Links status** on the left navigation pane.
3. The Links status overview page appears.
4. From the **Validation type** drop-down at the top, select **Manual** validation.
5. The latest Manual validation report list will appear.
6. Click **Validate links** at the top right to perform a new manual validation.

   > NOTE
   >
   > The analytics report for links is generated every 24 hours (UTC 00:00). If you run consecutive Manual validations within 24 hours, the already run manual validation reports are overwritten with the latest validation data. Once generated, data cannot be retrieved.
7. Once the validation is complete, you will receive a mail on your registered email, and you can view the analytics report on the overview page.

   > NOTE
   >
   > Only team member roles with the Validate link analytics permission can perform link validations.

### 3. Article level validation

When choosing the **Article level validation** from the **Validation type** drop-down, you can view the article/category-page link validations you have already run. This overview page will be empty if you haven't validated links at the article/category page level.

#### Validate links at the article/category-page level

The article/category-page level link validation can be done from the article **editor** section.

1. Navigate to the desired article/category page in the Knowledge base portal.
2. Click on the More () icon at the top right.
3. Click **Analytics** from the listed options.

   The **Article analytics** modal window appears.
4. Click **Validate now** to perform validation.

   > NOTE
   >
   > The article/category-page link validation is unlimited.

---

## Manage links

Click **Manage links** on the Links status overview page.

The **Manage links** overview page will appear.  
This section provides a high-level view of all the top metrics in the broken links.

* **Search** - You can search for a specific URL.
* **Link type** - Refers to whether the link is an External or Internal URL.
* **Dependency** - The number of times the link has been referenced in the Knowledge base articles.
* **Status** - To choose to see if a link is Ignored or Included.

### Add links to Ignore/Include list

1. In the **Manage links** window, select the checkbox of the desired links you wish to ignore or include.
2. In the status column, you can set the status to **Ignored** or **Included** from the dropdown.

   (or)
3. Select the checkbox of the desired link of which you wish to change the status.
4. Click on the **Ignore** option available above the links list.

   The links that are set to Included status will be displayed in the **Included** tab, and the links set to Ignored status will be displayed under the **Ignored** tab.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_ScreenShot-Links_status_analytics.png)

### Export

You can export the links into .csv format to your local storage.

1. Click on the **Export CSV** button above the links list.
2. Wait for a few seconds, and a Download ()icon appears next to the **Export CSV** button.
3. Click on the Download () icon, and the exported file will be downloaded to your local computer storage.

---

## Troubleshooting

### Working links appear as broken in the Link status report

Document360 enforces a 5-second validation timeout for link verification. If a request exceeds this limit, the system may flag the link as **Unknown** or **Broken**. Even if the link is functional, it may be incorrectly marked as broken due to the timeout restriction.

**Steps to resolve:**

1. **Manually check the URL**

   1. Open the link in a browser to confirm if it loads correctly.
   2. If the page loads, the link may have been incorrectly flagged as broken.
2. **Validate the link using Postman**

   3. Open Postman and create a new request tab.
   4. Enter the URL and select the **GET** method.
   5. Click **Send** to check the response status.
3. **Interpret the HTTP response status**

   6. If the response is **200 OK**, the link is functional.
   7. If the response code is anything other than **200**, the link might be broken.

![Postman interface showing a GET request with highlighted parameters and response status.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-Troubleshooting_Link_status_validation_.png)

Some of the important status codes are:

| **Status code** | **Status description** | **Description** |
| --- | --- | --- |
| **200 OK** | Success | The request was successful, and the expected response was returned. |
| **201 Created** | Resource created | The request was successful, and a new resource was created. |
| **204 No content** | No response body | The request was successful, but there is no response body (common for DELETE requests). |
| **400 Bad request** | Invalid request | The request has incorrect syntax or missing parameters. |
| **401 Unauthorized** | Authentication required | The request lacks valid authentication credentials (e.g., missing or incorrect API key). |
| **403 Forbidden** | Access denied | The request is valid, but the user does not have permission to access the resource. |
| **404 Not found** | Resource missing | The requested resource does not exist or the endpoint is incorrect. |
| **405 Method not allowed** | Invalid method | The HTTP method (GET, POST, etc.) is not allowed for this endpoint. |
| **500 Internal server error** | Server issue | A generic error indicating something went wrong on the server. |
| **502 Bad gateway** | Invalid response | The server received an invalid response from an upstream server. |
| **503 Service unavailable** | Server overloaded | The server is down or overloaded with requests. |
| **504 Gateway timeout** | Timeout error | The server did not receive a response from another service in time. |

If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

---

### FAQs

#### What is the purpose of the Links status feature in Document360?

The Links status feature is a broken link checker that helps validate and monitor all internal, external, and media file links on the knowledge base, improving SEO and reader experience.

#### What happens when a user exceeds the Manual validation limit?

When you exceed the validation limit as per your plan, the **Validate links** button will be disabled. The manual validation resets on the first day of every month, and the button is enabled again. You can contact our customer support if you need to increase this limit.

#### How can I prevent specific example links from being flagged as broken in the link status report?

If you have examples or placeholder links in your articles that are being detected as broken links in the analytics, you can exclude these links from validation to avoid confusion.

1. Navigate to **Analytics** () > **Link status**.
2. On the **Link status** page, click **Manage links** in the top-right corner.
3. In the **Manage links** page, by default, the **All links** tab will be selected.
4. Select the links you want to **ignore** from the list or use the search bar to find them.
5. Once you have selected the desired links, click **Ignore** ().

   The ignored links will be moved to the Ignored tab and will no longer appear in link validation reports.

If you want to include these links back in the validation process later:

1. Go to the **Ignored** tab.
2. Select the links you wish to include again.
3. Click **Include** (), and these links will be validated in future link checks.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="ticket-deflector-overview"></a>

## Ticket deflector analytics

**Plans supporting the use of ticket deflector**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Ticket deflector** analytics page provides an overview of all key metrics related to the ticket deflector form(s) in your Knowledge base site or widget.

---

## Accessing the Ticket deflector analytics page

To view Ticket deflector analytics, from the Knowledge base portal, navigate to **Analytics** () and then select **Ticket deflector**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Ticket_deflector_analytics.png)

### Using filters to customize data

By default, the data shows metrics for the last week. You can adjust these using filters on both **Ticket deflector** and **Feedback** tabs:

1. Click the **Date** filter dropdown.
2. Select a predefined range (e.g., **This month**, **Last month**) or choose **Custom** to specify a date range.
3. For private and mixed projects, you can filter the search analytics by All users, Team accounts, and Readers.
4. If using the **Knowledge base widget**, use the top-right dropdown to switch between **Knowledge base** and **Widget analytics**.
5. Select the JWT widget to track and analyze user interactions and engagement of reader analytics within private and mixed projects secured by JWT authentication.

   For more information on Knowledge base widget JWT authentication, read the article on [Managing the Knowledge base widget](/help/docs/managing-the-knowledge-base-widget).

![Updated_Screenshot-JWT_for_Search_analytics_June_release](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Updated_Screenshot-JWT_for_Search_analytics_June_release.png)

> NOTE
>
> Search analytics data can take up to 15 minutes to reflect in the Knowledge base portal.

---

### Ticket deflector tab

This is the default tab on the **Ticket deflector** analytics page. The **Ticket deflector** page shows the below four metric tiles:

| Field | Description |
| --- | --- |
| **Total feedback** | The total number of feedback entries including the responses from the Knowledge base and the number of forms submitted. |
| **Answered from knowledge base** | The number of queries answered by articles in the knowledge base. |
| **Form submitted** | The total number of ticket deflector forms submitted. |
| **Total search** | The total number of searches performed on the **Quick support** page of the Knowledge base. |

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734869391552.png)

---

## Sections of Ticket deflector tab

The **Ticket Deflector** tab displays various sections, each highlighting different aspects of its performance.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734869409488.png)

### 1. Satisfaction analysis

This graph shows the percentage of ticket deflector forms submitted and queries answered from the knowledge base. You can interact with the graphs by clicking on the legends at the bottom:

| Field | Description |
| --- | --- |
| **All** | Click to view the total number of feedback entries including the responses from the Knowledge base and the number of forms submitted. |
| **Form submitted** | Click to view the total number of ticket deflector forms submitted. |
| **Answered from knowledge base** | Click to view the total number of queries answered by articles in the knowledge base. |

1. Hover over the graph to find the metrics.
2. Click **Export image** ( ) to save the section as a PNG image.

---

### 2. Frequently selected questions

This section displays the top five most frequently chosen questions from the ticket deflector form. The list shows the questions and how often they were selected. You can export this list using the export () icon.

---

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Ticket_deflector_analytics.png)

### 3. Satisfaction

This section displays a pie chart showing the proportion of forms submitted (orange color) and the number of questions successfully answered by the Knowledge base (green color).  
Click **Export image** ( ) to save the section as a PNG image.

---

### 4. Most useful articles

This section highlights the top articles that were helpful in resolving queries which represents the queries that produced successful search results. It provides the following details:

* **Articles**: The title of the article.
* **Answered**: The number of queries the article helped resolve.

---

### 5. Keywords

In this section, you can view data related to specific keyword searches. The following information is available:

* **Keyword**: The keyword searched by the user.
* **Count**: The number of times the keyword was searched.
* **Answer found**: Indicates whether a suitable answer was found.
* **Answer not found**: Indicates whether the search failed to return an answer.

1. Click **Export CSV** to export the articles in the list.
2. Click the **Download** () icon to download the last exported file.

---

### 6. Search success rate

This section shows the percentage of searches performed using the selected ticket deflector form(s). The chart displays the percentage of successful and unsuccessful searches. Searches that generate results are classified as successful, while those that yield no results are considered unsuccessful.

Click **Export image** ( ) to save the section as a PNG image.

---

## Feedback tab

* The **Feedback** tab displays all user feedback related to ticket deflector forms. Each feedback entry is labeled to indicate its source, such as **Form Submitted** or **Answered from Knowledge Base***.*
* Each feedback entry displays the date and time (in minutes) it was received.
* Click open a feedback to view the feedback content.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734869658688.png)

---

### FAQs

#### What is a ticket deflector?

A **ticket deflector** is a feature designed to reduce the number of support tickets by providing users with relevant Knowledge base articles before they submit a ticket. When users begin filling out the ticket form, the system suggests helpful articles that might answer their questions, deflecting the need to raise a support request.

#### How does the ticket deflector work?

The ticket deflector suggests relevant knowledge base articles based on keywords from the user's query or question. As users type into the form, the system automatically searches the knowledge base and displays suggested articles that may provide the solution, potentially preventing ticket submission.

#### What does the ‘*Answered from Knowledge Base’* metric represent?

The Answered from Knowledge Base metric shows the number of queries that were successfully resolved by the suggested articles in your knowledge base, without the user needing to submit a ticket. This helps measure the effectiveness of your knowledge base in reducing support requests.

#### How can I improve the effectiveness of the ticket deflector?

To improve the effectiveness of the ticket deflector:

* Ensure your knowledge base is up to date with accurate and comprehensive articles.
* Use clear and relevant keywords in your articles to improve searchability.
* Regularly review and update the **Frequently selected questions** section to better address common user queries.
* Analyze the **Search Success Rate** to identify gaps in your knowledge base and add or improve articles accordingly.

#### How is the Search success rate calculated?

The **Search Success Rate** represents the percentage of searches that returned a relevant article for the user's query. It compares the total number of searches performed with the number of successful searches that resulted in the user finding a helpful article.

A chart legend represents data series in a chart, using colors or symbols to differentiate them. For example, each column of data in a chart is shown in a unique color, with the colors and series names displayed as the legend

<a id="manage-api-documentation"></a>

## Managing API documentation

**Plans supporting  API document generation**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The API documentation feature in Document360 makes it easy to create clear, interactive documentation by uploading your API specification files. This process automatically builds detailed documentation that covers everything from API endpoints to methods and responses, helping developers understand and use your API more effectively.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-New_API_button.png)

## Generating API documentation

There are three methods to generate API documentation in Document360:

* **From a URL**
* **From a JSON/YAML file**
* **With a CI/CD flow**

> NOTE
>
> Document360 supports OpenAPI 2.0, OpenAPI 3.0, and Postman API specifications.

### Generating API documentation from a URL

To upload the API specification file as a URL to Document360,

1. Navigate to the desired project in the Knowledge base portal.
2. Select **API documentation** (**{}**) from the left navigation bar.
3. Click the **Create** dropdown from the header menu bar and select **New API** or click the **New API** button from the top right corner. This will display the **New API reference** side panel.
4. In the **Choose source** screen, select the **Create from URL** radio button, and click **Next**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Create_API_from_URL.png)

5. In the **Source settings** screen, enter the URL for your API specification file in the **URL** field.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-URL_field.png)

6. Click **Add API reference** to navigate to the **Finish** screen.
7. On the **Finish** screen, you will be able to see the number of categories and articles that have been created for your API specification file.
8. Click **Publish** to generate your API documentation.

> NOTE
>
> If you wish to verify your API documentation before publishing, click **Close** on the Finish screen to return to the Documentation screen. You will be able to see the drafts of your API documentation in the **Categories & articles** pane.

### Generating API documentation from a JSON/YAML file

To upload the API specification file from a JSON/YAML file to Document360,

1. Navigate to the desired project in the Knowledge base portal.
2. Select **API documentation** (**{}**) from the left navigation bar.
3. Click the **Create** dropdown from the header menu bar and select **New API**. This will display the **New API reference** side panel.
4. In the **Choose source** screen, select the **Upload API definition** radio button, and click **Next**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Create_API_from_JSON_YAML.png)

5. In the **Source settings** screen, upload the API specification file in either JSON or YAML format.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Upload_API_definition.png)

6. Click **Add API reference** to navigate to the **Finish** screen.
7. On the **Finish** screen, you will be able to see the number of categories and articles that have been created for your API specification file.
8. Click **Publish** to generate your API documentation.

> NOTE
>
> To review your documentation before publishing, click **Close** to return to the Documentation screen. Your draft will be visible in the **Categories & Articles** pane.

### Generating API documentation with a CI/CD flow

Before you upload an API specification file with a CI/CD flow, ensure that the latest version of Node.js is installed on your system. If you are unfamiliar with Node.js, refer to [this guide](https://nodejs.org/en/learn/getting-started/how-to-install-nodejs) for installation instructions.

Next, from command prompt, install the d360 npm with the following command: `npm install d360 -g`

To upload the API specification file with a CI/CD flow,

1. Navigate to the desired project in the Knowledge base portal.
2. Select **API documentation** (**{}**) from the left navigation bar.
3. Click the **Create** dropdown from the header menu bar and select **New API**. This will display the **New API reference** side panel.
4. In the **Choose source** screen, select the **CI/CD Flow** radio button, and click **Next**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Create_API_with_CI_CD_flow.png)

5. Copy the API token from the **Source settings** screen.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-CI_CD_flow_API_key.png)

6. Paste the API token in the command line tool.
7. Choose the spec file path

   * For **JSON/YAML** file: Type your spec file's directory path in the "`--path`" parameter
   * For **URL**: Type your spec file URL in the "`--path`" parameter
8. Your API specification file will be imported, and API documentation will be generated

---

## Regenerate API documentation

If you make any changes to your API, such as adding any endpoints, you do not need to manually update your API documentation in Document360. You can simply regenerate your API documentation, and any changes in your API will automatically reflect in the API documentation.

> NOTE
>
> Any custom content you add to your API documentation will be retained when you regenerate your API documentation.

### Regenerate API documentation from URL

1. Navigate to the desired project in the Knowledge base portal.
2. Select **API documentation** (**{}**) from the left navigation bar.
3. Click **API docs reference** from the left navigation list pane.
4. Click the more (•••) icon next to the desired API reference for which you want to regenerate the API documentation.

   1. **To regenerate API documentation from the existing URL**:

      * Click **Resync.**
      * The API documentation will be regenerated as per the latest API specification file.
   2. **To regenerate API documentation with a new URL**:

      * Click **Edit.**
      * Enter the new URL in the **URL** field.
      * Click **Update.**
      * The API documentation will be regenerated as per the API specification file in the new URL.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Resync_API_URL.png)

### Regenerate API documentation from an API specification file

1. Navigate to the desired project in the Knowledge base portal.
2. Select **API documentation** (**{}**) from the left navigation bar.
3. Click **API docs reference** from the left navigation list pane.
4. Click the more (•••) icon next to the desired API reference for which you want to regenerate the API documentation.
5. Click **Edit**.
6. Upload the latest API specification file in JSON/YAML format.
7. Click **Update**. The API documentation will be regenerated as per the latest API specification file.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Update_JSON_YAML_file.png)

### Regenerate API documentation integrated with CI/CD flow

You can resync the API reference in your CI/CD pipelines with the help of your [d360 npm packages](https://www.npmjs.com/package/d360). D360 is the command line tool that helps you set up workflows that sync your API docs to Document360.

You can also perform the resync manually using the below command.

```
d360 apidocs:resync 
                    --apiKey=API_key_value
                    --userId=user_id_value
                    --apiReferenceId=API_reference_value
                    --path=Spec_file_path
```

Plain text

Copy

---

### FAQs

**Can I keep the generated API documentation in the draft state?**

After uploading the API reference file, if you click **Close** instead of **Publish**, all the generated API documentation articles are kept in the draft state.

**Can I move a specific API endpoint article from one API reference folder to another in Document360?**

No, it is not possible to move a specific API endpoint article from one API reference folder to another. However, you can move API endpoint articles between subfolders within the same API reference folder.

**Can an article from the API documentation have the same URL as a Knowledge base articles?**

No, a knowledge base article and an API documentation article cannot have the same URL. However, you can keep them under the same subdomain.

**How often is an API reference file resynced?**

If you generated your API documentation from a URL, or a JSON/YAML file, the API reference file is not resynced automatically, and will have to be updated manually. If you want the API reference file to be resynced automatically, it is recommended to integrate the API reference file with CI/CD flow.

---

## Helpful links

* [**d360 npm package link**](https://www.npmjs.com/package/d360)
* [**Source code**](https://github.com/document360/d360)

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="edit-clone-and-delete"></a>

## Edit, Clone, and Delete widget

**Plans supporting editing the knowledge base widget**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You can easily manage your Knowledge base Widget in Document360, as all the options are available in just a few clicks away.

## Edit Knowledge base Widget

1. Navigate to **Knowledge base Widget** in the Knowledge base portal.
2. Hover on the desired Knowledge base Widget and click () **Edit**.

![1_editwidget.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_editwidget.png)

3. Update the desired configurations in the **Configure & connect** tab.

![2_editwidget.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_editwidget.png)

4. Click **Save** to confirm the changes.

---

## Clone Knowledge base Widget

1. Navigate to **Knowledge base Widget** in the Knowledge base portal
2. Hover on the desired Knowledge base Widget that you want to clone.
3. Click (

   ) **Clone**.

![2_KBWidget_clone.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_KBWidget_clone.png)

4. Specify a title and update the desired configurations in **Configure & connect** tab.

![5_KBWidget_confirmclone.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_KBWidget_confirmclone.png)

5. Click **Save**.

---

## Delete Knowledge base Widget

1. Navigate to **Knowledge base Widget** in the Knowledge base portal.
2. Hover on the desired Knowledge base Widget that you want to delete.

![3_KBWidget_delete.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_KBWidget_delete%281%29.png)

3. Click (

   ) **Delete**.

![4_KBWidget_deletewidgetsetting.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_KBWidget_deletewidgetsetting.png)

4. Click **Yes** in the confirmation prompt. Click **No** to undo the process.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="managing-and-customizing-the-knowledge-base-widget"></a>

## Managing and customizing the Knowledge base widget

**Plans supporting knowledge base widget**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## Customizing the knowledge base widget

You can customize each knowledge base widget to improve the user experience.

![1_Screenshot-Overview_page_of_KNowledge_base_Widget](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Edit_kb_widget.png)

1. Log in to the Knowledge base portal and select your desired project.
2. Navigate to the **Widget ()** tab from the left navigation sidebar. The list of widgets created by the user will be displayed.
3. Hover over the desired widget and click the **Edit** (✎) icon.
4. In the **Configure & connect** tab, expand the **Style widget** section.
5. The following widget customization options are available:

   * [Widget color](/help/docs/styling-the-in-app-assistant#widget-color)
   * [Widget icon](/help/docs/styling-the-knowledge-base-widget#b-widget-icon)
   * [Widget position](/help/docs/styling-the-knowledge-base-widget#c-widget-position)
   * [Hide widget](/help/docs/styling-the-knowledge-base-widget#d-hide-widget)
   * [Hide most searched articles](/help/docs/styling-the-in-app-assistant#hide-most-searched-articles)

![2_Screenshot-Style_your_widget](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Edit_widget_style_widget_section.png)

### Widget color

You can choose the knowledge base widget theme color. This color is also set as the widget icon color.

1. Click **Change color** to open the color palette.
2. Select a color from the color picker or enter a hex, RGB, or HSL color code.

### Widget icon

Similarly, under the widget color section, you can replace the icon with an image or an available icon.

1. Click the **Change icon** button.
2. Choose an icon from the **Icon set** tab or insert an image from the **Insert image** tab:

   * To insert an image from a URL: Paste the URL and click **Insert.**
   * To upload an image: Click **Upload an image** and select a file from your Drive.

### Widget position

Choose the position of the widget launcher on your website or application.

1. Select **Left** or **Right** to change the widget position.
2. Enter the desired spacing values in the **Side spacing** and **Bottom spacing** fields to position the widget from the side or bottom of the window.

### Hide widget

When toggled on, the Knowledge base widget will be hidden.

NOTE

* The Knowledge base widget is enabled by default.
* To unhide a Knowledge base widget, turn off the **Hide widget** toggle and click **Save**.

### Hide most searched articles

When toggled on, the top search article section will be hidden.

> NOTE
>
> Enabling **Hide top search** disables the URL mapping functionality for the widget.

Once you complete making the desired customizations to the knowledge base widget, click the **Save** button next to the **Widget name** field.

---

## Adding a ticket deflector in Knowledge base widget

To add a ticket deflector to your Knowledge base widget,

1. Log in to the Knowledge base portal and select your desired project.
2. Navigate to the **Widget** tab from the left navigation sidebar. The list of widgets will be listed.
3. Hover over the desired widget and click the **Edit** (✎) icon.
4. In the **Configure & connect** tab, expand the **Ticket deflector** section.
5. Enable the **Show ticket deflector** toggle.
6. Select the desired ticket deflector.
7. If required, update the **Menu name field**.
8. Click the **Save** button next to the **Widget name** field.

![3_Screenshot-Ticket_deflector_in_KB_Widget](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Edit_widget_ticket_deflector.png)

Once you enable the ticket deflector toggle and click **Save**, the ticket deflector is added to the knowledge base widget.

---

## Content access for the Knowledge base widget

You may want to show only particular articles or hide some articles in your Knowledge base. You can do this effectively with the **Content access** option.

NOTE

The **autosave** option is available for navigation between the Knowledge base widget tabs.

---

### Restricting content access in a Knowledge base widget

To restrict content access in a knowledge base widget,

1. Navigate to **Knowledge base widget** () in the Knowledge base portal.
2. Hover on the desired Knowledge base Widget and click **Edit** ().

![1_filterwidgetcontent_workspace.gif](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_filterwidgetcontent_workspace%282%29.gif)

3. In the **Configuration & connect** tab, expand the **Content access** section.
4. You have three options:

   1. Project
   2. Workspace
   3. Category

#### Project

When you select **Project**, all the articles in the Knowledge base appear in the Widget.

> Project is selected by default.

---

#### Workspace

You can make the desired language(s) or workspace(s) appear in the Widget.

> **For example**, you want to select a different workspace with a specific language.

1. Select **Workspace** to view the list of available workspaces and languages.
2. Select the checkbox of the desired workspace(s) and language(s), and Click **Save**.

---

#### Category

You can make the desired categories appear in the Widget.

> **For example**, you want to show only the **Sales** categories in the Widget.

1. Click **Category** and select the workspace in the **Choose category**.
2. The list of categories available in the specific workspace appears, select the checkbox of the desired categories.  
   ![2_filterwidgetcontent_category.gif](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_filterwidgetcontent_category.gif)
3. If you want to add more categories from other workspace, expand the **Workspace(s)** to choose the desired categories.
4. Click **Save**.

---

> CAUTION
>
> **Changes in content access will directly affect your URL mapping**
>
> * If you make a change related to the configured URL mapping, the URL mapping will be **disabled** and appear as broken.
>
> > **For example**, you have set the filter Widget content at the project level and configured a URL mapping with a List of articles from category A in workspace V1. Now you are updating the Filter Widget configuration to show only the categories B and C in workspace V1. With this action, the URL mapping will be invalid. This is because the articles you configured in URL mapping will not appear in the Knowledge Base Widget.
>
> ---
>
> * In the URL mapping window, you can only configure articles that are made available in the Filter widget content.
>
> > **For example**, you have set the filter Widget content at the workspace level to show only workspace V1. In this case, you cannot configure a URL mapping with an article available in workspace V2.

---

## Domain restriction

Document360 lets you restrict the Knowledge Base Widget to specific domains.

Once a domain is added to the **Widget security** list, and if a project member wants to install the Knowledge Base Widget on a different domain, they will need to add that domain in the **Widget security** section.

If no domains are added to the list, the Knowledge base Widget can be added to any SaaS application or public website.

### Restrict the Knowledge base widget to a specific domain

To restrict your Knowledge base widget to a specific domain,

1. Navigate to **Knowledge base Widget** in the Knowledge base portal.
2. Hover on the desired Knowledge base Widget and click () **Edit**.

![1_domain_restriction.gif](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_domain_restriction.gif)

3. In the **Configure & connect** tab, expand the **Widget security** section. You can find the list of domains previously added (if added).
4. Enter the domain where you want the Knowledge base Widget to be displayed.

NOTE

The "www" is not a valid part of your domain. Only add what comes after the www. in your URL.

> **For example**: *document360.com*

5. Click **Add** and click **Save**.

NOTE

The **autosave** option is available for navigation between the Knowledge base Widget tabs.

---

## Adding custom links

Need to add a download link to an eBook or Google Sheets?  
You can direct an end user by adding a custom link to the Knowledge base Widget.

![2_addingcusotmlinks.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_addingcusotmlinks.png)

Links are added as a "section" to your Widget. They will be placed in the order they are added, underneath the **Top search articles** section.

To add a custom link,

1. Navigate to **Knowledge base Widget** in the Knowledge base portal.
2. Hover on the desired Knowledge base Widget and click (  ) **Edit**.
3. In the **Installation & Setup** tab, expand the **Add custom links** section.
4. In the **Add Custom Links**  section:

   * Type the title for your section
   * Type the display text for the link

     > **For example,** **Contact Us**
   * Type the URL link

     > **For example,** https://support.document360.com
5. Click the adjacent icon and choose the desired icon from the available options.
6. Click **Add** > **Save**.

![1_addlinks.gif](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_addlinks.gif)

**NOTE**

You can use a `mailto:` in the link field. For example: `mailto:<youremail@somedomain.com>`

### Edit a custom link

1. Navigate to **Knowledge base Widget** in the Knowledge base portal.
2. Hover on the desired Knowledge base Widget and click () **Edit**.
3. In the **Configuration & connect** tab, expand the **Add links** section.
4. In the **Add Links** section, locate the custom link you wish to edit.
5. Click () **Edit** and update the desired fields.
6. Click **Save**.

### Deleting a custom link

1. Navigate to **Knowledge base Widget** in the Knowledge base portal.
2. Hover on the desired Knowledge base Widget and click () **Edit**.
3. In the **Configuration & connect** tab, expand the **Add links** section.
4. In the **Add Links** section, locate the custom link you wish to delete.
5. Click () **Delete**.
6. Click **Save**.

---

## Securing Knowledge base widget authentication using JWT

You can implement an authentication configuration for the widget using JWT, ensuring a secure environment for private and mixed projects.

1. Navigate to Knowledge base widget in the Knowledge base portal.

   The list of widgets will appear.
2. Hover on the desired Knowledge base Widget and click () **Edit**.
3. In the **Configure & connect** tab, navigate to the **JWT** section and **enable** the JWT toggle.

1. **Client ID:** The client ID will be your project’s ID.
2. **Widget ID:** Since multiple widgets may exist, a Widget ID is provided for their unique purposes.
3. **Token endpoint:** A token endpoint is an HTTP endpoint that allows you to obtain an access token given an authorization code.
4. **Client secret:** Click **Regenerate** to generate the client secret. You need to save this for future purposes and the same client secret will apply to all widgets in the future.

> NOTE
>
> The Client secret will be required for JWT widgets you may create. Note that this information will not be stored in Document360.

   e. **Authorize URL:** Paste the authorized URL from your knowledge base widget webpage.

5. Click **Save**.

![Securing the Knowledge base widget](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Securing_Knowledge_base_widget_authentication_using_JWT.png)

Embed the authorized URL within your code and paste it into the **script section** on your webpage. This will implement a secure, authenticated widget that prevents unauthorized third-party access.

---

### Implementing the auth endpoint

```
[HttpGet]
[Route("authenticate")]
public async Task<IActionResult> WidgetAuthentication(string id)
{
    if (HttpContext.User.Identity.IsAuthenticated)
    {
        var clientData = new ClientDetails()
        {
            ClientId = "{Client ID}",
            Secret = "{Client secret}",
            TokenEndpoint = "{Token endpoint}",
            WidgetId = "{Widget ID}",
            SecurityGroupIds = "{Comma separated reader group IDs}", // mandatory for configuration to render KB widget
            TokenValidity = 15, // integer representing token validity in minutes
        };

        if (clientData == null)
            return NotFound();

        List<string> readerGroupids = null;
        if (!string.IsNullOrEmpty(clientData.SecurityGroupIds))
            readerGroupids = clientData.SecurityGroupIds.Split(',').Select(c => c.Trim()).ToList();

        var payload = new
        {
            username = "{Username}",
            firstName = "{First name}",
            lastName = "{Last name}",
            emailId = "{Email address}",
            readerGroupIds = readerGroupids,
            tokenValidity = clientData.TokenValidity,
            widgetId = clientData.WidgetId,
            projectId = clientData.ClientId
        };

        var payloadString = JsonConvert.SerializeObject(payload);

        var result = await client.RequestTokenAsync(new TokenRequest
        {
            Address = clientData.TokenEndpoint,
            ClientId = clientData.ClientId,
            ClientSecret = clientData.Secret,
            GrantType = "Widget",
            Parameters =
            {
                {
                    "payload",  payloadString
                },
                {
                    "id", clientData.ClientId
                },
            }
        });

        return Ok(new
        {
            accessToken = result.AccessToken,
            expiresIn = result.ExpiresIn
        });
    }
    else
    {
        return Unauthorized(new { success = false });
    }
}
```

C#

Copy

> NOTE
>
> You must include the comma-separated reader group IDs as security group IDs to configure and render the KB widget.

---

### FAQs

#### Why are certain categories appearing on the Knowledge base site but not in the widget?

This issue may occur if category-level access has not been properly configured for the widget. To ensure your categories are visible in the widget:

1. Verify that the team account or reader has permission to view the specific categories/articles in the Knowledge base widget.
2. Check whether category-level access is configured for the widget. If it is, you need to manually add the desired category in the content access section during widget configuration.

**To add the category to the widget:**

1. Navigate to **Knowledge base widget** () in the Knowledge base portal.
2. Hover over the desired widget and click the **Edit** icon ().
3. In the **Configuration & connect** tab, expand the **Content access** section.
4. Select **Category** and choose the desired category to appear in the widget.
5. Click **Save** to apply the changes.

#### The Knowledge base widget is not loading on the Knowledge base site. How can I fix this issue?

The Knowledge base widget may not load on your Knowledge base site if the API key is outdated. Updating the API key should resolve the issue and restore the widget functionality.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="url-mapping"></a>

## URL Mapping

**Plans supporting Knowledge base widget**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **URL Mapping** feature within the knowledge base widget allows you to tailor the display of specific articles and categories based on the pages your end users visit. This functionality not only enhances user experience by directing users to relevant content but also enables you to hide the knowledge base widget on certain URLs or provide a search bar with custom placeholders, guiding users on what to search.

---

## Using URL mapping

To configure URL mapping, you perform specific actions within the knowledgebase widget for designated URLs.

### Actions

There are four actions you can execute with URL mapping:

1. **Show article:** Displays a single article on the specified URL.
2. **Show list of articles:** Lists selected articles under the **Recommended** section within the Knowledge Base widget on the specified URL.
3. **Show search results:** Allows you to set a specific search term to query your knowledge base, returning relevant search results on the specified URL.
4. **Hide widget:** Prevents the Knowledge Base widget icon from appearing on the specified URL.

You can find these actions under the **URL Mapping** tab or when editing an existing mapping.

> NOTE
>
> For URL Mapping to work, the Knowledge base widget must be installed within your site or app. For more information, read the article on [Installing the Knowledge base widget](/help/docs/installing-the-knowledge-base-widget).

### URL Parameters

When configuring the Knowledge Base widget URL, you can include three types of parameters:

1. **Include Path**: `/thisis/a/path`
2. **Include Query**: `?animal=bear`
3. **Include Hash**: `#inbox`

You can also enable the **Is Regex** toggle to incorporate regular expressions into your URL configurations.

---

## Adding URL Mapping to your Widget

To integrate the desired widget into your knowledge base site, follow these steps:

1. Navigate to **URL Mapping** tab in the **Widget** () in the Knowledge base portal.
2. Click **New URL mapping** and specify the following:

   * **Name** - The URL Mapping name will only be shown on the URL mapping record within Document360
   * **URL structure**  - Select the desired URL parameter type (**Include path**/**Include query**/**Include hash**). You must enable at least one URL parameter
   * Type in the URL on which you want the article/category to show or action to occur.

     > NOTE
     >
     > Your domain name is *not* included in the URL path. For instance, `https://document360.com/ebook/rapid-guide-to-launch-your-knowledge-base/`, your URL Path would be `/ebook/rapid-guide-to-launch-your-knowledge-base/`
   * **Action** - Select the desired action.
   * **Select workspace** - Select the desired version (if you have multiple versions).
   * **Language to** - Select the desired language (if you have multiple languages).
   * **Article to show** - In the search bar, select the articles/categories you want to show from your knowledge base documentation.

   NOTE

   Folder categories are not available for selection. Only **page** and **index** category types are available for selection.
3. Click **Create**.

![1_URLmapping.gif](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_URLmapping.gif)Once an end user accesses your specified URL path and opens the Knowledge Base widget, they will see the mapped article/category. This information remains consistent as they navigate between the Knowledge Base widget tabs within the same version and language.

---

## Editing URL mapping

To modify an existing URL mapping:

1. Navigate to **Widget** () in the Knowledge base portal.
2. Hover on the desired Knowledge base widget and click the **Edit** () icon.

   In the **URL mapping** tab, you can find the list of available URL mapping.
3. Hover over the desired URL mapping and click the **Edit** () icon.

   The **Update URL mapping** blade will appear.
4. Update the desired information and click **Update**.

![2_urlmapping_edit.gif](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_urlmapping_edit.gif)

---

## Deleting URL mapping

You can delete a set URL mapping.

![3_urlmapping_delete.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_urlmapping_delete.png)

1. Navigate to **Widget** () in the Knowledge base portal.
2. Hover on the desired Knowledge base widget and click the **Edit** () icon.
3. In the **URL mapping** tab, you can find the list of available URL mapping.
4. Hover over the desired URL mapping and click the **Delete** () icon.
5. Click **Yes** in the **Delete confirmation** prompt.

---

## URL mapping settings

You can define the Knowledge base widget behavior for URLs that do not have configured mapping. Defining this behavior can improve the user experience and accessibility to the documentation.

![4_urlmapping_settings.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_urlmapping_settings.png)

1. Navigate to **Widget** () in the Knowledge base portal > **Configure & connect**.
2. Under **Set controls** section, expand the **URL mapping settings** section.
3. Select the desired option:

   * **Navigate to the page help/knowledge base**: Select this option to display the article/category in Page help or Knowledge base tab in the Widget.
   * **Do not make any changes to the existing setup**: Select this option to display the last opened article/category in the Widget.
4. Click **Save**.

---

## Basic URL matching

Understanding URL matching is crucial for effective URL mapping. A general-purpose regex for matching typical URLs looks like this:

```
^https?://?[a-zA-Z0-9.-]+/[a-zA-Z0-9/._-]*??[a-zA-Z0-9=&._-]*?#[a-zA-Z0-9_-]*?$
```

Regex

Copy

**Explanation of the components**

* `^https?://?`: Matches the protocol (e.g., `http://` or `https://`). The `?` makes the protocol optional.

  > NOTE
  >
  > Ensure to add a backward slash (\) before every forward slash (/) while testing your URL on https://regex101.com.
* `[a-zA-Z0-9.-]+`: Matches the domain name, including letters, numbers, dots (`.`), and hyphens (`-`).
* `/[a-zA-Z0-9/._-]*?`: Matches the path after the domain, allowing slashes, alphanumeric characters, dots, underscores, and hyphens.
* `?[a-zA-Z0-9=&._-]*?`: Matches optional query parameters (e.g., `?key=value`), making this part optional.
* `#[a-zA-Z0-9_-]*?`: Matches the fragment (e.g., `#section`), which is also optional.

---

### Examples of URL mapping using Regex

#### **Mapping URLs with specific paths**

To map a URL pattern like `/users/{id}`, use:

```
^/users/[0-9]+$
```

Plain text

Copy

This captures a user ID dynamically.

**Example Matches**

* `/users/123`
* `/users/456`

#### **Mapping URLs with query parameters**

For URLs like `/search?q={query}`, the regex would be:

```
^/search?q=[a-zA-Z0-9]+$
```

Regex

Copy

**Example Matches**

* `/search?q=apple`
* `/search?q=123abc`

#### **Mapping URLs with optional parameters**

For a URL pattern like `/products/{category}/{id}`, where category is optional:

```
^/products/[a-zA-Z]+?/[0-9]+$
```

Regex

Copy

**Example Matches**

* `/products/123`
* `/products/electronics/123`

#### **Mapping URLs with wildcard or multiple paths**

For `/blog/*`:

```
^/blog/.*?$
```

Regex

Copy

**Example Matches**

* `/blog`
* `/blog/how-to-code`
* `/blog/2021/10`

**Mapping URLs with subdomains**  
For subdomain URLs:

```
^https?://?[a-zA-Z0-9-]+.example.com$
```

Regex

Copy

**Example Matches**

* `http://blog.example.com`
* `https://shop.example.com`

#### Combining multiple components

To handle more complex URL mappings, you can combine the various components as needed. The comprehensive regex that matches a URL with an optional protocol, domain, path, query parameters, and fragment looks like this:

```
^https?://?[a-zA-Z0-9.-]+/[a-zA-Z0-9/._-]*??[a-zA-Z0-9=&._-]*?#[a-zA-Z0-9_-]*?$
```

Regex

Copy

---

## FAQs

**How can I remove the Page help and Search bar from the widget when URL mapping for a single article is configured?**

To remove the Page help and Search bar from the widget when URL mapping for a single article is configured:

1. Navigate to **Widget** () in the Knowledge base portal.
2. Hover over the desired widget and click the **Edit** () icon.
3. Paste the provided code in the **Custom CSS** tab:

   ```
   li#page-help-tab {
       display: none;
   }

   .article-header .article-back-icon {
       display: none;
   }

   .search-container {
       display: none !Important;
   }
   ```

   CSS

   Copy
4. Paste the provided code in the **Custom JavaScript** tab:

   ```
   setTimeout(function() { $('.search-container').hide();}, 2000);
   setTimeout(function() { $("#knowledge-base-tab").click();}, 2000);
   ```

   JavaScript

   Copy
5. Click **Save**.

This will hide the **Page help** tab and **Search bar** in the widget on the Knowledge base site when URL mapping for a single article is configured.

**How can I see the updates immediately in the KB Widget after adding or updating a URL Map?**

The updates are cached on the server for performance reasons and will automatically refresh every 15 minutes. However, if you need to see the changes immediately, you can clear the application cache.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="customizing-the-kb-widget-using-custom-css-javascript"></a>

## Customizing the Knowledge base widget using Custom CSS/JavaScript

**Plans supporting knowledge base widget**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Customizing the Knowledge Base (KB) widget allows you to personalize its appearance and behavior, making it align with your branding or specific functionality needs. In this article, we'll walk through customizing the widget's icon, setting up buttons for interaction, managing callbacks for show/hide functionality, and applying styling and localization adjustments.

---

## How to change the default widget icon?

You can easily replace the default Knowledge Base widget icon with a custom one that fits your brand’s design. This gives a more cohesive look to your website or app.

### **Creating a custom button**

To add a custom button that interacts with the Knowledge Base widget:

1. Add a new HTML element, a button, for example, anywhere on your page.

   ```
    <button id="doc360_help_btn" class="btn hide"><span>Help!</span></button>
   ```

   XML

   Copy
2. Assign the element a CSS class that includes `display: none`.

   ```
   .hide
   {
       display:none;
   }
   ```

   CSS

   Copy

### **Setting up callback functions**

To control the visibility of the custom button based on the Knowledge Base widget’s state, you’ll need to create callback functions in JavaScript.

Add the following [callback functions](https://developer.mozilla.org/en-US/docs/Glossary/Callback_function) to any of your JavaScript files or inside a `<script>` tag.

**Show button when widget loads:**

```
function doc360_callback()
{	
    document.getElementById('doc360_help_btn').classList.remove('hide');
}
```

JavaScript

Copy

**Show button after being hidden by URL mapping:**

`doc360_callback` needs to remove the `display: none` from your button. This will be executed when the Knowledge Base widget has completed loading the setting.

```
function doc360_show_callback()
{
    document.getElementById('doc360_help_btn').classList.remove('hide');
}
```

JavaScript

Copy

**Hide button based on URL mapping:**

`doc360_show_callback()` needs to remove the `display: none` from your button. This will be executed if the button was previously hidden by URL mapping

```
function doc360_hide_callback()
{
    document.getElementById('doc360_help_btn').classList.add('hide');
}
```

JavaScript

Copy

`doc360_hide_callback()`needs to add the `display: none` to your button. This will be executed by [URL mapping](/help/docs/url-mapping) if a valid map is found to hide Knowledge Base widget. These functions handle the button's visibility based on the Knowledge Base widget’s state or URL mapping.

> NOTE
>
> The show and hide callbacks are only necessary if you’re hiding the widget on specific pages using URL mapping.

### Integrating the callback functions

To make the widget recognize your custom callbacks, modify the Knowledge Base widget’s JavaScript snippet (found in the widget settings):

```
<!-- Document360 Knowledge Base assistant Start -->
<script>
    (function (w,d,s,o,f,js,fjs) {
        w['JS-assistant']=o;w[o] = w[o] || function () { (w[o].q = w[o].q || []).push(arguments) };
        js = d.createElement(s), fjs = d.getElementsByTagName(s)[0];
        js.id = o; js.src = f; js.async = 1; fjs.parentNode.insertBefore(js, fjs);
    }(window, document, 'script', 'mw', 'https://cdn.document360.io/static/js/assistant.js'));
    mw('init', { apiKey: 'YOUR KEY', 
                   callback:  doc360_callback, 
                   show_callback: doc360_show_callback,  
                   hide_callback: doc360_hide_callback });
</script>
<!-- Document360 Knowledge Base assistant End -->
```

JavaScript

Copy

### **Making the button open the widget**

Once the button is visible, you’ll want it to open the Knowledge Base widget when clicked. You can achieve this with either pure JavaScript or jQuery.

**Using Pure JavaScript:**

```
document.getElementById('doc360_help_btn').addEventListener('click', function () { 
    document.getElementById('document360-assistant-iframe').contentDocument.getElementById('doc360-button').click();
});
```

JavaScript

Copy

**Using jQuery:**

```
$('#doc360_help_btn').click(function() {
    $('#document360-assistant-iframe').contents().find('#doc360-button').click();
}); 
```

JavaScript

Copy

### **Customizing the button’s appearance**

Apply any custom CSS to the button to match your website’s branding. This could involve changing colors, font styles, or adding additional effects.

---

## How to change dark theme in Knowledge base widget?

You can use Custom JavaScript to create this customization.

1. Navigate to **Knowledge base Widget** in the Knowledge base portal and click on the (  ) Edit icon.

![kbwidget_darktheme.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1730066025105.png)

2. Open the **Custom CSS** tab, paste the below snippet, and click **Save**.

```
.doc360-widget-modal {
    background-color: black;
    color: white;
}
 
.doc360-widget-modal div,
.doc360-widget-modal li,
.doc360-widget-modal p,
.doc360-widget-modal ul,
.doc360-widget-modal span,
.doc360-widget-modal input,
.doc360-widget-modal textarea {
color: white !important;
  background-color: black !important;
}
 
.doc360-widget-modal button {
  color: white !important;
}

.eddy-feedback-btn:hover {
    color: black !important;
    background-color: #e4e4e7 !important;
}

.eddy-feedback-btn {
    background-color: black !important;
}
```

CSS

Copy

---

## How to change the fields displayed in the Knowledge base Widget?

You can use Custom JavaScript to create this customization.

1. Navigate to **Knowledge base Widget** in the Knowledge base portal and click on the () Edit icon.

![kbwidget_changefields.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1730066068782.png)

2. Open the Custom JavaScript tab to paste the below snippet.

```
$(document).ready(function() {
    if ($('.tab-link.current').length > 0) {
        $('.tab-link.current').html($('.tab-link.current').html().replace("Page help", "Destek"));
        $('.tabs li:last-child').html($('.tabs li:last-child').html().replace("Knowledge base", "DokÃ¼matasyon"));
    }

    setTimeout(function() {
        $('#top-search-title').html($('#top-search-title').html().replace("Top search articles", "En Ã‡ok Aranan DokÃ¼manlar"));
    }, 3000);
});
$(document).ready(function() {
    $('#search-input').each(function(ev) {
        if (!$(this).val()) {
            $(this).attr("placeholder", "Arama");
        }
    });
    $('#category-filter').each(function(ev) {
        if (!$(this).val()) {
            $(this).attr("placeholder", "Filtrele");
        }
    });
});
```

JavaScript

Copy

3. Replace the text as per your requirement.
4. Click **Save**.

---

## How to set the Knowledge base Widget to open automatically in the knowledge base site?

You can use Custom JavaScript to create this customization.

1. Navigate to **Knowledge base Widget** in the Knowledge base portal and click on the (  ) Edit icon.

![kbwidget_autoopen.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1730066097873.png)

2. Open the Custom JavaScript to paste the below snippet and click **Save**.

```
$(function() {
setTimeout(function(){
let iframe = $('#document360-widget-iframe');
let button = iframe.contents().find('#doc360-button');
button.trigger("click");}, 2000);
});
```

JavaScript

Copy

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="faq-knowledge-base-widget"></a>

## FAQ - Knowledge base widget

**Plans supporting knowledge base widget**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

#### 1. What is a Knowledge base widget?

The Knowledge base widget helps users find answers without leaving your site or application. The feature aims to assist users in finding solutions to common questions, troubleshooting issues, and learning about new features and functionalities, all without leaving the application.

---

#### 2. How is the Knowledge base widget useful for the users?

Here are some scenarios where you can find the Knowledge base widget helpful:

* **User onboarding**: A new user of an app can access the Knowledge base widget to learn the basics of using the app, such as setting up an account, navigating the user interface, and performing common tasks without leaving the application.
* **Technical support**: If a user encounters a problem or error message while using the app, they can use the Knowledge base to search for a solution rather than contacting customer support or searching for answers outside the app.
* **Learning about new features**: As an app or service is updated with new features and functionalities, users can access the Knowledge base widget to learn about what has changed, how to use the new features, and how to benefit from them. It can improve the overall user experience and adoption of new capabilities.

---

#### 3. Is it possible to configure multiple Knowledge base widgets?

Yes, you can configure up to 10 Knowledge base widgets in a project.

---

#### 4. How to change the position of the Knowledge base widget icon on your website?

1. Go to the **Installation & Setup** tab of the desired Knowledge base widget (**Knowledge base widget** > **Edit**).
2. In the **Style your widget** section, you can find the **widget position**.
3. Select the **Left** or **Right** button to change the icon position to left or right.
4. Enter the desired spacing values in the **Side spacing** and **Bottom spacing** fields to position the icon.
5. Click the **Save** button at the top.

---

#### 6. How to turn off the top search in the Knowledge base widget?

1. Go to the **Installation & Setup** tab of the desired Knowledge base widget (**Knowledge base widget** > **Edit**).
2. In the **Style your widget** section, enable the **Hide top search** toggle.
3. Click the **Save** button at the top.

---

#### 7. Why does a configured URL mapping appear broken?

The URL mapping would be broken due to any changes in the 'Filter widget content' configuration in the 'Installation & setup' tab. Check the URL mapping and update the configuration.

---

#### 8. How do I set my desired logo as a widget icon?

1. Go to the **Installation & Setup** tab of the desired Knowledge base widget (**Knowledge base widget** > **Edit**).
2. In the **Style your widget** section, you can find the **widget icon**.
3. Click the **Change icon** button.
4. Choose/upload the desired icon.
5. Click the **Save** button at the top.

---

#### 9. How to hide the Knowledge base widget?

1. Go to the **Installation & Setup** tab of the desired Knowledge base widget (**Knowledge base widget** > **Edit**).
2. In the **Style your widget** section, enable the **Hide widget** toggle.
3. Click the **Save** button at the top.

---

#### 10. Can I add custom links in the Knowledge base widget?

Yes, you can add custom links in the Knowledge base widget.

---

#### 11. What is URL mapping?

With URL mapping, you can make specific articles and categories appear in the knowledge base widget, depending on the page the end-user is on. You can also use URL mapping to hide the Knowledge base widget on a specific URL or provide a search bar with a custom placeholder to point end-users in the right direction on what to search.

---

#### 12. How to enable Ticket deflector in the Knowledge base widget?

1. Go to the **Installation & Setup** tab of the desired Knowledge base widget (**Knowledge base widget** > **Edit**).
2. Enable the **Show ticket deflector** toggle.
3. Click **Save** at the top.

---

#### 13. Can I add regular expressions (regex) in URL mapping?

You can include regular expressions in your URL by enabling the **Is Regex** toggle.

---

#### 14. What is regex?

Regex, short for "regular expression," is a sequence of characters that defines a search pattern used to match and manipulate text strings.

> For example, you can use regex to configure a single URL mapping for 20 articles with similar URLs.  
>  For instance, consider a scenario where you wish to configure URL mapping for the following articles with the base URL '`https://example.com/docs/drive`':
>
> * `https://example.com/drive-General`
> * `https://example.com/drive-settings`
> * `https://example.com/drive-functionA`
> * `https://example.com/drive-functionB`
> * `https://example.com/drive-functionC`
> * `https://example.com/drive-functionD`
> * `https://example.com/drive-functionE`
>
> Without regex, you would need to add individual URL mappings for each URL. However, by enabling regex, you can add with a single URL mapping: Select the "Include path" option and add `docs/drive` in the URL field. You can use regex to have a more efficient and streamlined mapping process.

---

#### 15. Can I add URL mapping for categories?

Yes, you can add URL mapping for categories. It applies only to page and index categories.

---

#### 16. How to remove the Knowledge base widget icon from an article?

1. Go to the **URL mapping** tab of the desired Knowledge base widget (**Knowledge base widget** > **Edit**).
2. Create a new URL mapping with **Hide** action for the desired article.

---

#### 17. What is the default language behavior of the Knowledge base widget?

The Knowledge base widget will now open in the default browser language by default. If the default browser language is not available in the Knowledge base widget, the default language of the Knowledge base will appear.

#### 18. How do I restrict the Knowledge base widget to a specific domain?

1. Go to the **Installation & Setup** tab of the desired Knowledge base widget (**Knowledge base widget** > **Edit**).
2. In the **Style your widget** section, you can find the **Keep your widget secure**.
3. Enter the domains where you want the Knowledge base widget to display.
4. Click **Add** > **Save**.

<a id="knowledge-base-site-20"></a>

## Knowledge base site 2.0

**Plans supporting Knowledge base site 2.0**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Knowledge Base Site 2.0 introduces an improved experience for accessing articles and browsing information. With an enhanced user interface, better search functionality using AI, and streamlined content organization, users can quickly find relevant articles and troubleshoot issues efficiently. New features such as real-time updates and interactive elements make it easier to navigate and engage with content. The Knowledge base site ensures a more intuitive and efficient knowledge-sharing experience for all users.

> For Your Information (FYI)
>
> To migrate from KB site 1.0 to KB site 2.0, read the article on [**KB site 2.0 migration**](/help/docs/kb-site-20-migration).

---

## Overview of Knowledge base site 2.0

![Image showing sections of Knowledge base site 2.0](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Knowledge_base_site_2.0.png)

### 1. Header section

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-New_Header_section_of_Knowledge_base_site_2.0(1).png "2_Screenshot-New_Header_section_of_Knowledge_base_site_2.0(1).png")

1. **Logo image:** Displays your organization’s branding element/logo. Clicking on it navigates you to your documentation home page.
2. **Workspace:**

   Use the dropdown to navigate through different workspaces available in the Knowledge base.

   Click on the API documentation workspace to navigate to the API documentation home page.
3. **Primary navigation:** Customize the primary navigation to help you navigate to different pages from your home page or Knowledge base site.
4. **Announcement** () **icon:** The "What’s New" page displays a list of recently published articles (new and forked) in the selected workspace.
5. **Acknowledgment required ()**: This page displays the list of acknowledgment required/acknowledged articles.
6. **Theme:** Switch between System theme, light, and dark themes in the Knowledge base site.   
   By default, the light theme will be set as the system theme.
7. **Language:** Select the desired language from the available list to read the articles.
8. **Secondary navigations:** Customize the secondary navigation to help you navigate to different pages from your home page or knowledge base site.

---

### 2. Left navigation pane

![Overview of the Knowledge base site 2.0](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-left_side%20pane_KBsite2.0.png)

1. **Search bar:** Access the search function by clicking here or using the shortcut Ctrl + K (Command + K on Mac). Search for desired articles in the Knowledge base or use Eddy AI search for information. To know more information, read the articles on [Search](/help/docs/document360-search).
2. **Hide navigation menu:** Click to hide the left side pane for a wider view of the article.
3. **Tree view:** View the hierarchy of categories and articles in a clear tree structure.
4. **Status of the article:** This small color badge represents the status of the article (new, updated, custom). For more information, read the article on [Article status](/help/docs/article-status).
5. **Context menu:** For private and mixed project users, hover over the context menu to view two options:

   * **Follow category/article:** Click to receive notifications whenever new articles are published or existing ones are updated. This is available only in private and mixed projects. For more information, read the article on [Follow articles and categories](/help/docs/follow-articles-and-categories).
   * **Export PDF:** Export the article/category as a PDF.

---

### 3. Article section

![Knowledge base site 2.0](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-New_Article_section_of_Knowledgemnt_base_Site_2.0.png)

1. **Breadcrumbs:** Navigate back to the category and sub-category of the article.
2. **Article title:** Displays the title of the article.
3. **Copy link:** Click to copy the article’s URL to the clipboard.
4. **Status badge:** Displays the status of the articles (new, updated, custom).
5. **Article date:** View the published or updated date of the article.
6. **Read time:** View the estimated average time it would take to read the article based on word count.
7. **Contributors:** View the list of contributors who have worked on this article.
8. **Share icon:** Share the article via Twitter, LinkedIn, Facebook, or Email.
9. **More sharing options:** Download the article as a PDF or print it.
10. **Follow**: Click here to follow the articles. This feature is available for reader accounts.
11. **Article summary:** Click to view the summary of the article generated by Eddy AI.
12. **Acknowledgement required**: Scroll to the end of the article and acknowledge article.

---

### 4. Image

When you click on an image on your Knowledge base site, the image opens in an image viewer.

* **Title text**: It displays the caption of the image, if any.
* **Open link**: To open the image URL, if available.
* **Zoom out** (): To zoom out or minimize the image.
* **Zoom in** (): To zoom in or enlarge the image.
* **Download** (): To download the image to your local storage.
* **Close** (X): To close the image.
* **Next** (): To move to the next image.
* **Previous** (): To move to the previous image.

  Hold and drag the image to move it anywhere on the screen. The image closes when you click anywhere on the screen outside the image.

  ![Knowledge base site view of an image](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_ScreenShot-Knowledge_base_site_2.0.png)

---

### 5. Right side pane

![Overview of the Knowledge base site 2.0](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-Right%20side%20pane_KBsite2.0.png)

1. **Hide navigation menu:** Click to hide the right-side pane for a wider view of the article.
2. **Files:** View attachments associated with the article.
3. **Tags:** View the list of tags associated with the article.
4. **In this article** (Previously “Table of Contents”)**:** View the list of headings within the article.

---

### 6. Article footer

![Article footer of the Knowledge base site 2.0](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Footer_section_of_Knowledge_base_site_2_0.png)

1. **Feedback of the Article:** Click **Yes** or **No** and enter your feedback for the article.
2. **Previous and Next Article:** Navigate to the previous and next articles in the category.
3. **Related articles:** View a list of associated related articles.

---

## Troubleshooting

This section provides step-by-step guidance to address common challenges that you may encounter while managing or accessing your knowledge base site. From website accessibility problems to configuration errors, each solution is tailored to help you quickly identify and resolve potential roadblocks.

### Website fails to load after entering the URL

If a website is not accessible when you enter a URL, possible causes could be incorrect URL entry, browser cache issues, VPN interference, network problems, server downtime, outdated browsers, or incorrect system date and time settings.

**Steps to resolve:**

1. Ensure the website URL is entered correctly.
2. Reload the page.
3. Clear browser cache:

   1. Right-click anywhere on the page and select **Inspect** to open the developer tools menu.
   2. Right-click the browser's reload button and choose **Hard reload** or **Empty cache**and **Hard reload**.
4. Check if a VPN is active on your device. Disable the VPN and attempt to access the site again.
5. Ensure your system's date, time, and time zone are set correctly.

If the issue persists after these steps, consider contacting the support team for further assistance.

### 504 gateway timeout while accessing the site

**Error:** 504 gateway timeout

If a 504 error occurs while accessing the site, one possible reason could be the sub-folder configuration.

**Steps to resolve:**

1. Check recent changes in the web server configuration:

   1. Review the location blocks or configuration files in the webserver for any recent changes.
   2. If changes are identified, revert them to their previous state.
2. Verify the sub-folder Configuration:

   1. A change in the sub-folder slug within the Sub-folder Configuration may cause the issue.
   2. Revert any recent changes to the sub-folder configuration to resolve the issue.

   For more reference on sub-folder configuration, refer to the article on [Hosting Document360 on a sub-directory](https://docs.document360.com/docs/document360-on-a-sub-folder).

### Page unresponsive while editing an article

**Error:** The page isn’t working. example.com redirected you too many times. ERR\_TOO\_MANY\_REDIRECTS.

If you encounter this error during article editing, possible causes could be an outdated browser cache, overly large articles causing performance issues, missing or improperly closed HTML tags, or excessive redirects due to incorrect configurations in the article.

**Steps to resolve:**

1. **Clear browser cache:** An outdated or corrupted browser cache can interfere with page functionality. Clear the cache, reload the browser and check if the issue persists.
2. **Reduce article length:** Large articles with extensive content can cause performance issues. Consider splitting lengthy articles into smaller sections and organizing them under relevant categories to enhance responsiveness.
3. **Check for missing closed tags:** Ensure all HTML tags in your article have corresponding closing tags, especially in Markdown. Elements like `<table>`, `<div>`, and `<p>` should be properly closed to prevent rendering problems.

These steps can improve your editing experience and help prevent **Page unresponsive** errors.

### Page isn’t working due to too many redirect**s**

**Error:** Page isn’t working: page redirected too many times

Possible causes of this error include incorrect JWT Login URL configuration, using the domain URL as the Login URL causing redirect loops, or outdated settings in the JWT configuration.

**Steps to resolve:**

1. **Check recent changes**: Review any recent updates made to the JWT Login URL in the configuration.
2. **Correct the Login URL**: Ensure the domain URL is not set as the Login URL. Using the domain URL can cause multiple redirect issues.
3. **Update JWT configuration**: Remove the incorrect Login URL from the JWT configuration and replace it with the correct one.

For detailed instructions on configuring JWT, refer to the [JWT article](https://docs.document360.com/docs/configuring-the-jwt-sso).

### Sorry! Project not found during custom domain configuration

**Error:** Sorry! This project does not exist.

Possible causes of this error include incorrect or missing CNAME record configuration, expired CNAME records in the DNS, or incomplete domain verification in the Document360 portal.

**Steps to resolve:**

1. **Verify CNAME Record**: Ensure the CNAME record is added correctly and click the 'Verify' button on the custom domain page in the Document360 portal. Once verified, the custom domain will be set up and active immediately.
2. **Check for CNAME Expiry**: If the CNAME record was updated in the DNS after some time, it may have expired, preventing domain verification and resulting in the error message.
3. **Reconfigure the Domain**: Reconfigure the custom domain, update the CNAME record, and verify the domain in Document360.

For detailed instructions, refer to the [custom domain mapping article](https://docs.document360.com/docs/custom-domain-mapping).

### Encountering "/home/error/" message while accessing the site

**Error:** /home/error/

Possible causes of this error include incorrect site configuration, server-side issues, or unresolved errors in the website's backend. You might encounter this error in the URL section after the domain URL.

**Steps to resolve:**

1. **Contact support**: Reach out to us at [**support@document360.com**](mailto:support@document360.com) with the following details:

   1. A screen share video demonstrating the issue on the page.
   2. Steps to reproduce the error, if possible.
2. **Provide HAR file**: Follow the steps outlined in this[guide](https://docs.document360.com/docs/document360-support-generating-a-har-file) to download the har file.
3. **Share console errors**:

   1. After downloading the har file, click on the ‘console’ tab in your browser's developer tools.
   2. Take a screenshot of the console errors displayed and include it in your email.

### Icons not rendering correctly on the user site

In some cases, icons on the user site may not render correctly, especially when there are a large number of icons for different navigations. The primary reason for broken icons is an unintended modification of the FontAwesome family provided by Document360. This occurs when changes to other classes or HTML tags on the user site unintentionally alter the icon font settings.  
To avoid this issue,

* Ensure that changes to the site's styling or class definitions do not impact the FontAwesome classes or font family settings.
* When targeting specific elements, double-check that icon-related styles remain intact and are not overwritten.

**Steps to resolve:**

**1. Inspect the broken icon:**

1. Use your browser’s developer tools to inspect the user site.
2. Click the broken icon using the selector tool to identify the issue.

2. **Check custom CSS:**

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. Review any font rules applied to various classes. In some cases, font changes may unintentionally apply to broader classes, affecting the icons.
3. Ensure font changes are applied only to the specific classes that require them. This will help preserve the default settings for Font Awesome and prevent any unintended impact on icons.

If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

### Knowledge base site loading without CSS styling

This issue typically occurs when the site is accessed from a network where Document360 domains are blocked or not whitelisted by your company or organization.

**Steps to resolve:**

1. Verify if the site works correctly when accessed from a different network. If it does, the issue is likely related to network restrictions.
2. To resolve this, whitelist the following domains in your network settings to ensure proper access and functionality.

![Image showing domains to whitelist to address troubleshooting](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-troubleshooting.png)

### Secure connection issues on the knowledge base site

**Error:**

* This site can’t provide a secure connection
* Your connection isn’t private
* The connection for this site is not secure

**Steps to resolve:**

1. **Check the CAA Record in DNS:**

   1. Verify if a CAA (Certification Authority Authorization) record is added for your knowledge base site in the DNS records.
   2. If no CAA record is found, inspect the SSL certificate used for the site. Refer to the steps in the provided video for guidance.

2. **Update the CAA Record:**

   1. Based on the SSL certificate provider, add the corresponding CAA record to your DNS.
   2. For example, if the certificate provider is Let’s Encrypt, add the second CAA record as specified in the instructions. Similarly, ensure the correct CAA record is added for your certificate type.

3. **Reference for CAA Records:**

   Learn more about CAA records and their importance by reviewing the following article:  
   [CAA Record and Why It Is Needed (SSL-Related)](https://www.namecheap.com/support/knowledgebase/article.aspx/9991/38/caa-record-and-why-it-is-needed-ssl-related/#caa_how).

4. **Contact the DNS Provider:**

   If the issue persists during custom domain setup, reach out to your DNS provider to confirm if there are any additional issues.

If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

### Encountering "ResourceNotFound" error while accessing the images, files or attachments

**Error**: ResourceNotFound

This error occurs when the SaaS token is not appended to the file URL in **private** and **mixed projects**. Document360 appends a SaaS token to ensure that only authorized users can access the file.

**Steps to resolve:**

* Ensure the SaaS token is appended to the file URL before accessing or sharing the file.
* Try downloading the file again directly from Document360.

![Error message indicating resource not found in XML file format.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1739344746842.png)

### Encountering "AuthenticationFailed" error while accessing images, files, or attachments

**Error:** AuthenticationFailed

This error occurs when the **SaaS token** has expired in **private** and **mixed projects**. In Document360, the SaaS token is valid for **15 minutes** before it automatically updates. If a file with an expired SaaS token is shared, users will not be able to access it. Possible causes includes:

1. **Restricted access to Private projects or content**

   Files in private projects or private content within mixed-visibility projects are restricted to users who do not have the necessary permissions.
2. **SaaS Token expiry**

   * Document360 files use **SaaS tokens** appended to their URLs for **temporary access**. Once the token expires, users cannot access the file.
   * Expiry time varies based on file type:

     + **Standard files:** The SaaS token expires **15 minutes** from the time the link is generated.
     + **Video files:** SaaS token expires **after 1 hour**.

> Example SaaS token:
>
> https://cdn.document360.io/4214231-3333-4222-huafgesu/exp/PaygOps-2024-Oct-29-03-54-19.zip?sv=2023-12-05&spr=https&st=2024-12-02T04%3A22%3A08Z&se=2024-12-02T04%3A52%3A08Z&sr=c&sp=r&sig=BtPheGpDGeLzQWNyv02oxWqWxvn%2FHwef05UCGJ6RsgHU%3D

**Steps to resolve**

* **Refresh the source webpage** and generate a new file link.
* Ensure you share the file within the valid token period (15 minutes for standard files, 1 hour for video files) to prevent expiration.

![Error message indicating authentication failure with details about the request and signature.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-Troubleshooting-Authentication%20failed.png)

<a id="customize-site"></a>

## Customize site

**Plans supporting customization of Knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In your Document360 project, you can manage your Knowledge base site design and customization from the unified **Customize site** feature. Customizing the appearance and functionality of your knowledge base is crucial to creating a seamless experience for your users. Document360's Customize Site feature allows you to tailor your knowledge base site to align with your brand identity and user preferences. Whether it's selecting themes, adjusting colors, or personalizing layouts, these customization options empower you to create a site that is not only visually appealing but also accessible and user-friendly.

Imagine managing a SaaS product’s support documentation. With **Customize site**, you can match your brand’s colors and logo, ensure accessibility using auto color contrast, and personalize layouts for better navigation.

> For your information (FYI)
>
> This enhancement is available in KB Site 2.0. To migrate from KB site 1.0 to KB site 2.0, read the article on [KB site 2.0 migration](/help/docs/kb-site-20-migration).

> NOTE
>
> **Customize site** is a project-level setting. The changes will reflect in the entire project.

---

## Basic site customization

To perform the basic customization:

1. Navigate to **Settings** ()**>** **Knowledge base site** **>** **Customize site** in the Knowledge base portal.

   The page holds all the basic site design configurations.
2. You can choose one of the three options to set the theme for your knowledge base site from the **Site theme** field:

   * Both Light & Dark
   * Light only
   * Dark only
3. In the **Branding** section, you can choose a **Logo** and **Favicon**. Additionally, you can set a custom redirection link for the logo. When a user clicks the logo on your Knowledge base site, they will be redirected to the specified link, such as your company website or a specific landing page.

   > NOTE
   >
   > Customers who already have a customized logo and favicon will not be affected until they navigate to the **Customize site** settings and save the changes.
4. In the **Colors** section, select the **Auto set color contrast to meet** [**WCAG**](https://www.w3.org/TR/WCAG21/) **standards** checkbox to apply the colors based on your brand to your site elements automatically.

   > NOTE
   >
   > For more information, read the article on [Web Content Accessibility Guidelines (WCAG)](/help/docs/web-content-accessibility-guidelines-wcag).

   1. In the **Brand color** section, you can choose a primary color for CTA's, selection states, and more.
   2. In the **Hyperlink color** section, you can customize the color of hyperlinks in your knowledge base to enhance the user experience. Under this option, you can choose from the three radio options:

      * **Use industry standard:** Applies a commonly used hyperlink color
      * **Use brand color**: Applies the same color you chose from the brand color
      * **Use a different color**: It allows you to select default, hover, and visited colors for hyperlinks.
   > NOTE
   >
   > If you have chosen the option **Auto set color contrast to meet WCAG standards**, both light and dark theme colors will be set automatically. Otherwise, you need to manually set colors for each theme.
5. In the **Fonts** section, you can change the fonts of your Knowledge base content anytime.

   There will be two sub-sections:

   1. **Article font paring**: This font will be applied to all your article titles and contents.

      Click on **Have a specific font combination in mind?** to select more font options. By clicking it, you can choose the font for titles and contents.
   2. **Site font**: Select the font in the dropdown. This will be applied throughout your Knowledge base site. It includes the left navigation pane (categories, sub-categories, article titles) and the navigations for the header, footer, secondary navigations, and controls.

6. In the **Styling** section, you can choose the style for the buttons and form elements. The three options available are:

   * Rounded
   * Sharp
   * Bubble
7. In the **Site layout** section, you will find two options:

   * **Full width**: Full width will extend your content to the edges of a browser window.
   * **Center**: The center layout will fit your content more in the center of a browser window.
8. Once done, click **Save**.

![Configuring the basic customization for the Knowledge base site.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Basic_site_customization.gif)

---

## Advanced site customization

Personalize your website by incorporating branding elements, header and footer sections, homepage, login page, and error pages in one central location.

1. Navigate to **Settings** ()**>** **Knowledge base site** **>** **Customize site** in the Knowledge base portal.

   The page holds all the basic site design configurations.
2. Click **Customize site**.
3. From this section, you can configure the following site elements:

   * [Site header & footer](/help/docs/site-header-and-footer): Customize the [Header](/help/docs/header-primary-navigation), [footer](/help/docs/footer-navigation), etc.,
   * [Main pages](/help/docs/main-pages): Customize the Home, Documentation, and Login pages
   * [Error pages](/help/docs/error-pages): Customize the [404 page](/help/docs/404-page), [Access denied](/help/docs/access-denied-page), [Unauthorized](/help/docs/unauthorized-page), and [IP restrictions](/help/docs/ip-restriction-page) pages
   * [Custom CSS / JavaScript](/help/docs/custom-css-javascript): Add advanced styling or interactivity to your site.

   The changes you apply on the left section can be previewed on the right window. To edit specific element, click on the desired item in the Preview window. The corresponding settings will appear in the left panel.
4. Use the dropdown to choose the different pages.

   The new interface for the Home page builder provides easier navigation and customization for each section of the homepage.
5. Click the **Save** button at the top right to save your changes.
6. Click **Preview** to get a glimpse of how your site looks.
7. Click **Publish**to commit all the changes you have made.

![Configuring the advanced customization for the Knowledge base site.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Advanced_site_customization.gif)

---

### FAQs

#### How do I change the site theme?

You can change the Knowledge base site theme by following the below steps:

1. Navigate to **Settings**() > **Knowledge base site**> **Customize site** in the Knowledge base portal.
2. In **Site theme** section, you can choose from three options:

   * Both Light & Dark
   * Light only
   * Dark only

#### How do I change the Favicons?

Favicon (short for favorite icon) is a small icon, usually 16x16 pixels, used by web browsers to identify your website. The favicon appears in the browser tab for the website, the bookmarks list, and the browsing history list.

1. Navigate to **Settings**() > **Knowledge base site**> **Customize site** in the Knowledge base portal.
2. In the **Branding** section, hover over the default favicon and click **Click to change** on Favigon.
3. Now, you can add a Favicon in one of two options available:

   * **Using a URL**: Paste the image URL from any external source and click on **Insert****.**
   * **Upload an image**: Choose your file from the Drive or Upload an image from your local computer storageand click **Insert**.
4. Click **Save****.**

> PRO TIP
>
> * Always use an image with minimalistic and square dimensions (in pixels).
> * As a best practice, ensure your favicon is sized at 48 x 48 pixels for optimal rendering across platforms.

#### Why is the favicon added not rendering on the Knowledge base site?

This issue could be faced when the favicon added does not meet the specified criteria, including size and format. Make the necessary changes to the favicon or try re-uploading it on your Knowledge base site.

#### How do I change the site logo?

Replace the default **Logo** displayed in the top left of the knowledge base by uploading your desired logo.

1. Navigate to **Settings**() > **Knowledge base site**> **Customize site** in the Knowledge base portal.
2. In **Branding** section, hover over the default **Logo** and click **Click to change**.
3. Now, you can add a Favicon in one of two options available:

   * **Using a URL**: Paste the image URL from any external source and click on **Insert**.
   * **Upload an image**: Choose your file from the Drive or Upload an image from your local computer storage and click **Insert**.
4. Once done, click **Save**.

#### How do I add text as the logo?

You can add a text as the logo by replacing the default logo displayed in the top left of the Knowledge base.

1. Navigate to **Settings**() > **Knowledge base site**> **Customize site** in the Knowledge base portal.
2. In **Branding** section, click **Don't have a logo? Use name instead**.
3. Enter the desired text in the input field.

   For example, you can add a company name or tagline instead of a logo image.
4. Click **Save**.

> NOTE
>
> You can add up to 30 characters for logo text.  
> The maximum size for a logo is:  
> Height - 40 px  
> Width - 270 px  
> When you upload a logo with a bigger size, the logo size will be scaled down and kept within the maximum size.
>
> For example, uploading a logo with a size 500x1000 px (height x width) will be scaled down to 40x80 px.

#### How do I add custom logo URL?

Add a clickthrough URL to your logo with the Logo URL. A user clicks the logo and redirects to the provided link.

1. Navigate to **Settings**() > **Knowledge base site**> **Customize site** in the Knowledge base portal.
2. Add the desired URL in the Logo URL field.
3. Click **Save**.

> NOTE
>
> * If you do not add a logo URL and a user clicks the logo, it redirects to the Knowledge base home page.
> * Custom logo URL is an optional field.

#### How do I set a different logo for different themes?

If you're using a KB site 2.0 project, you can add custom code to set different logos for light and dark themes.

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

```
.brand-logo img {
    content: url('Paste the Light mode logo URL here');
}

/* Override logo image when the theme is set to "dark" */
html[data-bs-theme="dark"] .brand-logo img {
    content: url('Paste the Dark mode logo URL here');
}
```

CSS

Copy

#### How to choose the brand color?

To choose the desired brand color for your Knowledge base site, follow the steps below:

1. Navigate to **Settings**() > **Knowledge base site**> **Customize site** in the Knowledge base portal.
2. Under **Colors**, you can choose the color for **Brand** color. This will be used as a primary color for CTA's, Selection states, and more.

> NOTE
>
> If you have chosen the option **Auto set color contrast to meet WCAG standards**, both light and dark theme colors will be set automatically. Otherwise, you need to manually set colors for each theme.

3. Once done, click **Save**.

#### How do I choose font family in customize site?

To change the fonts of your Knowledge base, follow the steps below:

1. Navigate to **Settings**() > **Knowledge base site**> **Customize site** in the Knowledge base portal.
2. Under **Fonts** section, there will be two sections: **Article font parsing** and **Site font**.

* **Article font paring**: This font will be applied to all your article Titles and Contents.

> NOTE
>
> Click **Have a specific font combination in mind?**, to select more font options. By clicking it, you can choose the font for titles and content.

* **Site font**: Select the font in the dropdown. This will be applied throughout the Knowledge base site. It includes the left navigation pane (categories, sub-categories, article titles) and the Navigations (header, footer, secondary navigations, controls).

3. Select the desired font and click **Save**.

> NOTE
>
> Document360 provides a list of common fonts used in documentation. However, you can configure your desired font in the knowledge base. For more information, read the article on [How to configure a custom font in the knowledge base?](/help/docs/how-to-configure-a-custom-font-in-the-knowledge-base)

#### How do I change the default paragraph style?

Currently, there is no direct option to change the default paragraph style. However, you can change the default article font in the Document360 editor.

To set the default font for your articles:

1. Navigate to **Settings**() > **Knowledge base site**> **Customize site** in the Knowledge base portal.
2. In the **Fonts** section, choose your desired font pair in the **Article font paring** tile. This font will appear in the Knowledge base articles.

   For instance, if you draft content in `Verdana` in the Knowledge base portal but select `Ubuntu + Open Sans` in the **Article font pairing**, in the Knowledge base site, the article title will appear in `Ubuntu`, and the article content will be in `Open Sans`.

> NOTE
>
> You can also select your custom font for your articles. For more information, read the article on [How to configure a custom font in the knowledge base?](/help/docs/how-to-configure-a-custom-font-in-the-knowledge-base)

To change the paragraph style for individual articles:

1. Open the desired article in the **Advanced WYSIWYG editor** and select the text.
2. Click **Format**, then choose a font style in the **Typography** section.

#### How do I change the button styles?

To change the button styles of your Knowledge base site, follow the steps below:

1. Navigate to **Settings**() > **Knowledge base site**> **Customize site** in the Knowledge base portal.
2. In the **Styling** section, you can select the button style from the options such as rounded, sharp, and bubble.

#### How do I change the site layout in customize site?

To change the site layout in customize site, follow the steps below:

1. Navigate to **Settings**() > **Knowledge base site**> **Customize site** in the Knowledge base portal.
2. Under Layout, you can find the Full width and Center.

* **Full width**: Full width will extend your content to the edges of a browser window.
* **Center**: The center layout will fit your content more in the center of a browser window.

3. Click **Save**.

#### How do I set the default font for my articles on the Knowledge base site?

To set the default font for your articles:

1. Navigate to **Settings**() > **Knowledge base site**> **Customize site** in the Knowledge base portal.
2. In the **Fonts** section, choose your desired font pair in the **Article font paring** tile. This font will appear in the Knowledge base articles.

   For instance, if you draft content in `Verdana` in the Knowledge base portal but select `Ubuntu + Open Sans` in the **Article font pairing**, in the Knowledge base site, the article title will appear in `Ubuntu`, and the article content will be in `Open Sans`.

> NOTE
>
> You can also select your custom font for your articles. For more information, read the article on [How to configure a custom font in the knowledge base?](/help/docs/how-to-configure-a-custom-font-in-the-knowledge-base)

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="kb-site-20-migration"></a>

## KB site 2.0 migration

**Plans supporting customization of knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 introduces Knowledge Base Site 2.0, offering advanced customization capabilities and new functionalities such as following articles and categories, sharing articles via private links, and more, enhancing user experience and engagement. This upgrade allows you to smoothly transition from Site 1.0 to Site 2.0, providing greater control over your Knowledge Base with improved configuration and customization options.

> **For Your Information (FYI)**
>
> By default, KB Site 2.0 is accessible for projects created after June 10th, 2024.

---

## Customizing your knowledge base site 2.0

1. Navigate to **Settings** ()> **Knowledge base site** > **Customize site** in the Knowledge base portal.

   The **Customize site** page will appear.
2. A new banner will be displayed to upgrade to Knowledge base site 2.0.

> NOTE
>
> This banner is displayed exclusively for Document360 1.0 Standard plan projects.

3. Click **Experience 2.0** in the banner to explore the KB site 2.0 preview.
4. Upon clicking, you can see two tabs: Site 1.0 (Active) and Site 2.0 (Preview). By default, Site 2.0 tab will be selected.
5. In the **Site 2.0** tab, you can view the **Knowledge Base Site 2.0 preview** banner with the following options:

   1. Go live with Site 2.0
   2. Customize site
   3. Preview site 2.0
   4. How to configure

![1_Screenshot-Customize_site_page_Kb Site 2.0](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Customize_site_page_Kb%20Site%202.0.png)

### **a. Go live with Site 2.0**

1. Click **Go live with Site 2.0** to publish KB Site 2.0 with the same functionalities as KB Site 1.0, without customizing it.

   The **Publish confirmation** panel will appear.

> NOTE
>
> You cannot deselect the configurations the first time you are editing.

2. Click **Continue.**

   The **Switch from Knowledge base site 1.0 to 2.0** panel will appear.
3. Enter the subdomain of your project and click **Switch to 2.0**.

   Now you have migrated your KB site into our latest version KB site 2.0.

> NOTE
>
> From KB Site 1.0, the logo, favicon, primary color, link colors, title & body font, and site layout will be retained.

4. Within 30 days, you can revert to KB Site 1.0 by clicking **Rollback to Site 1.0.** Our team will review your request, and your KB site will be reverted to version 1.0.

> NOTE
>
> After rollback to 1.0, the system stores last saved KB site preview.

![2_ScreenGIF-Go_Live_Site_2_0_Migration](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Go_Live_Site_2_0_Migration.gif)

### **b. Customize site**

1. Click **Customize site**.

   The overview of customize site page will appear.
2. You can customize various pages such as Site header & footer, Main pages, Error pages, and adding Custom CSS & JavaScript.
3. Once done, click **Save** to save the changes as a draft.
4. Click **Preview** to view the changes in the Knowledge base site.
5. Click **Go live with Site 2.0** to publish the changes in your Knowledge base site.
6. Select the desired configurations and click **Continue**.

   The **Switch from Knowledge base site 1.0 to 2.0** panel will appear.
7. Enter your subdomain of the project and click **Switch to 2.0**.

![3_ScreenGIF-Customize_site_2.0_option_Migration_2_0](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Customize_site_2.0_option_Migration_2_0.gif)

### **c. Preview site 2.0**

Click **Preview site 2.0** to view the KB site 2.0 with default branding elements retained from your KB site 1.0.

### **d. How to configure**

If you need guidance on configuration, click **How to Configure** to watch the instructional video.

---

### FAQ

**Will I lose any integrations or extensions when switching from KB site 1.0 to KB site 2.0?**

No, all integrations and extensions configured in KB site 2.0 will continue to work seamlessly.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="web-content-accessibility-guidelines-wcag"></a>

## Web Content Accessibility Guidelines (WCAG)

**Plans supporting WCAG**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In the digital age, accessibility is not just a feature but a necessity. Ensuring that all users, regardless of their abilities, can access and use our products is a cornerstone of inclusive design. Document360 is compliant with WCAG 2.1 A and AA standards, reinforcing our commitment to accessibility and inclusivity.

> For Your Information
>
> This WCAG is available exclusively in KB Site 2.0, which is accessible for projects created after June 10th, 2024.

---

## Implementing WCAG 2.1 A and AA in Document360

At Document360, we have aligned Document360 with WCAG 2.1 A and AA guidelines to ensure our knowledge base software is accessible to everyone. Here’s how we’ve achieved this:

1. **Text alternatives**: We provide text alternatives for all non-text content, such as images and icons, ensuring that screen readers can convey the information to all users.
2. **Keyboard navigation**: Document360 supports full keyboard navigation, enabling users to access all features and functions without using mouse.
3. **Readable text**: We ensure that all text content is readable and understandable, using clear fonts, appropriate contrast ratios, and simple language to enhance readability.

![WCAG 2.1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-WCAG.gif)

---

## Key Principles of WCAG 2.1

WCAG 2.1 is organized around four core principles that guide the creation of accessible content:

1. **Perceivable**: Information and user interface components must be presented to users in ways they can perceive. This includes providing text alternatives for non-text content.
2. **Operable**: Interface components and navigation must be easy to use, which includes making all functionality available from a keyboard, giving users enough time to read and use content, and providing ways to help users navigate and find content easily
3. **Understandable**: Information and the operation of the user interface must be understandable. This involves making text readable and comprehensible, ensuring web pages operate predictably.
4. **Robust**: Content must be robust enough to be interpreted reliably by a wide range of user agents, including assistive technologies. This ensures compatibility with current and future technologies.

> **NOTE**
>
> For more information, read the [**WCAG 2.0 Guidelines**](https://www.w3.org/TR/WCAG21/).

<a id="header-primary-navigation"></a>

## Header - Primary navigation

**Plans supporting customization of knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The primary navigation header of Document360 is the bar next to the logo at the top of your site. You can add menus in this space that help readers navigate to different pages from your Home page or Knowledge base site.

---

## Accessing the Header - Primary navigation

To access the customization settings of the header’s primary navigation,

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.

   This page holds all the basic site design configurations.
2. Click **Customize site**.
3. Select **Site header & footer** from the dropdown available on the left navigation pane.
4. Expand the **Header** option and select **Primary navigation**.

   ![To access header option in site customization in the Knowledge base portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/32_ScreenGif-Primary_navigation.gif)
5. Click **Add new item** to add a navigation menu either to the left or the right of the site header.

The available navigation types are

* Home
* Documentation
* Custom URL
* Call to action
* RSS feed
* Ticket deflector
* Glossary
* API documentation
* Custom page

![Image showing types of navigation available to add in the header](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Header_primary_navigation_nav_types.png)

> NOTE
>
> You can only add up to 6 new items to the header. On exceeding the limit, you will get a warning prompt below the left navigation pane stating, "You have reached the maximum count of 6. To add a new link, remove one existing link."

7. Click the **default background color** to open the color picker and change the color of the primary navigation of the header.
8. **Edit**, **delete**, or **reorder** the menus using the options in the left navigation pane.![6-Screenshot-Accessing_the_Primary_navigation_left_pane_options](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1730220371154.png)
9. Click the **Preview** option on the top right to preview the changes implemented.
10. Click the **Save** button to save all your recent changes.
11. Once done, click the **Publish** button to activate the changes made in the portal on the Knowledge base site.

![52_ScreenShot-Primary_navigation](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/52_ScreenShot-Primary_navigation.png)

### Knowledge base site view

![7-Screenshot-Primary_navigation_KB_view](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7-Screenshot-Primary_navigation_KB_view.png)

---

### FAQs

#### How can I customize the header in Document360?

To customize the header, you can add custom JavaScript code in **Settings** ()> **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal. This allows you to modify the header to include additional elements, such as links or icons.

#### Can I add social media icons to the header in Document360?

Yes, you can add social media icons by appending links and icons to the header navigation area using custom JavaScript. For example, you can include icons for LinkedIn, Twitter, Facebook, and Instagram.

#### How can I dynamically create a feedback link in the header?

You can use JavaScript to create a feedback link dynamically. For example, a `mailto` link can be appended to the header with the current page title as the email subject. This allows users to send feedback about a specific page directly.

#### How do I add buttons to the Knowledge base site header?

You can add colorful buttons to the Primary navigation header by following these steps:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.

   This page holds all the basic site design configurations.
2. Click **Customize site**.
3. Select **Site header & footer** from the dropdown available on the left navigation pane.
4. Expand the **Header** option and select **Primary navigation**.
5. Click **Add new item** to add a navigation menu either to the left or the right of the site header.

   The **Add new item** panel will appear.
6. In the **Select type** dropdown, choose **Call to action**.
7. Fill in the following fields:

   1. **Title**: Enter the text to display on the button.
   2. **Link**: Add a hyperlink, email address, or telephone number.
   3. Select the desired text color and background color.
8. Select the **Open link in new tab** checkbox to open the link in a new tab.
9. Click **Add**.

![Adding a call to action button in the Knowledge base site header.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-Adding_call_to_actions_button_in_the_header.png)

The public-facing website where end-users can access articles and find answers to their questions.

<a id="header-secondary-navigation"></a>

## Header - Secondary navigation

**Plans supporting customization of knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Header - Secondary navigation** in **Document360** is a versatile feature that enables you to enhance user navigation by adding menus below the logo. This customization allows seamless access to essential pages, offering readers a smooth browsing experience.

Consider a growing Knowledge base where users frequently visit specific sections such as **Pricing**, **Documentation**, or **Support**. Using the Header Secondary navigation, you can create quick-access menus for these pages, making it easier for visitors to locate important information without exploring multiple sections. This ensures an organized and efficient navigation system, especially beneficial for sites with extensive content.

---

## Accessing the Header - Secondary navigation

To access the Header- Secondary navigation, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations.
3. From the left dropdown, select **Site header & footer**.
4. Expand **Header**,then select **Secondary navigation**.
5. Click **Add new item** to create a navigation menu.

   The **Add new item** panel will appear.
6. In the **Select type** dropdown, choose from the following navigation types:

   1. **Single level**
   2. **Multiple level**
   3. **Ticket deflector**

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Accessing_the_header_secondary_navigation.png)

### **Single level** **navigation**

> NOTE
>
> The **Single level** option is selected by default. As the name suggests, it adds a single menu without any sub-menu items.

7. In the **Title** field, enter the text to display on the menu bar.
8. In the **Link** field, add hyperlink, email ID, or telephone number.
9. Select the **Open link in new tab** checkbox to open the link in a new tab.
10. Once done, click **Add**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Accessing_Single_level_navigation_in_the_secondary_navigation.png)

### **Multiple level** **navigation**

> NOTE
>
> The **Multiple level**  menu allows you to create a dropdown menu with multiple sub-menus under a single item.

11. In the **Title** field, enter the main menu title.
12. Click **Add sub menu**to add the sub menu items.
13. For each sub menu:

    1. In the **Title** field, enter the text to display on the menu bar.
    2. In the **Link** field, add hyperlink, email ID, or telephone number.
    3. Select the **Open link in new tab** checkbox to open the link in a new tab.
    4. Click **Add**.
    5. Click the **Delete**() icon to delete any submenu.
14. Once done, click **Add**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Accessing_multi_level_navigation.png)

### **Ticket deflector** **navigation**

15. In the **Title** field, enter the text to display on the menu bar.
16. In the **Select ticket deflector**dropdown, choose the desired [ticket deflector](/help/docs/adding-a-new-ticket-deflector).
17. Select the **Open link in new tab** checkbox to open the link in a new tab.
18. Once done, click **Add**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Accessing_ticket_deflector_in_secondary_navigation.png)

#### Managing secondary navigation items

19. Hover over the desired navigation item:

    1. Click the **Edit**() to modify the item.
    2. Click the **Delete**() to remove the item.
    3. Use the **Reorder** () icon to rearrange elements.
20. Select the **Show in home page** checkbox to display the secondary navigation bar on the Knowledge base site’s home page.
21. Click **Save** and then **Preview** to view the changes on the Knowledge base site.
22. Once done, click **Publish** to apply the changes.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Managing_secondary_navigation_items.png)

---

### Knowledge base site view

Here's how the secondary navigation appears on the Knowledge base site, showcasing the implementation of single-level navigation (e.g., **Glossary**), multiple level navigation (e.g., **Release notes**), and ticket deflector types.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Knowledge_base_site_view.png)

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="footer-navigation"></a>

## Footer

**Plans supporting customization of knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Add a "Footer" to your knowledge base site to add links to essential resources or information, such as pricing information, free trial sign-up, a Contact us page, etc. Similar to the primary and secondary navigation bar, team accounts can add up to six custom links to the footer navigation. Also, add and feature social media links to drive engagement in your social channels. Custom links will display on the left side of the footer navigation, while social media links will be on the right.

---

## Accessing the Footer navigation settings

1. Navigate to **Settings** ()> **Knowledge base site** > **Customize site** in the Knowledge base portal.

   The **Customize site** page contains all the basic site design configurations.
2. Click **Customize site**.
3. Select **Header & Footer** from the dropdown.
4. Click the **Footer** option.
5. You have two design options for the footer: **Basic footer** and **Custom footer**.

   * Click **Basic footer** to add navigation items and social media links.
   * Click **Custom footer** to customize the footer.
6. Use one of the two predefined themes available such as **Theme A** and **Theme B.**
7. Click on **Blank** to input your custom HTML footer.
8. You can **Edit, Delete** or **Reorder** the navigations from the left pane.
9. Click **Preview** on the right side to preview the changes.
10. Click **Save** to save all your recent changes.
11. Click **Publish** to activate the changes made in the portal on the Knowledge base site.

![Accessing the footer navigation settings in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Footer_overview_from_customize_site.gif)

---

### FAQ(s)

**Can I preview the changes made to the footer before saving?**

Yes, you can click Preview on the right side to preview the changes before saving.

**Is it possible to add social media links to the footer?**

Yes, you can add and feature social media links to drive engagement in your social channels.

**How do I delete the footer in the Knowledge base site?**

1. Navigate to **Settings** ()> **Knowledge base site** > **Customize site** > **Customize site**.
2. Select **Header & Footer** from the dropdown.
3. Click the **Footer** option.
4. Choose **Custom footer** and select **Blank**.
5. Without writing any HTML and CSS code, click **Save** and **Publish.**

The public-facing website where end-users can access articles and find answers to their questions.

<a id="custom-footer"></a>

## Custom footer

**Plans supporting customization of knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## Creating a custom footer

Creating a custom footer requires knowledge of HTML and CSS. Follow these steps to customize the footer on your **Knowledge Base Site**.

1. Navigate to the **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.

   This page displays all the basic site design configurations.
2. On the **Customize site** page, click the **Customize site** button.
3. Select the **Site header & footer** from the dropdown menu.
4. Click the **Footer** tab and choose the **Custom footer** option.

   There are three options:

   1. **Theme A:** A predefined black theme for the footer. You can edit the provided code if needed.
   2. **Theme B:** A predefined black theme for the footer. You can edit the provided code if needed.
   3. **Blank**: Add your custom HTML footer.
5. Turn on the **Preview** toggle to view the output without saving the changes.
6. Click **Save** to apply the changes.
7. Click **Publish** to activate the changes on your Knowledge base site.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Creating_a_custom_footer.gif)

---

### Linking a PDF or other files in the Custom footer

To attach a PDF or other files to the custom footer, follow these steps:

1. Navigate to **Drive** () and select the desired file in the Knowledge base portal.

   The **File details** panel will appear.
2. In the **Location** section, click the **Copy** icon to copy the file link.

> Example link: `https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Importing_multiple_article.gif`

4. Go to the **Settings** () > **Knowledge base site** > **Customize site** > **Customize site** in the Knowledge base portal.
5. Select the **Site header & footer** from the dropdown.
6. Click the **Footer** tab and choose the **Custom footer** option.
7. Select your desired theme.
8. In the **Custom Code** section, paste the copied link in the desired location.
9. Click **Save** and then **Publish** to finalize the changes.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Linking_a_PDF_in_the_Custom%20footer.gif)

<a id="rss-feeds"></a>

## RSS Feeds

**Plans supporting customization of knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**RSS** stands for **Really Simple Syndication**. It is an XML-based format that automatically updates with new information. **RSS Feed****s** provide a seamless way to keep your readers informed about the latest updates in your Knowledge base. By integrating **RSS Feed** options into your Knowledge base header or footer, you empower your audience to subscribe and stay updated with new and modified articles effortlessly.

Imagine a software company managing extensive documentation for their product updates. By enabling **RSS Feed****s**, customers can stay informed about every new release or bug fix without manually checking the Knowledge base. This ensures readers remain engaged and well-informed.

---

## Adding an **RSS Feed** option to your Knowledge base site

### Header - Primary navigation

To add an **RSS Feed** in the Header - Primary navigation:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations.
3. From the left dropdown, select **Site header & footer**.
4. Expand **Header**,then select **Primary navigation**.

   The **Primary navigation**panel will appear.
5. Click **Add new item** to add a navigation menu to the left or right of the site header.
6. In the **Select type**dropdown,select **RSS Feed**.
7. In the **Title** field, enter the desired title.
8. Select the **Open link in new tab** checkbox to open the **RSS Feed** in a new tab.
9. Once done, click **Add**.
10. Click **Save** and then **Preview** to view the changes on the Knowledge base site.
11. Once done, click **Publish** to apply the changes.

> NOTE
>
> For more information, read the article on [Header - primary navigation](/help/docs/header-primary-navigation).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Adding_RSS_feeds_in_header_primary_navigation.gif)

### Header - Secondary navigation

To add an **RSS Feed** in the Header - Secondary navigation:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations.
3. From the left dropdown, select **Site header & footer**.
4. Expand **Header**,then select **Secondary navigation**.

   The **Secondary navigation**panel will appear.
5. Click **Add new item**.
6. In the **Select type** dropdown, select **Single level****.**
7. In the **Title** field, enter the title as **RSS Feed**.
8. In the **Link** field, paste the **RSS Feed** XML page URL.
9. Select the **Open link in new tab** checkbox to open the **RSS Feed** in a new tab.
10. Once done, click **Add**.

> NOTE
>
> For more information, read the article on [Header - secondary navigation](/help/docs/header-secondary-navigation).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Adding_RSS_feeds_in_header_secondary__navigation.gif)

### Footer navigation section

To add an **RSS Feed** in the Footer navigation:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations.
3. From the left dropdown, select **Site header & footer**.
4. Select **Footer**.  
   **Basic footer**
5. Click **Add new link**.
6. Enter the title as **RSS Feed** and paste the **RSS Feed** XML page URL.
7. Select the **Open link in new tab** checkbox to open the link in a new tab.   
   **Custom footer**
8. Paste the **RSS Feed** XML page URL in the desired location in the HTML code.
9. Once done, click **Save**.

> NOTE
>
> For more information, read the articles on [Footer](/help/docs/footer-navigation) and [Custom footer](/help/docs/custom-footer).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Adding_RSS_feeds_in_footer_navigation.gif)

---

### **Using** **RSS Feed****s**

**RSS Feed****s** allow your readers to stay up-to-date with your Knowledge base through various tools, such as browser extensions, mobile apps, web apps, or desktop applications.

> NOTE
>
> Popular applications and extensions for **RSS Feed** management:
>
> * **RSS Feed** Reader Chrome Extension by Feeder.co
> * Feedly
> * Feeder
> * NewsBlur
> * Inoreader
> * Feedreader Online
>
> *Disclaimer: Some of these tools offer free services, while others may charge a fee depending on usage. Please review pricing details and user reviews before committing to any service. Document360 does not endorse these third-party tools.*

#### **Subscribing or adding Knowledge base Feeds to an RSS Reader**

1. **Accessing the Feed**

   * The reader clicks the **RSS Feed****s** option (with your custom-added text) in your Knowledge base header.
   * A new browser tab will appear displaying the XML file.
2. **Using a browser extension**

   * If the reader has an **RSS Feed** browser extension installed, it may automatically detect the XML file and prompt a **Subscribe** option.
3. **Using an RSS application**

   * Readers need to copy the URL of the XML file and paste it into their preferred **RSS Feed** reader application.

> NOTE
>
> **RSS Feed** allow your readers to stay up-to-date with your Knowledge base through various tools, such as browser extensions, mobile apps, web apps, or desktop applications.

---

## Removing an **RSS Feed** from the Knowledge base site

To remove an **RSS Feed**:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations.
3. From the left dropdown, select **Site header & footer**.
4. Navigate to the desired location such as Header - primary, Header - secondary, and footer navigation.
5. Hover over the **RSS Feed** item and click **Delete**().
6. Click **Save**.

> NOTE
>
> Even after removing the **RSS Feed** option from your Knowledge base site, readers who previously subscribed will continue to receive updates.

---

### FAQ

#### **Why does clicking the RSS feed lead to a 404 page, and how can I access the RSS feed?**

RSS feeds only work for **public projects** in Document360. If your project is set to private or has mixed access (a combination of public and private content), the RSS feed will display a 404 error page. To access the RSS feed, ensure that your project is publicly accessible.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="main-pages"></a>

## Main pages

**Plans supporting customization of Knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The Home page (previously "Home page builder") is the first page an end-user will see when they visit your Knowledge base. The Home page lets you customize your home page by adding links, changing colors, including categories from your knowledge base, and more.

---

## Home page

![1_Screenshot-Document360_landing_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Document360_landing_page.png)

> **NOTE**
>
> The header, primary and secondary navigation, and footer appear on the home page but are configured in **Settings** () > **Customize site** > **Header and Footer**.

---

### Accessing the Home page design settings

1. Navigate to **Settings** () > **Knowledge base site**> **Customize site** in the Knowledge base portal.

   The **Customize site** page will appear, holding all the basic site design configurations.
2. Click the **Customize site** button.
3. Select **Home** in the dropdown on the left.

   A default Home page design is available for you to customize. The different sections of the Home page are listed on the left, and a **Live preview** is available on the right.
4. If needed, click **Add section** and choose from the available Body block options each featured for specific content needs:

   * [Rich text](/help/docs/text-block): Add and format textual content using Markdown for enhanced readability and structure.
   * [Multicolumn card section](/help/docs/text-columns-block): Display content in organized columns, perfect for showcasing multiple topics or features side by side.
   * [Image with text](/help/docs/image-and-text): Combine visuals with textual descriptions to create a more dynamic and visually appealing layout.
   * [Custom code section](/help/docs/html-block): Embed Custom HTML and CSS code for advanced content customization.
   * [Knowledge base categories](/help/docs/knowledge-base-categories): Highlight key categories from your Knowledge base to improve navigation.
   * [Widgets](/help/docs/widgets): Add interactive elements, such as surveys or contact forms, to enhance user engagement.

   **Body blocks** enable Knowledge base admins to create visually appealing and intuitive Home pages that effectively guide users. Each block provides a unique way to display content, offering flexibility in designing an engaging and user-friendly **Home page**.

   For example, a software company can use the **Knowledge base categories** block to display product guides. In contrast, the **Image with text** block can highlight key features or announcements, enhancing the user experience and engagement.
5. You can reorder the section on the left pane using drag-and-drop () and click the eye () icon to hide the desired element.

   > **NOTE**
   >
   > The main **Hero section** at the top cannot be dragged and moved.
6. Click **Preview** at the top right to see how the page will look.
7. Click **Save** to save the changes.
8. Click **Publish** to activate the changes made in the portal on the Knowledge base site.

   > **NOTE**
   >
   > The **Publish** button becomes active only after you save your changes.

![Customizing the home page of the Knowledge base site.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-overview_page_of_home_page.gif)

---

### Home page themes

> **NOTE**
>
> You can only configure Home page themes if you are on a professional, business or enterprise plan.

Customize your Home page with the Document360 themes. You can configure a unique theme for each workspace or language.

1. Click the **Themes** () icon on the Home page design page
2. Select one of the themes: Engage, Innovate, Learn, or Default.
3. Click the eye () icon to view a static preview.
4. Click **Activate** to implement the selected theme.

![Customizing the home page of the Knowledge base site.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Previewing_the_themes_option_in_the_home_page.gif)

> **NOTE**
>
> The recommended resolution for the homepage image is 1920x415 pixels (width x height). You can customize the resolution as needed.

---

### Home page SEO

You can use a meta title, meta description, and a featured image for your Home page.

In the **Home page** customizing page,

1. Click the **Settings** () icon in the Home page design page.

   The **Settings** panel will appear.
2. You can enter the desired **Title** and **Meta description** for your Home page.
3. Turn on the **Visibility settings** toggle.

   When the toggle is turned off, the home page will no longer be visible in the Knowledge base. Instead, users will be directed to the documentation page of your Knowledge base.
4. Add a featured image from the Drive by clicking **Choose image**.
5. Click **Save**.

![Customizing the home page of the Knowledge base site.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Settings_page_in_Home_page.png)

---

## Documentation

The Documentation page lets you customize the category navigation by adjusting the position of the search bar and applying background colors.

### Accessing the Documentation page design settings

1. Navigate to **Settings** () > **Knowledge base site**> **Customize site** in the Knowledge base portal.

   The **Customize site** page will appear, holding all the basic site design configurations.
2. Click the **Customize site** button.
3. Select **Documentation** from the dropdown on the left.

   A default Documentation page design is available for you to customize. Customization options for the Documentation page are listed on the left, and a **Live preview** is available on the right.
4. Choose the search bar position:

   * **Left panel:** Place the search bar at the top of the left navigation panel.
   * **Secondary Header:** Position the search bar in the secondary header on the top right.
5. Check the **Add background color** box to apply a background color to the left navigation panel.
6. Click **Preview** at the top right to see how the page will look.
7. Once done, click **Save** to save your changes. If you haven’t saved your changes, an **UNSAVED CHANGES** badge will appear at the top, next to the save button.
8. Click **Publish** to make the changes live.

   ![Document360 interface showing Documentation page customize window.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Documentation_page.png)

---

## Login page

If your Knowledge base is private or mixed access, reader are required to login with their credentials to view the content. You can customize this login page using the **Customize site** option available in Document360.

### Accessing the Login page design settings

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Login page customization.png "Login page customization.png")

1. From the Knowledge base portal, navigate to **Settings** ()> **Knowledge base site** > **Customize site**.

   The page holds all the basic site design configurations.
2. Click the **Customize site** button.
3. In the dropdown menu on the left, select **Login** under **Main Pages**.

   You’ll see a default Login page design ready for customization.
4. Choose one of the following options:

   * **Basic Style**: Customize the default image only.
   * **Custom Style**: Add Custom HTML and CSS. You can turn on/off the **Preview** toggle on the right to switch between rendered view and code view.
5. Click **Preview** at the top right to see how the page will look.
6. Click the **Save** button to save your recent changes.
7. Click **Publish** to activate the changes in the portal on the Knowledge base site.

---

### FAQs

#### How do I add images to the Home page?

To add images to the Home page, paste the following code in the [Custom HTML](/help/docs/custom-html):

```
<img src="paris.jpg" alt="Paris" class="center">
```

XML

Copy

For customizing the alignment, add the following CSS code in the [Custom CSS & JavaScript](/help/docs/custom-css-javascript) section:

```
.center {
  display: block;
  margin-left: auto;
  margin-right: auto;
  width: 50%;
}
```

CSS

Copy

#### How do I change the position of the search bar to reflect on the knowledge base site?

To adjust the position of the search bar on your Knowledge base site, follow these steps:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site**. Select the dropdown, and click **Documentation**.
3. On the left panel, you have two options to switch the search bar position.

   **Left panel**: Place the search bar in the category tree on the left side.

   **Secondary Header**: Place the search bar on the right side in the secondary header.
4. If needed, check the **Add background color** box to apply the background color to the search bar.
5. Once done, click **Save** and **Publish**.

#### How do I change the browser tab title for my Knowledge base home page?

The SEO title of the home page appears as the browser tab name. To change the SEO title of the home page:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.

   The **Customize site** page will appear, holding all basic site design configurations.
2. Click the **Customize site** button.
3. In the dropdown on the left, select **Home**.
4. Click the **Settings** () icon in the Home page.

   The **Settings** panel will appear.
5. Enter the desired **Title** for your Home page.
6. Once done, click **Save** and **Publish**.

#### How to integrate a video loader into your home page?

Adding a visually appealing video loader to your homepage can create a sense of curiosity and interactivity for your visitors. Follow these simple steps to seamlessly integrate a video loader:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.

   The **Customize site** page will appear, holding all basic site design configurations.
2. Click the **Customize site** button.
3. In the dropdown on the left, select **Home**.
4. Create a new custom code section and insert the following HTML code, replacing the `src` link with the video link from your drive:

   ```
   htmlCopy code<div class="video__loader">
       <video muted autoplay loop>
           <source src="https://cdn.document360.io/560b3c6e-18a1-4ad6-babc-d0257662eab2/Images/Documentation/Revolving_Video.mp4" />
       </video>
   </div>
   ```

   XML

   Copy

   This code will seamlessly integrate the video loader into your homepage, enhancing its visual appeal and captivating your audience from the moment they arrive.
5. In the dropdown on the left, select **Custom CSS/JavaScript** and navigate to the **CSS** tab.
6. Replace `"Innovate"` in the following code snippet with the name of your configured theme (e.g., **Engage**, **Learn**, **Innovate**, or **Default**):

   ```
   cssCopy codebody.innovate {
       position: relative;
       overflow: hidden !important;
   }

   body.innovate.custom--loaded {
       overflow: auto !important;
   }

   /* Loader */
   .video__loader {
       width: 100%;
       min-height: 100vh;
       display: flex;
       align-items: center;
       justify-content: center;
       position: fixed;
       top: 0;
       left: 0;
       background: var(--color-dark);
       opacity: 1;
       visibility: visible;
       z-index: 9999999999;
       transition: all 1s ease;
   }

   .video__loader.remove--loader {
       opacity: 0;
       visibility: hidden;
   }

   .video__loader video {
       width: 100%;
   }
   ```

   CSS

   Copy

   This ensures that the CSS styling aligns with your chosen theme, optimizing the visual presentation for enhanced user experience.
7. Navigate to the **JavaScript** tab.
8. Replace `"innovate"` in the following code snippet with your theme name:

   ```
   javascriptCopy code/* Loader */
   var elBody = document.querySelector("body.innovate");
   var customLoaderVideo = document.querySelector(".video__loader");

   document.addEventListener("DOMContentLoaded", function() {
       setTimeout(function() {
           elBody?.classList.add("custom--loaded");
           customLoaderVideo?.classList.add("remove--loader");
       }, 5000);
   });
   ```

   JavaScript

   Copy

   This customization ensures that the JavaScript functionality integrates seamlessly with your theme, enhancing the overall performance of your site.

> NOTE
>
> The video loader function will operate exclusively on the homepage and will not apply to the documentation pages.

#### How to disable the Home page on the Knowledge base site?

1. Navigate to**Settings**() > **Knowledge base site**> **Customize site**in the Knowledge base portal.
2. Click the **Settings**() icon in the Home page design page.
3. Turn off the**Visibility settings** toggle and click **Save**.

#### How to add a contact/register button to your Login page?

Adding a support button to your login page can simplify the process of reaching out for assistance. Follow these easy steps to seamlessly integrate a support button into your login page:

1. Navigate to **Settings** () > **Knowledge base site > Customize site**.
2. Select the **Customize site** button.
3. Select **Login** from the left drop-down under the Main Pages group.
4. Then choose the **Custom style** radio button to enable modifications specifically for your login page.
5. In the HTML customization tab, add the following code to create your support button:

   ```
   htmlCopy code<div class="login-form--support">
       <button class="support-button">
           <a href="Support portal button or registration button link">Contact Support</a>
       </button>
       <p>Click here to Contact Support</p>
   </div>

   ```

   XML

   Copy
6. Next to the HTML tab, find the CSS customization tab. Paste the following code to ensure the support button is centered on the page:

   ```
   cssCopy code.login-form--support {
       text-align: center; /* Centers the content inside the element */
   }
   ```

   CSS

   Copy

By following these steps, you will successfully add a support button to your login page. This enhancement allows users facing challenges to easily access support resources without leaving the login interface, significantly improving their experience. Providing quick assistance right where it’s needed can lead to higher user satisfaction.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The public-facing website where end-users can access articles and find answers to their questions.

<a id="hero-section"></a>

## Hero section

The **Hero section** in **Document360** is a prominent feature displayed at the top of the Knowledge base site’s home page. It provides an opportunity to create a visually appealing introduction to your Knowledge base by customizing text, buttons, and the search bar. By tailoring the **Hero section**, you can ensure it reflects your brand and engages your audience effectively.

For instance, a software company can use the Hero section to prominently display a welcome message, highlight product updates, and provide quick navigation buttons to key resources. This makes it easier for users to find relevant information and creates a professional first impression.

---

## Accessing **Hero section**

To access the **Hero section**:

1. Navigate to **Settings**() > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations.
3. From the left dropdown, select **Home** page.

   The **Body** section lists all **Body blocks**, with the **Hero section** at the top.

   > NOTE
   >
   > The **Hero section**at the top cannot be deleted or reordered.
4. Click the **Hero section** to open the **Hero section** panel.

   #### **Adding background to the** **Hero section**
5. In the **Background type**dropdown, choose one of the following options:

   | **Background type** | Description | Alignment options |
   | --- | --- | --- |
   | None | No background will appear. By default, the background color is white. | **Left**, **Center**, **Right** |
   | Insert image | In the **Background image** section, click **Choose image** to upload an image from your drive.  Alternatively, enter the image URL in the **Image URL** field. | **Left**, **Center**, **Right** |
   | Color | Choose a color from the available options or use the **Custom color palette** for a custom color. | **Left**, **Center**, **Right** |
   | Gradient | Select a gradient from the available options. | **Left**, **Center**, **Right** |
   | Pattern | Choose a pattern from the given options. | **Left**, **Center**, **Right** |

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Accessing_the_Hero_section.gif)

   #### **Configuring the** **Hero section** **elements**
6. Expand the **Hero section** and configure the following elements:

   | Element | Actions |
   | --- | --- |
   | **Welcome text** | 1. Enter the desired title in the **Heading text** field. 2. Choose a text color using the **Text color**palette. 3. Click **Delete** () to remove this element. |
   | **Promo text** | 1. Enter the content in the **Paragraph text** field. 2. Choose a text color using the **Text color** palette. 3. Click **Delete** () to remove this element. |
   | **Buttons** | 1. Choose text and button colors using the **Text color**palette. 2. Enter text in the **First button text** field. 3. Provide the URL in the **First button url** field. 4. Click **Add button** to add up to three buttons. 5. Use **Delete** () or **Hide** () icons to remove or hide buttons. |
   | **Search** | The Search bar has no configurable options.  Click **Delete** () to remove the **Search** element if needed. |
7. Hover over any of the four elements (**Welcome text**, **Promo text**, **Buttons**, or **Search**) and click the **Hide** () icon to hide them from the Home page.
8. Click **Save** and then **Preview** to view the changes on the Knowledge base site.
9. Once done, click **Publish** to apply the changes.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Configuring_the_Hero_section_elements.gif)

### Knowledge base site view

Here's how the Hero section appears on the Knowledge base site, showcasing customized text, buttons, and search functionality, designed to provide a welcoming and navigable interface for users.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Knowledge_base_site_view.png)

---

### FAQ

#### How do I change the **Documentation** button text in the Home page?

1. Navigate to **Settings**() > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations.
3. From the left dropdown, select **Home** page.

   The **Body** section lists all **Body blocks**, with the **Hero section** at the top.
4. Expand the **Hero section** and select **Buttons**.
5. Update the **Documentation** button text.
6. Click **Save** and then **Preview** to view the changes on the Knowledge base site.
7. Once done, click **Publish** to apply the changes.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="text-block"></a>

## Rich text blocks

**Plans supporting customization of Knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Rich text** block is a feature that enables you to add a heading and paragraph with customizable formatting. It is ideal for highlighting key features, adding descriptions, or presenting additional information directly in your Knowledge base site’s home page. Easily format the text, apply styles, and enhance the user experience with engaging content.

**Example:** Use a **Rich text** block to showcase your best feature and make it stand out on your site:

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Rich_text_in_KBsite2_0_view.png)

---

### **Adding a** **Rich text** **Block**

To add a **Rich text** block to your Knowledge base site’s home page, follow the steps below:

1. Navigate to **Settings**() > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations.
3. From the left dropdown, select **Home** page.  
   The list of body blocks will appear in the **Body** section.

   In the **Body** section, the list of body blocks will appear.
4. Click **Add section** and select **Rich text**.  
   The **Rich text** block is added to the list.
5. Click the **Rich text** and select the desired background color.
6. Use the **Reorder**() icon to rearrange elements.
7. Click the **Hide**() icon to toggle the visibility of elements.
8. Expand the **Rich text** dropdown to access the **Heading**  and **Paragraph** options.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Rich_text_blocks.gif)

### **Available options**

9. Click **Heading** to edit the heading content.  
   The **Heading**  panel will appear.
10. Enter the desired text in the **Heading text** field.
11. Use the **Text color** palette to choose a color for your heading.
12. In the **Alignment** section, select one of the following options:

    1. **Left****:** Aligns the text to the left.
    2. **Center****:** Aligns the text to the center.
    3. **Right****:** Aligns the text to the right.
13. Click **Delete** to remove only the Heading element.
14. Click **Paragraph** to add a paragraph text block.
15. Enter your content in the **Paragraph text** field.
16. Format the paragraph using the following options:

    1. **Bold** (): Apply bold formatting to text.
    2. **Italic** (): Apply italic formatting to text.
    3. **URL/Link** (): Add URLs or hyperlinks within the text.
    4. **Unordered list** (): Add a bulleted list.
    5. **Ordered list** (): Add a numbered list.
    > NOTE
    >
    > **Markdown syntax** is supported for formatting **Paragraph text** block.
17. Choose the **Text color** palette to set the desired text color.
18. In the **Alignment** section, select one of the following:

    1. **Left****:** Aligns the text to the left.
    2. **Center****:** Aligns the text to the center.
    3. **Right****:** Aligns the text to the right.
19. Click **Delete** to remove only the Paragraph element.
20. Click **Save** and click **Preview** to view the changes on the Knowledge base site.
21. Once done, click **Publish** to apply the changes.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-available_options_in_Rich_text_blocks.gif)

---

### FAQ

#### How do I delete a **Rich text** block from my Knowledge base site’s home page?

Follow these steps to delete a **Rich text** block:

1. Navigate to **Settings**() > **Knowledge base site** > **Customize site** > **Customize site** in the Knowledge base portal.
2. From the left-side dropdown, select **Home** page.  
   The list of body blocks appear will in the **Body** section.
3. Click the desired **Rich text** block.  
   The **Rich text** panel will appear.
4. Click **Delete** and confirm by clicking **Yes** in the **Delete confirmation** prompt.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="text-columns-block"></a>

## Multicolumn card section

**Plans supporting customization of knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The Multicolumn card section allows you to add lists of features, an **About** section, or a **Contact** section to your homepage. Each column includes an icon, a title, and a description field. Using Multicolumn cards on your homepage creates a visually appealing structure that engages users, helps them quickly find key information, and highlights your core offerings.

For example, a software company could use the Multicolumn card section on its homepage to showcase key product features, such as **Data Security**, **User Management**, and **24/7 Support**. Each column could display an icon representing the feature, a concise title, and a brief description. This setup provides a quick interactive view of the software's benefits, helping potential customers quickly understand the product's value.

---

## Adding Multicolumn cards

To add a Multicolumn card section in the Knowledge base site, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations in the **Customize site** page.
3. From the left-side drop-down menu, select the **Home** page to customize.

   The body section will display a list of body blocks.
4. Click **Add section**, then select **Multicolumn card section**.

   By default, the multicolumn card section includes three elements.
5. Click the **Multicolumn card section** to edit the title and overall icon color for the section.
6. To add more column elements, click **Add element** under the Multicolumn card section.
7. The **Reorder** () icon facilitates the rearrangement of elements.
8. Click the **Hide** () icon to toggle the visibility of elements.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Adding_Multicolumn_Cards.gif)

### Available options for elements

9. Click an element to edit the following attributes:

   * **Icon**:

     + Click **Change** to update icons for each column.
     + In the **Icons** tab, select a Document360 or [Font Awesome](https://fontawesome.com/icons) icon.
     + In the **Image** tab, either enter the image URL or upload one from the Drive.
   * **Title**: Enter a title for the element. Click the **Hide** () icon to hide it.
   * **Icon color**: Change the icon’s color.
   * **Paragraph text**: Enter the description for each column. The following formatting options are available:

     + **Bold** (): Apply bold formatting to text.
     + **Italic** (): Apply italic formatting to text.
     + **URL/Link** (): Add URLs or hyperlinks within the text.
     + **Unordered list** (): Add a bulleted list.
     + **Ordered list** (): Add a numbered list.
10. Click **Preview** to see your changes in the Knowledge base site.
11. Once finished, click **Save** and **Publish**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Available_options_for_elements.png)

---

### Removing the Multicolumn card

To delete a multicolumn card, follow the steps below:

1. Click the **Multicolumn card section**.

   The Multicolumn card section navigation bar will appear.
2. Click **Delete** () in the navigation bar.
3. Click **Yes** in the **Delete confirmation** prompt.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Removing_the_multicolumn_card.png)

---

### FAQ

**How can I update a Multicolumn card element’s icon using Font Awesome?**

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Customize site** in the Knowledge base portal.
2. From the left-side drop-down menu, select the **Home** page to customize.
3. Click the desired element in the Multicolumn card section.
4. Click **Change** in the icon settings.
5. Expand the **Font Awesome** accordion, and enter the class name of the desired Font Awesome icon.

   For example, for the code `<i class="fa-solid fa-files"></i>`, the class name is `fa-solid fa-files`.

<a id="image-and-text"></a>

## Image with text block

**Plans supporting customization of knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Enhance your Knowledge base site’s home page with the **Image with text** block, a versatile option that combines text and an image to effectively showcase features, descriptions, or announcements. Unlike the **Rich text** block, this feature allows you to visually enrich your content with imagery.

**Example**: Using **Image with text** block, you can showcase your latest feature and its description with dynamic artifacts in your Knowledge base site’s home page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Image_with_text_knowlegde_base_site_view.png)

---

## Adding an Image with text block

To add a **Image with text** block to your Knowledge base site’s home page, follow the steps below:

1. Navigate to **Settings**() > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations.
3. From the left dropdown, select **Home** page.  
   The **Body** section will display a list of body blocks.
4. Click **Add section** and select **Image with text**.  
   The **Image with text** block is added to the list.
5. Use the **Reorder** () icon to rearrange elements.
6. Click the **Hide** () icon to toggle the visibility of elements.
7. Expand the **Image with text** dropdown to access the **Image**, **Heading**  and **Paragraph** elements.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Adding_image_with_text_feature.gif)

### Available options

8. Click the **Image** to edit the image.

   The **Image** panel will appear.
9. Click **Change**to upload or update the image.
10. In the **Image** tab, enter the image URL or upload one from your Drive.
11. In the **Alignment** section, select one of the following options:

    1. **Left****:** Aligns the image to the left.
    2. **Center****:** Aligns the image to the center.
    3. **Right****:** Aligns the image to the right.
12. Click **Heading** to edit the heading content.  
    The **Heading**  panel will appear.
13. Enter the desired text in the **Heading text** field.
14. Use the **Text color** palette to choose a color for your heading.
15. In the **Alignment** section, choose an alignment option: **Left**, **Center**, or **Right**.
16. Click **Delete** to remove only the Heading element.
17. Click **Paragraph** to add a paragraph text block.
18. Enter your content in the **Paragraph text** field.
19. Format the paragraph using the following options:

    1. **Bold** (): Apply bold formatting to text.
    2. **Italic** (): Apply italic formatting to text.
    3. **URL/Link** (): Add URLs or hyperlinks within the text.
    4. **Unordered list** (): Add a bulleted list.
    5. **Ordered list** (): Add a numbered list.
    > NOTE
    >
    > **Markdown syntax** is supported for formatting **Paragraph text** block.
20. Choose the **Text color** palette to set the desired text color.
21. In the **Alignment** section, choose an alignment option: **Left**, **Center**, or **Right**.
22. Click **Delete** to remove only the Paragraph element.
23. Click **Save** and click **Preview** to view the changes on the Knowledge base site.
24. Once done, click **Publish** to apply the changes.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Accessing_image_with_text_feature_.gif)

---

### FAQ

#### How do I delete an **Image with text** block from my Knowledge base site’s home page?

Follow these steps to delete an **Image with text** block:

1. Navigate to **Settings**() > **Knowledge base site** > **Customize site** > **Customize site** in the Knowledge base portal.
2. From the left-side dropdown, select **Home** page.  
   The list of body blocks appear will in the **Body** section.
3. Click the desired **Image with text** block.  
   The **Image with text** panel will appear.
4. Click **Delete** and confirm by clicking **Yes** in the **Delete confirmation** prompt.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="html-block"></a>

## Custom code section

**Plans supporting customization of** **Knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Custom code section** in **Document360** allows users to add personalized HTML and CSS code to their Knowledge base site home page. This feature is ideal for users looking to enhance their site with custom visuals and interactive widgets.

Suppose your organization runs seasonal promotions. You can use the **Custom code section** to embed a dynamic banner or a countdown timer directly on the home page of your Knowledge base site, ensuring your visitors are aware of ongoing offers or events.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Knowledge_base_site_output.png)

---

## Adding a **Custom code section**

To add a **Custom HTML** block to your Knowledge base site’s home page, follow the steps:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations.
3. From the left dropdown, select **Home** page.  
   In the **Body** section, a list of body blocks will appear.
4. Click **Add section** and select **Custom code section**.  
   The **Custom code section** block is added to the list.
5. Use the **Reorder** () icon to rearrange elements.
6. Click the **Hide** () icon to toggle the visibility of elements.
7. Click the **Custom code section**:

   1. In the **HTML** tab, add or edit the HTML code.
   2. In the **CSS** tab, add or edit the CSS code.
8. Turn on the **Preview** toggle to view the changes.
9. Click **Save** and then click **Preview** to view the changes on the Knowledge base site.
10. Once done, click **Publish** to apply the changes.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Adding_a_Custom_code_Section.gif)

---

### FAQ

#### How do I delete the **Custom HTML** block from my Knowledge base site home page?

To delete a **Custom HTML** block, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations.
3. From the left dropdown, select **Home** page.
4. In the **Body** section, select the desired **Custom code section**.

   The **Custom code section** navigation panel will appear.
5. Click the **Delete** () below the navigation bar.
6. Click **Yes** in the **Delete confirmation** panel.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="knowledge-base-categories"></a>

## Knowledge base categories block

**Plans supporting customization of** **Knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Knowledge base categories** block allows you to design a visually appealing and highly functional home page for your Knowledge base site. By showcasing links to popular categories or frequently accessed sections as cards, this feature helps users navigate your documentation effortlessly, improving their overall experience.

Imagine managing a growing Knowledge base for a SaaS product. Customers frequently visit the home page looking for guides, FAQs, or troubleshooting articles. By adding the **Knowledge base categories** block, you can prominently feature "Getting Started," "How-To Guides," or "Troubleshooting Articles" as categories, ensuring users can quickly find the most relevant information. This reduces search time and enhances user satisfaction.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Knowledge_base_site_view_of_Knowledge_base_categories.png)

---

## Adding **Knowledge base categories** block

To add a Knowledge base categories block to your Knowledge base site’s home page, follow the steps below:

1. Navigate to **Settings**() > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations.
3. From the left dropdown, select **Home** page.  
   The **Body** section will display a list of body blocks.
4. Click **Add section** and select **Knowledge base categories**.  
   The **Knowledge base categories** block will be added to the list.
5. Click the **Knowledge base categories** to edit the title and overall icon color for the section.
6. Click **Add element** to add more category elements.
7. Select the desired categories from your Knowledge base.
8. Use the **Reorder** () icon to rearrange elements.
9. Click the **Hide** () icon to toggle the visibility of elements.

#### Available options

10. Click a category element to edit the following attributes:

    1. **Icon**:

       * Click **Change** to update icons for each category element.
       * In the **Icons** tab, select either a Document360 or [Font Awesome](https://fontawesome.com/icons) icon.
       * In the **Image** tab, either enter the image URL or upload an image from the Drive.
    > **NOTE**
    >
    > Use square-dimension image files (e.g., 30px x 30px or 50px x 50px) to avoid distortions.

    1. **Title**: Enter a title for the category element.
    2. **Icon color**: Choose the desired color for the icon.
    3. **Paragraph text**: Add a description for each column using Markdown syntax.
    4. **Text color**: Select the text color for the title and paragraph.
11. Click **Save** and then **Preview** to view the changes on the Knowledge base site.
12. Once done, click **Publish** to apply the changes.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Adding_the_Knowledge_base_categories.gif)

---

### FAQ

#### How do I remove **the **Knowledge base categories** block?**

To remove a knowledge base categories block in the Knowledge base site:

1. Navigate to **Settings**() > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations.
3. From the left dropdown, select **Home** page.   
   The **Body** section will display a list of body blocks.
4. Select the desired **Knowledge base categories** in the **Body** section.
5. Click the **Delete** () below the navigation bar.
6. Click **Yes** in the **Delete confirmation** panel.

   To delete specific category elements, follow similar steps and select the desired element.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="widgets"></a>

## Widgets block

**Plans supporting customization of knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Widgets** are embedded blocks on the platform that serve specific purposes. Now, you can add widgets below the header section on your homepage.

## Adding widget(s) on your Home page

To add widgets to your Homepage,

1. Navigate to **Settings** () **> Knowledge base site > Customize site** in the Knowledge base portal.

   This page contains all the basic site design configurations.
2. Click **Customize site**.
3. From the left-side drop-down menu, select **Home page**.

   You can view the list of body blocks in the body section.
4. Click **Add section**.
5. Select **Widgets** from the available options.
6. The widgets block is added with a **Widgets** dropdown button.

> **NOTE**
>
> * Click the reorder icon () to rearrange elements.
> * Click the preview icon () to toggle the visibility of elements.

7. Click **Add element** and select from the five available widget options:

   1. **Most Viewed Articles:** Views are measured when the readers accessing the articles.
   2. **Most Liked Articles:** Likes are measured when a reader hits the  icon at the end of each article on the Knowledge base site.
   3. **Most Read Articles:** Reads are tracked when a reader:

      * Scrolls through more than half of the article, or
      * Spends more than one minute on the article, or
      * Clicks a hyperlink within the article.
   4. **Recently Modified Articles:** Published articles that have been updated and republished.
   5. **Recently Created Articles:** New articles that have been published for the first time.

> NOTE
>
> * Every time you create and publish an article, it will appear in both the **Recently Created Articles** and **Recently Modified Articles** sections.
> * Only the articles you have access to will appear in this block.

8. Click the desired widgets to add in your homepage.
9. Click on each widget to edit its heading.
10. Click **Preview** at the top to see how the widgets will appear on your Knowledge base homepage.
11. Once finished, click **Save and Publish** to apply the changes to your Knowledge base site.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Widget_knolwedge%20base%20portal%202.0%20view.png)

### Knowledge base site view

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Widget_knolwedge%20base%20site%202.0%20view.png)

---

## Deleting the widget section

To delete any widget elements or the entire widget block:

1. Navigate to Settings () **> Knowledge base site > Customize site** > **Customize site** in the Knowledge base portal.
2. In the **Home** dropdown, go to the **Widgets** section.

   The **Widgets** panel will appear.
3. Click **Delete** at the bottom.

   A delete confirmation prompt will appear.
4. Click **Yes** to confirm.
5. To delete the individual widget elements, follow the same process.
6. Once done, click **Save** and **Publish** to reflect the changes in the Knowledge base site.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Deleting_the_Knowledge_base_site.gif)

---

### FAQs

#### **How do I hide the widget elements from the Knowledge base site?**

To hide widget elements such as Most viewed articles, Most liked articles, Most read articles, Recently modified articles, and Recently created articles, follow the steps below:

1. Navigate to **Settings** () **> Knowledge base site > Customize site** > **Customize site** in the Knowledge base portal.
2. In the **Home** dropdown, select the **Widgets** section.
3. Hover over the desired widget element and click on the **Hide** () icon.
4. Once done, click **Save** and **Publish** to apply the changes.

   The hidden element will no longer be visible on the Knowledge base site.

#### **How do I rearrange the widget elements in the Knowledge base site?**

TO rearrange the widget elements, follow the steps below:

1. Navigate to **Settings** () **> Knowledge base site > Customize site** > **Customize site** in the Knowledge base portal.
2. In the **Home** dropdown, select the **Widgets** section.
3. Hover over the desired widget element and click the **drag and drop** () icon.
4. Once done, click **Save** and **Publish** to apply the changes.

#### **Why do my Recently Created Articles and Recently Modified Articles elements appear similar in the Knowledge base site?**

The two serve different purposes. **Recently Created Articles** lists newly created articles, while **Recently Modified Articles** lists the last five modified articles.

For instance, if you create five articles and then edit and publish them, those articles will appear in both lists because they are considered both recently created and recently modified.

The public-facing website where end-users can access articles and find answers to their questions.

<a id="error-pages"></a>

## Error pages

**Plans supporting error page**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Error pages in Document360 serve as fallback landing pages when a Knowledge base reader attempts to access broken, unauthorized, or restricted links. These pages enhance user experience by guiding users through brief, branded messages and redirecting them to the appropriate pages with clear action steps.

Imagine a scenario where a user tries to access an outdated or restricted link within the Knowledge base site. Instead of displaying a generic error message, you can direct the user to a custom-designed page that includes your brand logo, brief information about the error, and suggested next steps—such as navigating back to the homepage or contacting support. This ensures users remain engaged and informed while interacting with your Knowledge base site.

---

## Accessing the error pages design settings

To access the error page, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.

   The **Customize site** page holds all the basic site design configurations.
2. Click the **Customize site**.
3. From the left dropdown menu, select the desired error page:

   * [404](/help/docs/404-page)
   * [Access denied](/help/docs/access-denied-page)
   * [Unauthorized](/help/docs/unauthorized-page)
   * [IP restriction](/help/docs/ip-restriction-page)
4. A default page design is available for you to customize. You can choose from the two options:

   * **Basic style**: Customize the default image.
   * **Custom style**: Add custom HTML and CSS. Use the **Preview** toggle on the right side to switch between code view and rendered view.
5. Click **Save** to save all recent changes.
6. Click **Preview** to see the changes on the site.
7. Click **Publish** to activate the changes on the Knowledge base site.

> NOTE
>
> Once you configure an error page, you cannot revert to the default static page. It's recommended to use custom static pages to enhance the Knowledge base experience.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Accessing_custom_pages_Design_settings.gif)

---

### Difference between Access denied and Unauthorized pages

While the **Access denied** and **Unauthorized pages** may seem similar, they refer to distinct situations in the knowledge base.

* The **Access denied** page is shown when a user does not have permission to access specific content or sections within the knowledge base.
* The **Unauthorized** page, on the other hand, typically appears when a user tries to access a page or resource that requires authentication, but they are not logged in or their session has expired.

**Example:** Let’s say a user is logged into a private knowledge base but only has permission to view product documentation. If they attempt to access a confidential section reserved for admins, the **Access denied** page will appear, informing them they lack the required permission.

---

### FAQs

**Can I upload images from my local storage for error page design?**

Yes, you can import images from your drive or local storage.

**Why are the Access denied and Unauthorized error pages disabled for my project?**

These error pages are only available for Private or Mixed access projects.

**Can I add video or GIF elements to the error page design?**

Yes, you can add Screen GIFs and video elements to the error page design.

**Is it possible to switch back to the default static page after configuring a error page?**

No, once you configure a error page, you cannot switch back to the default static page.

<a id="404-page"></a>

## 404 page

**Plans supporting error pages**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## What is a 404 page?

A 404 page appears when a reader tries to access a nonexistent page on the Knowledge base site. For instance, when a reader attempts to access a deleted URL in the Knowledge base site, a 404 page will appear.

Customize the 404 error page of your Knowledge base site by adding a custom message and illustration. This enhances the reader's experience, guiding them to the desired pages instead of leaving them on a default 404 page. You can add links, titles, descriptions, and images that reflect your brand. The 404 page can be customized using either the basic or custom style.

> NOTE
>
> Once you configure a custom 404 page, you cannot revert to the default. It's recommended to have a custom 404 page to improve the reader experience.

---

## Customizing the 404 page

To customize the 404 page, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.

   The **Customize site** page contains all the basic site design configurations.
2. Click **Customize site**.
3. From the left dropdown menu, select **404** page.
4. Customize the page using one of two options:

   * **Basic style**: Allows customization of the default image.
   * **Custom style**: Add custom HTML and CSS. Use the **Preview** toggle to switch between code view and rendered view.
5. Click **Save** to save recent changes.
6. Click **Preview** to view changes.
7. Click **Publish** to apply changes to the Knowledge base site.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Accessing_custom_pages_Design_settings.gif)

---

### Basic style

#### Image

Upload a related image to enhance the page.

1. Click **Image**.

   The **Image** panel will appear.
2. Click **Change** and choose between two options:

   a. **Default images**: Select from the default images and click **Save**.

   b. **Image**: Either provide a URL or upload an image from your drive.

   * To upload from URL: Enter the image URL in the URL field and click **Save**.
   * To upload from your drive: Click **Upload an image**, select the file, and click **Save**.
3. Set the image alignment (left, center, or right) as needed.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Upload_Image_Basic_style.png)

#### Heading

1. Click **Heading**.

   The **Heading** panel will appear.
2. Enter the desired heading text.
3. Select a color from the text color palette.

> The default heading will be "404."

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Header_Basic_style_.png)

#### Paragraph

1. Click **Paragraph**.  
   The **Paragraph** panel will appear.
2. Enter a description for the page. This will help readers understand the context.
3. Select a color from the text color palette.

> The default text will be "Oops! Page not found."

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Paragraph_Basic_style_.png)

#### Buttons

Add up to three link buttons to guide readers to the desired pages.

1. Click **Buttons**.
2. Click the **Add button** to create a new button.
3. Enter text and URL for each button.
4. Click the **Delete** () icon to remove a button or the **Hide** () icon to hide it.
5. Click **Delete** at the bottom to remove all buttons.
6. Once done, click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Buttons_Basic_style_.png)

> NOTE
>
> Suggested links to include on the 404 page:
>
> * Home page
> * Contact page/form for readers to report a broken link
> * Knowledge base sitemap
> * Some of your most popular blog pages
> * Most popular or valuable product or category pages

---

### Custom style

Customize the 404 page with HTML or CSS section.

1. Select **Custom style** and switch between the **HTML** and **CSS** sections.
2. Update the code as required in each section.
3. Turn on the **Preview** toggle to view the updated page.
4. Once done, click **Save** and **Publish**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Custom_style_preview.png)

> NOTE
>
> **Page not found** feature in Document360 shows the list of URLs for which a 404-page error is shown after the link is accessed. It helps in replacing this URL with redirecting URL, which can provide the required content and enhance the reader experience. Also using redirection rule, we can fix the 404-page error.  
> For more information, read the article on [Page not found analytics](/help/docs/page-not-found-analytics).

> NOTE
>
> **Links status** feature checks for broken links across your Knowledge base site and helps you fix them to enhance SEO and improve reader experience. For more information, read the article on [Link status](/help/docs/links-status).

---

### FAQs

#### **What are the common causes of 404 errors?**

Some of the common causes of 404 errors for articles on the Knowledge base site are:

* **Deleted URL:** The article might have been deleted, and the page no longer exists.
* **Changed URL:** The URL of the article was changed, but a redirection wasn’t set up.

  > NOTE
  >
  > When updating an article URL, ensure a redirection rule is applied in the Knowledge base portal.
* **Subfolder path:** All articles on the Knowledge base site may result in 404 errors if the subfolder path is changed from its default name, **“docs.”** This issue applies only when the subfolder host is disabled. Change the subfolder path back to the default **“docs”** and save the changes.
* **Redirection rule:** A redirection rule might be misconfigured, either redirecting the article incorrectly or causing a 404 error.

  1. Go to **Settings** () > **Article redirect rules** and check for any rules applied to the article.
  2. Validate and remove unnecessary or misconfigured rules.
* **Incorrect URL:** The URL was mistyped or linked incorrectly. Ensure the article slug is in all lowercase letters.

  **Server issues:** A server problem prevented the page from loading.

#### **What are the best practices to create a 404 page?**

The best practices for creating a 404 page are:

1. **Keep the design consistent**

* Ensure the 404 page matches the overall look and feel of your website or product.
* Use the same branding, colors, and fonts to create a seamless experience and avoid confusion.

2. **Use clear and friendly language**

* Avoid overly technical jargon. Use simple, friendly language that lets users know they’re in the right place but the page is unavailable.
* Acknowledge the error with a human touch.

3. **Offer helpful navigation**

* Provide clear links to guide users back on track:

  + **Homepage**
  + **Search bar**
  + **Popular or recommended pages**
* Consider offering links to **frequently visited sections**, like support, contact, or a knowledge base.

4. **Add a search bar**

Give users the chance to search for what they were trying to find. A well-placed search bar can help them continue their journey seamlessly.

5. **Explain what might have happened**

* Include a short explanation of why the user may have ended up there (e.g., broken link, outdated URL).
* Keep it light and user-friendly: "It’s possible the page has been moved or no longer exists."

6. **Include a Call-to-Action (CTA)**

* Suggest actions they can take:

  + **Contact support** for help.
  + **Report the broken link**.
* For an e-commerce site, offering product recommendations or deals could also be beneficial.

7. **Add a touch of humor or personality**

* Inject some personality with humor or visuals. A light-hearted approach can ease the frustration of hitting an error.
* Use quirky messaging like: "Looks like this page is on vacation!" or visual elements like an illustration.

8. **Make the page functional**

* Ensure any buttons or links on the 404 page are working properly and are easy to locate.
* Double-check that navigation back to the homepage or other sections is smooth and intuitive.

9. **Add a feedback option**

Provide a link or form to report the issue or give feedback. This can help identify any broken links or common user issues.

10. **Consider SEO**

* Include proper meta tags and an SEO-friendly 404 page that informs search engines of the missing page.
* Include relevant internal links so search engines can still index your important pages.

11. **Use an eye-catching image or animation**

* Visuals can make the 404 page engaging. You can use custom illustrations, fun animations, or even GIFs to add interest and reduce frustration.

12. **Ensure it’s mobile-friendly**

* Make sure your 404 page is responsive and works well on mobile devices, just like the rest of your site.

<a id="access-denied-page"></a>

## Access denied page

**Plans supporting error page**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## Access denied page

The **Access denied** page appears when a reader with limited permissions in your knowledge base tries to access a URL they are not authorized to view.

For example, if a reader has access to only certain categories in a mixed knowledge base and attempts to access a restricted URL outside of their permissions, they will be redirected to the **Access denied** page.

Customize the **Access denied** page of your knowledge base to provide a more helpful experience by including a clear reason and solution, such as: *"*You don’t have permission to access this page. Contact your admin to request access*."* Customizing this page helps readers understand why they can’t access certain content and how to resolve the issue.

> NOTE
>
> * The **Access denied** page is available only for Private and Mixed projects.
> * Once a custom page is configured, you cannot revert to the default **Access denied** page. It's recommended to have a custom access denied page to enhance the user experience.

![2_Screenshot-Example_Access_denied_custom_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Example_Access_denied_custom_page.png)

---

## Customizing the Access denied page

To customize the Access denied page, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.

   The **Customize site** page contains all the basic site design configurations.
2. Click **Customize site**.
3. From the left dropdown menu, select **Access denied** page.
4. Customize the page using one of two options:

   * **Basic style**: Allows customization of the default image.
   * **Custom style**: Add custom HTML and CSS. Use the **Preview** toggle to switch between code view and rendered view.
5. Click **Save** to save recent changes.
6. Click **Preview** to view changes.
7. Click **Publish** to apply changes to the Knowledge base site.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Customizing_the_Access_Denied_page.gif)

---

### Basic style

#### Adding an image

You can upload an image to make the Access Denied page more engaging.

1. Click **Image**.

   The **Image** panel will appear.
2. Click **Change** and choose between two options:

   a. **Default images**: Select from the default images and click **Save**.

   b. **Image**: Either provide a URL or upload an image from your drive.

   * To upload from URL: Enter the image URL in the URL field and click **Save**.
   * To upload from your drive: Click **Upload an image**, select the file, and click **Save**.
3. Set the image alignment (left, center, or right) as needed.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Image_basic_style_access_denied_page.png)

#### Adding a heading

1. Click **Heading**.

   The **Heading** panel will appear.
2. Enter the desired heading text.
3. Select a color from the text color palette.

> The default heading will be "Sorry!".

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-heading_basic_style_access_denied_page.png)

#### Adding a paragraph

1. Click **Paragraph**.  
   The **Paragraph** panel will appear.
2. Enter a description for the page. This will help readers understand the context.
3. Select a color from the text color palette.

> The default paragraph will be “You are not authorized to access this article or page.”

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Paragraph_basic_style_access_denied_page.png)

### Custom style

Customize the **Access denied** page with HTML or CSS section.

1. Select **Custom style** and switch between the **HTML** and **CSS** sections.
2. Update the code as required in each section.
3. Turn on the **Preview** toggle to view the updated page.
4. Once done, click **Save** and **Publish**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Custom_style_access_denied_page.png)

---

### FAQs

**Is the Access denied page available for all project types?**

No, the Access denied page is only available for Private and Mixed projects.

**Can I revert to the default Access denied page after customizing it?**

No, once a custom page is configured, you cannot revert to the default Access denied page.

**How do I hide heading and paragraph elements on the Access denied page?**

To hide the **Heading** or **Paragraph** elements on the Access Denied page, follow these steps:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.

   The **Customize site** page will display all the basic site design configurations.
2. Click **Customize site**.
3. From the left dropdown menu, select **Access denied** page.
4. Hover over the **Heading** or **Paragraph** and click the **Hide** () icon.
5. To unhide these elements, click the **Unhide** () icon.

   > NOTE
   >
   > You cannot unhide or delete the image element in the Access denied page.

**Can I upload my own image for the Access denied page?**

Yes, you can upload your own image or select from default images for the Access denied page.

**What are the best practices while customizing the Access denied page?**

* **Use clear language**: Ensure the message is simple and instructive. Example: “You don’t have permission to access this page. Contact the admin for help.”
* **Link to help resources**: Consider adding a link to a FAQ section or a **Contact support** button for a better user experience.
* **Responsive design**: Ensure the page looks good on both desktop and mobile devices. Test your customizations to confirm that images and text are displayed correctly on all screen sizes.

<a id="unauthorized-page"></a>

## Unauthorized page

**Plans supporting error page**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## Unauthorized page

The **Unauthorized** page appears when a user without proper permissions attempts to access a restricted URL in your knowledge base. For example, this page will display if a user tries to access private content without the necessary access rights.

To improve user experience, you can customize the Unauthorized page by adding a descriptive message that explains the reason for restricted access and provides a solution, such as: “You don’t have permission to view this page. Contact your admin to request access.”

> NOTE
>
> Once you configure a **custom unauthorized** page, it cannot be reverted to the default version. We recommend creating a custom unauthorized page to enhance the user experience.

![2_Screenshot-Example_Unauthorized_denied_custom_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Example_Unauthorized_denied_custom_page.png)

---

## Customizing the Unauthorized page

Follow these steps to customize the Unauthorized page:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.

   The **Customize site** page contains all the basic site design configurations.
2. Click **Customize site**.
3. From the left dropdown menu, select **Unauthorized** page.
4. Customize the page using one of two options:

   * **Basic style**: Customize the default image and text.
   * **Custom style**: Add your own HTML and CSS for a fully personalized page.Use the **Preview** toggle to switch between code view and rendered view.
5. Click **Save** to save recent changes.
6. Click **Preview** to view changes.
7. Click **Publish** to apply changes to the Knowledge base site.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF_Accessing_Unauthorized_page.gif)

---

### Basic style

#### Adding an image

To enhance the page visually, you can upload a relevant image.

1. Click **Image**.

   The **Image** panel will appear.
2. Click **Change** and choose between two options:

   a. **Default images**: Select from the default images and click **Save**.

   b. **Image**: Either provide a URL or upload an image from your drive.

   * To upload from URL: Enter the image URL in the URL field and click **Save**.
   * To upload from your drive: Click **Upload an image**, select the file, and click **Save**.
3. Set the image alignment (left, center, or right) as needed.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Image_basic_style_access_denied_page.png)

#### Updating the heading

1. Click **Heading**.

   The **Heading** panel will appear.
2. Enter the desired heading text.
3. Select a color from the text color palette.

> The default heading will be "Sorry!".

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-heading_basic_style_access_denied_page.png)

#### Updating the paragraph

1. Click **Paragraph**.  
   The **Paragraph** panel will appear.
2. Enter a description for the page. This will help readers understand the context.
3. Select a color from the text color palette.

> The default paragraph will be “You are not authorized to access this article or page.”

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Paragraph_basic_style_access_denied_page.png)

### Custom style

Customize the **Unauthorized** page with HTML or CSS section.

1. Select **Custom style** and switch between the **HTML** and **CSS** sections.
2. Update the code as required in each section.
3. Turn on the **Preview** toggle to view the updated page.
4. Once done, click **Save** and **Publish**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Custom_Style_in_Unauthorized.png)

<a id="ip-restriction-page"></a>

## IP restriction page

**Plans supporting error page**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## IP restriction page

The **IP restriction page** appears when a reader attempts to access the Knowledge base site URL from a restricted IP address.

For example, if you've limited access to your knowledge base to a specific IP range, and a reader attempts to access the site from an IP address outside that range, they will see the **IP Restriction** page.

You can customize this page and provide a clear message with instructions, such as: “Your IP address is not authorized. Please contact your admin for access.” This helps users understand why they’re being restricted and how to resolve the issue.

> NOTE
>
> * IP restriction page is available only for the **Enterprise plan** projects.
> * Once a custom IP restriction page is configured, you cannot revert to the default version. It is recommended to create a custom page to enhance the reader experience.

---

## Customizing the IP restriction page

Follow these steps to customize the IP restriction page:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.

   The **Customize site** page contains all the basic site design configurations.
2. Click **Customize site**.
3. From the left dropdown menu, select **IP restriction** page.
4. Customize the page using one of two options:

   * **Basic style**: Modify the default image and text.
   * **Custom style**: Add your own HTML and CSS for advanced customization. Use the **Preview** toggle to switch between code view and rendered view.
5. Click **Save** to save recent changes.
6. Click **Preview** to view changes.
7. Click **Publish** to apply changes to the Knowledge base site.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Accessing_IP_restriction_page_in_the_Knowledge_base_portal.gif)

---

### Basic style

#### Adding an image

Upload a related image to enhance the page.

1. Click **Image**.

   The **Image** panel will appear.
2. Click **Change** and choose between two options:

   a. **Default images**: Select from the default images and click **Save**.

   b. **Image**: Either provide a URL or upload an image from your drive.

   * To upload from URL: Enter the image URL in the URL field and click **Save**.
   * To upload from your drive: Click **Upload an image**, select the file, and click **Save**.
3. Set the image alignment (left, center, or right) as needed.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Adding_images_in_the_IP_restriction_page.png)

#### Customizing the heading

1. Click **Heading**.

   The **Heading** panel will appear.
2. Enter the desired heading text.
3. Select a color from the text color palette.

> The default heading will be "Sorry!".

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Adding_header_in_the_IP_restriction_page.png)

#### Customizing the paragraph

1. Click **Paragraph**.  
   The **Paragraph** panel will appear.
2. Enter a description for the page. This will help readers understand the context.
3. Select a color from the text color palette.

> The default paragraph will be “Your IP address {{template:IPAddress}} is restricted from accessing this article or page.”

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Adding_Paragraph_in_the_IP_restriction_page.png)

### Custom style

Customize the **IP restriction** page with HTML or CSS section.

1. Select **Custom style** and switch between the **HTML** and **CSS** sections.
2. Update the code as required in each section.
3. Turn on the **Preview** toggle to view the updated page.
4. Once done, click **Save** and **Publish**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Adding_Custom_CSS&JS_in_the_IP_restriction_page.png)

<a id="custom-css-javascript"></a>

## Custom CSS & JavaScript

**Plans supporting the use of custom CSS and JS in Knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## CSS snippets

A snippet is a piece of reusable code, and a CSS Snippet "CSS (Cascading Style Sheets) + Snippet" is a set of utilities and interactive examples for CSS3. It helps create the frequently used layout templates. These are pre-written blocks of code that developers can quickly insert into their projects to achieve specific functionalities without writing the code from scratch.

These snippets help streamline the development process by saving time, reducing errors, and ensuring consistency across the codebase.

An example of a CSS snippet:

```
.shadow {
 box-shadow: 0px 5px 5px rgba(0,0,0,0.4);
 -moz-box-shadow: 0px 5px 5px rgba(0,0,0,0.4);
 -webkit-box-shadow: 0px 5px 5px rgba(0,0,0,0.4);
 }
```

CSS

Copy

The above CSS snippet can make borders and images stand out on your page.

### Customizing CSS using CSS snippets

To customize CSS using CSS snippets, follow the below steps:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. In the **CSS** tab, you can add code snippets in two ways:

   a. Enter the code snippet in the text area.

   b. Click **Add code snippets** to add the preloaded snippets (7 preloaded snippets).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Adding_code_snippet_in_the_Custom_CSS_tab.png)

3. Once done, click **Save** or Ctrl + S to save the changes you made.

   > For more information, read the article on [CSS Snippets](/help/docs/css-snippets).

---

## JavaScript snippets

A JavaScript snippet is a reusable piece of code written in JavaScript, typically used to perform specific tasks or add functionality to a web page. These snippets are often small, focused, and designed to be easily inserted into existing codebases.

### Customizing JavaScript using custom JavaScript snippets

To customize JavaScript using custom JavaScript snippets, follow the below steps:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **JavaScript**tab and paste the desired code in the JavaScript snippet.

   For example, to move the related articles above the feedback section in the Knowledge base site, paste the following code into the JavaScript snippet.

```
window.onload = function () {
$(".content_block_text" ).append("<div class=\"sperator\"><hr></div>");
$('.related-articles-container').appendTo('.content_block_text') 
}
```

JavaScript

Copy

4. Once done, click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Adding_the_code_in_Custom_JavaScript_snippet.png)

---

## Troubleshooting

### Adapting custom code for the Single Page Application (SPA) model in Document360

With the transition of the Document360 website to a Single Page Application (SPA) model, any custom JavaScript dependent on page refresh events may no longer function as expected. This is because SPAs refresh only the article content, not the entire page.

Below are the areas where users can inject Custom JavaScript within the Document360 portal:

1. **Custom JavaScript**

   Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. **Custom HTML Integrations**  
   Navigate to **Settings** () > **Knowledge base site** > **Integrations** > **Custom HTML** in the Knowledge base portal.

**Recommended solution**

To ensure compatibility with the SPA model, update your custom JavaScript to use the `articleload` event. This event triggers when the article content refreshes, ensuring your scripts work seamlessly in the new architecture.

1. Replace any code that relies on page refresh events with a subscription to the `articleload` event.
2. Use the following code snippet to adapt your custom scripts:

   ```
   window.addEventListener('articleload', function() {
     // Your custom JavaScript code here
   });
   ```

   JavaScript

   Copy
3. Test your updated scripts to confirm they function correctly in the SPA environment.

   If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

---

### FAQs

#### Can custom .css files be applied in Document360?

Yes, Document360 provides you the flexibility to apply custom .css files to tailor the appearance and style of your documentation.

#### If we need to cater to multiple brands, would we require a separate workspace for each brand, or can different styles/style sheets be applied to different projects within a workspace?

If you manage multiple brands, you can either create separate workspaces within a single project or purchase additional projects for each brand. It’s important to note that any CSS added to the project will be applied universally across all workspaces. However, you still have the flexibility to customize the styling of landing pages and other elements for each workspace individually.

<a id="css-snippets"></a>

## CSS Snippets

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## CSS Snippets

A CSS (Cascading Style Sheets) snippet provides a collection of utilities and interactive examples for CSS3, helping to create commonly used layout templates efficiently. CSS snippets are valuable code pieces for saving time and improving productivity during development.

Example of a CSS snippet:

```
.CustomLink
{
 font-size:25px;
}
```

CSS

Copy

The above CSS snippet can be used to change the hyperlink size on the **Knowledge base site**.

### Steps to customize CSS in the Document360 Knowledge base site using CSS snippets

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab.
3. Click **Add code snippets** on the top right of the code space.

   A window appears, preloaded with seven basic snippets that you can use to customize your knowledge base site namely,

* **Change body text font**
* **Change heading font**
* **Change table styles**
* **Center align images in articles**
* **Change home page builder hero section background**
* **Change callout colors**
* **Disable ‘back to top’ button**

  ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenShot-Customization.png)

You can also use snippets other than the pre-loaded Custom CSS snippets by adding your customized code snippets by navigating to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript**.

4. Press **Ctrl+S** or click the **Save** button on the top right to save the changes.

<a id="callout-styles"></a>

## Callout styles

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## What is a "Callout"?

A "Callout" is designed to highlight important information within the article content. You can insert callouts using both the Markdown and Advanced WYSIWYG editors in Document360.

---

### **Types of Callouts in Document360**

Document360 provides four inbuilt callouts for

1. **Info**

   > Your title goes here
   >
   > Your content goes here
2. **Warning**

   > Your title goes here
   >
   > Your content goes here
3. **Error**

   > Your title goes here
   >
   > Your content goes here
4. **Success**

   > Your title goes here
   >
   > Your content goes here

## Styling the Callouts

If you want to modify these callouts, follow these steps to change the background color and other styling options:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab, then click the **Add code snippets** link on the right side.

   The **Add code snippets** panel will appear.
3. Select **Change callout colors**. This will take you to the section where the existing callout colors are set.
4. Edit the code to make the necessary changes and add your branding colors.
5. Once done, click **Save**.

By modifying the custom color in the Callout snippet, the changes will be applied across the entire knowledge base.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Styling_callouts_in_Document360.gif)

---

### FAQ

**Can I style callout color in dark mode?**

You can style the callout color in dark mode. For more information, read the article on [How to change the callouts color in dark mode?](/help/docs/how-to-change-the-callouts-color-in-dark-mode).

<a id="body-font-style"></a>

## Body font style

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Body font style is essential in Document360 or any possible avenue for creating crisp, reader-required content. With Document360's **Custom CSS and JavaScript** function, users can achieve the desired font styling and overall Knowledge base look.

## Setting up the body font style using Custom CSS & JavaScript

Follow the below steps to change the body font style in Document360 using CSS Snippets.

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. Click the **Custom CSS** tab and then click the **Add code snippets** button on the top right.

   A window appears, preloaded with seven basic snippets that you can use to customize your knowledge base site.
3. Click the **Change body text font**. The snippet will be added to your Custom CSS code block.
4. Make the required changes to the code.
5. Click **Save** or press **Ctrl+S** to save the changes.

> **For example**, if you want to change the body font style to **ROBOTO** with the color Red, you can change that in the snippet code. Follow the explanatory GIF image added below.

## An explanatory GIF on changing the Body Font style

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Body%20Font%20-%20Custom%20CSS%20GIF.gif)

NOTE

**Nunito** is the default font style used. You can modify the custom font style and color in the body font snippet, and the modification applies to the entire Knowledge base.

<a id="image-alignment"></a>

## Image alignment

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Image alignment helps you keep your image in the intended area, either to the left, right, or center, and modify it to optimize the site experience for the user. It also helps you to keep the image and content proportions maintained when you resize the content on your Knowledge base site.

By default, images on your knowledge base site are aligned to the left.

## Center images in your Document360 Knowledge base

To align images centrally using custom CSS, follow the below steps:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click the **CSS** tab.
3. Click **Add code snippets** on the top right of the code space, and a window appears, preloaded with seven snippets that you can use to customize your Knowledge base site.
4. Click **Center align images in articles**, and the snippet will be added to your Custom CSS code block.
5. Click **Save**.

   For example,

KB site 1.0

KB site 2.0

```
.content_block .content_container .content_block_text img{
margin: 0 auto;
display: block;
}
```

CSS

Copy

```
article img {
    margin: 0 auto !important;
    display: block;
}
```

CSS

Copy

The image will now be centered within the frame on your Knowledge base site.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-Image_center_alignment.png)

### Aligning Images

#### 1. To align the image left

KB site 1.0

KB site 2.0

```
.content_block .content_container .content_block_text img {
    margin: 0px 0 0;
    display: block;
}
```

CSS

Copy

```
article img {
    margin: auto 0 0 0 !important;
    display: block;
}
```

CSS

Copy

#### 2. To align the image right

KB site 1.0

KB site 2.0

```
.content_block .content_container .content_block_text img {
    display: block;
    margin: 0 0 0 auto;
}
```

CSS

Copy

```
article img {
    margin: 0 0 0 auto !important;
    display: block;
}
```

CSS

Copy

#### Remove/erase a previously added code snippet

To remove the previously added code snippet, select the intended snippet and press **delete** on the keyboard.

> NOTE
>
> Before you add a new alignment snippet, don't forget to erase the previously added one.
>
> The image alignment that is set will be applied to the entire knowledge base.

---

## Resizing images on the Knowledge base site

To maintain the text and image proportions when you zoom in (enlarge) or zoom out (minimize) on your Knowledge base site,

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

KB site 1.0

KB site 2.0

```
.content_block .content_container .content_block_text img {
height: auto !important;
}
```

CSS

Copy

```
article img {
    height: auto !important;
}
```

CSS

Copy

3. Click **Save** on the top right.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Custom_CSS.png)

<a id="header-font-style"></a>

## Header font style

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Header fonts are the captain of the main content, as they lead the reader through the introduction to the main content. They are usually large and generally considered the higher-impact text in the content.

All these paramount things make choosing the right header font style more important when taking your content online.

The header fonts are usually the `<H1>`, `<H2>`, `<H3>`, and `<H4>` tags that you mostly use for your titles and headings.

NOTE

The most common Header font for technical documentation is **sans-serif**. Document360 provides this font and the freedom to customize Header fonts according to your preference.

---

## How to change the Header font style in Document360?

#### Using Custom CSS

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. Click the **Custom CSS** tab and click the **Add code snippets** button.

   A window appears, preloaded with seven basic snippets that you can use to customize your knowledge base site.
3. Click **Change heading font**. The snippet will be added to your Custom CSS code block.
4. Make the required changes to the code.
5. Click **Save** or press **Ctrl+S** to save the changes.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Header%20Font%20-%20Custom%20CSS%20GIF.gif)

NOTE

**Montserrat** is the default Header font style for all the `<H>` tags. You can modify the custom font style and color in the header font style snippet. This will be applied to the entire knowledge base.

<a id="table-style"></a>

## Table style

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Table style** is an important element in Document360 or in any possible avenue for creating a rich design layout for a document. Document360 has better layout options for **tables and table elements**.

## Why are the table elements important for a document?

Arranging information in a specific arrangement, typically with rows and columns, can help in understanding the complex structures of data.

## Style the tables using CSS Snippets in Document360

Follow the below steps to style the tables using CSS Snippets.

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab.
3. Click **Add code snippets** on the top right of the code space.

   A window appears, preloaded with seven basic snippets that you can use to customize your knowledge base site.
4. Click the **Change table styles** (the snippet appears on the Custom CSS code block).
5. Click **Ctrl+S** or **Save** on the top right to save the change.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_ScreenShot-Customization.gif)

### Adding custom CSS

You can also add custom CSS styling to your table, apart from the default snippet provided.

> For example,

```
table th, table td{
border: 1px solid #67cfbf;
padding: 2px 10px;
}
table th {
background: #fcf8c0;
font-weight: 600;
}
table th:empty {
display:none;
}
tbody tr:nth-child(odd) {
background-color: #f2f2f2;
}

```

CSS

Copy

If you input this custom CSS code in the code space in the **CSS** tab, your output will appear like below:  
![02_Screenshot_Table_style_CSS](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/02_Screenshot_Table_style_CSS.png)

<a id="article-redirect-rules"></a>

## Article redirect rule

**Plans supporting the use of article redirect rules in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You can set up an article redirect rule for any published or draft article URL. The redirect feature is helpful when you change an article's URL and that same URL has been referenced in other articles across your Knowledge base site. You can also perform a bulk import of redirect rules.

Redirect rules prevent users from clicking on **dead** or **broken links**.

---

## Adding an article redirect rule

You can change an article's URL or slug before or after publishing the article or category page. The URL of an index-type category can also be modified. You can make these changes directly in the article editor.

To add the article redirect rule, follow the steps below:

1. Navigate to **Settings** ()> **Knowledge base site** > **Article redirect rules** in the Knowledge base portal.

   The **Article redirect rules** page will appear with a list of existing rules (if any).
2. Click **New redirect** to create a new redirection rule.

   The **New redirect rule** panel will appear.
3. Select the desired **Redirect type**:  
    a. **Ends with**: To set the redirection rule for an article with the unique slug at the end of your URL.   
    b. **Replace with**: To set the redirection rule for the URL text between the domain name and the article slug.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Article_Redirect_rule_Overview_page.png)

#### Ends with

4. In the **Source path** field, type the unique slug at the end of your URL for the redirect.

> NOTE
>
> The URL slug in the source path must start with a **forward slash** (`/`).

5. In the **Destination URL** field, type the full destination URL or type the new slug for redirection. Adding a forward slash (**/**) at the beginning of the destination URL is optional.

> **Example**: To redirect the article URL from `https://docs.document360.com/docs/getting-started-with-document360` to `https://docs.document360.com/docs/getting-started-video-library`, add the source path and destination URL as mentioned below:  
> **Source path**: `/getting-started-with-document360`  
> **Destination URL:** `getting-started-video-library`

6. Click **Create**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Ends_with_redirection_rule.png)

#### Replace with

7. In the **Source path** field, type the text between the domain and the article slug that you want to redirect.

> **Example**: The source path in the URL `https://project.technicaldocumentation.com/v1/docs/fr/getting-started` is `/v1/docs/fr/`.

> NOTE
>
> The source path must start and end with a **forward slash** (`/`).

8. In the **Replace text** field, type the new URL text you want to use for redirection.

> **Example:** Replace `/v1/docs/fr/` with `/v2/docs/en/` in the URL `https://project.technicaldocumentation.com/v1/docs/fr/getting-started`.

> NOTE
>
> The replace text must start and end with a **forward slash** (`/`).

9. Click **Create**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Replace_with_redirection_rule.png)

---

### Best practices

If you manage a multilingual Knowledge base with multiple project workspaces, set redirect rules based on language or workspace. For instance, if you set a rule with the source path `/customer-support` and the destination `/sales-and-support`, this applies only to the default language of the main workspace.

* To apply this rule to another language (e.g., German: `/de/`), create a new rule with the source path `/de/customer-support` and the destination `/de/sales-and-support`.
* To apply the rule in another workspace (e.g., version 1: `/v1/`), set the source path `/v1/docs/customer-support` and the destination `/v1/docs/sales-and-support`.

---

### Site-level redirect rule

In the **Article redirect rules** page, you can set a subfolder redirect rule at the site level using the **Replace with** option. This is useful for migrating from another platform or redirecting deprecated workspaces/languages.

> Example: Set a redirect rule for the subfolder `/azure/serverless` to `/data/cloud360` in the URLs like `https://apidocs.serverless360.com/azure/serverless/article_slug`.

---

## Editing a redirect rule

To edit the article redirect rule, follow the below steps:

1. Navigate to **Settings** ()> **Knowledge base site** > **Article redirect rules** in the Knowledge base portal.

   The **Article redirect rules** page will appear with a list of existing rules (if any).
2. Use the **Filter** to find the desired redirection rule.
3. Hover over the desired rule and click the **Edit** () icon.

   The **Edit redirect rule** panel will appear.
4. Update the necessary field(s).
5. Click **Update**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Editing_a_redirect_rule.png)

---

## Deleting a redirect rule

To delete an article redirect rule, follow the below steps:

1. Navigate to **Settings** ()> **Knowledge base site** > **Article redirect rules** in the Knowledge base portal.

   The **Article redirect rules** page will appear with a list of existing rules (if any).
2. Use **Filter** to find the desired redirection rule.
3. Hover over the desired rule and click the **Delete** () icon.
4. To delete multiple rules, select the checkboxes next to the rules and click **Delete**.
5. Click **Yes** in the **Delete** confirmation panel.

> NOTE
>
> Deleted redirection rules cannot be retrieved.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Delete_a_redirection_rule.png)

---

## Filter a redirect rule

To filter the desired redirect rule, follow the steps below:

1. **Search**: Enter a keyword from the source path or destination URL in the search bar, and the result is populated.
2. **Type**: Filter by the type of redirect: **Ends with**, **Replace with**, or **Both**.
3. **Modified date**: Filter rules by the last modified date, with options such as 1 year, 3 months, 30 days, or 7 days. Click **Custom date** to choose any custom date range and select the desired date range.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Filter_a_redirection_rule.png)

---

## Importing redirect rules

To import bulk redirect rules at once, upload a CSV that matches the following template:

|  |  |  |
| --- | --- | --- |
| **Source** | **Destination** | **RedirectionType** |
| `/myoldarticle` | `newarticle` | endswith |
| `/en/customers/` | `/v1/docs/` | replacewith |

> NOTE
>
> The file size should be less than or equal to 1MB.

#### Import redirect rule file template

You can also download the template here:

[import-redirect-rule.csv](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/import-redirect-rule.csv)

To import redirect rules in bulk:

1. Prepare a CSV file that matches the provided template (file size ≤ 1MB).
2. Navigate to **Settings** ()> **Knowledge base site** > **Article redirect rules** in the Knowledge base portal.
3. Click **Import redirect rule**.

   The **Import redirect rules** panel will appear.
4. Drag and drop the CSV file or select **Click to Upload**.
5. Review the list of valid and invalid rules.

   > NOTE
   >
   > Click the **Download** () icon near to the invalid rules count to download the list of invalid rules.
6. Click **Import** to apply the valid rules.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_ScreenGIF-Importing_redirection_rule.gif)

---

## Exporting redirect rules

To export redirect rules as a CSV file, follow the steps below:

1. Navigate to **Settings** ()> **Knowledge base site** > **Article redirect rules** in the Knowledge base portal.
2. Click **Export** to download the rules as a CSV file.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Export_Redirection_rule.png)

---

### FAQs

#### **What are Dead links?**

Dead links, or broken links, are hyperlinks that no longer work due to issues like URL changes, incorrect URLs, or restricted/private articles. They typically result in a 404 error page.a

#### **What is an article slug?**

A slug is the part of a URL that uniquely identifies a specific article/page. It comes after the `/` in your project's root URL.

> **Example**:  
> **Article URL**: `https://docs.document360.com/docs/why-did-we-build-document360`
>
> **Slug**: `/why-did-we-build-document360`

#### **How many redirect rules can I set up in a project?**

You can set up a maximum of 10,000 redirect rules per project. If you exceed the limit, please contact our [support team](mailto:support@document360.com).

#### **Are there limits for the import redirect rules feature?**

You can import up to 1,000 redirect rules per day and use the import feature up to five times per day. If you exceed the limit, please contact our [support team](mailto:support@document360.com).

#### **Why is my published article redirecting to another article or leading to a 404 error on the Knowledge base site?**

This issue may occur due to a **redirection rule** applied to the article's link. A redirection rule can redirect the article to another page or cause a 404 error if it is misconfigured.

To resolve this:

1. Navigate to **Settings** ()> **Knowledge base site** > **Article** **redirect** **rules** in the Knowledge base portal.
2. Search for the article's slug in the search bar to check for any redirection rules.
3. If a rule is applied, validate its purpose. If the rule is unnecessary or misconfigured, remove it.
4. Save the changes and revisit the article to ensure it displays as expected on the Knowledge base site.

If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

#### **Why do I see the error "The KB site is redirected too many times when accessed?"**

This error occurs due to a redirect loop, often caused by setting the Document360 Knowledge base site URL as the Sign-in URL for JWT authentication. Ensure the Sign-in URL for JWT authentication is not the same as the Document360 KB site URL. Use a dedicated authentication page as the Sign-in URL to avoid redirect loops and resolve the error.

#### **How can we address the issue of 404 errors when we discontinue functionalities that lead to incoming links from sources we cannot control?**

For discontinued features, to manage 404 errors effectively, create a standard article informing users about the discontinuation of a functionality, which can be used to redirect relevant articles.

For multiple discontinued functionalities, consider establishing a centralized page that consolidates all related information, ensuring users can easily access updates and reducing the occurrence of dead links.

#### **How do I redirect an article from one page to another using Custom JavaScript?**

To redirect an article from one page to another using Custom JavaScript, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Custom CSS & JavaScript**.
3. Paste the following code in the **JavaScript** tab:

   ```
   $(document).ready(function() {
     if(window.location.href=="source URL") {
       window.location.replace("destination URL");
     }
   });

   ```

   JavaScript

   Copy
4. Replace the **source URL** and **destination URL** in the code.
5. Click **Save**.

#### **Why do I see the error "Failed to save article redirection rule” while saving a new article redirect?**

This error occurs when you try to use a destination slug (the target URL path for a redirection) as the source path for another redirection. Once a destination is defined in a redirection rule, it becomes a static target and cannot be reused as a source in a new rule.   
To avoid this error, ensure that the destination slug is not used as a source path in any existing or new redirection rules.

#### **How do I write a redirection rule to replace the workspace name in the URL?**

You can use redirection rules when migrating from a different platform to Document360.

* Old URL structure: `https://docs.document360.com/{oldworkspace}/section/page`
* New URL structure: `https://docs.document360.com/{newworkspace}/section/page`

The same domain must be mapped to both platforms for the redirection to work. For example,   
If the old workspace is v1 and the new workspace is v2:

| Source | Destination | Rule |
| --- | --- | --- |
| `/v1` | `/` | endswith |
| `/v1/` | `/v2` | replacewith |

This rule ensures that all requests pointing to the old workspace v1 are redirected to the new workspace v2.

#### **How can I redirect a specific article/category URL to the homepage of** **my documentation?**

To redirect a specific URL to the homepage of my documentation, change the destination URL as ‘**/**’.  
For example, if you wish to redirect the URL `https://docs.radixdlt.com/docs/welcome` to `https://docs.radixdlt.com` , set the source URL as /docs/welcome and destination URL as ‘**/**’ in the replace with redirection rule.

<a id="configuring-the-article-settings"></a>

## Article settings & SEO

**Plans supporting the article settings configurations**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Article settings & SEO** section in Document360 allows for configuring various elements of the Knowledge base site to improve user experience and ensure consistency across articles. This section includes settings for the article header, footer, search options, accessibility features, and more. Understanding these settings enables customization of how the Knowledge base site appears and functions, aligning it with your needs and enhancing reader engagement.

For instance, a company managing a software knowledge base customizes the article settings to display contributor names, estimated read time, and social sharing options. They also enable **Show article comments** for user feedback and **Show related articles** to guide readers to relevant content. These settings enhance usability and engagement in the knowledge base.

---

## Configuring the Knowledge base site article settings

To configure the Knowledge base site article settings:

1. Navigate to **Settings** () > **Knowledge base site** > **Article settings & SEO** in the Knowledge base portal.
2. In the **Article settings** tab, locate the various accordions that consist of elements displayed on Knowledge base site:

   1. **Accessibility**
   2. **Article header**
   3. **Article right**
   4. **Article bottom**
   5. **Category manager**
   6. **Site header**
   7. **Search settings**
   8. **FAQ**

By default, all article details are automatically shown, and each one can be turned on/off in the **Article settings & SEO** section.

> NOTE
>
> Changes made in **Article settings & SEO** apply to all articles in your Knowledge base site. However, some settings, such as Table of contents or Allow commenting, can be configured for individual articles.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Article_setting_in_the_Knowledge_base_portal.png)

---

### a. Accessibility

The **Accessibility** accordion includes:

| Feature | Description |
| --- | --- |
| **Enable read out loud** | Turn on this toggle to enable the **Read out loud** feature, which helps users to listen to articles instead of reading them from your Knowledge base site articles. For more information, read the article on [Enhancing accessibility with our read-out-loud feature](/help/docs/text-to-voice-functionality). |

#### Knowledge base portal

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Accessibility-Knowledge_base_portal.png)

#### Knowledge base site view

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Accessibility_Knowledge_base_site_view.png)

---

### b. Article header

The **Article header** accordion lets you customize header elements displayed at the top of each article on your Knowledge base site. This includes features like contributor lists, estimated read times, and sharing options. These features enhance user engagement by providing quick access to essential tools and information. For more information, read the article on [Article header](/help/docs/article-header).

#### Knowledge base portal

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Article_header_portal_view.png)

#### Knowledge base site view

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Article_Header_Knowledge_base_site_view.png)

---

### c. Article right

The **Article right** accordion allows you to choose features displayed in the right sidebar of your Knowledge base site articles:

| Features | Description |
| --- | --- |
| **Show table of contents** | Turn on this toggle and select the desired heading levels (H2, H3, and H4) to display as the Table of contents. Note that H3 and H4 can only be enabled if their parent heading is also enabled.  NOTE  In Document360, H1 is applied to article/page category titles. Hence, the headings starts from H2. |
| **Show article tags** | Turn on this toggle to display tags added to articles. For more information, read the article on [Adding tags](/help/docs/adding-a-new-tag) to an article. |
| **Show article files** | Turn on this toggle to display files attached to articles. For more information, read the article on [Adding files to articles](/help/docs/adding-files-to-articles). |

#### Knowledge base portal

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Article_right_Knowledge_base_portal_view.png)

#### Knowledge base site view

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Article_right_Knowledge_base_site_view.png)

---

### d. Article bottom

The **Article bottom** accordion configures features displayed at the bottom of Knowledge base site articles includes:

| Features | Description |
| --- | --- |
| **Show article comments** | Turn on this toggle to allow readers to comment on articles using their **Disqus** credentials.  NOTE  Ensure [Disqus integration](/help/docs/disqus) is configured in your Document360 project. |
| **Show feedback form** | Turn on this toggle to display a feedback section for articles. Feedback data is accessible in the **Analytics** () > **Feedback** section. For more information, read the article on [Feedback manager](/help/docs/feedback-manager-overview). |
| **Show Previous/next navigations** | Turn on this toggle to display previous and next navigations between articles at the bottom. If this toggle is turned on, the first article will show only **Next**, and the last article will show only **Previous**.  NOTE  Only articles and category pages appear in this navigation. Index and Folder category types are excluded. |
| **Show related articles** | Turn on this toggle to display related articles added to each article. Select the **Enable dual linking** checkbox to automatically add reciprocal links between related articles. For more information, read the article on [Adding related articles](/help/docs/related-articles).  NOTE  **What is dual linking?**  When dual linking is enabled, if Article-A is added as a related article in Article-B, then automatically Article-B will appear as a related article in Article-A. Save time by using dual linking for adding related articles. With this option, you can avoid adding the related articles in both articles. Instead, you can add a related article to one article and enable dual linking. |

#### Knowledge base portal

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Article_bottom_Knowledge_base_portal_view.png)

#### Knowledge base site view

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Article_bottom_Knowledge_base_site_view.png)

---

### **e. Category manager**

The **Category manager** accordion includes the following options:

| Feature | Description |
| --- | --- |
| **Show first hierarchical level of categories** | Enable this toggle to expand all main categories by default in the Knowledge base site. When this toggle is turned off, only the first level of the first main category will be expanded by default in the Knowledge base site. |
| **Automatically set article status** | Turn on this toggle to automatically display status tags (New/Updated) for newly published or updated articles.  When this toggle is turned off, no status tags will appear by default when an article is published. Then, it must be added manually. For more information, read the article on [Status indicator](/help/docs/status-indicator).  **Example**: A **New** tag (green) appears for newly published articles, while an Updated tag (orange) appears for edited and republished articles. |
| **Custom status indicator** | Turn on this toggle to add a custom status indicator, such as **Beta**, to articles.  If the Custom status indicator toggle is turned off, the custom status indicator tag is removed from the articles in the Knowledge base site. For more information, read the article on [Setting up the custom status indicator](/help/docs/status-indicator#setting-a-custom-status-indicator). |
| **Show bubble up status** | Turn on this toggle to allow readers to identify categories updated with the latest articles. |

#### Knowledge base portal

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Category_manager_Knowledge_base_portal_view.png)

#### Knowledge base site view

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-Category_manager_Knowledge_base_site_view.png)

---

### f. Site header

The **Site header** accordion includes the **What’s New** feature.

| Feature | Description |
| --- | --- |
| **Show What’s New** | Turn on this toggle to display a **What’s New** () icon, listing recently published or updated articles in the selected workspace. For more information, read the article on [What’s New](/help/docs/document-header). |

#### Knowledge base portal

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/11_Screenshot-WHats_new_Knowledge_base_portal_view.png)

#### Knowledge base site view

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/12_Screenshot-Whats_new_Knowledge_base_site_view.png)

---

### g. Search settings

The **Search settings** accordion includes the following options:

| Features | Description |
| --- | --- |
| **Highlight search keywords in articles** | Turn on this toggle to highlight searched keywords within articles in the Knowledge base site. |
| **Enable advanced search** | Turn on this toggle to perform advanced searches across multiple workspaces and languages. For more information, read the article on [Search in Knowledge base site](/help/docs/search-in-knowledge-base-site). |
| **No search result feedback** | Turn on this toggle to display feedback when no search results are found. For more information, read the article on [Search in Knowledge base site](/help/docs/search-in-knowledge-base-site). |
| **Show attachments tab in search** | Turn on this toggle to show attachments tab in search. |
| **Include common words in search** | Turn on this toggle to include common words in search results for broader results. Turn off this toggle for more focused searches. |

#### Knowledge base portal

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/13_Screenshot-search_Settings_in_the_Knowledge_base_portal.png)

#### Knowledge base site view

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/14_screenGIF-Knowledge_base_site_view.gif)

---

### h. FAQ

Expand the **FAQ** accordion to customize the FAQ generator settings at the project level. For more information, read the article on [Setting up the FAQ generator](/help/docs/ai-faq-generator#setting-up-the-faq-generator).

#### Knowledge base portal

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/15_Screenshot-FAQ_in_the_Knowledge_base_portal_view.png)

---

### FAQs

#### **How do I make only H2 headings appear in the table of contents across all articles in the Knowledge base site?**

To customize the table of contents to display specific level of headings:

1. Navigate to **Settings** () > **Knowledge base site** > **Article settings & SEO** in the Knowledge base portal.
2. In the **Article settings** tab, expand the **Article right** accordion.
3. Turn on the **Show table of contents** toggle and select only the **H2** checkbox.

#### **How do I localize variable text in the right sidebar of an article?**

To localize the text displayed in the right sidebar:

1. Navigate to **Settings** ()> **Knowledge base portal** > **Localization & Workspaces** in the Knowledge base portal.
2. In the **Localization variables** tab, expand the **Article right** accordion.
3. Update elements such as Table of contents, Tags, and Files.

   > NOTE
   >
   > By default, the system localizes variables to the respective language.
4. Click **Save**.

#### **How do I localize variable text at the bottom of an article?**

To localize the text displayed at the bottom of an article:

1. Navigate to **Settings** ()> **Knowledge base portal** > **Localization & Workspaces** in the Knowledge base portal.
2. In the **Localization variables** tab, expand the **Article bottom** accordion.
3. Update elements such as:

   * Previous article
   * Next article
   * Related articles
4. Click **Save**.

#### **How do I change the status indicator tag validity?**

To change the validity of status indicator tags for articles:

1. Open the desired article in the **Documentation editor**.
2. Click the **More** () icon and select **More article options**.
3. In the **Status indicator** tab, set the desired validity (1–90 days) in the **Show status for** field.
4. Click **Save**.

#### **How do I change the variable text for status indicators?**

To update the variable text for status indicators in the Category manager:

1. Navigate to **Settings** ()> **Knowledge base portal** > **Localization & Workspaces** in the Knowledge base portal.
2. In the **Localization variables** tab, expand the **Category manager** accordion.
3. Update elements such as New, Updated, Custom, and Deprecated.
4. Click **Save**.

#### **How do I manually set a status indicator for an article?**

To assign a status indicator to an individual article:

1. Open the desired article in the Knowledge base portal.
2. Click the **More** () icon and select **More article options**.
3. In the **Status indicator** tab, choose the desired status.
4. Click **Save**.

#### **What happens if I override an automatically set article status?**

If the **Automatically set article status** toggle is on, project-level settings take precedence over the article level settings, and the status will follow the predefined rules (e.g., **Updated** for republished drafts).

#### **How do I set the status indicator for multiple articles?**

To apply a status indicator to multiple articles at once:

1. Navigate to **Documentation** () > **All articles** in the Knowledge base portal.
2. Select the articles and click **Status indicator** at the top.
3. Choose the desired status and click **Apply**.

#### **How do I choose a background color for a custom status indicator?**

To customize the background color of a status indicator:

1. Navigate to **Settings** ()> **Knowledge base site** > **Article settings & SEO** in the Knowledge base portal.
2. In the **Article settings** tab, expand the **Category manager** accordion and locate the **Custom status indicator**.
3. Click the color option, choose a color, and click the ☑ icon.
4. Hover over the eye () icon to preview the selected color.

#### **How do I enable Bubble up status?**

To enable the Bubble up status in the Knowledge base portal:

1. Navigate to **Settings** () > **Knowledge base site** > **Article settings & SEO** > **Article settings** in the Knowledge base portal.
2. Expand the **Category manager** accordion and turn on the **Show bubble up status** toggle.

#### **Where does the Bubble up status appear?**

The count of articles with **New**, **Updated**, or **Custom** statuses appears next to the category name in folders, indexes, and pages, including subcategories.

#### **How long does the Bubble up status appear?**

The Bubble up status remains visible as long as there are articles in the respective category or subcategory with an active status indicator (New, Updated, or Custom).

* It disappears when all status indicators within the category/subcategory expire.
* Clicking the Bubble up status does not affect its visibility.

#### **How do I localize variables for "What’s New"?**

To modify the "What’s New" text for localized content:

1. Navigate to **Settings** ()> **Knowledge base portal** > **Localization & Workspaces** in the Knowledge base portal.
2. In the **Localization variables** tab, expand the **General** accordion.
3. Update the **What’s New** field and click **Save**.

#### **What happens if I change the article status at the article level when the Automatically set article status option is enabled?**

When the **Automatically set article status** option is enabled, the project-level settings override individual article-level changes:

* If an updated and republished article is manually set to **New** at the article level, the system will still apply the **Updated** status based on the global settings.
* This ensures consistency with the project-wide configuration, even when manual changes are made.

#### **How do I enable breadcrumb navigation for my Knowledge base site?**

#### For Knowledge base site 1.0

1. Navigate to **Settings** ()> **Knowledge base portal** > **Article settings & SEO** in the Knowledge base portal.
2. Expand the **Article header** section, turn on the **Breadcrumb navigation** toggle.

#### For Knowledge base site 2.0

Breadcrumb navigation is enabled by default in Knowledge base site 2.0 and cannot be turned off.

<a id="article-header"></a>

## Article header

**Plans supporting article settings updates for the Knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Customize the header elements displayed at the top of each article on your knowledge base site, allowing readers to access features such as contributor lists, estimated read time, and sharing options. These options enhance user engagement by providing readers with quick access to important information and tools.

---

## Enabling the Article header elements

To enable Article header elements, follow these steps:

1. Navigate to **Settings** () > **Knowledge base site** > **Article settings & SEO** in the Knowledge base portal.
2. In the **Article settings** tab, expand the **Article header** accordion and turn on the following toggles:

   * **Show article contributors -** Display a list of team members who contributed to the article, allowing readers to view other contributions by each member.
   * **Show read time estimate -**Show an estimated reading time based on an average reading speed of 200 words per minute.
   * **Show Follow button -** Allow readers to follow the article for updates. Read the article on [Follow articles and categories](/help/docs/follow-articles-and-categories) for more information.
   * **Show share options -** Provide quick access to social media sharing options, including Twitter, LinkedIn, Facebook, and Email.
   * **Show print button -** Enable printing of a formatted version of the article.
   * **Show published/updated date -** Show the article’s publication and last updated dates.
   * **Show download as PDF button -** Allow readers to download a well-formatted PDF of the article.

> NOTE
>
> Changes made in the Article header settings apply to all articles at the project level and cannot be customized for individual articles, categories, workspaces, or languages.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/28_ScreenShot-Article_header(1).png "28_ScreenShot-Article_header(1).png")

After enabling these options, it’s helpful to test that each setting displays correctly. We recommend viewing an article as an end-user on the Knowledge base site to ensure the header elements appear as configured.

---

## **Article header elements in the Knowledge base site**

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/29_ScreenShot-Article_header(2).png "29_ScreenShot-Article_header(2).png")

|  | Feature | Description |
| --- | --- | --- |
| 1. | **Article contributors** | Displays a list of team members who contributed to the article. Click on a contributor’s name to see all articles they have contributed to within the project. |
| 2. | **Read time estimate** | Displays an estimated reading time at a rate of 1 minute per 200 words. |
| 3. | **Follow button** | Displays a **Follow** () button, allowing readers to follow the article. For more information, read the article on [Follow articles and categories](/help/docs/follow-articles-and-categories). |
| 4. | **Share option** | Displays a **Share** () icon. When clicked, it displays sharing options for social media sites (Twitter (), LinkedIn (), Facebook (), Email ()), each of which can be enabled or disabled individually. |
| 5. | **Print option** | Allows readers to click the **More** () icon, revealing a print option that opens a print preview window. If a printer is set up on the user’s computer, selecting **Print** will produce a formatted copy of the article. |
| 6. | **Published/**  **Updated date** | Displays the article’s published and last updated dates in the knowledge base site. |
| 7. | **Export as PDF** | Allows readers to click the **More** () icon and select **Export** to download a well-formatted PDF of the article. |

---

### Localizing the Article header text

To customize the variable text in the article header based on each language, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base portal** > **Localization & Workspaces** in the Knowledge base portal.
2. Select the **Localization variables** tab.
3. Choose the desired language in the **Select Language** section.
4. Expand the **Article header** accordion.
5. Edit the fields as needed.
6. Click **Save** to apply the changes.

> NOTE
>
> * By default, the variable texts are localized to the respective language.
> * Localization variables here are separate from the Content reuse ([Variables](/help/docs/variables) and [Snippets](/help/docs/snippets)) in Document360.

![Image showing article header section in Localization and Workspaces](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/30_ScreenShot-Article_header.png)

---

### FAQs

**How do I hide the breadcrumbs on the Knowledge base site?**

Breadcrumbs will be visible on the KB site 2.0 by default. However, in KB site 1.0, you get the option of turning on/off the **Show breadcrumb navigation** toggle from the **Article header** accordion in **Article settings & SEO**.

**How do I export a draft or a new article as a PDF?**

To export the draft articles or articles as PDF:

1. Navigate to the draft article in the Knowledge base portal.
2. Click on the **More** () icon near the share option.
3. Click the **Export** **PDF** option to download a neatly formatted PDF document onto your computer's local storage.

**How do I set my default email application for the Share** () **>**  **Email** () **feature on the Knowledge base site?**

When you click the **Share** () icon and select **Email** () in a Knowledge base article, it opens in your browser’s default email application. To set this to your preferred application, like Outlook, follow these steps:

1. Press `Windows + I` to open the **Settings** app.
2. Go to **Apps > Default apps**.
3. Scroll down and select **Choose default apps by protocol**.
4. In the list, find **Mail**.
5. In the **MAILTO** section, click on the current default and choose your preferred email application.

Your email links from the Knowledge base site should now open in the selected app.

**How do I hide the “Print” option on the Knowledge base site?**

To hide the **Print** option in the Knowledge base site:

1. Navigate to **Settings** () > **Knowledge base site** > **Article settings & SEO** in the Knowledge base portal.
2. In the **Article settings** tab, expand the **Article header** accordion.
3. Turn off the **Show print button** toggle.

The **Print** option will now be hidden on the Knowledge base site.

**How do I hide the “Export PDF” option on the Knowledge base site?**

To hide the **Export PDF** option in the Knowledge base site:

1. Navigate to **Settings** () > **Knowledge base site** > **Article settings & SEO** in the Knowledge base portal.
2. In the **Article settings** tab, expand the **Article header** accordion.
3. Turn off the **Show download as PDF button** toggle.

The **Export PDF** option will now be hidden on the Knowledge base site.

<a id="document-header"></a>

## Site header-What's new

**Plans supporting the What’s New feature**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The "What’s New" feature in Document360 allows users to quickly access recently published or updated articles in the selected workspace.

---

### Enabling or disabling the 'What’s new' option

1. Navigate to **Settings** > **Knowledge base site** > **Article settings & SEO** in the Knowledge base portal.
2. Expand the **Site header** accordion.
3. By default, the **Show What’s New** toggle will be enabled. You can show or hide the What's New **()** icon on the KB site by turning the toggle on or off.

![Enabling or disabling What's new toggle in the Knowledge base portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshots-Enabling_or_disabling_What's_new.png)

---

## Accessing the What’s new feature

1. Click the Announcement **()** icon on the top right navigation of the Knowledge base site.

   A page will display a list of recent articles published (new and forked) in the selected workspace.
2. Select the desired workspace and language.
3. You can filter the articles by Last 24 hours, Last 7 days, or Last 30 days.

![Accessing the What's new feature in the Knowledge base site.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-accessing_the_whats_new_feature.png)

<a id="follow-articles-and-categories"></a>

## Follow articles and categories

**Plans supporting readers to follow articles and categories**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Follow articles and categories** in Document360 allow users to stay updated with new content and changes in the Knowledge base. By following articles and categories, readers can receive notifications whenever new articles are published or existing ones are updated. This feature helps keep readers informed and engaged with the latest information, ensuring they do not miss important updates.

> For Your Information (FYI)
>
> This feature is available only for **Private** and **Mixed** projects in **KB site 2.0**, which is accessible for projects created after June 10th.

> **NOTE**
>
> The Follow articles and categories feature is applicable only for **Private** and **Mixed projects**.

---

## Enabling the ‘Show Follow button’ from KB Portal

1. Navigate to **Settings** () > **Knowledge base site** > **Article settings & SEO** in the Knowledge base portal**.**

   The **Article settings** page will open by default.
2. In the **Article header** section, turn on the **Show Follow button** toggle.

![Reader notification](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Enabling_Reader_Notification.png)

> **NOTE**
>
> By default, the **Show Follow button** toggle is turned on for all new Private and Mixed projects.

---

## Using Follow articles and categories in KB Site

1. Navigate to the desired category and click the **More (•••)** option in the Knowledge base site.
2. Click on **Follow category**.

   A message "Notification turned on" will appear.
3. To follow the article, navigate to the desired article and click **Follow (  ).**

![Reader notification](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-follow_and_Follow_category.png)

When you follow an article, you'll receive email notifications for updates in the following scenarios:

* A new version of an article or a page category is published.
* Any newly published article, page category, or replicated article is published.
* An article or page category is republished.
* A published article is unhidden or recovered from the recycle bin.
* The next version of an article is published via the Zapier and Crowdin integration.
* The next version of an article is published via the API endpoint.

> **NOTE**
>
> * When you follow a category, you will receive email notifications in **30 minutes** if there are any updates in that category. This includes updates to all sub-categories up to level six and all associated articles.
> * In mixed projects, you will see the **Follow category** option. Clicking it will take you to the login page if you are not logged in to the knowledge base site.

Email notifications are not triggered in the following cases:

* When articles or categories are deleted.
* When articles or categories are hidden.
* When the next version of an article is hidden.
* When an article is reordered or moved to another category.
* When the reader doesn’t have view access to the article/category on the KB site.

> NOTE
>
> Readers will be redirected to the respective article on the KB site or to the login page from the email notification.

---

### FAQs

#### How do readers configure their email domain for notifications?

The reader will receive all emails from the configured email domain in **Settings (****)** > **Knowledge base portal** > **Notifications** > **Email domain**. By default, emails will be sent from **support@document360.com** if the email domain is not configured.

#### How do I customize the ‘Follow’ button for the Follow articles and categories?

You can change the **Follow** variable name in **Settings (****)** > **Localization & Workspace** > **Localization variables** > **Article Header.** Enter the desired name in the **Follow** field and click **Save** to save the changes.

#### How do I unfollow a category?

To unfollow a category,

1. Navigate to the desired category and click the **More (•••)** option in the Knowledge base site.
2. Click **Unfollow** to stop notifications. A **Notification turned off** message will appear.

#### How do I unsubscribe from the Follow articles and categories email?

Click **Unsubscribe** in the email and if the reader hasn’t logged in to the KB site, it navigates to the login page. The appropriate article or category will be unfollowed automatically by clicking on the unsubscribe button.

#### Is the ‘Follow Article’ feature available for JWT users?

Currently, the "Follow Article" feature is not available for users with JWT authentication.

<a id="search-in-knowledge-base-site"></a>

## Search in Knowledge base site

**Plans supporting Search in Knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Your Document360 knowledge base includes a fast and intuitive search above the articles. Results are filtered by relevance to the search term. They are listed with the name of the article/category, a preview of the search term within the article/category, and the breadcrumb of the article/category. **Advanced search** allows you to segregate the search results with the available filter options. You can perform a combined search across all the workspaces and languages simultaneously. Using **Search attachments**, you can search for content inside PDF attachments in the Knowledge base site.

The search functionality enhances user experience by allowing readers to find relevant articles, attachments, and resources effortlessly. Advanced features, such as filters and keyword operators, streamline the search process, making it indispensable for organizations with diverse and extensive documentation.

---

## Attributes used in the Knowledge base site search

Search results are based on the following attributes:

* Article and category titles
* Tags
* Slug of articles and categories (index and page)
* Breadcrumb
* Text content within articles and categories

> NOTE
>
> **Search priority sequence:** Article title > Associated tags > Article slugs > Breadcrumbs > Article content.

---

## Advanced search

Advanced search helps filter results with various options, enabling combined searches across workspaces and languages.

**Example:** Searching for the `login` keyword across multiple workspaces:

1. Search for the `login` keyword in the Knowledge base site search bar.
2. Select **More article filters**.
3. Apply filters like Workspace, Language, Tags, Contributors, Date, and Categories.

   The search results will populate based on the applied filters.

### Enabling advanced search

To enable the advanced search:

1. Navigate to **Settings** () > **Knowledge base site** > **Article settings & SEO** in the Knowledge base portal.
2. In the Search settings accordion, turn on the **Enable advanced search** toggle.
3. Select the **Include all workspaces in site searches** checkbox to ensure that, by default, the search filter in the Knowledge base site displays **All workspaces** instead of **Current workspace** in the search bar. This allows users to fetch search results from all workspaces automatically.

> NOTE
>
> If the **Enable advanced search** toggle is turned off, the filter options will not appear in the Knowledge base site.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_New_Screenshot-Enabling_Advanced_Search_in_the_knowledge_base_portal.png)

### Accessing advanced search in the Knowledge base site

1. Enter a keyword in the search bar in the Knowledge base site.

   The related search results will be populated.
2. Click **More article filters** to access advanced search options.
3. Use the available filters to refine results:

| Filter | Description |
| --- | --- |
| **Workspace** | Filter search results by workspace:   * **Current workspace**: Fetches results within the current workspace. * **All workspaces**: Fetches results across all available workspaces. * **Specific**: Allows selecting specific workspaces to limit search results to those. |
| **Language** | Filter search results by language:   * **Current language**: Fetches results in the active language. * **All languages**: Fetches results across all available languages. * **Specific**: Allows selecting specific languages to focus search results on them. |
| **Tags** | Apply this filter to narrow results to articles containing the selected tags. |
| **Contributor** | Filter search results by contributors. Select contributors from the dropdown and apply the filter. |
| **Date** | Filter results by a specific date range such as Last 7 days, Last 30 days, Last 90 days, and Custom range. |
| **Categories** | Select categories to refine the search results to articles or pages belonging to those categories. |

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Accessing_advanced_search_in_KB_site.gif)

---

## Search attachments

Search attachments enable users to find content within PDF files in the knowledge base site. When a reader searches for a keyword, two filter tabs appear in the search results:

* **Categories:** Displays search results for the keyword within categories.
* **Articles**: Displays search results for the keyword within articles.
* **API Docs**: Display search results for keywords within API documentation.
* **Files**: Displays search results for the keyword within PDF attachments.

  **Example**: The Search attachments feature enhances search functionality for both readers and team accounts. In the Knowledge base site, if a keyword like SharePoint yields no results in articles, readers can switch to the Files tab to find relevant content within PDF attachments and view them at the right side of the article. In the Knowledge base portal, team accounts searching for a keyword in the Drive can rely on this feature to scan PDF files (up to 10 MB) for the keyword, displaying results even if the file name doesn’t match for relevant PDF content.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_new_Screenshot-Search_attacment_.png)

### Enabling attachment tab in search

1. Navigate to **Settings** () > **Knowledge base site** > **Article settings & SEO** > **Article settings** in the Knowledge base portal.
2. Expand the **Search settings** accordion and turn on the **Show attachments tab in search** toggle.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-enabling_attachment_tab_in_search.png)

> NOTE
>
> * If the **Show article files** toggle is turned off, the **Show attachments tab in search** toggle will be inaccessible. To enable it, expand the **Article right** accordion and turn on the **Show article files** toggle.
> * When the **Show attachments tab in search** functionality is disabled, the search will only operate within the article/page category elements such as title, slug, tags, and content.

---

## No search result feedback

When a search does not return any articles in the knowledge base, it either displays a blank results page or a feedback form if the **No search result feedback** option is enabled. This feedback form allows readers to provide details about what they were looking for. The submitted feedback can be reviewed in the [Search analytics](/help/docs/analytics-search) module, enabling team accounts to assess the input and update the knowledge base as needed.

### Enabling no search result feedback

To enable the **No search result feedback** form,

1. Navigate to **Settings** () > **Knowledge base site** > **Article settings & SEO** > **Article settings** in the Knowledge base portal.
2. Expand the **Search settings** accordion, turn on the **No search result feedback** toggle.

> **NOTE**
>
> No search result feedback form will be available on the Knowledge base site and the Knowledge base widget.

When no search result feedback form is turned off, a blank result appears for no-result searches.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Enabling_no_search_result_feedback.png)

**Knowledge base site view**

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-No_search_feedback_KB_site.png)

---

## Search filters

The **Filter** option, located to the left of the search bar on your knowledge base site, allows you to narrow search results using various filters:

* **Search category titles**: Displays category titles and articles containing the search keyword.
* **Search attachments**: Displays files attachments containing the search keyword.
* **Workspace**: Filters results within the selected workspace:

  + Current Workspace: Searches the active workspace.
  + All Workspaces: Includes all workspaces, including API documentation.
  + Specific: Allows selection of specific workspaces.
* **Language**: Filters results by language:

  + Current Language: Searches the active language.
  + All Languages: Includes all supported languages.
  + Specific: Allows selection of specific languages in your Knowledge base.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Search.png)

---

## Search operator support

Implementing search operators such as quotation marks would allow users to construct precise queries, significantly improving search accuracy and user satisfaction.

* **Double Quotes (**`""`**):**

  Double quotes are used to search for an exact phrase. When you put words inside double quotes, the search engine looks for those exact words in that exact order.
* **Minus Sign (**`-`**):**

  The minus sign is used to exclude certain words from the search results. When you place a minus sign directly before a word (without a space), the search engine will exclude results containing that word.

Let us explore some of the examples,

* `search -recipe` fetches records containing `search`, but not `recipe`.
* `search-recipe` fetches records containing `search` and `recipe` (there’s no exclusion because the minus (`-`) is in the middle of the word).
* `-recipe` fetches every record except those containing `recipe`.
* `-recipe` pasta fetches records containing `pasta`, but not `recipe`.
* `"-recipe"` fetches records containing `“-recipe”` (no exclusion performed).

---

## FAQs

#### What is Advanced search?

Advanced search allows a combined search across all workspaces and languages simultaneously, helping readers locate desired results using available filters.

#### How do I hide the search bar on the Home page?

The search bar of the Home page is visible by default but can be hidden. Hiding the search bar in the header of the home page does not affect its appearance on the knowledge base.

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** and select **Customize site**.
2. Select the **Header & Footer** dropdown and then choose **Home**.
3. Click on the **Hero section** and select **Search**.
4. Hover over the **Search** option and click the eye () icon to hide the search bar on the home page.

#### How do I exclude an article from search?

You can exclude an article from searches within your knowledge base or external search engines. For more information, read the article on [Excluding articles from search engines](https://docs.document360.com/docs/excluding-articles-from-searches).

Articles that have been hidden will not appear in your knowledge base site and, therefore, will not be searchable by your readers. However, your team members can search for them in the Knowledge base portal. For more information, read the article on [hiding the article](https://docs.document360.com/help/docs/hiding-article).

> NOTE
>
> Similarly, you can also hide the categories and page categories.

#### Will my search include API documentation results?

In the Knowledge base site search, the **Current workspace** filter will be selected by default. To search within your regular documentation and API documentation as well, you need to select **All workspaces** from the **Filter** option available on the search bar.

However, in Document360 1.0, to search within all workspaces you need to enable the option in your Knowledge base site settings:

1. Navigate to **Settings** () > **Knowledge base site** > **Article settings & SEO** > **Article settings** in the Knowledge base portal.
2. Expand the **Search settings** section, select the **Include all workspaces in site searches** checkbox.

#### How does the search bar behave when RTL languages, such as Hebrew and Arabic, are selected?

When you select an RTL language, such as Hebrew or Arabic, from the language dropdown, the search bar will automatically adjust to align text to the right and take input from right to left.

If multiple languages are selected:

**All selected languages are RTL (e.g., Hebrew and Arabic):** The search bar will maintain the right-to-left input and right alignment.

**A mix of RTL and LTR Languages:** The search bar's behavior will depend on the default language selected. The input will start from the right if the default language is RTL. If the default is LTR, the input will start from the left.

<a id="liking-or-disliking-an-article"></a>

## Liking or disliking an article

**Plans supporting article like or dislike feature**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In the Document360 Knowledge base site, users can like or dislike an article or page category, providing valuable feedback to improve content quality. Users can perform this action multiple times if needed.

Imagine a reader is viewing an article in your Knowledge base site about creating and managing categories for organizing content. The instructions are helpful, but the reader notices that one step is missing a screenshot, which would make the process clearer. The reader can click the **dislike** () icon to submit feedback, explaining that adding a screenshot for step 3 would improve the article.

This feedback process allows readers to directly contribute to enhancing the Knowledge base, ensuring it remains helpful and accurate for everyone.

> NOTE
>
> The undo likes and dislikes feature is supported only in KB Site 2.0 projects. If you’d like to migrate your project to KB Site 2.0, please read the article on [KB site 2.0 Migration](/help/docs/kb-site-20-migration).

---

## Liking or Disliking an article

To like an article:

1. Navigate to the desired article in the Knowledge base site.
2. Scroll down to the end of the article and click the **like** () icon to like the article.

   The **Leave a feedback** panel will appear.
3. Optionally, enter your feedback in the provided space.
4. Select the **Notify me about updates** checkbox and enter your email address if you wish to be notified of updates related to your feedback.
5. Click **Submit.**

   To dislike an article,
6. Click the **dislike** () icon.

   The **Help us to improve this article** panel will appear.
7. Select an existing feedback option or click **Others** to provide custom feedback.
8. If required, select the **Notify me about updates** checkbox and enter your email to receive notifications.
9. Click **Submit.**
10. To undo your action, click the **like** () or **dislike** () icon again.

> NOTE
>
> * Users who dislike an article must provide a comment explaining their feedback; otherwise, the dislike will not be counted.
> * Similarly, readers can like or dislike articles in the Knowledge base widget.
> * In the Public Knowledge base site, you can undo **like** () or **dislike** () actions within 30 days unless you clear your browser cache, which deletes saved data and prevents reversal.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-liking_and_disliking_an_Article.gif)

---

### FAQs

**What happens if I click dislike (), provide feedback, and then undo the dislike? What will happen to my feedback in the Feedback manager?**

If you undo a dislike after submitting feedback, the following will occur in the Feedback manager in the Knowledge base portal:

* If the feedback is in an open state, it will be deleted.
* If the feedback is assigned to a team member or in any other state, it will be marked as  **Removed**, indicating that the feedback is no longer active.

**Will undoing a dislike still be recorded in the Analytics section?**

No, once you undo a dislike, the action is canceled and will not be recorded in the **Analytics** () section. This ensures that only active interactions are captured for analysis.

**What happens if I select the "Notify me about updates" checkbox?**

If you select **Notify me about updates** and provide your email, the designated team handling feedback can respond in the Knowledge base portal, and you’ll be notified of any replies related to your feedback.

**Can I provide multiple likes or dislikes on the same article over time?**

You cannot give multiple likes and dislikes on the same article. However, you can change your feedback by simply clicking the opposite button (like or dislike) to switch your feedback status. If you've already left comments, these will remain associated with the new feedback type.

<a id="smart-bar"></a>

## Smart bars

**Plans supporting the use of** **Smart bar****s in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Smart bar** feature in **Document360** allows you to display customizable banners or bars across your Knowledge base site. These bars can convey information, announcements, or messages, tailored to specific conditions such as user location, browser type, or project language settings. By leveraging **Smart bar****s**, you can enhance user engagement and direct attention to critical updates effortlessly.

Imagine you are rolling out a new feature update for your product. To ensure all users are aware, you can create a **Smart bar** to display a notification about the update at the top of every article in the Knowledge base site. You can even localize the bar to show it in different languages based on user preferences.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_New_Screenshot-Smartbars_Knolwedge_base_site_view.png)

---

## **Smart bar** **overview**

The **Smart bar** overview page consists of several key elements:

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_New_Screenshot-Overview_of_Smart_bars.png)

1. **Select language**: Displays the global language and any existing project languages along with the number of **Smart bar****s** configured for each.

   For example, **Spanish (2)** means two **Smart bar****s** exists in Spanish.
2. **Status**: Indicates whether a **Smart bar** is active. If the **Status** toggle is turned off, the **Smart bar** will not appear in the Knowledge base site.
3. **Details**: Shows the name, position, and a preview option for each **Smart bar**.
4. **Show rules**: Lists conditions under which the **Smart bar** will appear.
5. **Hide rules**: Lists conditions under which the **Smart bar** will be hidden.
6. **Edit** (): Hover over a **Smart bar** to access the Edit () option.
7. **Delete** (): Hover over a **Smart bar** to delete () it.
8. **Filters**: Use the filter panel to sort **Smart bar****s** by name, location, show rules, or hide rules.
9. **New smart bar**: Click to create a new **Smart bar**.

---

## Creating a new **Smart bar**

To create a new **Smart bar**:

1. Navigate to **Settings** () > **Knowledge base site** > **Smart bar****s** in the **Knowledge base portal**.
2. Click **New smart bar**.
3. In the **Name** field, enter a suitable name.
4. By default, the **Status** toggle is turned on. You can disable it if needed.

#### Configuring the content

5. Expand the **Content** section to define the message.
6. Use the **Global** toggle to set the **Smart bar** visibility for all languages or specific ones.

   1. **Global On**: The message appears across all Knowledge base site pages and languages.
   2. **Global Off**: A language dropdown appears to select specific languages.
7. Add the desired content using basic formatting tools such as Bold (), Italics (), Underline (), Hyperlink (), and Code view ().

#### Customizing **Design and location**

8. Expand the **Design and location** section to personalize the **Smart bar**.
9. Select a position from these options:

   1. **Site top**
   2. **Site bottom**
   3. **Article top**
   4. **Article bottom**

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-four_positions_of_Smart_bar.png)
10. Choose a color theme:

    1. **Light theme**: The background color is grey, and the text color is black.
    2. **Dark theme**: The background color is black, and the text color is white.
    3. **Custom theme**: Customize the background color, CTA background color, text color, and CTA text color using the color picker or by entering Hex, RGB, or HSL codes.

**Advanced display conditions (optional)**

11. Configure visibility rules for showing or hiding the **Smart bar** based on:

| **Condition** | **Description** | **Example** |
| --- | --- | --- |
| **URL** | Define specific URLs to include or exclude. | To display a promotional banner only on the product page URLs of your website. |
| **Query strings** | Use query parameters with operators like Exists, Equals, or Not Equals. | To show a discount code banner when a specific campaign query string is present in the URL. |
| **IP address** | Target specific IP addresses or ranges. | To restrict the visibility of an internal update **Smart bar** to office network IP ranges. |
| **Browser** | Display **Smart bar****s** based on the user’s browser. | To display a compatibility warning for users accessing the site with older browser versions. |
| **Device** | Target devices such as desktops, mobiles, or tablets. | To show a mobile app download banner only for users on mobile devices. |
| **Project** | Configure visibility for specific projects, categories, or tags. | To announce a new feature release to users accessing content in a specific project category. |
| **Language** | Available only if **Global** toggle is turned on. | To display a localized welcome message based on the user’s preferred language. |

12. Select **AND**/**OR** computation for multiple rules (when adding more than one rule):

    * **AND**: All conditions must be true to show/hide the **Smart bar**.
    * **OR**: Any conditions must be true to show/hide the **Smart bar**.
13. Click **Delete** () icon next to each rule to delete that rule alone.
14. Click **Add**.

    The **Smart bar** overview page will display the newly added **Smart bar**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Adding_Smart_bar.gif)

---

### FAQs

#### **How do I edit a** **Smart bar****?**

To modify or update a **Smart bar**,

1. Navigate to **Settings** () > **Knowledge base site** > **Smart bar****s** in the **Knowledge base portal**.
2. Hover over the desired **Smart bar** and click the **Edit** () icon.
3. Modify the name, content, design, or visibility rules.
4. Click **Update** to save changes.

#### **How do I delete a** **Smart bar****?**

To delete a **Smart bar**,

1. Navigate to **Settings** () > **Knowledge base site** > **Smart bar****s** in the Knowledge base portal.
2. Hover over the desired **Smart bar** and click the **Delete** () icon.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="cookie-consent"></a>

## Cookie consent

**Plans supporting the use of cookie consent in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

A cookie is a small piece of data stored in a web browser by a website, which the website can retrieve later. In general, **consent** means that users agree to the website's use of cookies for purposes such as analytics, personalization, or targeted advertising. Since the implementation of the EU's General Data Protection Regulation (GDPR), cookie consent has become a critical component of websites and applications. In Document360's knowledge base site, you can add a cookie consent bar or popup for your readers.

---

## Adding a cookie consent message to your knowledge base site

1. Navigate to **Settings** () > **Knowledge base site** > **Cookie consent** in your Knowledge base portal.

   The **Cookie consent** page will appear.

> **NOTE**
>
> Turn on the **Enable the cookie consent on your knowledge base site** toggle and click **Save**. The cookie consent will be visible to your readers.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Cookie_consent_Overview_page.png)

### **Select language**

2. Set the cookie consent message to **All languages** to display it across all languages of your knowledge base site. Otherwise, select your desired language to display the cookie consent in that language.

   The default cookie consent message will appear in the selected language.

> **NOTE**
>
> * Localize the cookie consent message and customize its style for your Knowledge base site.
> * If the cookie consent message is set to **All languages**, it will appear across all languages.
> * If no separate cookie consent is added for a specific language in your project, the **All languages** cookie consent will be displayed.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot_Selecting_languages_for_Cookie_Consent.png)

### **Content**

3. Add your custom cookie consent message using basic text formatting tools such as **bold**, *italics*, underline, or `code view`. You can also add hyperlinks if necessary.
4. To restore the default message, click **Restore default message** at the bottom of the content field.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screnshot-Content_part_in_the_cookie_consent.png)

### **Theme and position**

5. In the **Banner type** field, select either **Bar** or **Popup** to be displayed on your knowledge base site.
6. The **Banner position** varies based on the banner type selected:

   * **Bar**: Choose either **Top** or **Bottom** of the page.
   * **Popup**: Select the position from options such as **Top left**, **Top center**, **Top right**, **Bottom left**, **Bottom center**, or **Bottom right**.

   Since consent is required for site visitors, a CTA(Call to action) is crucial.
7. In the **CTA type** field, choose whether the CTA should be **Text**, **Button**, or **Icon**.
8. In the **CTA text** field, enter the call-to-action text.
9. In the **Banner style** field, select a color theme for the cookie consent banner:

   1. **Light theme**: The background color is white, and the text color is black.
   2. **Dark theme**: The background color is black, and the text color is white.
   3. **Custom theme**: Customize the background color, CTA background color, text color, and CTA text color using the color picker or by entering Hex, RGB, or HSL codes.
10. Use the color picker or enter Hex codes in the **Background color** field to set the banner's background color.
11. Use the **Text color** field to set the banner’s text color.
12. Use the **CTA background color** field to set the background color for the CTA.
13. Use the **CTA text color** field to set the text color for the CTA.
14. Click **Preview** to see a preview of the actual cookie consent message.
15. After you've configured the desired content, theme, and position, turn on the **Enable the cookie consent on your knowledge base site** toggle.
16. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Them_and_position.png)

---

### FAQs

**What is cookie consent?**

Cookie consent refers to users agreeing to let a website use cookie for purposes such as analytics, personalization, or targeted advertising.

**Can I customize the cookie consent message?**

Yes, you can customize the cookie consent message using text formatting tools and adding hyperlinks.

**Is it possible to set the cookie consent message in multiple languages?**

Yes, you can set the cookie consent message to appear in a specific language or in all languages.

**How can I control or disable cookie settings in Document360?**

Currently, Document360 allows customization of the cookie consent banner. However, all cookies added by Document360 are essential to the platform’s functionality. There is no option to disable or decline these cookies.

For more advanced control over cookies, including optional cookies, we recommend using a dedicated cookie management platform.

A European law that establishes guidelines for protecting the privacy and security of personal data, regulating how companies collect, store, and manage such information.

A prompt on a website that encourages users to take a specific action, such as clicking a button, signing up, or downloading content.

<a id="accessing-the-ticket-deflectors"></a>

## Accessing the ticket deflectors in portal

**Plans supporting the use of ticket deflector**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Ticket deflectors are a powerful feature designed to reduce the volume of support tickets by empowering users to resolve their queries independently. By providing self-service options directly within your knowledge base site, ticket deflectors streamline the support process, enabling quicker resolutions and improving overall user satisfaction.

Consider a scenario where a customer encounters an issue while navigating your website. Instead of raising a support ticket, they use the ticket deflector to find a step-by-step troubleshooting guide in the knowledge base site, resolving their issue without contacting support. This not only saves time for the customer but also reduces the workload for your support team.

---

## **Ticket deflectors** overview page

To access the **Ticket deflectors** overview, navigate to **Settings** () > **Knowledge base site** >**Ticket deflectors** in the knowledge base portal.

The **Ticket deflectors** page includes the following elements:

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Overview_of_ticket_deflector.png)

1. **Title**: Displays the title of each ticket deflector.
2. **Status**: A toggle that indicates whether the ticket deflector is online or offline.
3. **Last updated by**: Shows the team member who last updated the ticket deflector settings or content.
4. **Last updated**: The date when the ticket deflector settings or content was last modified.
5. **New ticket deflector**: Click **New ticket deflector** to create a new ticket deflector.
6. **Integrate your Helpdesk**: Click **Integrate your Helpdesk** to configure integrations with platforms like Freshdesk or Zendesk.

   Hover over any ticket deflector to access additional options:
7. **Copy** (): Click the **Copy** () icon to generate a link for the ticket deflector. This link allows users to access the ticket deflector form directly online. This icon is available only if the ticket deflectors is active.
8. **Clone**(): Duplicate an existing ticket deflector, including its settings and content, to quickly create a similar form.
9. **Preview in Knowledge base**(): Preview the ticket deflector form as it will appear on the knowledge base site. This helps ensure the content and flow are correct before publishing.
10. **Edit**(): Modify the ticket deflector form's settings, flow, questions, or links.
11. **Delete** (): Remove the ticket deflector from the knowledge base.

> NOTE
>
> * You must set the ticket deflector to offline mode before deleting it.
> * **Ticket deflectors** can only be configured for the main workspace of the project and its languages.

---

## Helpdesk configuration

Ticket deflectors support integration with third-party helpdesk platforms like **Freshdesk** and **Zendesk**. This enables seamless ticket creation directly from the ticket deflector form.

1. Navigate to **Settings** () > **Knowledge base site** >**Ticket deflectors** in the knowledge base portal.
2. Click **Integrate your Helpdesk** to open the configuration panel.
3. Choose one of the following options:

   * **Freshdesk****– Create ticket**
   * **Zendesk****– Create ticket**

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Helpdesk_configuration_panel.png)
4. Configure the selected platform:

   **Freshdesk** **Integration**

   1. Enter the API key and domain URL obtained from **Freshdesk**.
   2. Click **Validate & save** to complete the integration.

> NOTE
>
> For more information on obtaining the API key, refer to this [help article](https://support.freshdesk.com/en/support/solutions/articles/215517-how-to-find-your-api-key).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Freshdesk_configuration_panel.png)

**Zendesk** **Integration**

1. Enter the API key, domain URL, and the **Zendesk** agent’s email address.
2. Click **Validate & save** to complete the integration.  
   Ensure all credentials are accurate for successful validation.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Zendesk_configuration_panel.png)

---

## Adding **Ticket deflectors** in Header and Footer sections

The live ticket deflector form can be added and accessed in the knowledge base site's header and footer sections.

#### Header navigation

To access the Header - Primary navigation, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations.
3. From the left dropdown, select **Site header & footer**.
4. Expand **Header**,then select **Header navigation**.
5. Click **Add new item** to create a navigation menu.

   The **Add new item** panel will appear.
6. In the **Select type** dropdown, select **Ticket deflector**.
7. Enter a title and select the desired ticket deflector from the dropdown.

   Only ticket deflector forms with an active status will be listed.
8. Select the **Open link in new tab** checkbox to open the link in a new tab.
9. Once done, click **Add**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Adding_Ticket_deflector_in_Header_navigation.gif)

To access the Header - Secondary navigation, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.
2. Click **Customize site** to access the design configurations.
3. From the left dropdown, select **Site header & footer**.
4. Expand **Header**,then select **Secondary navigation**.
5. Click **Add new item** to create a navigation menu.

   The **Add new item** panel will appear.
6. In the **Select type** dropdown, select **Ticket deflector**.
7. Enter the desired title in the **Title** field.
8. Paste the desired Ticket’s deflector’s link.
9. Select the **Open link in new tab** checkbox to open the link in a new tab.
10. Once done, click **Add**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Adding_Ticket_deflector_in_Header_secondary_navigation.gif)

#### Footer navigation

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** in the Knowledge base portal.

   The **Customize site** page contains all the basic site design configurations.
2. Click **Customize site**.
3. Select **Site header & footer** from the dropdown.
4. Click the **Footer** option.
5. You have two design options for the footer: **Basic footer** and **Custom footer**.

   **Basic footer**
6. Click **Add new link**.
7. Enter the title and paste the desired Ticket deflector’s link.
8. Select the **Open link in new tab** checkbox to open the link in a new tab.
9. Once done, click **Add**.

   **Custom footer**
10. Paste the desired Ticket deflector’s link in the desired code location.
11. Click **Save** and then **Preview** to view the changes on the Knowledge base site.
12. Once done, click **Publish** to apply the changes.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Adding_Ticket_deflector_in_footer_navigation.gif)

### Using form link

The ticket deflector can be added in other relevant places where customer support tickets must be deflected. This will encourage using self-service for troubleshooting and ensure the queries are resolved. Use the copied ticket deflector form link to add the ticket deflector to the knowledge base site.   
You can add the ticket deflector form link to other relevant sections, such as:

* Inside articles or category pages
* Deprecation messages
* Smart bars
* Cookie consent notifications
* Snippets and variables
* Knowledge base home page
* Knowledge base assistant

---

### FAQs

#### How can I copy the ticket deflector form link?

To copy the ticket deflector form link:

1. Navigate to **Settings** () > **Knowledge base site** > **Ticket deflectors** in the Knowledge base portal.
2. Click the **Copy** () icon next to the ticket deflector.

   This link can be shared on websites, social media, or other platforms for direct access to the form.

#### What does the **Clone** option do in Ticket deflector?

The **Clone** () option duplicates an existing ticket deflector form, preserving its settings, questions, and content. You can then customize the cloned form as needed.

#### Can I preview the ticket deflector before publishing it?

Click **Preview in Knowledge base** to view the ticket deflector form as it will appear on the knowledge base site.

#### How can I delete a ticket deflector?

To delete a ticket deflector:

1. Navigate to **Settings** () > **Knowledge base site** > **Ticket deflectors** in the Knowledge base portal.
2. Set the desired ticket deflector’s status to offline.
3. Hover over the ticket deflector and click **Delete** ().

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="adding-a-new-ticket-deflector"></a>

## Adding a new ticket deflector

**Plans supporting the use of ticket deflector**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Ticket deflectors streamline query resolution by helping users find answers independently before reaching out for support. This guide walks you through creating a ticket deflector, from setting up its components to customizing its functionality for user needs.

Imagine you run a SaaS platform with extensive documentation. A user encounters an issue with billing. Instead of submitting a support ticket immediately, the ticket deflector helps the user locate a relevant FAQ or guide on resolving billing issues. If the provided resources don’t solve their problem, they are directed to a tailored contact form to raise a ticket.

> NOTE
>
> In business and enterprise plans you can have multiple ticket deflectors of up to 10.

---

## Creating a new Ticket deflector

To create a ticket deflector, follow these steps:

1. Navigate to **Settings** () >**Knowledge base site** > **Ticket deflectors** in the Knowledge base portal.
2. Click **New ticket deflector**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Creating_a_new_ticket_deflector.png)

### Step 1: Ticket deflector Form Title, Slug, and Description

The ticket deflector form will appear with the default title “**How can we help you?”**

1. Click the **Ticket deflector title** and edit the desired title. Titles cannot exceed 150 characters (including spaces).
2. The **Ticket deflector slug** is autogenerated but can be edited. Slugs cannot exceed 150 characters.

> NOTE
>
> Changing the Ticket deflector’s URL will break any existing references to it.

3. Add a concise description to inform users about the purpose of the ticket deflector.
4. Ensure the **Online** setting is toggled on for the deflector to appear on the Knowledge base site.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Adding_Ticket_deflector_step1.png)

### Step 2: **Context questions**

**Why are** **Context questions** **important?**  
**Context questions** help understand user issues, guide them effectively, and determine the next step in resolution. While called "questions," they can be phrased as statements or prompts based on your audience's needs.

> NOTE
>
> There is no character limit for **Context questions**.

1. Click **Questions** to begin. By default, two questions are provided.
2. For each question:  
   a. Enter the desired text (e.g., *I have a pricing question*).  
   b. Turn on the **Enable search** toggle to require users to search the knowledge base before proceeding.  
   c. Select the **Make search optional** checkbox to allow skipping the search step.  
   d. Choose the next action from the **If user selects this option, go to...** dropdown (e.g., contact form).  
   e. Hover over any question and click the **Delete**() icon to remove unwanted questions.  
   f. Click **Add questions** to include more questions.  
   g. Use the **Reorder**() icon to rearrange the question order.

> NOTE
>
> * At least one qualifying question is mandatory.
> * There are no limits to the number of questions per form.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Context_question_step2.png)

### Step 3: **Suggestions**

In **Suggestions**, adding steps to the Document360 ticket deflector provides simple checkpoint navigation based on user responses. You can guide users directly to the contact form or include additional steps and questions to help them self-serve using the knowledge base.

> NOTE
>
> **Suggestions** are optional for the ticket deflector form. You can create a form with a simple Q&A style or direct users to the contact form or helpdesk ticket based on their responses to the qualifying questions.

#### Creating block steps

1. In the **Suggestions** section, click **Add** to create a block step.
2. Choose one of the following suggestion types:

   1. **Additional question**
   2. **Answer**
   3. **Answer from your knowledge base**

**a.** **Additional question**  
This section is similar to **Context questions** and you can narrow queries further.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Creating_block_steps_Additional_question.png)

1. Enter a title for the block step.
2. Enter the desired question for the block step.
3. Choose the next action from the **If user selects this option, go to...** dropdown (e.g., contact form).
4. Hover over any question and click the **Delete** () icon to remove unwanted questions.
5. Click **Add questions**to include more questions.
6. Use the **Reorder** () icon to rearrange the question order.

**b.** **Answer**  
Enter the desired title and provide a straightforward text answer with basic formatting options (bold, italics, underline, hyperlinks, and code view).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Creating_block_steps_Answer.png)

**c.** **Answer from your knowledge base**  
In this section, you can direct users to a relevant article.

1. Enter the title for the step block.
2. Select the desired workspace in the **Workspace** dropdown.
3. Search and add the article in the **Article** field.

   By default, the next step will be the **Contact form**.

> NOTE
>
> Multiple articles cannot be linked.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_ScreenGIF-Answer_from_your_Knowledge_base.gif)

---

### Step 4: **Help request**

**Contact form**

The next step in a ticket deflector is the contact form. These form fields can be configured or customized to suit the ticket deflector's requirements. You can customize the following field names:

* **Email:** Users will provide their email address for further communication. This is a mandatory field.
* **First Name:** Users will provide their first name. This is a mandatory field.
* **Last Name:** Users will provide their last name. Turn on the toggle to make this field mandatory if required.
* **Telephone:** Users will provide their telephone number. Turn on the toggle to make this field mandatory if required.
* **Description:** Users will describe their issue in this field. This is a mandatory field.
* **Form submission text:** You can update the form submission button text as needed.
* **Allow attachments****:** Turn on this toggle to allow users to upload attachments. A maximum of five attachments, each up to 2 MB, is allowed.
* **Enable captcha****:** Turn on this toggle to enable a CAPTCHA for the form. This protects against bots and spam submissions.
* **After submission message****:** In the **After submission message** accordion, type a custom thank-you message for users after they submit the form. This is a mandatory field and cannot exceed 250 characters, including spaces.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Help_Request_Contact_form.png)

### Step 5: **Ticket submission settings**

**Ticket submission email notification**

In the **Ticket submission email notification** section, you can configure the email subject and the recipients of the notification emails.

1. **Email subject**

   * Enter the desired subject for the email.
   * The email subject cannot exceed 100 characters.
2. **Send notification email to**

   * Add one or more team accounts associated with the project as recipients of the notification email.
   * Click the  button to search and select from the list of team accounts.
3. **These emails** **(adding additional recipients)**

   * Add individual or group email IDs as additional recipients. This is an optional field.
   * There is no limitation on the number of recipients.
   * Enter a valid email ID and press **Enter** on your keyboard.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Ticket_submmision_email_notification.png)

> NOTE
>
> **Mapping Ticket deflector forms to specific emails**
>
> Each ticket deflector form can be mapped to different email addresses within your company.
>
> For example:
>
> * A sales ticket deflector form can send notifications to [**sales@yourcompany.com**](mailto:sales@yourcompany.com).
> * An operations ticket deflector form can send notifications to [**tech@yourcompany.com**](mailto:tech@yourcompany.com).
>
> This feature ensures that relevant departments are notified about submissions or tickets specific to their forms.

**Connect a helpdesk**

From the received ticket deflector, you can create a helpdesk ticket:

1. Expand the **Create helpdesk ticket** accordion and turn on the **Create helpdesk ticket on form submission** toggle.
2. Click **Connect a helpdesk**.

   The helpdesk configuration panel will appear.
3. Select the desired helpdesk application, such as **Freshdesk** or **Zendesk**.
4. Enter the appropriate credentials and click **Validate & save**.

> NOTE
>
> For more information, read the article on [Accessing the Ticket deflectors in portal.](/help/docs/accessing-the-ticket-deflectors)

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-connecting_a_helpdesk.png)

---

### How do I localize the variable text in the ticket deflector?

To localize text in the ticket deflector:

1. Navigate to **Settings** () >**Localization & Workspaces**> **Localization variables** in the Knowldge base portal.
2. Select the desired language.
3. Expand the **Ticket deflector** section and update the desired text(s).

   By default, the variable texts are localized to the respective language.
4. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-Localizing_the_ticket_deflector.png)

<a id="integrations-getting-started"></a>

## Integrations in Document360

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 makes it easy to integrate third-party apps and services into your knowledge base, offering over 25 integration options. These integrations provide specialized solutions in the following categories:

* **Analytics**
* **Chat**
* **Comments**
* **Marketing automation**

## Adding a new integration

Follow these steps to add a third-party app or service to your Document360 project:

1. Navigate to **Settings**()> **Knowledge base site** > **Integrations**in the knowledge base portal.
2. In the **Installed integrations** section, you’ll see a list of any existing integrations. You can turn each one on or off directly from this section.
3. Scroll down to view more apps available for integration.
4. Find the app or service you want to integrate and click **Add**.
5. In the **Add new integration** window, choose either **Basic configuration** or **Custom configuration**.
6. Enter the required information, such as the **Description** and **App ID**.
7. Click **Add**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Integrations%20-%20Overview%20page.png)

> **NOTE**
>
> The required information (ID or URL) may vary depending on the integration.

For detailed setup instructions for a specific app, click the **Learn more** link in the popup.

Once added, the integration will appear in the **Installed integrations** list.

---

## Integration controls

You can control your integrations from the **Integration overview** settings page ( **Settings**()> **Knowledge base site** > **Integrations**). Here, you can:

* **Status** – Turn integrations on or off without deleting them. Green indicates active, while Gray indicates inactive.
* **Type** – The name and icon of the integration
* **Description** – The custom description given by the user
* **Updated on** – The last log date the integration was added or updated
* **Users** – The team members who added or updated the integration

### Integrations available

| Analytics | Chat | Commenting | Marketing automation |
| --- | --- | --- | --- |
| * [Amplitude](/help/docs/amplitude) * [FullStory](/help/docs/fullstory) * [GoSquared](/help/docs/gosquared) * [Google Analytics](/help/docs/google-analytics-integration) * [Google Tag Manager](/help/docs/google-tag-manager) * [Heap](/help/docs/heap) * [Hotjar](/help/docs/hotjar) * [Mixpanel](/help/docs/mixpanel) * [Segment](/help/docs/segment-integration) | * [Belco](/help/docs/belco) * [Chatra](/help/docs/chatra) * [Crisp](/help/docs/crisp) * [Doorbell](/help/docs/door-bell) * [Freshchat](/help/docs/freshchat) * [Gorgias](/help/docs/gorgias) * Intercom * [Kommunicate](/help/docs/kommunicate) * [LiveChat](/help/docs/livechat) * [Olark](/help/docs/olark) * [Sunshine Conversations](/help/docs/sunshine) | * [Comment](/help/docs/commento) * [Disqus](/help/docs/disqus) | * [Freshmarketer](/help/docs/freshmarketer) * [VWO](/help/docs/vwo) * [Zoho PageSense](/help/docs/zoho-page-sense) |

---

## Custom HTML

Some integrations require adding code snippets to your site. The Custom HTML integration setting allows you to embed multiple third-party widgets into your Knowledge Base.

### Adding Custom HTML code for integrations

1. Navigate to **Settings**()> **Knowledge base site** > **Integrations**in the knowledge base portal.
2. Under **Custom HTML**, select **Add**.
3. Choose where to insert the custom HTML code:

   * **Header**
   * **Begin Body**
   * **End Body**
4. Paste your code snippet into the provided field, then click **Add**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Custom%20HTML%20-%20Integrations.png)

Your code snippet is now active and will appear on the **Integrations** overview page.

---

## Editing or deleting an integration

You can update already added integration's credentials anytime on the **Integrations** overview page.

#### Editing an integration:

1. Hover over the integration and click the **Edit** icon.
2. Update the **Status** (on/off), **Description**, or **App ID/URL**.
3. Click **Update** to save the changes.

#### Deleting an integration:

1. Hover over the integration and click the **Delete** icon.
2. Confirm the deletion by clicking **Delete** in the prompt.

---

### FAQs

#### What should I do if my integration isn’t working, or the toggle button is unresponsive?

First, double-check that the App ID and URL for the integration are correct. If the toggle button is unresponsive, ensure you have a stable internet connection. For app-specific errors, click the Learn more link in the setup window for detailed instructions.

#### What are the best practices for managing my integrations?

Periodically review your active integrations to make sure they’re still relevant to your business needs. Also, keep your integrations up-to-date to avoid any interruptions in functionality.

#### What is the best practice for installing a script to capture analytics on my documentation site?

The recommended approach is to use the **Custom HTML** option in the Integrations section available in the Knowledge base site settings. Add the script in the code space and save your changes. This allows you to seamlessly add your analytics script, ensuring it functions correctly within your documentation site.

<a id="advanced-insertion-rules-in-integration"></a>

## Code inclusion and exclusion conditions

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

After completing an integration setup in Document360, you can configure specific **Code inclusion/exclusion conditions** to manage where and how the integrated application’s code runs. This is useful for targeting specific cases or users.

For example, when integrating Google Analytics, you can set conditions to extract data based on:

* **IP Address** – Limit analytics to a specific IP or IP range.
* **Workspace** – Show analytics based on a selected workspace.
* **Language** – Collect data for specific languages on your site.

You can apply **AND/OR** logic to refine conditions when:

* Multiple conditions are added.
* All conditions should be true.
* Any one condition can be true.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Code%20inclusion%20in%20Integrations%20-%201.png)

### IP address condition

Define conditions based on user IP addresses to allow or restrict data collection from specific locations.

1. On the **Upgrade Integration** window, in the **Select Condition Type** field, choose **IP Address**.
2. From the **Include or Exclude** dropdown, select *Show* or *Hide* based on your needs.
3. In the **IP type** field, choose *Exact* or *Range* to specify a single IP or multiple IP addresses.
4. In the **IP address** field, specify the individual IP addresses or a range.

**Example**: To collect data only from internal users, choose **Exact** in the IP type field to monitor only a specified IP. For a range, set the operator to **Range** and define the IP range you need, allowing data collection across multiple addresses.

### Workspace condition

Set conditions for specific workspaces to control where analytics data is shown or hidden.

1. In the **Select Condition Type** field, choose **Workspace** in the Upgrade Integration window.
2. From the **Include or Exclude** dropdown, select *Show* or *Hide* based on your needs.
3. In the **Select workspaces** field, specify which workspaces to include or exclude. You can add multiple conditions for different workspaces as needed.

### Language condition

Configure language-based conditions to show or hide data collection for selected languages.

1. In the **Select Condition Type** field, choose **Language** in the Upgrade Integration window.
2. From the **Include or Exclude** dropdown, select *Show* or *Hide* based on your needs.
3. In the **Select languages** field, specify the language(s) to include or exclude in the integration. You can add multiple conditions for different languages as needed.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Code%20inclusion%20in%20Integrations%20-%202.png)

<a id="livechat"></a>

## LiveChat

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**LiveChat** is an online customer service tool that uses Artificial Intelligence (AI) to help you connect with your customers instantly. It makes real-time communication easy, allowing your business to respond to customer needs quickly and efficiently.

Integrating **LiveChat** with your **Document360** knowledge base enables customers to get instant support while they browse your content. This not only improves the user experience but also helps your support team handle multiple chats at once, reducing costs and improving customer satisfaction.

![01_Screenshot_Livechat_Integration2](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733728804137.png)

---

## Integrating **Document360** and **LiveChat**

To integrate ****LiveChat**** and ****Document360****,

1. From the Knowledge base portal, go to ****Settings** ()** > ****Knowledge base site**** > ****Integrations****.
2. Select **LiveChat** from the list of integrations and click **Add**. The ****Add new integration**** window appears.
3. Add a **Description** and enter your **LiveChat** **ID**.

   > NOTE
   >
   > The **LiveChat** ID is a unique code snippet obtained from the **LiveChat** application. This ID is necessary for integrating LiveChat and **Document360** in the Knowledge Base portal.
4. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
5. Once done, click **Add**.

![2_ScreenGIF-Document360_and_Livechat](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Document360_and_Livechat.gif)

---

## Obtaining the LiveChat ID

#### For existing customers in **LiveChat**

1. Access your **LiveChat** **dashboard** and click **Install** at the top bar.
2. In the **Install chat widget manually** section, find the LiveChat ID within the snippet code, identified with the prefix "*window.lc.license=*".

![3_Screenshot-getting_Live_chat_ID_Existing_customers](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-getting_Live_chat_ID_Existing_customers.png)

#### For a new **LiveChat** user/customer

1. During the initial setup of your **LiveChat** [account](https://www.livechat.com/), you can copy the **LiveChat** **ID** during the installation process.
2. After you complete the LiveChat ID integration setup in your Document360 knowledge base portal, open your **LiveChat** account interface to view and reply to the **LiveChat**s from your users.

   > NOTE
   >
   > With **LiveChat**, you can deploy bots to screen conversations within your documentation site's **LiveChat** chat box, helping to satisfy your customers with their regular queries.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="olark"></a>

## Olark

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Olark** combines live chat functionality with customer data collection to help you improve communication with your users. By integrating **Olark** with **Document360**, you can customize and manage your customers' live chat experience effectively.

**Key Features of** **Olark**

* **Visitor** **Cobrowsing PowerUp**  
  Assist customers directly by navigating their screen in real-time, making troubleshooting and guidance easier.
* **Visitor Geolocation**  
  Gain insights into your customers' locations to provide a more personalized and relevant support experience.
* **Visitor Insights PowerUps**  
  Access detailed customer information, including browsing behavior and interaction history, to enhance your support quality.
* **Transcripts**  
  Maintain a complete record of chat conversations for reference, training, and quality assurance.

---

## Integrating **Document360** and **Olark**

To integrate ****Olark**** and ****Document360****,

1. Log in to the Knowledge base portal and navigate to ****Settings**** **()**> ****Knowledge base site****> ****Integrations****.
2. Select **Olark** from the list of integrations and click **Add**. The ****Add new integration**** window appears.
3. Add a Description and enter your **Olark** **ID**.

   > NOTE
   >
   > The **Olark** **ID** is a unique code snippet obtained from the **Olark** application, which is necessary for integrating **Olark** and **Document360** in the Knowledge Base portal.
4. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
5. Once done, click **Add**.

![2_ScreenGIF-Integrating_Document360_Olark](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Integrating_Document360_Olark.gif)

---

## Obtaining the **Olark** ID

1. Sign in to your **Olark** account, navigate to **Settings** and select **Channels**.
2. In the **Installation Code** section, click **Copy to Clipboard** to copy the entire code.
3. In the copied code, locate the `olark.identify()` function. The ID is the thirteen-digit number (including dashes) following this function.
4. Copy the **Olark** ID.Use this ID for the integration setup in **Document360**.

Once you complete the **Olark** integration with your **Document360** knowledge base, you can view and reply to your customer chats.

![3_Screenshot-Getting_Olark_ID](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Getting_Olark_ID.png)

> NOTE
>
> You can integrate **Olark**, if you want a lightweight, customizable chat box on your site with built-in automation rules.

---

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="freshchat"></a>

## Freshchat

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Freshchat** is a modern messaging software designed for sales and customer engagement teams to communicate effectively with website visitors. It enables businesses to deploy AI-powered chatbots with seamless integration features.

The platform supports integration with popular communication channels, including **WhatsApp****,** **Apple Business Chat****,** **Facebook Messenger****, and** **LINE**. This allows you to provide a unified messaging experience across your website and mobile app.

**Key Features of** **Freshchat****:**

* **One** **inbox****:** Consolidate messages from different communication platforms into a single inbox, making it easy to manage conversations.
* **Self-Service with AI Bots:** Empower customers with AI-driven chatbots to find answers independently, reducing response times and improving efficiency.

![002_Screenshot_Freshchat_Integration](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/002_Screenshot_Freshchat_Integration.png)

---

## Integrating **Document360** and **Freshchat**

To integrated ****Freshchat**** and ****Document360****,

1. From the Knowledge base portal, go to ****Settings**** **()**> ****Knowledge base site****> ****Integrations****.
2. Select **Freshchat** from the list of integrations and click **Add**. The ****Add new integration**** window appears.
3. Add a Description and enter your **Freshchat** **Token**.

   > NOTE
   >
   > The **Freshchat** **Token** is a unique code snippet obtained from the **Freshchat** application, which is necessary for integrating **Freshchat** with **Document360** in the Knowledge Base portal.
4. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
5. Once done, click **Add**.

![1_ScreenGIF-Integrating_Document360_and_Freshchat](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Integrating_Document360_and_Freshchat.gif)

---

### Obtaining the **Freshchat** Token

To obtain the **Freshchat** token,

1. Log in to your **Freshchat** dashboard.
2. Navigate to **Settings** > **Admin settings**.
3. Select the **Configuration and Workflows** section and scroll down to **Workflows**.
4. Select **Web Chat Settings** > **Integration Settings.**
5. Under the **Web messenger** section, find and copy the token. This token will be required to integrate **Freshchat** with other platforms.

![2_ScreenGIF-Getting_token_from_freshdesk_for_Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Getting_token_from_freshdesk_for_Document360.gif)

After completing the **Freshchat** integration with your **Document360** knowledge base, open your **Freshdesk** account interface to view and reply to your users.

---

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="crisp"></a>

## Crisp

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Crisp** is a shared inbox platform that centralizes all your customer conversations, providing a seamless solution for instant online communication. It enables your team to efficiently handle multiple customer interactions simultaneously while maintaining high customer satisfaction.

**Key features of** **Crisp** **include:**

* **Cost Efficiency:** A single agent can manage multiple conversations at the same time, reducing operational costs.
* **Predefined Answers:** Set automated responses to common customer queries to save time and improve consistency.
* **Enhanced Communication Tools:** Empower your interactions with customers by adding images, buttons, and GIFs to your messages.

---

## Integrating **Document360** and **Crisp**

To integrate **Crisp** and **Document360**,

1. From the Knowledge base portal, navigate to ****Settings** ()** > ****Knowledge base site**** > ****Integrations****.
2. Select **Crisp** from the list of integrations and click **Add**. The ****Add new integration**** window appears.
3. Add a **Description** and enter your **Crisp** **website ID**.

   > NOTE
   >
   > The **Crisp** website ID is a unique code snippet obtained from the **Crisp** application. This ID is necessary for integrating **Crisp** and **Document360** in the Knowledge Base portal.
4. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
5. Once done, click **Add**.

![2_ScreenGIF-Integrate_Document360_and_crisp](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Integrate_Document360_and_crisp.gif)

---

### How do I get the **Crisp** Website ID?

#### For an existing customer in **Crisp**:

1. Open your **Crisp** **dashboard**.
2. Click **Settings** > **Website Settings**.
3. Copy the **Website ID** from the **Setup Instructions** section.

![02_Screenshot_Crisp_Integration](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/02_Screenshot_Crisp_Integration.png)

#### For a new customer in **Crisp**:

1. Obtain your **Crisp** **Website ID** during the **Crisp** account installation process. This ID is essential for completing the integration.
2. Follow the **Crisp** integration steps within your **Document360** **Knowledge base portal**.
3. Once the integration is complete, open your **Crisp** account interface to view and respond to chats from your users seamlessly.

> NOTE
>
> You can integrate **Crisp** if you want a chatbot with in-built email campaigns and a reliable mobile application.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="chatra"></a>

## Chatra

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

****Chatra**** is a user-friendly chat software designed for websites, enabling real-time interaction between customers and company representatives. It allows a single agent to handle multiple customer conversations simultaneously, helping reduce operational costs while maintaining high customer satisfaction.

With **Document360**, you can integrate ****Chatra**** into your knowledge base, providing customers with instant access to support as they navigate your content.

![2_Screenshot_Chatra_Integrations](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot_Chatra_Integrations.png)

---

## Integrating **Document360** and ****Chatra****

To integrate ****Chatra**** and ****Document360****,

1. From the Knowledge base portal, go to ****Settings** ()** > ****Knowledge base site**** > ****Integrations****.
2. Select ****Chatra**** from the list of integrations and click **Add**. The **Add new integration** window will appear.
3. Add a **Description** and enter your ****Chatra** ID**.

   > NOTE
   >
   > The ****Chatra**** ID is a unique code snippet obtained from the ****Chatra**** application. This ID is necessary for integrating ****Chatra**** and **Document360** in the Knowledge Base portal.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

![2_Screenshot-integrating_Document360_and_Chatra](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-integrating_Document360_and_Chatra.gif)

---

### Obtaining the ****Chatra**** ID

#### For an existing customer in ****Chatra****:

1. Log in to your ****Chatra**** account to access the ****Chatra** dashboard**.
2. Navigate to **Settings** > **Chat widget**.
3. In the **Chat Widget** window, look for the line that contains `w.Chatra.ID`. The value next to it is your ****Chatra** ID**.

![3_Screenshot-Chatra_ID_chat_widget_existing_user](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Chatra_ID_chat_widget_existing_user.png)

#### For a new ****Chatra**** user/customer:

1. Sign up for a ****Chatra**** account and verify your email address.
2. After email verification, you will receive your ****Chatra** ID** in the confirmation email.

Follow the steps to integrate ****Chatra**** with your **Document360** **Knowledge base portal**. Once the integration is complete, log in to your ****Chatra**** account to view and respond to chats from your users.

![4_Screenshot-Chatra_ID_chat_widget_new_user_customer](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Chatra_ID_chat_widget_new_user_customer.png)

> NOTE
>
> Integrate ****Chatra**** with **Document360** to have real-time conversations with your documentation site's users, initiate targeted chats and triggers, know real-time visitors lists, and more. [Click here](https://chatra.com/help/) to know more about the special features that you can reap from ****Chatra**** to your Documentation site.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="door-bell"></a>

## Doorbell

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Doorbell** is an intuitive chat software designed to help you collect, manage, and analyze customer feedback. It streamlines the feedback process, enabling smooth interactions that can lead to increased conversions.

With **Doorbell**, users can enhance their feedback by attaching screenshots, providing additional context for better insights and resolution.

![003_Screenshot_Doorbell_Integration](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/003_Screenshot_Doorbell_Integration.png)

---

## Integrating **Document360** and **Doorbell**

To integrate **Doorbell** and **Document360**,

1. From the Knowledge base portal, go to ****Settings** ()** > ****Knowledge base site**** > ****Integrations****.
2. Select **Doorbell** from the list of integrations and click **Add**. The ****Add new integration**** window will appear.
3. Add a **Description** and enter your **Doorbell** **ID** and **Doorbell** **AppKey**.

   > NOTE
   >
   > **Doorbell** ID and **Doorbell** App Key are the unique codes snippet obtained from the Doorbell application. These are necessary for integrating **Doorbell** and **Document360** in the Knowledge Base portal.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

![2_Screenshot-integrating_Document360_Doorbell](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-integrating_Document360_Doorbell.gif)

### Obtaining **Doorbell** ID and App Key

#### For an existing customer in **Doorbell**

1. Log in to your **Doorbell** account and navigate to **Settings > Installation Instructions**.
2. In the **Installation Instructions**, find the JavaScript code. The **ID** and **AppKey** are specified within the code.

![3_Screenshot-Getting_Doorbell_ID_and_App_key](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Getting_Doorbell_ID_and_App_key.png)

#### For a new **Doorbell** user/customer

1. Sign up for a **Doorbell** account.
2. During the initial account setup, you will receive your **Doorbell** **ID** and **AppKey**.

After you complete the **Doorbell** integration in your **Document360** knowledge base, open your **Doorbell** account interface to view the feedback from your visitors.

> NOTE
>
> With **Doorbell**'s automatically generated screenshots and sentiment analysis, you can effectively collect, manage, and analyze in-app user feedback from your documentation site. Additionally, you receive instant alert notifications through email or other group notification systems, ensuring timely responses to user feedback.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="gorgias"></a>

## Gorgias

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Gorgias** is a multi-channel helpdesk solution that connects business applications and communication channels, giving support agents a unified view of their customers. It streamlines customer support by centralizing interactions from various platforms into a single interface.

With **Document360**, you can seamlessly integrate **Gorgias** into your knowledge base, enhancing your ability to manage customer queries efficiently.

---

## Integrating **Document360** and **Gorgias**

To integrate **Gorgias** and **Document360**,

1. From the Knowledge base portal, go to ****Settings** ()** > ****Knowledge base site**** > ****Integrations****.
2. Select **Gorgias** from the list of integrations and click **Add**. The ****Add new integration**** window appears.
3. Add a **Description** and enter the **Gorgias** **ID**.

   > NOTE
   >
   > The **Gorgias** ID is a unique code snippet obtained from the **Gorgias** application. This ID is necessary for integrating **Gorgias** and  **Document360** in the Knowledge Base portal.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

![1_Screenshot-Integrating_Gorgias_Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Integrating_Gorgias_Document360.png)

---

## Obtaining the **Gorgias** App ID

#### For an existing customer in **Gorgias**

1. Log in to your **Gorgias** account and navigate to **More Options** from the **Ticket** dropdown.
2. Select **Settings > Channels > Chat.**
3. Click **Add Chat** and choose the **Any Other Website** option under the integration setup.
4. Click **Create & Customize**.
5. Follow the prompts to customize your chat configuration.
6. Choose the specific **Launcher** for your chat and click **Next.**
7. Once the setup is complete, click **Install Manually** to proceed with the integration.

![2_ScreenGIF-Getting_Gorgias_ID](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Getting_Gorgias_ID.gif)

#### For a new customer in **Gorgias**

1. During the initial setup of your LiveChat account, copy the **Gorgias** **ID** provided during the installation process.
2. Follow the steps to integrate **Gorgias** with your **Document360** **Knowledge base portal**.

Once the integration is complete, log in to your **Gorgias** account to view and respond to user chats seamlessly.

> NOTE
>
> You can integrate **Gorgias** if you need a space where your team members work together to manage, organize, respond to, and report on customer requests (or tickets).

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="belco"></a>

## Belco

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Belco** is a real-time chat software designed for websites, enabling customers to instantly connect with your support team.

By integrating **Belco** with your **Document360** knowledge base, you can provide users with instant support while they navigate your content. Additionally, **Belco** helps reduce operational costs by allowing a single agent to handle multiple customer conversations simultaneously, all while maintaining high customer satisfaction.

---

## Integrating **Document360** and **Belco**

To integrate **Belco** and **Document360**,

1. From the Knowledge base portal, go to ****Settings** ()** > ****Knowledge base site**** > ****Integrations****.
2. Select **Belco** from the list of integrations and click **Add**. The ****Add new integration**** window appears.
3. Add a **Description** and enter your **Belco** **Shop ID**.

   > NOTE
   >
   > The **Belco** Shop ID is a unique code snippet obtained from the **Belco** application. This ID is necessary for integrating **Belco** and **Document360** in the **Knowledge base portal**.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

![1_Screenshot-Document360_and_Belco](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Document360_and_Belco.png)

---

### Obtaining the **Belco** Shop ID

#### For an existing customer in **Belco**

1. Log in to your Belco Chat dashboard and click the **Setup Guide** icon.
2. Click **Install Our Plugin**, enter your shop information, and select **JavaScript** as the installation option.
3. In the generated JavaScript code, find the **Belco** **Shop ID**.

![2_ScreenGIF-getting_Belco_shop_ID](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-getting_Belco_shop_ID.gif)

#### For a new [Belco](https://www.belco.nl/) user/customer

1. During the initial setup of your **Belco** account, copy the **Belco** **ID** provided during the installation process.
2. Follow the steps to integrate the **Belco** **ID** with your Document360 knowledge base portal.

Once the integration is complete, log in to your **Belco** account to view and respond to chats from your users.

![0004_Screenshot_Belco_Integration](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/0004_Screenshot_Belco_Integration.png)

> NOTE
>
> You can integrate **Belco** if you want to connect a chatbot with a simple interface and a well-structured platform with a powerful e-commerce plugin.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="sunshine"></a>

## Sunshine Conversations

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

****Sunshine Conversations**** is an API-based modern CRM tool built on **AWS**, designed to help businesses communicate directly with their customers using social media and messaging services.

With ****Sunshine Conversations****, businesses can send messages to customers through social media messaging applications or directly on their website applications. By integrating ****Sunshine Conversations**** with your Document360 knowledge base, you can streamline customer communication and enhance user engagement.

---

## Integrating Document360 and ****Sunshine Conversations****

To integrate ****Sunshine Conversations**** and ****Document360****,

1. From the Knowledge base portal, go to ****Settings**** **()** > ****Knowledge base site**** > ****Integrations****.
2. Select ****Sunshine Conversations**** from the list of integrations and click **Add**. The ****Add new integration**** window appears.
3. Add a **Description** and enter your **App ID**.

**NOTE**

The App ID is a unique code snippet obtained from the ****Sunshine Conversations**** application. This ID is necessary for integrating ****Sunshine Conversations**** and **Document360** in the Knowledge Base portal.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

![1_ScreenGIF-Integrating_Document360_and_Sunshine](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Integrating_Document360_and_Sunshine.gif)

---

## Obtaining the ****Sunshine Conversations**** ID

1. Access your ****Sunshine Conversations**** dashboard and complete the initial account setup
2. Go to the **Apps** section in the dashboard and click **Create New App**.
3. Enter a name for your app and any relevant descriptions to help identify its purpose.
4. After filling in the details, save your app. The app will now appear in your **Apps** list.
5. Navigate back to the dashboard and choose the app for which you want to obtain the App ID.
6. Navigate to **Settings** from the dashboard of the selected app.
7. Scroll down to the **App Details** section to find the **App ID**. Click **Copy** to copy the App ID to your clipboard.

> NOTE
>
> If you need API keys, navigate to the **API Keys** section in the same **Settings** menu. Follow the instructions to generate and copy the keys.

![2_Screenshot-Getting_ID_from_Sunshine](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Getting_ID_from_Sunshine.png)

After completing the ****Sunshine Conversations**** integration in your **Document360** knowledge base, you can open the ****Sunshine Conversations**** account interface to set up the backend for message Conversations with social media messaging applications.

> [Click here](https://docs.smooch.io/guide/web-messenger/#styling-the-conversation-interface) to visit the ****Sunshine Conversations**** documentation page for backend setup.

> NOTE
>
> With ****Sunshine Conversations****' communication, you can engage with customers from WhatsApp and SMS, thus ensuring every possibility of customer interaction happens alive.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="kommunicate"></a>

## Kommunicate

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Kommunicate**is a chat software designed for websites, enabling real-time communication between customers and support teams. It provides businesses with an instant online solution to connect with their customers and streamline support operations.

With features like **AI-powered chatbots**, **Kommunicate** enhances customer interactions by automating responses to common queries and improving efficiency. Additionally, it reduces operational costs by allowing a single agent to handle multiple conversations simultaneously while maintaining high customer satisfaction.

By integrating **Kommunicate** with your **Document360** knowledge base, you can deliver seamless support experiences directly within your knowledge base, ensuring faster resolution of customer inquiries.

![1_Screenshot_Kommunicate_Integration1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot_Kommunicate_Integration%281%29.png)

---

## Integrating Document360 and **Kommunicate**

To integrate **Kommunicate** and **Document360**,

1. From the Knowledge base portal, go to ****Settings**** **()** > ****Knowledge base site**** > ****Integrations****.
2. Select **Kommunicate** from the list of integrations and click **Add**. The ****Add new integration**** window appears.
3. Add a **Description** and enter your **Kommunicate** **ID**.

   > NOTE
   >
   > The **Kommunicate** ID is a unique code snippet obtained from the **Kommunicate** application. This ID is necessary for integrating **Kommunicate** and **Document360** in the **Knowledge base portal**.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

![1_ScreenGIF-Integrating_Document360_and_Kommunicate](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Integrating_Document360_and_Kommunicate.png)

---

## Obtaining the **Kommunicate** App ID

#### For existing **Kommunicate** customers

1. Log in to your **Kommunicate** account and navigate to **Settings > Install**.
2. Copy the **App ID** from the JavaScript code in the **Install** **Kommunicate** **on your website** section. The **Kommunicate** **App ID** is the value that follows `appId` in the JavaScript code.

![04_Screenshot_Kommunicate_Integration](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/04_Screenshot_Kommunicate_Integration.png)

#### For new **Kommunicate** users/customers

1. During the **Kommunicate** account installation process, you will receive the **Kommunicate** **App ID.** Make sure to copy and save it for use in the integration.
2. Follow the steps to integrate the **Kommunicate** **App ID** with your **Document360** **Knowledge base portal**.

After completing the integration, log in to your **Kommunicate** account to view and respond to chats from your users.

![02_Screenshot_Kommunicate_Integration](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/02_Screenshot_Kommunicate_Integration.png)

> NOTE
>
> In the **Kommunicate** AI chatbot, you can qualify leads, schedule meetings, and support your customers 24/7. Thus, you can manage customer conversations more efficiently with less churn rate.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="google-analytics-integration"></a>

## Google Analytics

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Google Analytics** is a widely used **analytics tools** that lets you view website usage metrics such as **conversions**, **traffic sources**, **bounce rates**, **exit percentages**, and more.

You can integrate [Google Analytics](https://analytics.google.com/) with Document360 to know how your users interact with your knowledge base site, highly searched articles, and user locations.

To enable the Google Analytics integration, you'll need a **Google Analytics account** and a **Google Analytics ID**.

> NOTE
>
> You will need administrative privileges on your Google Analytics account to access the ID.

---

## Integrating Document360 and Google Analytics

1. From the Knowledge base portal, go to **Settings**()> **Knowledge base site** > **Integrations**.
2. Select **Google Analytics (New)** from the list of integrations and click **Add**.
3. The **Add new integration** panel will appear.
4. You can either configure with Basic configuration or Custom configuration.

**Basic configuration** - Configure a standard integration of Google Analytics with your Knowledge base.

You need to provide the following details:  
 a. Description: Enter the desired description.  
 b. Google Analytics ID: Type your Google Analytics ID.

> NOTE
>
> The Google Analytics ID is a unique code snippet obtained from the Google Analytics application. This ID is necessary for integrating Google Analytics and Document360 in the Knowledge Base portal.

**Custom configuration** - Configure an advanced integration of Google Analytics with your Knowledge base by adding custom events in snippet code.

To configure with Custom configuration:  
 a. Type a Description  
 b. Type the desired snippet code

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

![1_ScreenGIF-integrating_Google_Analytics_and_Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-integrating_Google_Analytics_and_Document360.gif)

---

## Obtaining Google Analytics ID

1. From the **Google Analytics account**, go to **Admin > Property Settings > Tracking Code**.
2. This opens the Tracking ID Info page with the snippet, and the **Tracking ID** is what we need to input in the **Google Analytics ID** field back in the Document360 portal.

![002_Screenshot_Google_Analytics_Integration](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/002_Screenshot_Google_Analytics_Integration.jpg)

After completing the Google Analytics integration setup in your Document360 knowledge base portal, you can track your knowledge base site performance and get visitor insights.

> NOTE
>
> You can integrate Google Analytics to track user insights like view counts, geolocation, device-wise metrics, behavioral flow, and more.

---

### Helpful links

* [**What is a Tracking ID?**](https://support.google.com/analytics/answer/7372977?hl=en)
* [**What is a Measurement ID?**](https://support.google.com/analytics/answer/7372977?hl=en)
* [**What is a Universal analytics property?**](https://support.google.com/analytics/answer/10220206?hl=en)

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="google-analytics-new"></a>

## Google Analytics (GA4)

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Google Analytics** is a widely used analytics tool that lets you view website usage metrics such as conversions, traffic sources, bounce rates, exit percentages, and more. **Google Analytics (New)** integration in Document360 is specifically for **Google Analytics (GA4)**.

> NOTE
>
> GA4 is the 4th iteration of Google Analytics. It provides you with a **Measurement ID** instead of a **Tracking ID**.
>
> GA3 - Tracking ID begins with the 'UA-'  
> GA4 - Measurement ID starts with the 'G-'
>
> To learn more, visit the [help article](https://support.google.com/analytics/answer/9539598).

---

## Integrating Document360 and Google Analytics(GA4)

You can integrate [Google Analytics (GA4)](https://support.google.com/analytics/answer/10089681?hl=en) with Document360 to know how your users interact with your Knowledge base site, highly searched articles, and user locations. You'll need a **Google Analytics account** and a **Google Analytics ID**to enable the Google Analytics integration.

> NOTE
>
> You will need administrative privileges on your Google Analytics account to access the ID.

1. From the Knowledge base portal, go to **Settings**() > **Knowledge base site** > **Integrations**.
2. Select **Google Analytics (New)** from the list of integrations and click **Add**.
3. The **Add new integration** panel will appear.
4. You can either configure with Basic configuration or Custom configuration.

**Basic configuration** - Configure a standard integration of Google Analytics with your Knowledge base.

You need to provide the following details:  
 a. Description: Enter the desired description.  
 b. Google Analytics ID: Type your Google Analytics ID.

> NOTE
>
> Google Analytics ID is the **Measurement ID** of your desired property in Google Analytics (GA4). The Google Analytics ID is a unique code snippet obtained from the Google Analytics application.

**Custom configuration** - Configure an advanced integration of Google Analytics with your Knowledge base by adding custom events in snippet code.

To configure with Custom configuration:  
 a. Type a Description.  
 b. Type the desired snippet code.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

![1_ScreenGIF-integrating_Google_Analytics_and_Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-integrating_Google_Analytics_and_Document360.gif)

---

## Obtaining Google Analytics ID (Measurement ID)

A Google tag ID is a string of letters and numbers usually beginning with "G-".

1. From the **Google Analytics account**, go to **Admin > Property Settings > Data streams**.
2. Click the desired data stream for which you need the Measurement ID.
3. In the Google tag section at the bottom of the Web stream details page, click **Configure tag settings**.
4. In **Your Google tag** section, copy the **"G-..."** ID appears in the top right.
5. This opens the Tracking ID Info page with the snippet, and the **Tracking ID** is what we need to input in the **Google Analytics ID** field back in the Document360 portal.

> For more information, see [Google Analytics support article](https://support.google.com/analytics/answer/9539598#find-G-ID).

![Obtaining Measurement ID from Google Analytics GA4](https://storage.googleapis.com/support-kms-prod/4vzOnPW93ZjrGTZKfeIJYHXXPmpfCmc0UMHy)

*(Image source: Google support docs)*

After completing the Google Analytics integration setup in your Document360 knowledge base portal, you can track your knowledge base site performance and get visitor insights.

> NOTE
>
> You can integrate Google Analytics to track user insights like view counts, geolocation, device-wise metrics, behavioral flow, and more.

> For information on migration from GA3 to GA4, see [Google Analytics help](https://support.google.com/analytics/answer/10607999?hl=en&ref_topic=10737980)

The public-facing website where end-users can access articles and find answers to their questions.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="google-tag-manager"></a>

## Google Tag Manager

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Google Tag Manager** is a tag management system. This tool allows the user to easily update measurement codes and related code fragments collectively known as tags in a website or a mobile app. You can use Google Tag Manager to add and update your tags for better analytics and marketing. Google Tag Manager can also be used for site analytics and remarketing.

---

## Integrating Google Tag Manager with Document360

1. From the Knowledge base portal, go to **Settings**()> **Knowledge base site** > **Integrations**.
2. Select **Google Tag Manager** from the list of integrations and click **Add**.
3. The **Add new integration** panel will appear.
4. You can either configure with Basic configuration or Custom configuration.

**Basic configuration**: Configure a standard integration of Google Analytics with your Knowledge base.

**To configure with Basic configuration:**  
 a. Type a Description.  
 b. Type the Google Tag Manager ID.

> NOTE
>
> The Google Tag Manager ID is a unique code snippet obtained from the Google Tag Manager application. This ID is necessary for integrating Google Tag Manager and Document360 in the Knowledge Base portal.

**Custom configuration**: Configure an advanced integration of Google Tag Manager with your Knowledge base by adding custom events in snippet code.

**To configure with Custom configuration:**  
 a. Type a Description.  
 b. Type the desired snippet code.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGif-Google_tag_manager.gif)

---

## Obtaining Google Tag Manager ID

#### For an existing user of Google Tag Manager

1. Click on **add new container** in your **Google Tag Manager** > **Web** (from the Create Container panel) > **Install Google Tag Manager**.

![003_Gif_Google_Tag_Manager_Integrations](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/003_Gif_Google_Tag_Manager_Integrations.gif)

2. Click on **Workspace**, you can find the code on the primary menu bar next to Workspace changes.

![005_Screenshot_Google_Tag_Manager_Integration](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/005_Screenshot_Google_Tag_Manager_Integration.png)

#### For a new Google Tag Manager user

1. After the initial Google Tag Manager Account setup, click > **Admin** (next to versions in the primary menu) > **Add Container name**  and **Container platform**.
2. Copy code from the snippet in the **Install Google Tag Manager** popup.

![002_Gif_Google_Tag_Manager](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/002_Gif_Google_Tag_Manager.gif)

After completing the Google Tag Manager integration setup in your Document360 knowledge base portal, you can open your Google Tag Manager account interface to view and access code and related code fragments(tags).

> NOTE
>
> You can integrate Google Tag Manager if you want to update your  tags for conversion tracking, site analytics, and more.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="heap"></a>

## Heap

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Heap**is a **product analytics** tool for analyzing user behavioral data and is convenient for a product and marketing team. It helps with extracting user data and reports in a product that helps to tweak the product.

Some key features of the **Heap** include

**Event feed**: Client-side events will appear in your app's Event Feed as they happen.

**Analysis**: With tools like Graph analysis, Funnel analysis, Users analysis, Retention analysis, Influential analysis, Path analysis, and more, your customer communications will become significantly more effective.

---

## Integrating Document360 and **Heap**

1. From the Knowledge base portal, go to **Settings**()> **Knowledge base site** > **Integrations**.
2. Select **Heap** from the list of integrations and click **Add**.
3. The **Add new integration** panel will appear.
4. You can either configure with Basic configuration or Custom configuration.

**Basic configuration**: Configure a standard integration of **Heap** with your Knowledge base.

You need to provide the following details:  
 a. Description: Enter the desired description.  
 b. **Heap** App ID: Type your **Heap** App ID.

> NOTE
>
> The **Heap** ID is a unique code snippet obtained from the **Heap** application. This ID is necessary for integrating **Heap** and Document360 in the Knowledge Base portal.

**Custom configuration**: Configure an advanced integration of **Heap** with your Knowledge base by adding custom events in snippet code.

To configure with Custom configuration:  
 a. Type a Description.  
 b. Type the desired snippet code.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

![1_ScreenGIF-Integrating_Document360_and_Heap](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Integrating_Document360_and_Heap.gif)

---

## Obtaining **Heap** App ID

#### For an existing customer in **Heap**

you can follow the below steps to get the **Heap** **App ID**:

1. Navigate to the **Heap** App dashboard.
2. In the left navigation panel, scroll down and click on **Account** > **Install**.
3. The **Install** **Heap** **on your Development environment** window appears.
4. Select the platform as **Web**.
5. Scroll down to the **Web Installation**, copy the **Heap** ID from the snippet code provided.

![2_ScreenGIF-Existing_customer_in_Heap](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Existing_customer_in_Heap.gif)

#### For a new customer in **Heap**

1. You will be getting the **Heap** App ID during the **Heap** account installation process.
2. After completing the **Heap** integration setup in your Document360 knowledge base portal, open your **Heap** account interface to view and reply to the chats from your users.

![3_Screenshot-new_customer_in_heap](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-new_customer_in_heap.png)

Now you can track and view all your Knowledge base site analytics and user behaviour from **Heap** dashboard.

> NOTE
>
> **Heap** integration helps you with **Heap**’s advanced analytics report, you can analyse user behavioural data and tweak your product features.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="segment-integration"></a>

## Segment

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Segment** is a powerful tool for analyzing user data and will be extremely useful for a product and marketing team to understand user behavior. Good businesses use analytics to have a competitive edge.

**Segment** helps to collect, transform, send, and archive your first-party customer data. **Segment** simplifies managing data and connecting new tools, allowing to spend more time using your data and less time collecting it. You can monitor data from all your other tools, use **Segment** to watch it, and choose the correct data accordingly.

---

## Integrating Document360 and **Segment**

1. From the Knowledge base portal, go to **Settings**() > **Knowledge base site** > **Integrations**.
2. Select **Segment** from the list of integrations and click **Add**.
3. The **Add new integration** panel will appear.
4. You can either configure with a Basic configuration or Custom configuration.

**Basic configuration**: Configure a standard integration of **Segment** with your Knowledge base.

You need to provide the following details:  
 a. Description: Enter the desired description.  
 b. **Segment** ID: Type your **Segment** ID.

> NOTE
>
> The **Segment** application. This ID is necessary for integrating **Segment** and Document360 in the Knowledge Base portal.

**Custom configuration**: Configure an advanced integration of **Segment** with your Knowledge base by adding custom events in snippet code.

To configure with Custom configuration:  
 a. Type a Description.  
 b. Type the desired snippet code.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

![1_Screenshot-Integrating_Segment_and_Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Integrating_Segment_and_Document360.gif)

---

## Obtaining the **Segment** ID

1. From the **Segment** dashboard, navigate to the left side toolbar and click the **Develop** section.
2. Scroll down, and under **Account info**, you can copy the **Account SID**.

![2_Screenshot-Getting_Segment_ID](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Getting_Segment_ID.png)

After completing the **Segment** integration in the Document360 knowledge base, you can open **Segment** account interface to manage your data and tools.

> NOTE
>
> You can integrate **Segment** to better understand your users with schematized and actionable data to enhance your knowledge base and site experience.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="hotjar"></a>

## Hotjar

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Hotjar** is a behavior analytics tool that helps you get product insights with user-behavior analytics attributes. **Hotjar** provides tools such as heatmaps, session recordings, and surveys that allows to empathize with and understand your users.

---

## Integrating Document360 and **Hotjar**

1. From the Knowledge base portal, go to **Settings**() > **Knowledge base site** > **Integrations**.
2. Select **Hotjar** from the list of integrations and click **Add**.
3. The **Add new integration** panel will appear.
4. You can either configure with a Basic configuration or Custom configuration.

**Basic configuration**: Configure a standard integration of **Hotjar** with your Knowledge base.

You need to provide the following details:  
 a. Description: Enter the desired description.  
 b. **Hotjar** ID: Type your **Hotjar** ID.

> NOTE
>
> The **Hotjar** ID is a unique code snippet obtained from the **Hotjar** application. This ID is necessary for integrating **Hotjar** and Document360 in the Knowledge Base portal.

**Custom configuration**: Configure an advanced integration of **Hotjar** with your Knowledge base by adding custom events in snippet code.

To configure with Custom configuration:  
 a. Type a Description.  
 b. Type the desired snippet code.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

![1_ScreenGIF-integrating_hotjar_and_Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-integrating_hotjar_and_Document360.gif)

---

## Obtaining the **Hotjar** ID

1. From the **Hotjar** overview page, hover over the **Set up** **Hotjar** from the left side and click on it.
2. Under the **Setup** section, you can copy the **Hotjar** **ID** from the snippet next to `hjid`.

![2_Screenshot-Getting_Hotjar_ID](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Getting_Hotjar_ID.png)

After completing the **Hotjar** integration in the Document360 knowledge base, you can open  **Hotjar** account interface to view knowledge base site analytics and performance through features like tracking, highlights, recordings, heatmaps, and surveys.

> NOTE
>
> Why should I integrate **Hotjar**?
>
> You can integrate **Hotjar**, an analytical tool, to give behaviour analytics and feedback data on your customers through tools like heatmaps, session recordings, surveys, and an incoming feedback assistant.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="amplitude"></a>

## Amplitude

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Amplitude** is a **product analytical tool** for analyzing product usage data. It also helps the product and marketing team draw out user behavioural data and reports in a product to tweak it.

Some key features of **Amplitude** are

* **Real-time user analytics** like retention, funnels, revenue analysis, and flexible user segmentation.
* Help analyze user behaviour using their key feature called **microscope**.

---

## Integrating **Amplitude** and Document360

1. From the Knowledge base portal, go to **Settings**() > **Knowledge base site** > **Integrations**.
2. Select **Amplitude** from the list of integrations and click **Add**.
3. The **Add new integration** panel will appear.
4. You can either configure with Basic configuration or Custom configuration.

* **Basic configuration**: Configure a standard integration of **Amplitude** with your Knowledge base.

You need to provide the following details:  
 a. Description: Enter the desired description.  
 b. **Amplitude** API key: Type your **Amplitude** API key.  
 c. Use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.

![1_ScreenGIF-Integrating_Amplitude_and_Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Integrating_Amplitude_and_Document360.gif)

> NOTE
>
> The **Amplitude** API Key is a unique code snippet obtained from the **Amplitude** application. This ID is necessary for integrating **Amplitude** and Document360 in the Knowledge Base portal.

* **Custom configuration**: Configure an advanced integration of **Amplitude** with your Knowledge base by adding custom events in snippet code.

To configure with Custom configuration:  
 a. Type a Description.  
 b. Type the desired snippet code.  
 c. Use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.

5. Once done, click **Add**.

#### Session replay and Autocapture implementation

After signing up and activating the account, **Amplitude** prompts you to connect your first application by adding a single snippet. Use the below HTML code snippet to enable Session replay with Autocapture.

```
<script src="https://cdn.amplitude.com/script/AMPLITUDE_API_KEY.js"></script>
<script>
  window.amplitude.add(window.sessionReplay.plugin({sampleRate: 1}));
  window.amplitude.init('AMPLITUDE_API_KEY', {
    "fetchRemoteConfig":true, "autocapture":true
  });
</script>
```

Custom

Copy

For more detailed information about Session Replay implementation, refer to the [Session Replay instrumentation documentation](https://amplitude.com/docs/session-replay/instrument-session-replay) article.

---

## Obtaining the **Amplitude** API Key

#### For an existing customer in **Amplitude**

From the **Amplitude** project dashboard, go to **projects**, and under the **General** section, you can copy the **API Key**.

#### For a new customer in **Amplitude**

1. Register an account in [Amplitude](https://amplitude.com/amplitour/register).
2. You will get the **Amplitude** **API Key** in your initial **Amplitude** Account setup.

![2_Screenshot-getting_Amplitude_app_key](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-getting_Amplitude_app_key.png)

Now you can navigate back to the **Amplitude** dashboard to view analytical reports for the project(site). Also, track and view all the knowledge base site analytics, and user behaviour from here.

---

## FAQ

**Why should I integrate** **Amplitude****?**

You can integrate **Amplitude** to track visitors based on collaborative analytics that helps to fine-tune your product with pre-eminent product analytics reports.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="fullstory"></a>

## FullStory

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**FullStory** is a user-experience Intelligence tool for analyzing user data and will be extremely useful for a product and marketing team to understand user behavior. You can monitor clicks and page transitions easily using **FullStory**.

**FullStory** has special analytics features like real-time user analytics that include retention and funnels. Magic-moments is a unique feature in **FullStory**, which is used to showcase readymade recording sessions of users.

---

## Integrating Document360 and **FullStory**

1. From the Knowledge base portal, go to **Settings**() > **Knowledge base site** > **Integrations**.
2. Select **FullStory** from the list of integrations and click **Add**.
3. The **Add new integration** panel will appear.
4. You can either configure with Basic configuration or Custom configuration.

**Basic configuration**: Configure a standard integration of **FullStory** with your Knowledge base.

You need to provide the following details:  
 a. Description: Enter the desired description.  
 b. **FullStory** ID: Type your **FullStory** ID.

**Custom configuration**: Configure an advanced integration of **FullStory** with your Knowledge base by adding custom events in snippet code.

To configure with Custom configuration:  
 a. Type a Description.  
 b. Type the desired snippet code.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

![1_ScreenGIF-Integrating_Document360_and_FullStory](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Integrating_Document360_and_FullStory.gif)

---

## Obtaining the **FullStory** ID

#### For an existing user of **FullStory**

From the **FullStory** dashboard, navigate to the left corner, click on your work name dropdown, and select **Settings** in it.

On the Settings window, navigate to **FullStory** **Setup** section and Under **Install your** **FullStory** **snippet** you can find the **FullStory** ID:

```
window['_fs_org']

```

Plain text

Copy

#### For a new user of **FullStory**

![2_Screenshot-API_Key_FullStory](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-API_Key_FullStory.png)

After completing the **FullStory** integration in the Document360 knowledge base, you can open the **FullStory** account segment to view the segment-based analytics. Also, track and view all your knowledge base site analytics and user behaviour for your **FullStory** dashboard.

---

## FAQs

**Why should I integrate** **FullStory** **?**

You can integrate **FullStory** to view the site's analytics with segment-based data and online recording sessions.

**What is a** **FullStory** **ID?**

The **FullStory** ID is a unique code snippet obtained from the **FullStory** application. This ID is necessary for integrating **FullStory** and Document360 in the Knowledge Base portal.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="mixpanel"></a>

## Mixpanel

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

****Mixpanel**** is an event-centric analytics tool that tracks user events rather than automatically capturing data.

It enables tracking of:

* Conversion from the **static/dynamic** (feature page) page.
* The dropping rate in the **sales funnel**.
* **Referral sites** with good **ROI**.

**Document360** supports ****Mixpanel**** as one of its many third-party integrations.

---

## Prerequisites before integrating **Mixpanel** with **Document360**

When integrating **Mixpanel** with **Document360**, you can choose from two configuration options:

* **Basic configuration**: This option allows you to set up **Mixpanel** quickly by entering minimal information. However, to enable tracking, you must manually add JavaScript code in the **Customize site** section after completing the integration setup.
* **Custom configuration**: This option provides advanced tracking capabilities, letting you enter JavaScript code directly during the configuration process. For more complex use cases, additional customization can also be applied in the **Customize site** section.

Regardless of the configuration you choose, **no data will be sent to** **Mixpanel** **until JavaScript code is implemented.** Users must write or obtain custom code based on their specific tracking requirements.

> NOTE
>
> **Document360** offers the flexibility to integrate **Mixpanel** in a way that best fits your unique tracking requirements. Since each use case is different, the JavaScript code needed for the integration must be prepared and tested by your team. This approach ensures the code is tailored specifically to your needs and maximizes the effectiveness of your **Mixpanel** integration.

---

## Integrating **Document360** and **Mixpanel**

1. In the Knowledge base portal, navigate to ****Settings**** ()> ****Knowledge base site**** > ****Integrations****.
2. Select **Mixpanel** from the list of integrations and click **Add**.
3. The **Add new integration** window will appear.

**Document360** offers two configuration options for integrating **Mixpanel**:

* **Basic configuration**
* **Custom configuration**

### Basic configuration

Use **Basic configuration** to set up standard **Mixpanel** integration quickly. This option requires adding additional JavaScript code in the **Customize site** section of **Document360** after setting up the integration.

1. Enter the description in the **Add new integration** window.
2. Enter your ****Mixpanel**** ID.
3. Optionally, use the **Code inclusion/exclusion conditions** feature to apply the code based on **IP address**, **Workspace**, or **Language**.
4. Click **Add** to save your integration.
5. Navigate to ****Settings**** ()> ****Customize site****, and click **Custom CSS & JavaScript** to manually add the required JavaScript code to enable data tracking.

![1_ScreenGIF-Integrating_Mixpanel_and_Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Integrating_Mixpanel_and_Document360.gif)

### Custom configuration

Use **Custom configuration** to set up advanced **Mixpanel** integration. This option allows you to add JavaScript code directly in the configuration panel and further customize the integration based on your needs.

1. Enter the description in the **Add new integration** window.
2. Add the desired JavaScript snippet in the configuration window.
3. Optionally, use the **Code inclusion/exclusion conditions** feature to apply the code based on **IP address**, **Workspace**, or **Language**.
4. Click **Add** to save your integration.

For more advanced use cases, you can also add JavaScript code in the ****Customize site**** section.

---

## Obtaining the **Mixpanel** ID

1. [Sign in](https://mixpanel.com/login/) to your **Mixpanel** account.
2. Click **Settings** and then select **Set up** **Mixpanel**.
3. Copy the **Mixpanel** ID.

---

## Sample JavaScript Codes for **Mixpanel** Integration

Below are sample codes for implementing **Mixpanel** tracking. These examples serve as a starting point and must be customized to fit your specific use case.

> NOTE
>
> The following code snippets are examples to illustrate how to configure **Mixpanel** tracking in **Document360**. These are not one-size-fits-all solutions and should be adapted by your development team to suit your requirements.

### Basic page view tracking

Tracks when a user views a page, along with the page URL, title, and referrer.

```
javascriptCopy codewindow.mixpanel.track("Page View", { 
    "Page URL": window.location.href, 
    "Page Title": document.title, 
    "Referrer": document.referrer 
});
```

JavaScript

Copy

### Button click tracking

Tracks when a specific button on the page is clicked.

```
javascriptCopy codedocument.getElementById("subscribeButton").addEventListener("click", function() {
    window.mixpanel.track("Button Click", { 
        "Button Name": "Subscribe", 
        "Page URL": window.location.href 
    });
});
```

JavaScript

Copy

---

### FAQs

#### **What is a** **Mixpanel** **ID?**

The **Mixpanel** ID is a unique code snippet obtained from the **Mixpanel** application. This ID is necessary for integrating **Mixpanel** and **Document360** in the Knowledge Base portal.

#### **Why should I integrate** **Mixpanel****?**

Integrating **Mixpanel** provides robust event-based tracking capabilities, enabling you to analyze user behavior and optimize your Knowledge Base performance.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="vwo"></a>

## VWO

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**VWO** experience Optimization Platform is an all-in-one platform that helps with business metrics. It empowers you to discover insights, test ideas, and improve engagement across the entire customer journey.

The features offered by VWO are

* **Test product features**
* **Extracting user intention details**
* **Push notifications**
* **Creation and optimization of product roadmaps**

---

## How will you integrate Document360 and VWO?

1. From the Knowledge base portal, go to **Settings** > **Knowledge base site** > **Integrations**.
2. Select **VWO** from the list of integrations and click **Add**.
3. The **Add new integration** panel will appear.
4. You can either configure it with a basic configuration or a custom configuration.

**Basic configuration**: Configure a standard integration of the VWO Account with your Knowledge base.

You need to provide the following details:  
 a. Description: Enter the desired description.  
 b. VWO Account ID: Type your VWO Account ID.

> NOTE
>
> **What is VWO Account ID?**  
> The VWO Account ID is a unique code snippet obtained from the VWO application. This ID is necessary for integrating VWO and Document360 in the Knowledge Base portal.

**Custom configuration**: Configure an advanced integration of VWO with your knowledge base by adding custom events to the snippet code.

To configure with Custom configuration:  
 a. Type a Description.  
 b. Type the desired snippet code.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

![1_ScreenGIF_Integrating_VWO_and_Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF_Integrating_VWO_and_Document360.gif)

### How do I get the VWO Account ID?

#### For a new VWO customer

1 . Register an account in **VWO** and **sign in**.

2 . On Account setup, you will be auto-directed to the **install code section** (you can copy the snippet and paste it into an external text editor).

3. Copy the **var account\_id** from the snippet you copied to your external editor.

![001_Screenshot_VWO_Integration](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/001_Screenshot_VWO_Integration.png)

#### For an existing VWO customer

1. Click on your profile picture > **Edit profile**.
2. On the top, copy the **Account ID**.

![2_Screenshot-Getting_VWO_Account_ID](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Getting_VWO_Account_ID.png)

After completing the **VWO** integration in the Document360 knowledge base, you can open VWO account interface to manage web optimization and run test experiments.

> NOTE
>
> Why should I integrate VWO?
>
> You can integrate VWO to get an intuitive point-and-click visual editor for conducting website **A/B testing**. You can also test different variations of the homepage on a small sample of visitors.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="freshmarketer"></a>

## Freshmarketer

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Freshmarketer** marketing automation is a cloud-based conversion optimization solution offering analytics and testing features.

The testing feature in Freshmarketer is A/B testing, and its analytics features are heatmaps and funnel analysis.

The Heat map tool summarizes visitor clicks and mouse movements in real time. The funnel analysis tool helps identify the visitor drop-off on a multi-page website.

Now, you can enjoy the benefits of these features in Document360 by integrating the Document360 knowledge base with Freshmarketer.

---

## How will you integrate Freshmarketer and Document360?

1. From the Knowledge base portal, go to **Settings** > **Knowledge base site** > **Integrations**.
2. Select **Freshmarketer** from the list of integrations and click **Add**.
3. The **Add new integration** panel will appear.
4. Add a  **Description**  and enter the **Freshmarketer Tag Src**.

   > NOTE
   >
   > **What is Freshmarketer Tag Src?**  
   > The **Freshmarketer Script Tag Src** is a combination of the **Freshmarketer URL** and a **Freshsales Analytics authentication token**, which you can obtain from the Freshmarketer application.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

![1_Screenshot-Integrating_Document360_and_Freshmarketer](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Integrating_Document360_and_Freshmarketer.png)

---

### How do I get the Freshmarketer Script Tag Src?

1. Open your **Freshmarketer Dashboard**, and click on **Admin settings**.
2. Select the **Tracking and Integrations** section and navigate down to the **CRM Code Library** under Website and Event Tracking.
3. Click **Get started** button next to the **Java** section.
4. You can get the **Script Tag Src** as a URL.

![2_ScreenGIF-Getting_Integrating_ID_from_Freshmarketer](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Getting_Integrating_ID_from_Freshmarketer.gif)

After completing the Freshmarketer integration with your Document360 knowledge base, you can view and manage your contact list, deliver marketing campaigns, and set up automated emails from the Freshmarketer dashboard.

> NOTE
>
> Why should I integrate Freshmarketer?
>
> You can choose to integrate Freshmarketer to upgrade your marketing modules to the next level with list management, marketing campaigns, and automated email marketing.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="zoho-page-sense"></a>

## ZOHO PageSense

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Zoho PageSense** is a conversion optimization and personalization platform that helps you optimize your website, personalize pages to suit your target audience, and boost the overall conversion rate.

With Zoho PageSense, you can do a lot of **tracking**, **analysis**, **optimization**, and **personalization** to your platform.

## How will you integrate Document360 and Zoho PageSense?

1. From the Knowledge base portal, go to **Settings** > **Knowledge base site** > **Integrations**.
2. Select **Zoho PageSense** from the list of integrations and click **Add**.
3. The **Add new integration** panel will appear.
4. Add a  **Description**  and enter the **Zoho PageSense ID**.

   > NOTE
   >
   > **What is Zoho PageSense ID?**  
   > The **Zoho PageSense ID** is a code you get from the Zoho PageSense Interface application for Document360 and Zoho PageSense Integration in the Document360 Knowledge base portal.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

![1_Screengif-Integrating_Document360_and_Zoho_PageSense](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screengif-Integrating_Document360_and_Zoho_PageSense.gif)

---

### How do I get the Zoho PageSense ID?

1. Register an account in **Zoho PageSense** and **sign in**.
2. Create a **Project**.
3. On the **Project Dashboard**, click on **Snippet** from the top bar.
4. In the Snippet page, click on the **Synchronous tab** and copy the **Zoho PageSense ID** from the snippet.

![2_Screenshot-Getting_Zoho_PageSense_ID](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Getting_Zoho_PageSense_ID.png)

After completing the **Zoho PageSense** integration in your Document360 knowledge base, you can open your Zoho PageSense account interface to view site analytics and performance. Zoho Pagesense allows you to  track, test, analyze, and optimize to improve your product for better conversion.

> NOTE
>
> Why should I integrate Zoho PageSense?
>
> You can integrate Zoho PageSense to get a one-step solution for Complete Conversion Rate Optimization (CRO) to work with different types of experiments like heatmaps, A/B testing, form analytics, and session recording.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="gosquared"></a>

## GoSquared

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**GoSquared** is a platform that will help turn your visitors into loyal customers with a suite of products to connect with your customers.

The integrated suite of products that come with GoSquared are

* **Analytics**
* **Live chat**
* **Automation**
* **Customer Data Hub**

The **Now dashboard** and the **Trend dashboard** are the other two features that give you real-time insights and historical insights on your site performance respectively. [Click here](https://www.gosquared.com/support/articles/1604607-what-is-gosquared) to learn more about GoSquared.

---

## Integrating GoSquared with Document360

1. From the Knowledge base portal, go to **Settings**() > **Knowledge base site** > **Integrations**.
2. Select **Freshmarketer** from the list of integrations and click **Add**.
3. The **Add new integration** panel will appear.
4. Add a  **Description**  and enter the **GoSquared Project Token**.

   > NOTE
   >
   > **GoSquared Project Token** is a code obtained from the GoSquared, and used for integrating Document360 and GoSquared in the Document360 Knowledge base portal.

5. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
6. Once done, click **Add**.

### Obtaining GoSquared Token

1. Register and create an account in GoSquared.
2. Login into your registered GoSquared account.
3. Navigate into your project dashboard in GoSquared and Click **Current project > General**.

![003_Gif_GoSquared_Integration](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/003_Gif_GoSquared_Integration.gif)

4. From the **General** page, copy the **GoSquared code snippet**.
5. Now you can get the **GSN code** from the code snippet.

   Existing customers may also follow the same steps.
6. After completing the GoSquared integration with Document360 knowledge base, open your GoSquared account interface to view the analytic reports, and chatbox, and you can prompt users based on the behavioral data.

---

## FAQ

Why should I integrate GoSquared with Document360?

With GoSquared integration, you ca engage with customers using multi-channel messaging, live chat for converting, and web analytics.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="commento"></a>

## Commento

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Commento is a modern commenting interface that can be embedded into your website application. Commento is fast and bloat-free with a modern interface. Refer to the below information to understand how you can bring this commenting interface into your Knowledge base site.

![1_Screenshot_Commento_Integration](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot_Commento_Integration.png)

---

## How will you integrate Document360 with Commento?

### Method 1

1. From the Knowledge base portal, navigate to Settings () > **Knowledge base site** > **Integrations**.
2. From the **Comments** section, select **Commento** and click **Add**.
3. The **Add new integration** panel will appear, add a **Description** to it.
4. If required, you can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
5. Once done, click **Add**.

![1_Screenshot-Integrating_Document360_and_commento](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Integrating_Document360_and_commento.png)

After completing the **Commento integration** setup in your Document360 knowledge base, head back to your Commento account to see Commento Analytics, and you can also import comments from Disqus if you are using it.

### Method 2

1. On the Commento platform, open the **Staging** tab.
2. Click on **Installation Guide**.
3. In the HTML code displayed under the **Universal Snippet**, replace the URL with the domain of your project.
4. Copy this code.
5. Head back to your Document360 platform and navigate to Settings () > **Knowledge base site** > **Integrations**.
6. Under the **Custom HTML** section, click **Add**.
7. Paste the copied code.
8. From the **Insert code** options, select **At the end of body (below </body>)**.
9. Once done, click **Add**.

   Commento will be integrated with your Document360 Knowledge base.

To know more or explore Commento, please check [**Commento's help articles**](https://docs.commento.io/getting-started).

---

## FAQ

**What do I do when comments like ‘*This domain is not registered with Commento*’ appear on the Knowledge base site?**

To prevent comments from appearing on your Knowledge base site, navigate to Settings () > **Knowledge base site** > **Integrations** and turn off the **Commento** toggle.

The public-facing website where end-users can access articles and find answers to their questions.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="disqus"></a>

## Disqus

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Disqus** is a platform that enables reader commenting and admin moderation on Document360 articles. Integrating Disqus is useful when you want a multilingual-supported comment plugin that can automatically blend into the design of your Knowledge base site.

---

## Integrating Disqus with Document360

1. From the Knowledge base portal, navigate to **Settings** () > **Knowledge base site** > **Integrations**.
2. Click **Disqus** from the list of integrations and click **Add**.

   The **Add new integration** panel will appear.
3. Add a **Description** and enter your **Disqus URL**.

   > NOTE
   >
   > The **Disqus URL** is a unique code snippet obtained from the Disqus Account Interface. This URL is necessary for integrating Disqus and Document360 in the Knowledge Base portal.

   You can use the **Code inclusion/exclusion conditions** feature to insert the code based on certain conditions such as the IP address, Workspace, and Language.
4. Once done, click **Add**.

![1_Screenshot-Integrating_Document360_and_Disqus](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Integrating_Document360_and_Disqus.png)

---

### Generating Disqus URL

1. Sign in to your **Disqus account dashboard**.
2. Click **Install Disqus** and then click **Select Platform**.
3. Scroll down and click the **Install manually with Universal code** button.
4. In the **Universal code Install Instructions** window, scroll down and copy the URL from under  `s.src =` in the snippet.

![3_ScreenGIF-Getting_Disgus_URL](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Getting_Disgus_URL.gif)

You can view and reply to your customer chats after completing the Disqus integration with your Document360 knowledge base.

---

### FAQ

#### How does Disqus benefit a Knowledge base site?

Disqus is a platform that enables reader commenting and admin moderation on Document360 articles, providing a multilingual-supported comment plugin that blends into the site's design.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="all-extensions"></a>

## Document360 Extensions - Getting started

**Plans supporting Extensions**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 extensions enhance the functionality of your Knowledge base by seamlessly integrating it with third-party platforms, enabling a more connected and efficient workflow. These extensions allow you to access, manage, and share Knowledge base content directly from other platforms, reducing the need to switch between tools. By integrating Document360 with your existing tools, you can streamline operations and improve collaboration across teams.

## Accessing the Extensions page

1. Navigate to **Settings** () > **Knowledge base portal**> **Extensions** in the Knowledge base portal.

   You can find the list of already configured extensions at the top, if any.
2. Use the dropdown to filter the below list of Extension categories:

   * All extensions
   * Helpdesk
   * Team collaboration
   * Code repositories
   * Translation & browser
3. Click **Connect** on the intended Extension tile.

The extensions available are categorized in the following way:

**Helpdesk**

* [Freshdesk](/help/docs/freshdesk)
* [Zendesk](/help/docs/zendesk-1)
* [Intercom](/help/docs/intercom-integration)
* [Salesforce](https://docs.document360.com/docs/salesforce-integration)

**Team collaboration**

* [Slack](/help/docs/slack)
* [Microsoft Teams](/help/docs/microsoft-teams)
* [Drift](/help/docs/drift)
* [Zapier](https://docs.document360.com/docs/zapier-integration)
* [Make](/help/docs/make-1)

**Code repositories**

* [GitHub](https://portal.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/document/help/view/7678f7e8-9fd8-48a1-ba64-c0d7ed5ffb45)

**Translation and browser**

* [Chrome](/help/docs/chrome-extension)
* [Crowdin](/help/docs/crowdin)
* [Phrase](/help/docs/phrase)

<a id="freshdesk"></a>

## Freshdesk

**Plans supporting integration of Freshdesk extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Document360** knowledge base can be integrated with **Freshdesk** as an extension. With this integration, your support agents can seamlessly carry out customer engagement and ticket conversations using support articles from your knowledge base, without switching between tabs. Support agents can also create articles in the **Document360** knowledge base directly from the **Freshdesk** environment.

---

## Basic setup guide

To establish a connection between **Freshdesk** and the **Document360** knowledge base, follow the below steps:

1. Navigate to ****Settings**** () > ****Knowledge base portal**** > ****Extensions**** in the ****Knowledge base portal****.
2. Scroll down to the **Freshdesk** extension under the **Help desks** section.
3. Click **Connect** on the tile to generate an API token.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Freshdesk.png)

4. Copy the generated API token by clicking on the **Copy ()** icon.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Freshdesk_api_token.png)

5. If you wish to regenerate a token, click **Refresh token**.
6. Navigate to the **Freshdesk** website and log in to your helpdesk.
7. Navigate to **Admin** > **Support Operations** section and select Apps.
8. In the App Marketplace, search for the **Document360** app.
9. Input the copied API token and click **Install**.

You can add multiple API keys from different **Document360** knowledge bases. Click on the Add key button and, using a similar flow, copy and paste the API key in the field and click on Install.

---

### Multi-product support

If your company offers more than one product and maintains different **Document360**-powered knowledge bases for each product, managing multiple **Freshdesk** portals can be cumbersome.

To address this, **Freshdesk** offers **Multi-Product Support**, a feature that allows you to handle customer support activities for different products from a single Freshdesk portal. The agent interface remains the same for these products unless segregated by automation rules. Agents can view tickets from all products in their ticket view.

For seamless integration of multiple **Document360** knowledge bases with a single **Freshdesk** portal, refer to the [Multi-product setup guide](https://support.freshdesk.com/support/solutions/articles/37638-supporting-multiple-products-with-freshdesk).

---

## Feature highlights

### 1. Search for and share articles

* Once the API key has been validated by **Freshdesk**, your **Document360** knowledge base is now successfully integrated with the **Freshdesk** environment.
* **Document360** comes in handy when responding to your support tickets; you can search for and share articles with your customers from your integrated knowledge base with just a few clicks. You can do all this without having to leave the Helpdesk environment.

![image](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Freshdesk_search_bar.png)While responding to open tickets,

1. You can find the **Document360** icon along with the formatting options in the ticket response window.
2. Click on the icon, and you can access the knowledge base on a side window.
3. You would be able to select the workspace and the language of the knowledge base you want to access.
4. Now type in the search term in the search bar, and the relevant article list will be displayed below.
5. When you hover over the article with your mouse pointer, you can find two buttons, +link and +Content.

   * **+Link** inserts the hyperlink of the article inside the mail response
   * **+Content** inserts the entire content of the article inside the mail response

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Freshdesk_link_connect_buttons.png)

#### Automated article search

Apart from the regular search, to make things convenient, **Freshdesk** will automatically search the knowledge base using the ticket title and return matching articles under Recommended articles as soon as you click on the **Document360** icon.

### 2. Create articles for knowledge base from **Freshdesk**

Did you not find the support article you’re looking for (or) feel the need to add a new article to the knowledge base?  
You can now create articles for your knowledge base from the **Freshdesk** environment.

1. Click on the **Document360** icon in the ticket response window.
2. A side window with knowledge base access would be displayed.
3. Now select the workspace and language in which you would like to create an article.
4. Select the **+Create New Article** option at the top of the window.
5. Use the Markdown editor to create the article.
6. Add the title of the article and select the category for the article.

![image](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Freshdesk_create_new_article.png)

> NOTE
>
> You cannot create a new category from **Freshdesk**. You can only add articles to any existing categories.

7. Article body editor

   * Basic text formatting: Headings- H2 and H3, Bold, Italics, Ordered List, and Unordered List
   * Insert: Code block, Hyperlink, Image
   * Toggle between editor and display view

![image](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Freshdesk_new_article_editor.png)

8. Once you have added the content for the article, click **Create**.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="freshservice"></a>

## Freshservice

**Plans supporting the integration of** **Freshservice** **extensions with** **Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Enhance your IT service management with **Document360** knowledge base integration for **Freshservice**. This powerful combination allows your IT support team to effortlessly access and share knowledge base articles during ticket resolution, all without leaving the **Freshservice** interface.

Additionally, support agents can contribute to the knowledge base by creating new articles directly from **Freshservice**.

---

## Basic configuration steps

Follow these steps to set up the **Document360** integration with **Freshservice**:

1. Access your **Document360** account and navigate to **Settings** () > **Knowledge base portal** > **Extensions**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Freshservice_integration.png)

2. Locate **Freshservice** in the **Help desks** section.
3. Click **Connect** to generate an API token.
4. Copy the generated API token.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Freshservice_api_token_details.png)

5. To create a new token, use the Refresh token option.
6. Log in to your Freshservice account.
7. Navigate to **Admin** > **Automated & Productivity** > **Apps**.
8. In the Apps marketplace, search for **Document360**.
9. Paste the copied API token and click **Install**.

You can integrate multiple **Document360** knowledge bases by repeating this process with different API keys.

---

## Feature highlights

### Search and share articles

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Freshservice_search_bar.png)

Once integrated, **Document360**'s knowledge base becomes a powerful tool for resolving IT service requests:

1. When responding to a ticket, locate the **Document360** icon in the response toolbar.
2. Click the icon to open the knowledge base sidebar.
3. Choose the relevant workspace and language.
4. Use the search bar to find articles or browse the auto-suggested articles based on the ticket title.
5. Hover over an article to reveal two options:

   1. **+Link**: Adds the article URL to your response.
   2. **+Content**: Pastes the full article content into your response.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Freshservice_link_connect.png)

#### Automated article search

Apart from the regular search, to make things convenient, **Freshservice** will automatically search the knowledge base using the ticket title and return matching articles under Recommended articles as soon as you click on the **Document360** icon.

### Create articles for knowledge base from **Freshservice**

You can add articles to your knowledge base directly from **Freshservice**:

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Freshservice_create_article.png)

1. Click the **Document360** icon in the ticket response area.
2. In the sidebar, select **+Create article**.
3. Choose the appropriate workspace and language.
4. Provide a title and select a category for the new article.
5. Use the built-in editor to craft your article:

   * Basic formatting options: H2, H3, Bold, Italic, Numbered List, Bullet List.
   * Insert features: Code blocks, Hyperlinks, Images.
   * Toggle between edit and preview modes.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Freshservice_text_editor.png)

6. After completing the article, click the **Publish** button to add it to your knowledge base.

> NOTE
>
> New categories cannot be created from **Freshservice**. Articles can only be added to existing categories.

<a id="zendesk"></a>

## Zendesk

**Plans supporting integration of Zendesk extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Zendesk** is a customer support software that allows businesses to effectively manage customer questions, complaints, or any other support requests.

With the Document360 knowledge base integrated into your Zendesk platform, your support agents can provide on-point responses to customer queries by searching for and sharing support articles without toggling between different tabs on their browsers.

Without leaving the Zendesk environment, agents can create articles on the Document360 knowledge base efficiently.

## Basic setup guide

### Installing Document360 on Zendesk

Before you can make use of Document360, the app needs to be installed separately on your Zendesk support console. Visit Zendesk and log in to your account.

1. Go to the [**Zendesk Marketplace**](https://www.zendesk.com/marketplace/) and click on **Apps.**
2. In the newly opened Marketplace tab, enter Document360 in the **Filter apps** field.
3. Click on the app.
4. Click on the **How to install** tab to view the instructions and complete any pre-install tasks.
5. Click **Install** at the top right.
6. If you have multiple accounts, select the intended account and click **Install**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zendesk.gif)
7. To complete the installation, you will have to enter the title, token, and restriction details in the respective fields.
8. Once done, click **Install**.

### Configuring Document360 with Zendesk

To obtain an API token from Document360, follow the steps below.

1. On the Document360 portal, navigate to Settings () > **Knowledge base portal** > **Extensions**.
2. In the **Helpdesk** section, click **Zendesk**.
3. Click **Setup**.
4. In the Generate API token option, click **Generate**.

   A **Generate extension token** popup will appear.
5. Click **Yes**.

   A **Connect with Zendesk** popup will appear where you will have your token displayed.
6. Click on the Copy () iconto copy the token.
7. Click **Close**.
8. Go to the Zendesk platform and fill in the **Title** field.
9. In the **Token** field, paste the copied API token from Document360.
10. Add your preferred restriction settings. By default, this option is turned off.
11. Click **Install**.

    ![To generate token and install Document360 on Zendesk](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGif-Zendesk.gif)

---

## Zendesk federated search

Follow these steps to configure Zendesk Federated Search in Document360:

### **1. Access Zendesk setup in Document360**

1. Navigate to **Settings** ()> **Knowledge base portal** > **Extensions** in the Document360 portal.
2. In the **Helpdesk** section, click **Zendesk**.
3. Click **Setup** to open the **Zendesk configuration panel**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Integrating_the_zendesk_extension.png)
4. In the Zendesk configuration panel, click **Configure** under **Zendesk federated search**.

   The **Setup Zendesk federated search** panel will appear.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Configuring_Zendesk_Federated_search.png)
5. Provide the following details:

   * **Subdomain**:  
     Copy the subdomain from your Zendesk URL.  
     Example: For the URL `https://kovaico3776.zendesk.com/admin/apps-integrations/apis/zendesk-api/settings/tokens/`, the subdomain is `https://kovaico3776.zendesk.com`.
   * **Email ID**:

     1. Go to the **Zendesk overview page**, click **Settings** (), and select **Go to Admin center**.
     2. In the left navigation bar, go to **Channels** and click **Email** to view email configurations.
     3. In the **Support addresses** section, locate your Zendesk account’s admin email address.
   * **Zendesk API Token**:

     1. From the **Zendesk overview page**, click **Settings** (), and select **Go to Admin center**.
     2. In the left navigation bar, go to **Apps and integrations** > **Zendesk API**.
     3. Click **Add API token** and copy the generated token.
6. Click **Validate** to confirm the details you entered.
7. In the **Sync with Zendesk** dropdown, select the desired **workspace** and **language** in your Document360 project to sync with Zendesk.
8. Once the configuration is complete, click **Save**.

   You can now search and access your Document360 articles as external sources within the Zendesk platform.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Setting_up_the_Zendesk_federated_search.png)

---

## Search and share articles on ticket responses

While responding to support tickets, you can use the installed Document360 app to respond to customers. You can directly access the Knowledge base in the Zendesk environment.

![4_Screenshot-Search_and_Share_article.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1731052747809.png)

The installed app is available on the right side of the open ticket response window.

1. Click on the **Document360** app.
2. As the Document360 frame loads, Zendesk will automatically search for articles based on the title of the support ticket.
3. You can always type in the search term in the field, and the relevant articles will be listed below.
4. Click on **Link article** of the article you wish to attach.
5. You can also preview the article by clicking on **Preview**.
6. In the preview mode, there will be three options,

   * **Open Document360** - The article opens in a new tab.
   * **Link article** - Insert the article link in your response message.
   * **Insert content** - Add the entire article's content to your response message.
7. This makes it easier and more instantaneous for agents to respond to customers as they don't have to navigate between the Document360 and Zendesk tabs.

   Once you link an article to a response, the **Linked** label isn't in the article list. This helps you identify the article that is already linked to the conversation.

---

## Create an article on the Knowledge base from Zendesk

On the Zendesk platform, you can create articles in your Knowledge base, without the need for additional team accounts.

![5_Screenshot-Creating_Articles_From_Zendesk.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Creating_Articles_From_Zendesk.png)

1. Click **Create an article** in the Document360 app frame or click on the plus (**+**) icon.
2. Add the **Title** of the article and select the **category or subcategory** in which you want to place the new article.

> NOTE
>
> You can create root-level categories and subcategories on your knowledge base from Zendesk.

3. You can author the content of your article in the Markdown editor.
4. In the **Article body editor**, basic text formatting such as headings (H2 and H3), Bold, Italics, Ordered list, and Unordered list, and **Insert** options such as code block, Hyperlink, and Image are available.
5. Once done, click **Create**.

   The article is created in a **draft** state, allowing your editors to review and enhance it before publishing it on the Knowledge base.

### Document360 quick launch in the reply window

* In the chat controls at the bottom, you can find the Document360 icon as the **D** logo.
* Click on it, and the module opens

![6_Screenshot-quick_Launch.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1731058817733.png)

1. Select the Document360 workspace and language you want to refer to.
2. The relevant articles appear when you use the search.
3. From this window, you can either:  
    **Link article** - to share the article's Document360 URL  
    (or)  
    **Insert article** - to insert the article's content in the response
4. Click on the plus (**+**) icon to create articles for your Document360 Knowledge base from Zendesk.

---

## Removing Document360 from Zendesk

To uninstall a configured Document360 application from Zendesk, follow the steps below:

1. On the Zendesk platform, from the left navigation pane, navigate to **Apps and integrations** > **Apps** > **Zendesk Support apps**.

   The **My Apps** page will appear.
2. You can find the list of apps currently installed.
3. Hover over the Document360 app.
4. Click on the settings () icon and then click **Uninstall**.
5. In the **Uninstall App** prompt window, click **Uninstall App.**

---

## FAQ

**Can I push multiple articles from Zendesk to Document360 simultaneously?**

You can transfer articles from Zendesk to Document360 but the process involves pushing articles one at a time, individually.

<a id="intercom-integration"></a>

## Intercom

**Plans supporting integration of Intercom extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Intercom is a conversational and messenger-based business solution provider. It is a SaaS product that enables effective customer communication using chatbots, live messaging, etc.

You can use Intercom with Document360 to provide real-time support for your website users by searching and sharing articles (link or article content) from your Document360 Knowledge base within the Intercom chat box.

**Prerequisites:** To enable the Intercom messenger integration in Document360, you will need an Intercom account and the Intercom workspace ID associated with that account.

---

## Basic setup guide

To integrate Intercom with your Knowledge base portal, follow the below steps:

1. Navigate to **Settings** () > **Knowledge base portal**> **Extensions** in the Knowledge base portal.

   You can find the **Intercom** under the Helpdesk section.
2. Click **Connect** on the tile to generate an API token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Intercom.png)
3. You are redirected to the **Intercom** page.   
    If you are not logged in, then the **Intercom sign-in** page will appear.
4. On the authorization page, click **Authorize access**.

![image](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/14_Screenshot-Extension_Intercom_Installing_the_app_Authorization_popup.png)

6. You will be redirected to the **Extensions** page on Document360.
7. Click the Edit () icon in the Intercom tile.
8. Choose the workspace and language from the dropdown.

   The selected workspace and language will be added to the Document360 app on Intercom.

If you wish to remove the Intercom integration from your Document360 portal, follow these steps:

1. On the Intercom page, click **Settings ()** from the left navigation sidebar.
2. Click open the **Integrations** dropdown and select **App Store**.
3. Under the **Manage** section, click **Your installed apps**.

   You can find the Document360 app.
4. Click on the Document360 app tile and scroll down to find the **Uninstall** button.
5. Click **Uninstall** and the Intercom integration will be removed and no longer available in your Document360 portal.

---

## Search for and share articles in chat response

When a customer or website user tries to initiate the chat support conversation by clicking on the **Intercom** messenger () icon on your web page, you will get a notification on the Intercom workspace. Your support agent or you can respond to the conversations from the Intercom workspace.

You can also search and share an article with the user on the Intercom platform. Follow the below steps in that instance:

1. Click the Document360 icon, and a small search window appears.
2. Type the keyword or question in the search bar and press Enter.
3. The top three relevant articles from your knowledge base are listed.

![image](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1732005752060.png)

4. If there are more relevant articles, click on the **see more** option.
5. Click on the intended article, and it will be inserted in your chat window as an assistant or a sharded article.

   This action enables you to quickly share the article with the customer within the ongoing chat conversation.
6. Click either the **Send** or **Send and Close** button.

   The customer receives the article assistant or the shared article in the chat.
7. The article will open in a separate tab when the customer clicks on the assistant.

   With this, you can respond by either sharing an article from the Knowledge base or sending an Article search app assistant, allowing customers to search for articles themselves.

> NOTE
>
> When an article link is clicked in the Intercom chat, it opens within the chat box.

## Article search app assistant

![image](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1732006699477.png)

Apart from searching and sharing an article with the users, you or your agent might also need to add an article from the Intercom workspace to your knowledge base.

Follow the steps below to create an Intercom article that reflects on your Document360 portal.

1. Click on the Document360 icon available in the chat response options in line with the **Send** button.
2. A small Document360 app assistant opens, where you can find the **Create an article** option with the following fields,

* Article title - give a suitable title for the article
* Article body - give a suitable body content for the article
* Category - choose a suitable category from the dropdown

3. Fill in the required fields.
4. Click **Create article**.

![image](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/001_Screenshotnew_Intercom_Extension.png)

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="salesforce"></a>

## Salesforce

**Plans supporting integration of Salesforce extension with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
| **✗** | **✗** | Add-on |

Document360 integration within the Salesforce console enhances and equips your support agents with a robust knowledge base while serving customers. With the Document360 app integrated into the Salesforce console, users and support agents within your organization can search for and view articles from your knowledge base directly within the console. They can also create new articles for your knowledge base on the go, directly from the Salesforce environment.

---

## Searching and managing Knowledge base content in Salesforce

### Knowledge base

* In the **Knowledge Base** tab, you can search for and view articles and categories within your knowledge base.
* Utilize the dropdown menus located at the top right of the section to select your knowledge base's workspace and language preferences.
* Options such as **Copy link** and **Open article** are provided for each article and category, excluding folder categories.

### Searching for articles and categories

You have the ability to search for articles and categories using various parameters such as name, content, tag, and slug within the Search field.

* Enter your search term, and relevant results for articles and categories will be displayed.
* Click the desired article or category to access and review the information. Upon clicking, the selected article or category will be presented in the reader's view.
* You can use the **Filter** field to refine your search specifically by the name of articles and categories.

### Reader view

To access and read articles or look up information, simply click on any search result or navigate to the article/category using the category manager. Upon clicking, the selected article/category will be displayed in the reader's view. This functionality applies to all articles and categories, excluding folder categories.

You have the option to copy the entire article or specific excerpts for use in your responses or communications.

* **Copy link**: Click the Copy icon located at the top right of the section to copy the link to the article/category page. This link can be pasted into your responses or any input within the Salesforce environment.
* **Open site**: To view the article/category on your Knowledge Base site, click the Open Article icon adjacent to the Copy icon. This action will open the Knowledge Base site view of the article/category in a new tab.

![6-ScreenGIF-Search_and_share_article_feature_in_Salesforce-min](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6-ScreenGIF-Search_and_share_article_feature_in_Salesforce-min.gif)

---

## Basic setup guide

You need a Salesforce account to perform the below steps to set up a connection between Salesforce and Document360. If you are a registered Salesforce user (Salesforce Lightning platform account), skip this step and go directly to the Installation step.

### Create a Salesforce account

1. To sign up for Salesforce, go to the [**Sign up page**](https://www.salesforce.com/in/form/signup/freetrial-sales/).
2. Enter the details required and click **Start my free trial**.
3. Visit the Salesforce pricing page to choose and purchase plans that suit your needs.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-Salesforce.png)
4. You will receive an email with the verification link, account URL, and username on your registered email. Click the **Verify Account** link in the mail.
5. Enter the verification code you received in your mail inbox and click the **Verify** button.

> NOTE
>
> The verification code will be sent via another mail.

You will be redirected to the Salesforce Home page.

### Install the Document360 app on Salesforce

Use the below link to install the Document360 app.

1. Go to [AppExchange page](https://appexchange.salesforce.com/listingDetail?listingId=a0N4V00000GYmjZUAT&tab=e).
2. Click **Get It Now**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Salesforce.png)
3. Log in with your Trailblazer account.
4. Select the desired Salesforce project space:

   * **Install in Production** - To install the Document360 application in the production environment of your Salesforce project.
   * **Install in Sandbox** - To install the Document360 application in the sandbox environment of your Salesforce project.
5. Review the installation details and click **Confirm and Install**.
6. Enter your Salesforce credentials and click **Log In**.
7. Select from any one of the three options provided:

   * **Install for admins only** - To provide Document360 application access for only admins.
   * **Install for all users** - To provide Document360 application access for all users.
   * **Install for specific profiles** - To provide Document360 application access to specific user profiles.

> NOTE
>
> This action will determine the Document360 availability for the users within the Salesforce application.

7. Click the **Install** button.
8. Wait for the Installation complete prompt and click **Done**.

### Add a Visualforce page in the Salesforce developer console

Now, you must add the code provided below in your Salesforce developer console to create a Visualforce page.

1. Search for **Visualforce pages** in the **Quick find** field at the top left and select the **Visualforce pages** option in the search results.
2. Click the **New** button.
3. Type the Label, Name, and Description of the page.
4. Select the **Available for Lightning Experience, Experience Builder sites, and the mobile app** checkbox to enable it.
5. Paste the below code into the **Visualforce Markup** section.

```
<apex:page standardController="Case"> <apex:canvasApp applicationName="Document360" namespacePrefix="Document360" height="800" width="750px"/> </apex:page>
```

Markup

Copy

The height and the width of the application can be edited in pixels. For example, Height = “800px“ width = “750px“.

6. Click the **Save** button at the top.

![4-ScreenGIF-Adding_visualforce_page_in_developer_console-min1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4-ScreenGIF-Adding_visualforce_page_in_developer_console-min%281%29.gif)

---

## Authorize Salesforce integration from your Document360 portal

Login to your Document360 portal to authorize the Salesforce integration.

1. Navigate to the Document360 portal.
2. Go to Settings () > **Knowledge base portal** > **Extensions** > **Salesforce** under the Helpdesk section.

> NOTE
>
> Salesforce is an addon purchase in your Document360 project. Click **Buy now** to purchase.

3. Click **Connect**.
4. Select the authorization type:

   * **Live** - To perform authorization for your production project in Salesforce.
   * **Sandbox** - To perform authorization for your sandbox project in Salesforce.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenShot-Salesforce.png)
5. In the **Allow access** window, click **Allow** and wait for a few seconds.
6. Now, you can find the status as ‘*Project connected to Salesforce…*’ in the Salesforce assistant. You can also find the Salesforce account URL associated with your project.
7. Once configured, click **Detail** button on the Salesforce tile to view the configuration information.
8. Click the Delete () icon if you want to remove the configuration.

---

## FAQs

**What is the technical architecture of the Document360 and Salesforce integration?**

The Document360 and Salesforce integration involves utilizing APIs provided by both platforms to enable seamless data transfer and synchronization.

**Which APIs are used for integration, and how are they authenticated?**

Both Document360 and Salesforce offer REST (Representational State Transfer) APIs. Authentication is typically managed through API keys, OAuth tokens, or other secure methods to ensure data confidentiality and integrity.

**Can custom fields in Document360 be integrated with custom objects in Salesforce?**

Yes, custom fields in Document360 can be mapped to custom objects in Salesforce, allowing for a more tailored integration based on specific organizational requirements.

**How is document versioning handled during synchronization?**

Document versioning may involve tracking changes in Document360 and updating corresponding records in Salesforce. The integration should handle versioning in a way that maintains data accuracy and consistency.

**What security measures are in place to protect data during the integration process?**

Security measures may include data encryption during transit, secure API authentication, role-based access controls, and compliance with industry-specific standards to safeguard sensitive information.

**What steps are involved in upgrading the integration when new versions are released?**

Upgrading the integration involves reviewing documentation for any changes in APIs or features, testing in a staging environment, and ensuring compatibility before deploying the update to the production environment.

**Is it possible to have Salesforce as IdP with either SAML/OpenID SSO(Single Sign On)?**

Yes, it is possible to use Salesforce as an IdP with either SAML/OpenID.

<a id="cases-page"></a>

## Cases page

**Plans supporting integration of Salesforce extension with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
| **✗** | **✗** | Add-on |

In Salesforce, a Case refers to a customer query, feedback, or concern. Support agents use cases as reference points to enhance service delivery. Customers may reach out through various channels such as phone, email, web, or social media platforms.

Integrating Document360 with the Cases home page on Salesforce streamlines access to knowledge base articles directly within the Salesforce console. This integration facilitates quicker resolution of customer issues by providing agents with relevant information at their fingertips.

---

## Integrating Document360 and Cases home page

To set up a connection between Document360 and Cases in Salesforce, follow the below steps:

1. From the Salesforce home page, navigate to **Service**, then select **Cases**.
2. The recently added cases are displayed on the Cases home page. If you don't have any active cases, you can create a new one.
3. To add a new case, click **New** at the top right.

   In the pop-up window, you can provide details about your new case, such as its nature, customer information, case origin, priority, and more.
4. Click **Save**.

   Once the desired case is selected, its overview page will appear.
5. Click the Quick settings icon at the top right and select **Edit Page**.
6. In the Quick Find search bar, type **Lightning App Builder** to access the Lightning App Builder page, where you can customize your cases page with drag-and-drop components.
7. Search for **Visualforce** in the Lightning App Builder and drag the Visualforce component onto the design page. Adjust the component's height in pixels as required in the right section.

> NOTE
>
> Make sure to utilize the exact or larger height pixel size specified during the creation of the Document360 Visualforce page. For more information, refer to the article on [Salesforce](https://docs.document360.com/docs/salesforce).

8. The Document360 app is added to the page. You can add, delete, or reposition the different components on the page.
9. Once done, click **Save**.
10. An activate component prompt appears. Click the **Activate** button.
11. Now navigate back to the **Cases** page, and the knowledge base section is added.

![5-ScreenGIF-Adding_visualforce_component_in_Cases_page-min1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5-ScreenGIF-Adding_visualforce_component_in_Cases_page-min%281%29.gif)

### Create Knowledge base articles in Salesforce

After integration, without leaving the Salesforce environment, you can directly create an article for your knowledge base.

1. Click the **Create article** tab.
2. Enter the title of the article.
3. Select the desired category where you want the new article to be placed.
4. Provide the article content in the Content section. You can utilize markdown syntax in this section.
5. Once you've finished, click the **Create article** button at the bottom.

> NOTE
>
> The newly created article will be in **draft state**. An admin, owner, or editor can then access the Document360 portal to review and publish the new article.

---

## Recommendations

* Document360 automatically retrieves articles relevant to your case and presents them in this tab. These articles are sourced based on keywords found in the **Subject** field of the case.
* By default, articles from the main workspace and default language are showcased as recommendations. However, you have the flexibility to adjust the workspace and language preferences using the dropdown menu located at the top widget.
* This section displays up to five articles. Each article is accompanied by its title, a brief content excerpt, options to copy the content, and the ability to open the article in a new tab.

![8_Screenshot-Recommended_tab_for_Salesforce_cases_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1731245955408.png)

<a id="slack"></a>

## Slack

**Plans supporting integration of Slack extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

is a cloud-based team communication platform that helps different teams in an organization work together seamlessly. Integrating Document360 with Slack enables your agents to access your knowledge base directly within their workspace.

Apart from searching for articles, you can create user-friendly documentation and author in the Markdown editor for any version or language in your knowledge base on Slack.

---

## Basic setup guide

To set up a connection you must have a Slack account.

### Connecting the Document360 extension in Slack

1. Navigate to Settings () > **Knowledge base portal** > **Extensions** in the Knowledge base portal. Go to the desired Document360 project.
2. You can find Slack in the listed extensions.
3. In the Slack assistant, click **Connect**.
4. The app will redirect you to Slack to grant access to your workspace.
5. Click **Allow** and return to Document360.
6. The success message would also display the name of the connected Slack workspace.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Slack.gif)

---

## Commands and uses

Once the integration between Document360 and your Slack workspace is established, you can use the different functions of Document360 with the **/doc360** in your conversations, either in 'direct message' conversations or in a channel.

### **Commands**

|  |  |
| --- | --- |
| **Help** | **/doc360**<space>**help** |
| **Search article** | **/doc360**<space>**search**<space>**query** |
| **Create Article** | **/doc360**<space>**create**<space>**Title of the article** (optional) |

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1731301155878.png)

### Search and share articles

#### **Command:** `/doc360 search query`

Once Document360 is connected to your Slack workspace, your team can easily search for and share support articles within Slack using specific commands. This makes it faster to share knowledge and add context to conversations without needing to ask others for information or switch between tabs.

You can access all Knowledge base articles directly in Slack and share any article you find by linking it directly in your chat.

To search for an article during a conversation,

1. Enter the search command`/doc360 search query` and hit Enter.
2. Select the **version** and **language** of the knowledge base you want to search.

   The search results will be populated with two options:

* **Open Article** - to open the article in a new tab
* **Link Article** - to send the article result in the conversation

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Search_and_share_articles.gif)

### Creating an article from Slack

To create an article for your Knowledge base, enter the `/doc360 create` command followed by an optional title to open the article creation model.

#### Command: `/doc360 create Title_of_the_article`

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenVideo-Article_Creation_from_Slack.gif)

1. Choose the version of the Knowledge base you want to use to create the Article.
2. Select the category under which the Article should be placed.

> NOTE
>
> You cannot create a new category on Slack. However, you can add articles to any existing category.

3. Enter the content of your Article using the Markdown editor.

   The Article would be created in a draft state, allowing your editors to review and enhance it before publishing it on the Knowledge base.

---

## Removing the Document360 app from the Slack workspace

1. From your Slack workspace, visit Slack's App Directory.
2. Select **Manage** at the top right.
3. Choose **Document360** from the list in the left-hand column.

   You will be redirected to the **Document360 App Info page**.
4. In the **configuration section**, scroll down to the **Remove application** and click **Remove App**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenVideo-Removing_Doc360_Slack(1).gif)

If you face any issues, please get in touch with us at [support@document360.com](mailto:support@document360.com).

<a id="microsoft-teams"></a>

## Microsoft Teams

**Plans supporting integration of MS Teams extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Microsoft Teams is a widely used messaging and business collaboration application that helps a company's workforce stay organized and engage in conversations on a single platform.

## Teams and **Document360**

Once you configure the API and connect **Teams** and **Document360**, you can experience the cross-platform functionality in your Teams application.

After integrating, you can search for and share articles from your knowledge base in Teams, chats, and channels without leaving Microsoft Teams.

---

## Basic setup guide

### 1. Add the **Document360** app to Teams

1. On the Microsoft Teams window, click on **Apps** from the left navigation bar.
2. In the search bar, type in Document360.
3. Click on the app assistant and click **Add**.

![1_ScreenVideo-Adding_Dco360_in_MicrosoftTeams](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenVideo-Adding_Dco360_in_MicrosoftTeams.gif)

4. Now, you can find the Document360 logo in the bottom chat controls and at the search bar at the top when you type `/Document360` and press **Enter**.
5. If you already have a live knowledge base powered by Document360, you can easily connect it using an API key.

### 2. API key generation on **Document360**

1. From the **Knowledge base portal**, go to **Settings**() >**Knowledge base portal**>**Extensions**>**Team collaboration**.
2. You'll find the **Microsoft Teams** assistant.
3. Click **Connect**, and the **Microsoft Teams details** blade appears with a generated API key.
4. Copy the generated API token, which would be required while connecting your knowledge base with your **Teams** app.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Microsoft_Teams.png)

### 3. **Document360** API Configuration

Your knowledge base would be connected and accessible only after configuring the API between Teams and **Document360**.

You can access the **Add API Key** field in the Teams application by,

1. In **Microsoft Teams**, go to any chat and click **+** in the text field.
2. Click **Document360** from the listed Apps and then click **Add API key**.
3. Paste the generated API key in the Teams API key window. You will get a success message indicating the integration status.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1731247419615.png)
4. To uninstall or remove the integration right-click on the Document360 app and click **Uninstall**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenShot-Microsoft_Teams.png)

---

## Searching and Sharing Articles

After successful integration, you can search for and share articles from your **Document360** knowledge base without leaving the Microsoft Teams platform with individual contacts and channels.

When you want to search for a particular article from the integrated knowledge base,

1. Click the **Document360** logo from the chat controls.
2. Enter the keyword in the search bar.
3. Select all the relevant articles from the search results.

![4_Screenshot-Article_search_and_send](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1731246868630.png)

(or)

1. Enter `/Document360search` in the new message field at the bottom and hit Enter.
2. Another sub-field would appear with the search bar.
3. Enter your search query, and the results are populated.
4. Click on the result, and it will be added to the conversation.

You can edit your response with a custom message before sending it.

---

## FAQs

**Does Microsoft Teams have a Knowledge base feature?**

There is no built-in Knowledge base feature available on Microsoft Teams. However, you can integrate Knowledge base and documentation platforms like Document360 to work seamlessly with Teams.

**Can I share content from my Knowledge base on Teams?**

You can share article content, excerpts, links, media, and files from your Document360 Knowledge base in your Teams chats, replies, and posts.

**Is it possible to add the Microsoft Teams extension for non-readers?**

Yes, you can add a Microsoft Teams extension for non-readers by using the generated API token in the team collaboration settings of the extension.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="drift"></a>

## Drift

**Plans supporting integration of Drift extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Drift is a conversational messenger platform you can add to your website, Knowledge base, or online business. Integrating your Document360-powered Knowledge base with the Drift chat application gives you an additional edge when providing support or answering your customers' queries.

You can share relevant articles and information from your Knowledge base without leaving the Drift conversation page. During real-time conversations, this would make so much sense and cut back on the response time, as the service provider (your support agent) doesn't have to navigate to a separate window or browser tab to search the articles from your knowledge base and then share the link.

---

## Basic setup guide

To enable this extension, you should have a registered Drift account. If you don't have one, you can create one by following the signup instructions on the application website, <https://app.drift.com>.

In Document360, there are three steps to establish a connection between Document360 and Drift:

1. Acquire custom JavaScript from the Drift portal
2. Setting up Drift Chat on Document360
3. Configuring your Document360 knowledge base on Drift Composer

> NOTE
>
> * If you're an existing user of Drift or have it added to any of your company's websites or Document360 home page, you can skip the 1st and 2nd sections of the Basic Setup Guide.

### 1. Acquire custom JavaScript from the Drift portal

#### a. If you are a new customer to Drift:

You will get the code assistant during the initial account setup, and after signup,  log in to your Drift account on the [Drift app website](https://app.drift.com/home/dashboard).

1. Log in to your Drift **Dashboard**.
2. Navigate to Settings ()> **App Settings.**
3. From the tree-view menu on the left, click **App settings** and select the **Install** option.
4. Select **JavaScript**, and a code window will appear.
5. Click **Copy** to copy the script to your clipboard.

#### b. If you are an existing customer of Drift:

You can follow Step 2, outlined for the new customer

![1_ScreenVideo-Drift_Code_Copy.gif](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Draft_widget_javascript.png)

The copied JavaScript would come in handy on the Document360 portal.

### 2. Setting up Drift Chat on Document360

To set up the drift chat window on your Document360 page,

1. Go to your project in the Document360 portal.
2. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
3. From the left navigation pane, click on the **JavaScript** tab.
4. Paste the copied script and click **Save**.

![2_ScreenVideo-copy_paste_code.gif](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_GIF-Drift_extension_javascript_code.gif)

Now, the Drift chat icon appears on your Document360. Your customers can use this assistant chat window to interact with you. You can share and manage articles from your knowledge base without leaving the drift chat response.

### 3. Configuring your Document360 knowledge base on Drift Composer

> NOTE
>
> Only when document360 is authorized and configured can you search for and share articles from your knowledge base with your end users.

1. Navigate to Settings () > **Knowledge base portal** > **Extensions** > **Team collaborations**.
2. Navigate to Drift and click **Connect**.
3. The page would be redirected to an authorized page on Drift.
4. Click the **Authorize App**.

![3_ScreenVideo-Drift_Setup.gif](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_GIF-Drift_extension_authorization.gif)

After successful integration, you can access the connected knowledge base on Drift conversations using slash commands (**/doc360**).

Once the Knowledge base has been integrated and authorized, you can search for articles from your knowledge base using keywords.

1. In the admin chat response window, type **/doc360**, then a space followed by the search term.
2. Hit enter, and a relevant article search list will appear.
3. Now you have three buttons below each of the listed articles:

* **Share**: Sends the article link along with the meta text provided to your end-user chat.
* **Edit**: This allows you to edit the text or link and then press 'Enter.'
* **Cancel**: This aborts the article search.

<a id="zapier-setup-guide"></a>

## Zapier - Setup guide

**Plans supporting integration of Zapier extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Zapier is an online automation tool that helps to connect Document360 with other third-party tools and applications. Zapier acts as a buffer by creating automated workflows called Zaps, which work based on actions and triggers.

### Prerequisites

1. You must have an active Zapier account to begin with or [**sign up**](https://zapier.com/sign-up) for one.
2. An account in the third-party application you wish to connect with Document360 using Zapier (for example, Google Docs, Typeform, and more.)

Check out [Zapier's getting started guide](https://zapier.com/resources/guides/quick-start) to learn how to connect to Document360 with other apps on Zapier, build workflows, and automate repetitive tasks

## API key generation in Document360

1. Navigate to the desired Document360 project.
2. Navigate to Settings ()> **Knowledge base portal** > **Extensions** > **Team collaboration**.
3. On the Zapier extension tile, click **Connect**.
4. A **Zapier details** popup appears with a generated **Token**.
5. Click the Copy () icon.

This API key will be used to connect the Document360 knowledge base with third-party applications on Zapier.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Zapier_setup_guide.png)

---

## Zapier use cases for Document360

Below are some useful Zapier integrations that can enhance your experience with Document360 by connecting it to popular tools:

* [Google Docs + Document360](/help/docs/google-docs-document360-integration)
* [Google Sheets + Document360](/help/docs/document360-with-google-sheets-integration)
* [Google Drive + Document360](/help/docs/google-drive-document360)
* [Trello + Document360](/help/docs/document360-with-trello-integration)
* [GitHub + Document360](/help/docs/github-document360)
* [Confluence Server + Document360](/help/docs/confluence-document360)
* [Zoho CRM + Document360](/help/docs/zoho-crm-document360)
* [Pipedrive + Document360](/help/docs/pipedrive-document360)
* [Hubspot + Document360](/help/docs/hubspot-document360)
* [Asana + Document360](/help/docs/asana-and-document360-integration)
* [monday.com + Document360](/help/docs/mondaycom-document360)
* [Typeform + Document360](/help/docs/typeform-document360)
* [Document360 + Gmail](/help/docs/document360-gmail)
* [Document360 + Mailchimp](/help/docs/document360-mailchimp)

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="google-docs-document360-integration"></a>

## Integrating Google Docs with Document360

**Plans supporting integration of Zapier extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Many organizations around the world use Google Docs as a document management tool. Google, as a platform, offers a more integrated environment where managing multiple forms of documents and files is rather easy.

---

## Integrating Google Docs with Document360

Using Document360 as your knowledge base platform, you can collaborate with multiple external vendors who contribute content through Google Docs. While Google Docs is a great platform for collaboration, manually transferring these articles to Document360 can be time-consuming and effort-intensive.

By connecting Google Docs and Document360 on Zapier, you can easily facilitate the content flow between these platforms. To establish a connection between Google Docs and Document360, follow the below steps:

1. Ensure that you have logged into your [Zapier account](https://zapier.com/app/dashboard).
2. From the left navigation menu, click **Create** and then click **Zaps** from the optionsavailable.
3. Zap will be created with **Trigger** and **Action** flow.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zapier_Google_Docs.gif)

### Connecting Google Docs and Document360 in Zapier

![2_Screenshot-Connecting_Google_Docs_and_Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Connecting_Google_Docs_and_Document360.png)

### Step 1: Connecting Google Docs

1. In the **Trigger** field, choose **Google Docs**.
2. In the **Trigger event** field, select the required Event to trigger in the Google Docs.

   If you wish to configure a different app later, you can do that by clicking on **Change**.
3. Click the **Account** field, and a **Sign-in** window will appear.
4. Enter your sign-in credentials and click **Allow**.

![3_Screenshot_Google_Doc_Sign_in_credentials](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot_Google_Doc_Sign_in_credentials.png)

5. Click **Continue.**

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-Zaps.png)
6. Find the list of folders retrieved from your connected Google Drive account.
7. Choose the desired folder and click **Continue**.
8. Zapier runs a test to make sure the trigger is correctly configured.
9. Create a Google Doc inside the selected folder and test the trigger.

### Step 2: Connecting Document360

1. In the **Action** field, choose **Document360**.
2. On the Setup blade that appears on the right, select a desired event in the **Event** field.
3. Click the **Account** field and a **Sign-in** window appears.
4. Enter your sign-in credentials and click **Allow**.

   To generate the API token from the Document360 portal,
5. Navigate to Settings () > **Knowledge base portal** > **Extensions** > **Team collaboration**.
6. On the Zapier extension tile, click **Connect**.
7. Click the Copy () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Zapier_Google_docs.gif)
8. Head back to the Zapier window and paste the API token in the field.
9. Click **Yes, Continue to Document360**.

![6_Screenshot_Zapier_API_Token_Pasting](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot_Zapier_API_Token_Pasting.png)

8. You can find the connected Document360 project on the **Connect Document360 account** page.

   If you wish to configure a different account later, you can do that by clicking on Change.
9. Click **Continue**.

### Step 3: Customize Zap

1. Map the fields from Google Docs into Document360. Map all the required fields:

![5_Screenshot-Map_the_fields_from_the_Google_Docs_into_Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Map_the_fields_from_the_Google_Docs_into_Document360.png)

* **Title**: By default, the title in Google Docs is selected here. However, you will have various options available depending on your business requirements.
* **Content**: By default, content in Google Docs is selected here. However, you will have various options available depending on your business requirements.
* **Version**: Choose the desired workspace in the knowledge base project where you wish to create the article.
* **Language**: Choose the desired language in the selected workspace in which you wish to create the article.
* **Category**: Choose the desired category in the selected language in which you want the article to be created.
* **Publish**: Choose True for the article to be published. Choose False for the article to be in draft state.

2. Once done, click **Continue**.

> NOTE
>
> Only after you map all the required fields, the **Continue** button will be enabled.

### Test Zap

1. In the test section, click **Test step**.
2. If it is successful, you will get the message ‘*An Article was sent to Document360*’.

   In your Document360 Knowledge base portal, you'll find the article titled after the Google Docs file name, located in the folder you previously selected.
3. Head back to the Zapier setup window.

### Turn on Zap

1. After testing the Zap, review or edit the settings before turning on the Zap.
2. You can edit the settings configured on the **Google Docs** trigger and the corresponding action of the new article in **Document360**.
3. You would get a success message stating **Your Zap is on**. You can click on the **Manage your Zap** button to go to your Google Docs+Document360 Zap overview page.

![7_Screnshot_Zap_connection_Successful](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screnshot_Zap_connection_Successful.png)

---

## Zap overview

#### Create articles in Document360 from a new Google Docs file

You can view and edit the information about the Zaps created on the Zap overview page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenShot-Google_docs.png)

### Deleting a Zap

1. Navigate to the **Zapier dashboard**. On the overview page, a list of all existing Zaps will be displayed.
2. Click the arrow (**>**) icon to the right of the desired Zaps and click **Turn off and delete Zap**.

   The selected Zap will be deleted.

<a id="document360-with-google-sheets-integration"></a>

## Integrating Google Sheets with Document360

**Plans supporting integration of Zapier extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Many organizations use spreadsheets as their go-to tool for collecting and organizing data, which is among the simplest of its uses. Google Sheets is a free, web-based spreadsheet platform from Google that allows users to organize, collaborate, analyze, and edit distinct types of information. Multiple users can format and edit files in real time, and any changes made to the spreadsheet can be tracked by a revision history.

---

## Integrating Google Sheets with Document360

Using Document360 as your Knowledge base platform, you can maintain a Google Sheets log of all articles in the Knowledge base. Each time a new article is added, an entry must also be made in Google Sheets. While Google Sheets makes tracking straightforward, manually updating every addition in Document360 can be time-consuming and effort-intensive.

By connecting Document360 and Google Sheets on Zapier, you can easily facilitate the content flow between Google Sheets and Document360. To establish a connection between Google Sheets and Document360, follow the below steps:

1. Ensure that you have logged into your [Zapier account](https://zapier.com/app/dashboard).
2. From the left navigation menu, click **Create** and then click **Zaps** from the optionsavailable.
3. Zap will be created with **Trigger** and **Action** flow.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zapier_Google_Docs.gif)

### Connecting Google Sheets and Document360 in Zapier

### 1. Setting up the trigger: Connecting Document360

1. In the **Trigger** field, choose **Document360**.
2. On the Setup blade that appears on the right, select a desired event in the **Event** field.
3. Click the **Account** field, and a **Sign-in** window will appear.
4. Enter your sign-in credentials and click **Allow**.

   To generate the API token from the Document360 portal,
5. Navigate to Settings () > **Knowledge base portal** > **Extensions** > **Team collaboration**.
6. On the Zapier extension tile, click **Connect**.
7. Click the Copy () icon to copy the token.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Zapier_Google_docs.gif)

8. Head back to the Zapier window and paste the API token in the field.
9. Click **Yes, Continue to Document360**.

   ![3_Screenshot_Zapier_API_Token_Pasting](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot_Zapier_API_Token_Pasting.png)
10. You can find the connected Document360 project on the **Connect Document360 account** page.

    If you wish to configure a different account later, you can do that by clicking on Change.
11. Click **Continue**.

### 2. Setting up the action: Connecting Google Sheets

1. In the **Action** field, choose **Google Sheets**.
2. On the Setup blade that appears on the right, select **Create Spreadsheet Row** in the **Event** field.
3. Click the **Account** field and a **Sign-in** window appears.
4. Enter your sign-in credentials and click **Allow**.
5. Click **Continue**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zapier_Google_Sheets.gif)
6. In the **Configure** blade, update the following fields:

   * **Drive** - The default option is **My Google Drive** or choose the drive from the list.
   * **Spreadsheet** - Select the desired Spreadsheet file from your Google Drive.
   * **Worksheet** - Choose the desired worksheet in the selected spreadsheet file above.
7. As soon as you select the worksheet, you can find the column headings listed. Select the Document360 article attribute you want to map with the respective field. Click **Continue**.

   > NOTE
   >
   > Zaps are intended to only add rows to the end of the spreadsheet and not any other row in between.
8. Once done, move ahead to the **Test** section and click **Publish**.

   You will get a **Zap published** popup to confirm that the Zap is on.

![5_Screenshot_Zap_connection_Successful](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1731402818017.png)

> NOTE
>
> If you rename your sheet or worksheet(s) within the Sheet, you'll need to reselect them in the Zap Editor to update to the new names.

---

## Zap overview

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Google_sheets.png)

### Deleting a Zap

1. Navigate to the **Zapier dashboard**. On the overview page, a list of all existing Zaps will be displayed.
2. Click the arrow (**>**) icon to the right of the desired Zaps and click **Turn off and delete Zap**.

   The selected Zap will be deleted.

> NOTE
>
> Since you’re building a Zap that uses Google Sheets to add data, there are a few things you will need to do to get that sheet ready to work with Zapier. Refer [Work with Google Sheets in Zaps](https://help.zapier.com/hc/en-us/articles/8496276985101-Work-with-Google-Sheets-in-Zaps) for more information on how to interact with your sheet effectively.

---

## FAQ

**How is a spreadsheet different from a worksheet?**

A Spreadsheet is the overall file you select from Google Drive, while a Worksheet is the specific tab within that file where the data is located.

<a id="google-drive-document360"></a>

## Integrating Document360 with Google Drive

**Plans supporting integration of Zapier extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Integrating Google Drive with Document360 enables seamless access to your files directly within your Knowledge base portal. This integration allows you to easily link, manage, and share Google Drive files, for easy collaboration and documentation workflows.

---

## Integrating Document360 with Google Drive

Using Document360 as your knowledge base platform, you can efficiently manage and share documents across your team. However, manually linking and organizing files from Google Drive to Document360 can be a time-consuming task.

You can automate file management by integrating Google Drive with Document360 through Zapier. This ensures a smooth workflow between these platforms. To set up the integration between Google Drive and Document360, follow the steps below:

1. Log into your [Zapier account](https://zapier.com/app/dashboard).
2. From the left navigation menu, click **Create** and then clickZapsfrom the optionsavailable.

   Zap will be created with **Trigger** and **Action** flow.

![1_Screenvideo-Creating_a_workspace_in_zapier_dashboard2](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenvideo-Creating_a_workspace_in_zapier_dashboard%282%29.gif)

### Connecting Google Drive and Document360 in Zapier

![2_Screenshot-Connection_Google_Drive_and_Document360_in_Zapier](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Connection_Google_Drive_and_Document360_in_Zapier.png)

### 1. Setting up the trigger: Connecting Document360

1. In the **Trigger** field, choose **Document360**.
2. On the Setup blade that appears on the right, select a desired event in the **Event** field.
3. Click the **Account** field, and a **Sign-in** window will appear.
4. Enter your sign-in credentials and click **Allow**.

   To generate the API token from the Document360 portal,
5. Navigate to Settings () > **Knowledge base portal** > **Extensions** > **Team collaboration**.
6. On the Zapier extension tile, click **Connect**.
7. Click the Copy () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Zapier_Google_docs.gif)
8. Head back to the Zapier window and paste the API token in the field.
9. Click **Yes, Continue to Document360**.

![4_Screenshot_Zapier_API_Token_Pasting](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot_Zapier_API_Token_Pasting.png)

     You can find the connected Document360 project on the **Connect Document360 account** page.

10. If you wish to configure a different account later, click **Change**.
11. Click **Continue**.

### 2. Setting up the action: Connecting Google Drive

1. In the **Action** field, choose **Google Drive**.
2. On the Setup blade that appears on the right, select a desired action from the available options in the **Event** field.
3. Click the **Account** field and a **Sign-in** window appears.
4. Enter your sign-in credentials and click **Allow**.
5. Click **Continue**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zapier_Google_Drive.gif)
6. In the **Configure** blade, update the following fields:

* **Drive** - The default option is **My Google Drive** or choose the drive from the list.
* **Folder** - Select the desired folder from the dropdown.
* **File** - Select the desired file from the dropdown. This is a mandatory field.
* **Convert to Document** - Choose **True** or **False** based on your requirements.
* **File Name** - Enter a suitable file name.
* **File Extension** - Enter a suitable extension for the file.

  > NOTE
  >
  > The configurations details differ based on the Action event you choose. The above mentioned fields are required if select upload actions.

7. Once done, click **Continue**.
8. Go to the **Test** section and click **Test step**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGif-Zapier_Google_Drive.gif)

   If successful, you will get the message ‘*Test item sent! Check your Google Drive account to view it.*’
9. Once done, click **Publish**.

   A **Zap published** popup confirms the Zap is on.
10. Click **Manage your Zap** to go to the Google Drive+Document360 Zap overview page.

![7_Screenshot_Zap_connection_Successful](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1732093770417.png)

---

## Zap overview

You can view and edit the information about the Zaps created on the Zap overview page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Google_drive.png)

### Deleting a Zap

If a Zap is no longer needed or is outdated, you can delete it to keep your Zapier dashboard organized. To delete a Zap,

1. Navigate to the **Zapier dashboard**. On the overview page, a list of all existing Zaps will be displayed.
2. Click the arrow (**>**) icon to the right of the desired Zaps and click **Turn off and delete Zap**.

   The selected Zap will be deleted.

Zapier is a web automation tool used to connect web apps and services. It's used to automate and streamline your online workflows without coding, whether automating things like social media, project management, note-taking, email, or meetings.

Zapier allows users to automate tasks between apps with no coding required. By creating Zaps (automated workflows), you can trigger actions across different platforms, saving time and reducing errors.

<a id="document360-with-trello-integration"></a>

## Integrating Trello with Document360

**Plans supporting integration of Zapier extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Trello is a visual project management tool that empowers individuals and teams to organize their projects into boards. It helps to ideate, plan, manage, and celebrate their work together in a collaborative, productive, and organized way.

---

## Integrating Trello with **Document360**

Using **Document360** as your knowledge base, you can integrate it with Trello to manage documentation tasks more efficiently. For example, your documentation team may use Trello boards to organize tasks for writers, editors, and external agencies. Instead of manually updating tasks in both Trello and **Document360**, you can connect them using Zapier to automate task synchronization and keep everything updated seamlessly.

By connecting Trello and **Document360** on Zapier, you can easily synchronize tasks between Trello and your knowledge base on **Document360**. To set up the connection between Trello and **Document360**, follow the steps below:

1. Ensure that you have logged into your [Zapier account](https://zapier.com/app/dashboard).
2. From the left navigation menu, click **Create** and then click **Zaps** from the optionsavailable.
3. Zap will be created with **Trigger** and **Action** flow.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zapier_Google_Docs.gif)

### Connecting Trello and **Document360** in Zapier

To establish a connection between Trello and Document360, follow the below steps:

#### Setting up the trigger: Connecting **Document360**

1. In the **Trigger** field, choose **Document360**.
2. On the Setup blade that appears on the right, select a desired event in the **Event** field.
3. Click the **Account** field, and a **Sign-in** window will appear.
4. Enter your sign-in credentials and click **Allow**.

   To generate the API token from the **Document360** portal,
5. Navigate to Settings () > **Knowledge base portal** > **Extensions** > **Team collaboration**.
6. On the Zapier extension tile, click **Connect**.
7. Click the Copy () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Zapier_Google_docs.gif)
8. Head back to the Zapier window and paste the API token in the field.
9. Click **Yes, Continue to Document360**.

![3_Screenshot_Zapier_API_Token_Pasting](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot_Zapier_API_Token_Pasting.png)

10. You can find the connected **Document360** project on the **Connect Document360 account** page.

    If you wish to configure a different account later, you can do that by clicking on Change.
11. Click **Continue**.

#### Setting up the action: Connecting Trello

1. In the **Action** field, choose **Trello**.
2. On the Setup blade that appears on the right, select **Create Card** in the **Event** field.
3. Click the **Account** field and a **Sign-in** window appears.
4. Enter your Trella account sign-in credentials and click **Allow**.
5. Click **Continue**.

![4_Screenvideo-Trello_login_in_credentials_sign_in_window](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenvideo-Trello_login_in_credentials_sign_in_window.gif)

6. In the **Setup action** section, choose the intended **Trello board** and **list.**
7. In the **Name** and **Description** field, you can choose one or more Document360 attributes (for example, Content, ID, contributor, version, and update date).
8. In the **Label** field, pick a color label to apply to the card.
9. In the **Card position**, you can choose from two positions (top or bottom).
10. In the **Members** field, choose the members in your Trello board.
11. Hit the **Continue** button at the bottom.
12. Once done, move ahead to the **Test** section and click **Publish**.

    You will get a **Zap published** popup to confirm that the Zap is on.

![5_Screenvideo-Successful_prompt_from_Zapier_Connection](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenvideo-Successful_prompt_from_Zapier_Connection.gif)

### **Syncing Articles to Trello**

After you have successfully created a Zap and configured it, each time an article is published on your connected **Document360** project by any team member, a Trello card will be added to the selected list and board. This card would contain all the article attributes, like content, contributor, publish date, and any other information you have configured on Zap.

Now, looking at the Trello board (for example, Kanban, Agile, etc.) for documentation, you maintain a list of all the published articles on your Knowledge base amongst other lists like new articles and reviews pending. Each article is added as a card to either of the lists, depending on its status.![1_Screenshot_Overview_page_of_trello](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot_Overview_page_of_trello.png)

---

## Zap overview

You can view and edit the information about the Zaps created on the Zap overview page.  
![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-Gmail_extension.png)

### Deleting a Zap

To delete a Zap that you have created,

1. Navigate to the **Zapier dashboard**. On the overview page, a list of all existing Zaps will be displayed.
2. Click the **Zap actions** () icon to the right of the desired Zap and click **Delete**.

   The selected Zap will be deleted.

<a id="github-document360"></a>

## Integrating GitHub with Document360

**Plans supporting integration of Zapier extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Many organizations worldwide use Git to manage code repositories, with GitHub being one of the most popular platforms. GitHub enables developers to showcase their work and collaborate globally.   
Developers use Git commands to commit new features and bug fixes to their project repositories. GitHub also offers an intuitive graphical interface for managing these repositories efficiently.

---

## Integrating GitHub with **Document360**

Using **Document360** as your Knowledge base platform, you can integrate it with GitHub to streamline content management. For example, when developers commit new code or updates to a GitHub repository, corresponding changes may need to be reflected in your knowledge base. Manually updating **Document360** for every change can be time-consuming and prone to errors.

By connecting **Document360** and GitHub via Zapier, you can automate this process, ensuring seamless synchronization between your code repository and knowledge base. To establish a connection between GitHub and **Document360**, follow the below steps:

1. Ensure that you have logged into your [Zapier account](https://zapier.com/app/dashboard).
2. From the left navigation menu, click **Create** and then click **Zaps** from the optionsavailable.
3. Zap will be created with **Trigger** and **Action** flow.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zapier_Google_Docs.gif)

### Connecting GitHub and **Document360** in Zapier

Follow the below steps to establish a connection between GitHub and Documnet360:

#### Step 1: Connecting GitHub

1. In the **Trigger** field, choose **GitHub**.
2. In the **Trigger event** field, select the required Event to trigger in the GitHub.

   If you wish to configure a different app later, you can do that by clicking on **Change**.
3. Click the **Account** field, and a **Sign-in** window will appear.
4. Enter your sign-in credentials and click **Authorize Zapier**.
5. Choose the desired folder and click **Continue**.

   Zapier runs a test to make sure the trigger is correctly configured.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Zapier_Github.png)

#### Step 2: Connecting **Document360**

1. In the **Action** field, choose **Document360**.
2. On the Setup blade that appears on the right, select a desired event in the **Event** field.
3. Click the **Account** field and a **Sign-in** window appears.
4. Enter your sign-in credentials and click **Allow**.

   To generate the API token from the **Document360** portal,
5. Navigate to Settings () > **Knowledge base portal** > **Extensions** > **Team collaboration**.
6. On the Zapier extension tile, click **Connect**.
7. Click the Copy () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Zapier_Google_docs.gif)
8. Head back to the Zapier window and paste the API token in the field.
9. Click **Yes, Continue to Document360**.

   ![5_Screenshot_Zapier_API_Token_Pasting1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot_Zapier_API_Token_Pasting%281%29.png)
10. You can find the connected Document360 project on the **Connect Document360 account** page.

    If you wish to configure a different account later, you can do that by clicking on Change.
11. Click **Continue**.

#### Step 3: Customize Zap

![6_Screenvideo-Map_fields_from_GitHub_into_Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenvideo-Map_fields_from_GitHub_into_Document360.png)

1. Map all the required fields:

* **Title**: The default selection is **New Commit in GitHub**. However, you can choose from various options based on your business requirements.
* **Content**: The default selection is **Commit Message**, but you can select other options depending on your needs.
* **Version**: Select the workspace in your knowledge base project where the article should be created.
* **Language**: Choose the language for the article within the selected workspace.
* **Category**: Select the category under the chosen language where the article will be created.
* **Publish**: Set to **True** to publish the article immediately or **False** to save it as a draft.

2. Once done, click **Continue**. The button enables only when all the fields are filled.

#### Step 4: Test Zap

1. In the test section, click **Send** **Test**.
2. If it is successful, you will get the message ‘*Test Article sent! Check your Document360 account to view it*’.

   In your Document360 Knowledge base portal, you'll find the article titled ‘*New commit in GitHub*’, located in the folder you previously selected.
3. Head back to the Zapier setup window and click **Next**.
4. Once done, click **Publish**.

#### Turn on Zap

To turn on a Zap once it is tested and published, follow the below steps:

1. After testing the Zap, review or edit the settings before turning on the Zap.
2. You can edit the settings configured on the **GitHub** trigger and the corresponding action of the new article in **Document360**.
3. You will get a success message stating **Your Zap is on**. You can click on the **Manage your Zap** button to go to your Zap overview page.

---

## Zap overview

### Create articles in **Document360** from new GitHub commits

You can view and edit the information about the Zaps created on the Zap overview page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-GitHub.png)

### Deleting a Zap

To delete a Zap that you have created,

1. Navigate to the **Zapier dashboard**. On the overview page, a list of all existing Zaps will be displayed.
2. Click the **Zap actions** () icon to the right of the desired Zap and click **Delete**.

   The selected Zap will be deleted.

<a id="confluence-document360"></a>

## Integrating Confluence Server with Document360

Many organizations use wikis as a central hub for storing and managing project-related information. Confluence is a popular, secure wiki platform that enables teams to collaborate effectively by organizing and sharing work in dedicated team workspaces. Users can create pages or blogs to capture, structure, and collaborate on ideas and projects, ensuring every team member has access to the knowledge and resources they need.

---

## Integrating Confluence Server with **Document360**

Using **Document360** as your knowledge base platform, you can maintain a log of all articles in Confluence Server. Each time a new article is added to **Document360**, an entry must also be made in Confluence. While Confluence helps with tracking, manually updating each addition can be time-consuming.

By connecting **Document360** and Confluence Server on Zapier, you can easily automate the content flow between **Document360** and Confluence. To establish a connection between Confluence Server and **Document360**, follow the below steps:

1. Ensure that you have logged into your [Zapier account](https://zapier.com/app/dashboard).
2. From the left navigation menu, click **Create** and then click **Zaps** from the optionsavailable.
3. Zap will be created with **Trigger** and **Action** flow.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zapier_Google_Docs.gif)

### Connecting Confluence Server and **Document360** in Zapier

To establish a connection between Confluence Server and Documnet360, follow the below steps:

#### Step 1: Connecting Confluence Server

1. In the **Trigger** field, choose **Confluence server**.
2. In the **Trigger event** field, select **New Page or Blog Post** to trigger in the Confluence Server.

   If you wish to configure a different app later, you can do that by clicking on **Change**.
3. Click the **Account** field, and a **Sign-in** window will appear.
4. Enter your sign-in credentials and click **Yes, Continue to Confluence Server**.
5. Click **Continue**.

   Zapier runs a test to make sure the trigger is correctly configured.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Confluence_server.png)

#### Step 2: Connecting **Document360**

1. In the **Action** field, choose **Document360**.
2. On the Setup blade that appears on the right, select a desired event in the **Event** field.
3. Click the **Account** field and a **Sign-in** window appears.
4. Enter your sign-in credentials and click **Allow**.

   To generate the API token from the **Document360** portal,
5. Navigate to Settings () > **Knowledge base portal** > **Extensions** > **Team collaboration**.
6. On the Zapier extension tile, click **Connect**.
7. Click the Copy () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Zapier_Google_docs.gif)
8. Head back to the Zapier window and paste the API token in the field.
9. Click **Yes, Continue to Document360**.

![6_Screenshot_Zapier_API_Token_Pasting](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot_Zapier_API_Token_Pasting.png)

10. You can find the connected Document360 project on the **Connect Document360 account** page.

    If you wish to configure a different account later, you can do that by clicking on Change.
11. Click **Continue**.

#### Step 3: Customize Zap

1. Map all the required fields:

* **Version**: Select the workspace in your knowledge base project where the article should be created.
* **Language**: Choose the language for the article within the selected workspace.
* **Category**: Select the category under the chosen language where the article will be created.
* **Publish**: Set to **True** to publish the article immediately or **False** to save it as a draft.

2. Once done, click **Continue**. The button enables only when all the fields are filled.

#### Step 4: Test Zap

1. In the test section, click **Test step**.
2. If it is successful, you will get the message ‘*A Document was sent to Document360*’.

   In your **Document360** Knowledge base portal, you'll find the article named ‘*Title of your Page / Blog post*’, located in the folder you previously selected.
3. Head back to the Zapier setup window and click **Next**.
4. Once done, click **Publish.**

### Turn on Zap

To turn on a Zap once it is tested and published, follow the below steps:

1. After testing the Zap, review or edit the settings before turning on the Zap.
2. You can edit the settings configured on the **Confluence Server** trigger and the corresponding action of the new article in **Document360**.
3. You would get a success message stating **Your Zap is on**. You can click on the **Manage your Zap** button to go to your Zap overview page.

![5_Screenshot_Zap_connection_Successful1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot_Zap_connection_Successful%281%29.png)

## Zap overview

### Create articles in **Document360** from the new Confluence Server Page

You can view and edit the information about the Zaps created on the Zap overview page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenShot-Confluence_server.png)

### Deleting a Zap

To delete a Zap that you have created,

1. Navigate to the **Zapier dashboard**. On the overview page, a list of all existing Zaps will be displayed.
2. Click the **Zap actions** () icon to the right of the desired Zap and click **Delete**.

   The selected Zap will be deleted.

<a id="zoho-crm-document360"></a>

## Integrating Zoho CRM with Document360

**Plans supporting integration of Zapier extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Customer relationship management (CRM) is a technology for managing all your company’s relationships and interactions with customers and potential customers. The goal of a CRM is to improve business relationships. A CRM system helps companies stay connected to customers, streamline processes, and improve profitability.

A CRM solution helps you focus on your organization’s relationships with individual people, including customers, service users, colleagues, or suppliers, throughout their lifecycle. This includes finding new customers and providing support and additional services throughout the relationship.

One popular CRM is Zoho CRM which has a rich set of features to manage your customer relationship.

---

## Integrating Zoho CRM with **Document360**

Using **Document360** as your Knowledge base platform and Zoho CRM for managing customer relationships, you may encounter a need to create a corresponding knowledge base article in **Document360** whenever a new lead or contact is added in Zoho CRM. This ensures that relevant information about leads or contacts is easily accessible and well-documented.

To establish a connection between Zoho CRM and **Document360**, follow the below steps:

1. Ensure that you have logged into your [Zapier account](https://zapier.com/app/dashboard).
2. From the left navigation menu, click **Create** and then click **Zaps** from the optionsavailable.
3. Zap will be created with **Trigger** and **Action** flow.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zapier_Google_Docs.gif)

### Connecting Zoho CRM and **Document360** in Zapier

To establish a connection between Zoho CRM and Document360, follow the below steps:

![2_Screenshot-Connecting_Steps_of_Doc360_Zoho_Crm](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Connecting_Steps_of_Doc360_Zoho_Crm.png)

#### 1. Setting up the trigger: Connecting Zoho CRM

1. In the **Trigger** field, choose **Zoho CRM**.
2. In the **Trigger event** field, select the required Event to trigger in the Zoho CRM.

   If you wish to configure a different app later, you can do that by clicking on **Change**.
3. Click the **Account** field, and a **Sign-in** window will appear.

   The Zoho domain is an optional field. Select the domain based on your requirements.
4. Once done, click **Yes, Continue to Zoho CRM**.
5. Enter your sign-in credentials and click **Accept**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Zoho_CRM.png)
6. Click **Continue**.
7. Zapier runs a test to make sure the trigger is correctly configured.

#### 2. Setting up the action: Connecting **Document360**

1. In the **Action** field, choose **Document360**.
2. On the Setup blade that appears on the right, select a desired event in the **Event** field.
3. Click the **Account** field and a **Sign-in** window appears.
4. Enter your sign-in credentials and click **Allow**.

   To generate the API token from the Document360 portal,
5. Navigate to **Settings**() > **Knowledge base portal**> **Extensions**> **Team collaboration**.
6. On the Zapier extension tile, click **Connect**.
7. Click the Copy () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Zapier_Google_docs.gif)
8. Head back to the Zapier window and paste the API token in the field.
9. Click **Yes, Continue to Document360**.

![5_Screenshot_Zapier_API_Token_Pasting1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot_Zapier_API_Token_Pasting%281%29.png)

10. You can find the connected Document360 project on the **Connect Document360 account** page.

    If you wish to configure a different account later, you can do that by clicking on Change.
11. Click **Continue**.

#### 3. Customize Zap

1. Map the required fields:

* **Version:** Select the workspace in your knowledge base project where the article should be created.
* **Language**: Choose the language for the article within the selected workspace.
* **Article**: Choose the desired article from the desired category.
* **Publish**: Set to **True** to publish the article immediately or **False** to save it as a draft.

2. Once done, click **Continue.**

#### 4. Test Zap

1. In the test section, click **Test step**.
2. If it is successful, you will get the message ‘*A Document was sent to Document360.*’

   In your Document360 Knowledge base portal, you'll find the article titled ‘*Lead Source in Zoho CRM*’, located in the folder you previously selected.
3. Head back to the Zapier setup window and click **Continue**.
4. Once done, click **Publish**.

#### Turn on Zap

To turn on a Zap once it is tested and published, follow the below steps:

1. After testing the Zap, review or edit the settings before turning on the Zap.
2. You can edit the settings configured on the **Zoho CRM** trigger and the corresponding action of the new article in **Document360**.
3. Turn on the Zap toggle.
4. You would get a success message stating **Your Zap is on**. You can click on the **Manage your Zap** button to go to your Zap overview page.

---

## Zap overview

You can view and edit the information about the Zaps created on the Zap overview page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenShot-ZohoCRM.png)

### Deleting a Zap

To delete a Zap that you have created,

1. Navigate to the **Zapier dashboard**. On the overview page, a list of all existing Zaps will be displayed.
2. Click the arrow (**>**) icon to the right of the desired Zaps and click **Turn off and delete Zap**.

   The selected Zap will be deleted.

<a id="pipedrive-document360"></a>

## Integrating Pipedrive with Document360

**Plans supporting integration of Zapier extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Customer relationship management (CRM) is a technology for managing all your company’s relationships and interactions with customers and potential customers. Pipedrive is a deal-driven customer relationship management CRM solution that also works as an account-management tool with the ability to assist with marketing and the entire sales process. Pipedrive's proactive nature automatically tracks and organizes calls and emails and synchronizes schedules across devices.

---

## Integrating Pipedrive with **Document360**

Using **Document360** as your Knowledge base platform and Pipedrive as your sales platform, you may encounter a need to create a corresponding Knowledge base article in **Document360** whenever a new lead or contact is added in Pipedrive. This ensures that relevant information about leads or contacts is easily accessible and well-documented.

To establish a connection between Pipedrive and **Document360**, follow the below steps:

1. Ensure that you have logged into your [Zapier account](https://zapier.com/app/dashboard).
2. From the left navigation menu, click **Create** and then click **Zaps** from the optionsavailable.
3. Zap will be created with **Trigger** and **Action** flow.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zapier_Google_Docs.gif)

### Connecting Pipedrive and **Document360** in Zapier

To establish a connection between Pipdrive and Document360, follow the below steps:

![2_Screenshot-Connnecting_steps_Document360_Pipedrive](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Connnecting_steps_Document360_Pipedrive.png)

#### Step 1: Connecting Pipedrive

1. In the **Trigger** field, choose **Pipedrive**.
2. In the **Trigger event** field, select the required Event to trigger in the GitHub.

   If you wish to configure a different app later, you can do that by clicking on **Change**.
3. Click the **Account** field, and a **Sign-in** window will appear.
4. Enter your sign-in credentials and click **Allow and Install**.

   Zapier runs a test to make sure the trigger is correctly configured.

![3_Screenshot-Pipedrive_Sign_in_credentials](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Pipedrive_Sign_in_credentials.png)

#### Step 2: Connecting **Document360**

1. In the **Action** field, choose **Document360**.
2. On the Setup blade that appears on the right, select a desired event in the **Event** field.
3. Click the **Account** field and a **Sign-in** window appears.
4. Enter your sign-in credentials and click **Allow**.

   To generate the API token from the **Document360** portal,
5. Navigate to **Settings**() > **Knowledge base portal** > **Extensions** > **Team collaboration**.
6. On the Zapier extension tile, click **Connect**.
7. Click the Copy () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Zapier_Google_docs.gif)
8. Head back to the Zapier window and paste the API token in the field.
9. Click **Yes, Continue to Document360**.

![5_Screenshot_Zapier_API_Token_Pasting2](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot_Zapier_API_Token_Pasting%282%29.png)

     You can find the connected **Document360** project on the **Connect Document360 account** page.

10. Click **Continue**.

#### Step 3: Customize Zap

1. Map all the required fields:

* **Title**: Choose a suitable title from the options available.
* **Content**: Choose suitable content based on your business requirements.
* **Version**: Select the workspace in your knowledge base project where the article should be created.
* **Language**: Choose the language for the article within the selected workspace.
* **Category**: Select the category under the chosen language where the article will be created.
* **Publish**: Set to **True** to publish the article immediately or **False** to save it as a draft.

2. Once done, click **Continue**. The button enables only when all the fields are filled.

#### Step 4: Test Zap

1. In the test section, click **Test step**.
2. If it is successful, you will get the message ‘*A Document was sent to Document360.*’

   In your **Document360** Knowledge base portal, you'll find the article titled ‘*Title of your Pipedrive deal*’, located in the folder you previously selected.
3. Head back to the Zapier setup window and click **Next**.
4. Once done, click **Publish**.

#### Turn on Zap

To turn on a Zap once it is tested and published, follow the below steps:

1. After testing the Zap, review or edit the settings before turning on the Zap.
2. You can edit the settings configured on the **Pipedrive** trigger and the corresponding action of the new article in **Document360**.
3. You would get a success message stating **Your Zap is on**. You can click on the **Manage your Zap** button to go to your Zap overview page.

---

## Zap overview

### Create articles in **Document360** whenever a new sales deal is added in Pipedrive

You can view and edit the information about the Zaps created on the Zap overview page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-Pipedrive.png)

### Deleting a Zap

To delete a Zap that you have created,

1. Navigate to the **Zapier dashboard**. On the overview page, a list of all existing Zaps will be displayed.
2. Click the **Zap actions** () icon to the right of the desired Zap and click **Delete**.

   The selected Zap will be deleted.

<a id="hubspot-document360"></a>

## Integrating Hubspot with Document360

**Plans supporting integration of Zapier extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Many organizations around the world need a business automation tool that allows business promotions and manages marketing efforts by controlling sales processes. One such platform is HubSpot, a leading inbound marketing, sales, CRM, and customer success growth stack.

---

## Integrating HubSpot with **Document360**

Using Document360 as your knowledge base platform and HubSpot for managing customer support tickets, you may encounter a need to automatically check if a related article exists in your internal knowledge base whenever a new support ticket is created in HubSpot. If no related article is found, a new knowledge base article can be created to address the knowledge gap and assist in resolving the support ticket efficiently.

To establish a connection between HubSpot and **Document360**, follow the below steps:

1. Ensure that you have logged into your [Zapier account](https://zapier.com/app/dashboard).
2. From the left navigation menu, click **Create** and then click **Zaps** from the optionsavailable.
3. Zap will be created with **Trigger** and **Action** flow.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zapier_Google_Docs.gif)

### Connecting HubSpot and **Document360** in Zapier

To establish a connection between HubSpot and Document360, follow the below steps:

#### Step 1: Connecting HubSpot

1. In the **Trigger** field, choose **HubSpot**.
2. In the **Trigger event** field, select the required Event to trigger in the HubSpot.

   If you wish to configure a different app later, you can do that by clicking on **Change**.
3. Click the **Account** field, and a **Sign-in** window will appear.
4. Enter your sign-in credentials and select the checkbox.
5. Click **Connect app**.

   Zapier runs a test to make sure the trigger is correctly configured.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Hubspot.png)
6. Click **Continue**.

#### Step 2: Connecting **Document360**

1. In the **Action** field, choose **Document360**.
2. On the Setup blade that appears on the right, select a desired event in the **Event** field.
3. Click the **Account** field and a **Sign-in** window appears.
4. Enter your sign-in credentials and click **Allow**.

   To generate the API token from the **Document360** portal,
5. Navigate to **Settings**() > **Knowledge base portal** > **Extensions** > **Team collaboration**.
6. On the Zapier extension tile, click **Connect**.
7. Click the Copy () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Zapier_Google_docs.gif)
8. Head back to the Zapier window and paste the API token in the field.
9. Click **Yes, Continue to Document360**.

![4_Screenshot_Zapier_API_Token_Pasting2](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot_Zapier_API_Token_Pasting%282%29.png)

You can find the connected Document360 project on the **Connect Document360 account** page.

10. Click **Continue.**

#### Step 3: Customize Zap

1. Map all the required fields**:**

   * **Ticket name**: By default the ticket name will be set to ‘*Title in Document360.’*
   * **Ticket description**: By default the ticket description will be set to ‘*Content in Document360.’*
2. **Version**: Select the workspace in your knowledge base project where the article should be created.
3. **Language**: Choose the language for the article within the selected workspace.
4. **Should this step be considered a "success" when nothing is found?**: Set to **True** or **False**.
5. Once done, click **Continue**.
6. Click **Test & Continue**.

#### Turn on Zap

To turn on a Zap once it is tested and published, follow the below steps:

1. After testing the Zap, review or edit the settings before turning on the Zap.
2. You can edit the settings configured on the **HubSpot** trigger and the corresponding action of the new article in **Document360**.
3. You would get a success message stating **Your Zap is on**. You can click on the **Manage your Zap** button to go to your Zap overview page.

---

## Zap overview

### Create articles in **Document360** from new support tickets in HubSpot

You can view and edit the information about the Zaps created on the Zap overview page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-Hubspot.png)

### Deleting a Zap

To delete a Zap that you have created,

1. Navigate to the **Zapier dashboard**. On the overview page, a list of all existing Zaps will be displayed.
2. Click the **Zap actions** () icon to the right of the desired Zap and click **Delete**.

   The selected Zap will be deleted.

<a id="asana-document360"></a>

## Integrating Asana with Document360

**Plans supporting integration of Zapier extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Many organizations use Asana to organize, track, and manage their work across teams. Integrating Asana with **Document360** allows you to streamline task management and ensure alignment between your documentation efforts and Knowledge base updates.

---

## Integrating Asana with **Document360**

Using Document360 as your Knowledge base platform and Asana for managing content collaboration with external vendors, you may encounter a need to streamline the process of adding articles created in Asana to your **Document360** Knowledge base. While this can be done manually, it is time-consuming, effort-intensive, and prone to errors. Automating this process ensures efficiency and accuracy, reducing the risk of mishaps while maintaining a seamless content workflow.

To establish a connection between Asana and **Document360**, follow the below steps:

1. Ensure that you have logged into your [Zapier account](https://zapier.com/app/dashboard).
2. From the left navigation menu, click **Create** and then click **Zaps** from the optionsavailable.
3. Zap will be created with **Trigger** and **Action** flow.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zapier_Google_Docs.gif)

### Connecting Asana and **Document360** in Zapier

To establish a connection between Asana and Documnet360, follow the below steps:

![2_Screenshot-connecting_steps_Asana_Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-connecting_steps_Asana_Document360.png)

#### Step 1: Setting up the Trigger: Connecting Asana

1. In the **Trigger** field, choose **Asana**.
2. In the **Trigger event** field, select the required Event to trigger in the Asana.

   If you wish to configure a different app later, you can do that by clicking on **Change**.
3. Click the **Account** field, and a **Sign-in** window will appear.
4. Enter your sign-in credentials and click **Allow**.

   Zapier runs a test to make sure the trigger is correctly configured.

   If your account is already linked to Asana, you can directly select your account in the **Sign-in** window.
5. Select your Asana account and click **Next**.
6. Select the desired Workspace and click **Next**.
7. Select the desired Project and click **Next**.

![3_Screenshot-Asana_Sign_in_credentials](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Asana_Sign_in_credentials.png)

#### Step 2: Setting up action: Connecting Document360

1. In the **Action** field, choose **Document360**.
2. On the Setup blade that appears on the right, select a desired event in the **Event** field.
3. Click the **Account** field and a **Sign-in** window appears.
4. Enter your sign-in credentials and click **Allow**.

   To generate the API token from the Document360 portal,
5. Navigate to Settings () > **Knowledge base portal** > **Extensions** > **Team collaboration**.
6. On the Zapier extension tile, click **Connect**.
7. Click the Copy () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Zapier_Google_docs.gif)
8. Head back to the Zapier window and paste the API token in the field.
9. Click **Yes, Continue to Document360**.

![5_Screenshot_Zapier_API_Token_Pasting3](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot_Zapier_API_Token_Pasting%283%29.png)

   You can find the connected Document360 project on the **Connect Document360 account** page.

8. Click **Continue**.

#### Step 3: Customize Zap

1. Map all the required fields:

   * **Title**: Choose a suitable title from the options available.
   * **Content**: Choose suitable content based on your business requirements.
   * **Version**: Select the workspace in your Knowledge base project where the article should be created.
   * **Language**: Choose the language for the article within the selected workspace.
   * **Article**: Choose the article within the selected category.
2. Once done, click **Continue**. The button enables only when all the fields are filled.

#### Step 4: Test Zap

1. In the test section, click **Test step**.
2. If it is successful, you will get the message ‘*A Document was sent to Document360.*’

   In your Document360 Knowledge base portal, you'll find the article located in the folder you previously selected.
3. Head back to the Zapier setup window and click **Next**.
4. Once done, click **Publish**.

#### Turn on Zap

To turn on a Zap once it is tested and published, follow the below steps:

1. After testing the Zap, review or edit the settings before turning on the Zap.
2. You can edit the settings configured on the **Asana** trigger and the corresponding action of the new article in **Document360**.
3. You would get a success message stating **Your Zap is on**. You can click on the **Manage your Zap** button to go to your Zap overview page.

---

## Zap overview

### Create articles in Document360 from new Asana tasks

You can view and edit the information about the Zaps created on the Zap overview page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Asana_extension.png)

### Deleting a Zap

To delete a Zap that you have created,

1. Navigate to the **Zapier dashboard**. On the overview page, a list of all existing Zaps will be displayed.
2. Click the **Zap actions** () icon to the right of the desired Zap and click **Delete**.

   The selected Zap will be deleted.

<a id="mondaycom-document360"></a>

## Integrating Monday.com with Document360

**Plans supporting integration of Zapier extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Many organizations rely on [Monday.com](http://Monday.com) to efficiently organize, track, and manage their work across teams. With its versatile boards and customizable workflows, it enables teams to handle diverse tasks and projects seamlessly. For example, a documentation team comprising writers, editors, and external content agencies can use Monday.com to streamline content creation and collaboration processes effectively.

---

## Integrating Monday.com with **Document360**

If you are using **Document360** as your knowledge base platform and Monday.com for managing content collaboration with external vendors, you may encounter a need to streamline the process of transferring articles created in Monday.com to your **Document360** knowledge base. While this task can be performed manually, it is labor-intensive, time-consuming, and prone to errors. Automating this process ensures efficiency, accuracy, and a smooth content workflow, minimizing the risk of mishaps.

To establish a connection between Monday.com and **Document360**, follow the below steps:

1. Log into your [Zapier account](https://zapier.com/app/dashboard).
2. From the left navigation menu, click **Create** and then click **Zaps** from the optionsavailable.

   Zap will be created with **Trigger** and **Action** flow.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zapier_Google_Docs.gif)

### Connecting Monday.com and **Document360** in **Zapier**

To establish a connection between Monday.com and Document360, follow the below steps:

![1_Screenshots-Connecting_Monday_com_and_Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733211230837.png)

#### Step 1: Setting up Trigger: Connecting Monday.com

1. In the **Trigger** field, choose **Monday.com**.
2. In the **Trigger event** field, select the required Event to trigger on Monday.com.

   If you wish to configure a different app later, you can do that by clicking on **Change**.
3. Click the **Account** field, and a **Sign-in** window will appear. You will have to enter the **API v2 Token**.

   To obtain the **API v2 Token** from the Monday.com profile,
4. Navigate to **Profile** > **Administration**.
5. From the left navigation sidebar, click **Connections**.
6. Under the **API** tab, click the Copy () icon to copy the personal API token.

   ![3_ScreenGIF-Generating_API_token_in_Monday_com](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Generating_API_token_in_Monday_com.gif)
7. Paste the token in the **Zapier** window, and click **Yes, Continue to Document360**.

   1. **Zapier** runs a test to make sure the trigger is correctly configured.
8. Click **Continue**.

#### Step 2: Setting up Action: Connecting **Document360**

1. In the **Action** field, choose **Document360**.
2. On the Setup blade that appears on the right, select a desired event in the **Event** field.
3. Click the **Account** field and a **Sign-in** window appears.
4. Enter your sign-in credentials and click **Allow**.

   To generate the API token from the **Document360** portal,
5. Navigate to **Settings** () > **Knowledge base portal**> **Extensions** > **Team collaboration**.
6. On the **Zapier** extension tile, click **Connect**.
7. Click the Copy () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Zapier_Google_docs.gif)
8. Head back to the **Zapier** window and paste the API token in the field.
9. Click **Yes, Continue to Document360**.

![5_Screenshot_Zapier_API_Token_Pasting3](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot_Zapier_API_Token_Pasting%283%29.png)

    You can find the connected **Document360** project on the **Connect Document360 account** page.

8. Click **Continue**.

#### Step 3: Customize Zap

1. Map all the required fields:

   * **Title**: Choose a suitable title from the options available.
   * **Content**: Choose suitable content based on your business requirements.
   * **Version**: Select the workspace in your Knowledge base project where the article should be created.
   * **Language**: Choose the language for the article within the selected workspace.
   * **Article**: Choose the article within the selected category.
2. Once done, click **Continue**. The button enables only when all the fields are filled.

#### Step 4: Test Zap

1. In the test section, click **Test step**.
2. If it is successful, you will get the message ‘*A Document was sent to Document360.*’

   In your **Document360** **Knowledge base portal**, you'll find the article located in the folder you previously selected.
3. Head back to the **Zapier** setup window and click **Next**.
4. Once done, click **Publish**.

#### Turn on Zap

To turn on a Zap once it is tested and published, follow the below steps:

1. After testing the Zap, review or edit the settings before turning on the Zap.

   You can edit the settings configured on the **Monday.com** trigger and the corresponding action of the new article in **Document360**.

   You will get a success message stating **Your Zap is on**.
2. Click the **Manage your Zap** button to go to your Zap overview page.

---

## Zap overview

### Create articles in **Document360** from new Monday.com items

You can view and edit the information about the Zaps created on the Zap overview page.  
![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-Monday.com.png)

### Deleting a Zap

To delete a Zap that you have created,

1. Navigate to the **Zapier dashboard**. On the overview page, a list of all existing Zaps will be displayed.
2. Click the arrow (**>**) icon to the right of the desired Zaps and click **Turn off and delete Zap**.

   The selected Zap will be deleted.

<a id="typeform-document360"></a>

## Integrating Typeform with Document360

**Plans supporting integration of Zapier extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Typeform is a versatile platform for creating interactive forms, surveys, and quizzes. It offers an intuitive interface and engaging design to help businesses collect user feedback, conduct surveys, and gather data in a conversational format. Typeform is commonly used to gather questions from customers or prospects through engaging forms and surveys.

---

## Integrating Typeform with Document360

Using Document360 as your knowledge base platform and Typeform for collecting customer or prospect questions, you may encounter a need to streamline the process of transferring responses collected in Typeform to your Document360 knowledge base. Automating this process ensures efficiency, accuracy, and a smooth content workflow, reducing manual effort and improving response management.

To establish a connection between Typeform and Document360, follow the below steps:

1. Ensure that you have logged into your [Zapier account](https://zapier.com/app/dashboard).
2. From the left navigation menu, click **Create** and then click **Zaps** from the optionsavailable.

   Zap will be created with **Trigger** and **Action** flow.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zapier_Google_Docs.gif)

### Connecting Typeform and Document360 in Zapier

To establish a connection between Typeform and Document360, follow the below steps:

![1_Screenshot-Connecting_typeform_document360.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733316665587.png)

#### Step 1: Setting up trigger: Connecting Typeform

1. In the **Trigger** field, choose **Typeform**.
2. In the **Trigger event** field, select the required Event to trigger in the Typeform.

   If you wish to configure a different app later, you can do that by clicking on **Change**.
3. Click the **Account** field, and a **Sign-in** window will appear.
4. Enter your sign-in credentials.
5. Select the checkbox, and click **Let me in**.

   Zapier runs a test to make sure the trigger is correctly configured.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Typeform.png)

#### Step 2: Setting up action: Connecting Document360

1. In the **Action** field, choose **Document360**.
2. On the Setup blade that appears on the right, select a desired event in the **Event** field.
3. Click the **Account** field and a **Sign-in** window appears.
4. Enter your sign-in credentials and click **Allow**.

   To generate the API token from the Document360 portal,
5. Navigate to Settings () > **Knowledge base portal** > **Extensions** > **Team collaboration**.
6. On the Zapier extension tile, click **Connect**.
7. Click the Copy () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Zapier_Google_docs.gif)
8. Head back to the Zapier window and paste the API token in the field.
9. Click **Yes, Continue to Document360**.

   ![5_Screenshot_Zapier_API_Token_Pasting1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot_Zapier_API_Token_Pasting%281%29.png)
10. You can find the connected Document360 project on the **Connect Document360 account** page.

    If you wish to configure a different account later, you can do that by clicking on Change.
11. Click **Continue**.

#### Step 3: Customize Zap

1. Map all the required fields:

   * **Title**: Choose a suitable title from the options available.
   * **Content**: Choose suitable content based on your business requirements.
   * **Version**: Select the workspace in your Knowledge base project where the article should be created.
   * **Language**: Choose the language for the article within the selected workspace.
   * **Category**: Select the category under the chosen language where the article will be created.
   * **Publish**: Set to **True** to publish the article immediately or **False** to save it as a draft.
2. Once done, click **Continue**. The button enables only when all the fields are filled.

#### Step 4: Test Zap

1. In the test section, click **Send** **Test**.
2. If it is successful, you will get the message ‘*Test Article sent! Check your Document360 account to view it*’.

   In your Document360 Knowledge base portal, you'll find the article located in the folder you previously selected.
3. Head back to the Zapier setup window and click **Next**.
4. Once done, click **Publish**.

#### Turn on Zap

To turn on a Zap once it is tested and published, follow the below steps:

1. After testing the Zap, review or edit the settings before turning on the Zap.
2. You can edit the settings configured on the **Typeform** trigger and the corresponding action of the new article in **Document360**.
3. You will get a success message stating **Your Zap is on**. You can click on the **Manage your Zap** button to go to your Zap overview page.

---

## Zap overview

### Create articles in Document360 from new Typeform entries

You can view and edit the information about the Zaps created on the Zap overview page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-Typeform.png)

### Deleting a Zap

To delete a Zap that you have created,

1. Navigate to the **Zapier dashboard**. On the overview page, a list of all existing Zaps will be displayed.
2. Click the **Zap actions** () icon to the right of the desired Zap and click **Delete**.

   The selected Zap will be deleted.

<a id="document360-gmail"></a>

## Integrating Gmail with Document360

**Plans supporting integration of Zapier extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Gmail is a widely used email service developed by Google that provides users with a simple and efficient platform for sending, receiving, and organizing emails. Known for its user-friendly interface, Gmail offers features like powerful search capabilities, spam filtering, and integration with other Google services such as Google Drive and Calendar. Gmail is a versatile tool for communication and collaboration.

---

## Integrating Gmail with Document360

While using Document360 as your knowledge base platform and Gmail as your communication tool, you may encounter a need to keep external vendors or stakeholders informed about updates to your knowledge base. The Document360-Gmail integration simplifies this process by automatically sending custom emails via Gmail whenever a new article is published in your Document360 knowledge base. This ensures seamless communication, reduces manual effort, and keeps all stakeholders effortlessly updated.

To establish a connection between Gmail and Document360, follow the below steps:

1. Ensure that you have logged into your [Zapier account](https://zapier.com/app/dashboard).
2. From the left navigation menu, click **Create** and then click **Zaps** from the optionsavailable.

   Zap will be created with **Trigger** and **Action** flow.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zapier_Google_Docs.gif)

### Connecting Gmail and Document360 in Zapier

To establish a connection between Gmail and Documnet360, follow the below steps:

#### Step 1: Setting up trigger: Connecting Document360

1. In the **Trigger** field, choose **Document360**.
2. On the Setup blade that appears on the right, select a desired event in the **Event** field.
3. Click the **Account** field, and a **Sign-in** window will appear.
4. Enter your sign-in credentials and click **Allow**.

   To generate the API token from the Document360 portal,
5. Navigate to **Settings**() > **Knowledge base portal** > **Extensions** > **Team collaboration**.
6. On the Zapier extension tile, click **Connect**.
7. Click the Copy () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Zapier_Google_docs.gif)
8. Head back to the Zapier window and paste the API token in the field.
9. Click **Yes, Continue to Document360**.

   ![5_Screenshot_Zapier_API_Token_Pasting1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot_Zapier_API_Token_Pasting%281%29.png)
10. You can find the connected Document360 project on the **Connect Document360 account** page.

    If you wish to configure a different account later, you can do that by clicking on Change.
11. Click **Continue**.

#### Test trigger

To test the Document360 trigger,

1. Click **Test trigger** to confirm that the correct account is connected, and the trigger setup is correct.
2. If no error is found, click **Continue**.

   The Document360 account has been successfully linked, and the trigger is set up.

#### Step 2: Setting up action: Connecting Gmail

1. In the **Action** field, choose **Gmail**.
2. On the Setup blade that appears on the right, select the desired event in the **Event** field.
3. Click the **Account** field and a **Sign-in** window appears.
4. Enter your sign-in credentials and click **Allow**.
5. Click **Continue**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Gmail_extension.png)

#### Step 3: Customize Zap

1. Map all the required fields:

* **To**: Enter the recipient's email address. Multiple addresses can be added individually or as a comma-separated list.
* **Cc**: Add email addresses to copy recipients on this email. Multiple addresses can also be added individually or as a comma-separated list.
* **Bcc**: Enter email addresses to blind-copy recipients on this email. Multiple addresses can be added similarly.
* **Subject**: Enter the subject line for the email.
* **From**: Choose an email address or alias linked to your Gmail account.
* **From Name**: Enter the sender's name (must be associated with the connected email address).
* **Body type**: Select the email format as either **Plain Text** or **HTML**.
* **Body**: Write the main content of the email.
* **Add signature default**: Optionally, include a default signature in the email.
* **Label or mailbox**: Select a value for label or mailbox.
* **Attachments**: Attach files by selecting an actual file or providing a public URL to download and attach the file.

> NOTE
>
> Fields marked as required (\*) must be filled in.

2. Once done, click **Continue**. The button enables only when all the fields are filled.

#### Step 4: Test Zap

1. In the test section, click **Test step**.
2. If it is successful, you will get the message ‘*A Draft was sent to Gmail.*’

   In your Document360 Knowledge base portal, you'll find the article located in the category you have previously selected.
3. Head back to the Zapier setup window and click **Next**.
4. Once done, click **Publish**.

#### Turn on Zap

To turn on a Zap once it is tested and published, follow the below steps:

1. After testing the Zap, review or edit the settings before turning on the Zap.
2. You can edit the settings configured on the **Gmail** trigger and the corresponding action of the new article in **Document360**.
3. You will get a success message stating **Your Zap is on**. You can click on the **Manage your Zap** button to go to your Zap overview page.

---

## Zap overview

### Send emails via Gmail with new articles in Document360

You can view and edit the information about the Zaps created on the Zap overview page.  
![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-Gmail_extension.png)

### Deleting a Zap

To delete a Zap that you have created,

1. Navigate to the **Zapier dashboard**. On the overview page, a list of all existing Zaps will be displayed.
2. Click the **Zap actions** () icon to the right of the desired Zap and click **Delete**.

   The selected Zap will be deleted.

<a id="document360-mailchimp"></a>

## Integrating Mailchimp with Document360

**Plans supporting integration of Zapier extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Mailchimp is a marketing platform used by organizations worldwide for effective email communication and audience engagement. It offers an all-in-one solution for creating, sharing, and managing emails, advertisements, and other messages tailored to your audience's preferences. With powerful tools, Mailchimp enables users to maintain an up-to-date contact list, track subscriber interactions, and gain insights into audience behavior, ensuring data-driven marketing strategies.

---

## Integrating **Document360** with Mailchimp

Using **Document360** as your knowledge base platform and Mailchimp as your marketing tool, you may encounter a need to keep your audience informed about updates to your knowledge base. The **Document360**-Mailchimp integration streamlines this process by automatically creating or updating campaigns in Mailchimp whenever new content is added or updated in your **Document360** knowledge base. This ensures timely communication, reduces manual effort, and keeps your audience engaged with the latest information.

To establish a connection between Mailchimp and Document360, follow the below steps:

1. Ensure that you have logged into your [Zapier account](https://zapier.com/app/dashboard).
2. From the left navigation menu, click **Create** and then click **Zaps** from the optionsavailable.

   Zap will be created with **Trigger** and **Action** flow.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Zapier_Google_Docs.gif)

### Connecting Gmail and **Document360** in Zapier

To establish a connection between Gmail and Document360, follow the below steps:

#### Step 1: Setting up trigger: Connecting **Document360**

1. In the **Trigger** field, choose **Document360**.
2. On the Setup blade that appears on the right, select a desired event in the **Event** field.
3. Click the **Account** field, and a **Sign-in** window will appear.
4. Enter your sign-in credentials and click **Allow**.

   To generate the API token from the Document360 portal,
5. Navigate to **Settings**() > **Knowledge base portal** > **Extensions** > **Team collaboration**.
6. On the Zapier extension tile, click **Connect**.
7. Click the Copy () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Zapier_Google_docs.gif)
8. Head back to the Zapier window and paste the API token in the field.
9. Click **Yes, Continue to Document360**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Zapier_Google_docs.gif)
10. You can find the connected Document360 project on the **Connect Document360 account** page.

    If you wish to configure a different account later, you can do that by clicking on Change.
11. Click **Continue**.

#### Step 2: Setting up action: Connect Mailchimp

1. In the **Action** field, choose **Mailchimpmail**.
2. On the Setup blade that appears on the right, select the desired event in the **Event** field.
3. Click the **Account** field and a **Sign-in** window appears.
4. Enter your sign-in credentials and click **Allow**.
5. Click **Continue**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Mailchimp.png)

#### Step 3: Customize Zap

1. Map all the required fields:

* **Audience**: Choose the audience group you want to target for the campaign.
* **Segment or Tag**: Specify the segment or tag to filter your audience. If left blank, the campaign will be sent to the entire selected audience.
* **Email Subject**: Enter the subject line for your email.
* **Preview Text**: Add a snippet that will appear alongside the subject line in recipients' inboxes.
* **From Name**: Set a custom sender name (must be associated with the connected email address).
* **From Email address**: Select the email address or alias from your connected Gmail account.
* **Template**: Choose a template or supply HTML content for the email. If both options are left blank, the campaign draft will not include any content.
* **Email content (HTML)**: Choose a template or provide HTML content. Only one option can be selected; if both are left blank, the campaign draft will have no content.

> NOTE
>
> Fields marked as required (\*) must be filled in.

#### Step 4: Test Zap

1. In the test section, click **Test step**.
2. If it is successful, you will get the message ‘*A Draft was sent to your mail.*’

   In your Document360 Knowledge base portal, you'll find the article located in the category you have previously selected.
3. Head back to the Zapier setup window and click **Next**.
4. Once done, click **Publish**.

#### Turn on Zap

To turn on a Zap once it is tested and published, follow the below steps:

1. After testing the Zap, review or edit the settings before turning on the Zap.
2. You can edit the settings configured on the **Mailchimp** trigger and the corresponding action of the new article in **Document360**.
3. You will get a success message stating **Your Zap is on**. You can click on the **Manage your Zap** button to go to your Zap overview page.

---

## Zap overview

### Create campaigns in Mailchimp from new articles in **Document360**

You can view and edit the information about the Zaps created on the Zap overview page.  
![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-Gmail_extension.png)

### Deleting a Zap

To delete a Zap that you have created,

1. Navigate to the **Zapier dashboard**. On the overview page, a list of all existing Zaps will be displayed.
2. Click the **Zap actions** () icon to the right of the desired Zap and click **Delete**.

   The selected Zap will be deleted.

<a id="make-setup-guide"></a>

## Make - Setup guide

**Plans supporting integration of Make extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Make** (formerly Integromat) is an online automation platform that connects **Document360** with various third-party tools and applications. It serves as a bridge to create automated workflows, known as Scenarios, that operate seamlessly through predefined triggers and actions.

### Prerequisites

* You must have an active **Make** account to begin with or [**sign up**](https://us2.make.com/organization) for one.
* An account in the third-party application you wish to connect with **Document360** using **Make** (for example, Google Docs, Typeform, and more.)

## API key generation in **Document360**

To generate an API key in the Document360 portal, follow the below steps:

1. Navigate to the desired **Document360** project.
2. Navigate to **Settings** ()>**Knowledge base portal**>**Extensions**>**Team collaboration**.
3. On the **Make** extension tile, click **Connect**.
4. A **Make details** popup appears with a generated **Token**.
5. Click the **Copy** () icon.

This API key will be used to connect the Document360 Knowledge base with third-party applications on **Make**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Make_extension.png)

---

## **Make** use cases for **Document360**

Below are some useful **Make** integrations that can enhance your experience with **Document360** by connecting it to popular tools:

* [Integrating Asana with Document360](/help/docs/asana-document360)
* [Integrating Monday.com with Document360](/help/docs/mondaycom-document360)
* [Integrating Typeform with Document360](/help/docs/typeform-document360)
* [Integrating Google Docs with Document360](https://docs.document360.com/docs/google-docs-and-document360-integration)
* [Integrating Jira with Document360](/help/docs/jira-and-document360-integration)

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="asana-and-document360-integration"></a>

## Integrating Asana with Document360

**Plans supporting integration of Make extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Asana** is a versatile platform designed for organizing, tracking, and managing work efficiently. It allows teams to create and manage tasks under various projects, streamlining collaboration and ensuring accountability. For documentation teams comprising writers, editors, and external content contributors, **Asana** provides a centralized space to coordinate efforts, track progress, and maintain clarity across projects.

---

## Integrating **Asana** with **Document360**

To integrate Asana with Document360,

1. Ensure that you have logged into your [Make account](https://www.make.com/).
2. Click **Sign in** at the top to log in to your **Make** account.

   The **Make** dashboard will appear.

![1_Screenshot-Make_signin_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733464343369.png)

### Step 1: Create a new scenario

1. Click **Create a new scenario** at the top right.
2. Click the add (**+**) icon, and a list of available applications appears.
3. In the Search field, type in the app name, **Asana**.
4. Select **Asana** and choose the desired task you wish to map with **Asana**.

   For example, select **Watch Tasks or subtasks** to get updates on the new tasks.
5. Click **Create a connection** and enter a connection name.
6. Click **Save**.
7. Allow **Asana** to access your **Make** account by clicking **Allow**.
8. Click **OK**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Asana_Make.gif)

### Step 2: Connecting **Asana**

Connect your **Asana** account with the new scenario in the **Asana** module.

![2_Screenshot-Asana_task_details](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733466870362.png)

1. Select a connection in the **Connection** field. If you have already connected **Asana** with **Make**, select the desired connection.
2. Click the **Filter** dropdown and select **Project**.
3. Click the **Workspace** dropdown and select the desired workspace.
4. Click the **Project ID** dropdown and select the project for which you want to track the tasks.
5. Click the **Completed Since** field and enter the date in the `MM/DD/YYYY HH:MM` format to only return tasks that are either incomplete or that have been completed since the mentioned time.
6. Click the **Modified Since** field and enter the date in the *MM/DD/YYYY HH:MM* format to only return tasks that have been modified since the given time.
7. In the **Limit** field, enter the maximum number of tasks that **Make** will return during one execution cycle.
8. Click **OK**.
9. In the **Choose where to start** popup, select the date/time from when you want to start watching new tasks.
10. Click **Ok**.

Your **Asana** account is now connected with **Make**.

### Step 3: Connecting **Document360**

Once you have connected **Asana** with **Make**, the next step is to link your **Document360** account.

![3_Screenshot-Asana_add_new_module](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733468868456.png)

1. On the **Integration Asana** page, click the **Add another module** (+) option.
2. In the Search field, enter **Document360**.
3. Select **Document360** and select the action you want to perform in **Document360**.

   For example, you can select **Create an article** to create a draft article.
4. In the **Document360** window, select the connection that you have already connected.  
   To create a new connection,

   1. Click **Create a connection** and enter the **Connection name**.
   2. Enter your API key and click **Save**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGif-Asana_Make.gif)
5. To generate the API token from the **Document360** portal,
6. Navigate to **Settings** () > **Knowledge base portal**> **Extensions** > **Team collaboration**.
7. On the **Make** extension tile, click **Connect**.
8. Click the **Copy** () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Asana_Make.gif)
9. Head back to the **Make** window and paste the API token in the field.
10. Click the **Article Title** field and select the parameters you want as the title of your **Document360** article.

    For example, you can select the Task name parameter and retrieve the task name as the title of your **Document360** article.
11. Click the **Article Content** field and select the parameters you want as the content of your **Document360** article.

    For example, you can select the Assignee Name, Resource Type, and Due On parameters.
12. From the **Project Category ID** dropdown, select the category where you want the new article to be created.
13. Click **OK**.

    ![4_Screenshot-Document360_asana_module](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733472905161.png)

### Step 4: Test the scenario

To test the scenario before activating and publishing,

1. Click the **Run once** button at the bottom left to test your scenario.

   The test details appear at the bottom of the page.
2. To test the scenario, create a new task in the associated **Asana** project.
3. Once you create the task, a new article will be created in the associated **Document360** category.

   You can verify this with the test details at the bottom of the page. If required, you can also navigate to the **Document360** project and check the newly created article.

### Step 5: Schedule the scenario

1. To schedule your scenarios, enable the toggle at the bottom left.

   Turning on this toggle will run the scenario every 15 minutes.
2. Once done, click **OK** to save.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenShot-Asana_Make.png)

### Step 6: Activate the scenario

1. Click the **Exit editing** () icon at the top.

   The integration dashboard page will appear.
2. Turn on the **ON/OFF** toggle near the **Edit** option, to activate the scenario.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenShot-Asana_Make.png)

   Once activated, your scenario will run according to the set schedule.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="monday-document360-integration"></a>

## Integrating Monday.com with Document360

**Plans supporting integration of Make extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Many organizations rely on [Monday.com](http://Monday.com) to efficiently organize, track, and manage their work across teams. With its versatile boards and customizable workflows, it enables teams to handle diverse tasks and projects seamlessly. For example, a documentation team comprising writers, editors, and external content agencies can use Monday.com to streamline content creation and collaboration processes effectively.

---

## Integrating Monday.com with **Document360**

To integrate [Monday.com](http://Monday.com) with **Document360**,

1. Ensure that you have logged into your [Make account](https://www.make.com/).
2. Click **Sign in** at the top to log in to your **Make** account.

   The **Make** dashboard will appear.

![1_Screenshot-Make_signin_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733728223372.png)

### Step 1: Create a new scenario

1. Click **Create a new scenario** at the top right.
2. Click the add (**+**) icon, and a list of available applications appears.
3. In the Search field, type in the app name, Monday.com.
4. Select Monday.com and choose the desired task you wish to map with Monday.com.

   For example, select **Watch Board’s Column Values** to get triggers when the board’s column values have changed.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreeGif-Monday.com_Make.gif)

### Step 2: Connecting Monday

1. Click **Create a webhook** and enter a webhook name.
2. Click **Create a connection** and enter a connection name.
3. Enter the API token in the **API Key** field.
4. Click **Save**.
5. Allow Monday.com to access your **Make** account by clicking **Allow**.
6. Click **OK**.

   To obtain the **API v2 Token** from the Monday.com profile,
7. Navigate to **Profile** > **Administration**.
8. From the left navigation sidebar, click **Connections**.
9. Under the **API** tab, click the Copy () icon to copy the personal API token.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Generating_API_token_in_Monday_com.gif)

### Step 3: Connecting **Document360**

Once you have connected Monday.com with **Make**, the next step is to link your **Document360** account.

1. On the **Integration Monday** page, click the **Add another module** (+) option.

![3_Screenshot-Monday_add_module](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733729853164.png)

2. In the Search field, enter **Document360**.
3. Select **Document360** and select the action you want to perform in **Document360**.

   For example, you can select **Create an article** to create a draft article.
4. In the **Document360** window, select the connection that you have already connected.  
   To create a new connection,

   1. Click **Create a connection** and enter the **Connection name**.
   2. Enter your API key and click **Save**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGif-Monday.com_Make.gif)

   To generate the API token from the **Document360** portal,
5. Navigate to **Settings** () > **Knowledge base portal**> **Extensions** > **Team collaboration**.
6. On the **Make** extension tile, click **Connect**.
7. Click the **Copy** () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Asana_Make.gif)
8. Head back to the **Make** window and paste the API token in the field.
9. Click the **Article ID** field and select the required option from the list.
10. In the **Text to Append** field, enter the details required to setup the connection:

    * Group title
    * Item name
    * Update at
    * Assignee
    * Status
11. Click **OK**.  
    ![4_Screenshot-Monday_Document360_make_module](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733734467420.png)

### Step 4: Test the scenario

To test the scenario before activating and publishing,

1. Click the **Run once** button at the bottom left to test your scenario.

   The test details appear at the bottom of the page.
2. To test the scenario, create a new task in the associated Monday.com project.
3. Once you create the task, a new article will be created in the associated **Document360** category.

   You can verify this with the test details at the bottom of the page. If required, you can also navigate to the **Document360** project and check the newly created article.

### Step 5: Schedule the scenario

1. To schedule your scenarios, enable the toggle at the bottom left.

   Turning on this toggle will run the scenario immediately as the data arrives.
2. Once done, click **OK** to save.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenShot-Monday.com_Make.png)

### Step 6: Activate the scenario

1. Click the **Exit editing** () icon at the top.

   The integration dashboard page will appear.
2. Turn on the **ON/OFF** toggle near the **Edit** option, to activate the scenario.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenShot-Monday.com_Make.png)

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="typeform-and-document360-integration"></a>

## Integrating Typeform with Document360

**Plans supporting integration of Make extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Typeform is a versatile platform for creating interactive forms, surveys, and quizzes. It offers an intuitive interface and engaging design to help businesses collect user feedback, conduct surveys, and gather data in a conversational format. Typeform is commonly used to gather questions from customers or prospects through engaging forms and surveys.

## Integrating Typeform with **Document360**

To integrate Typeform with Document360,

1. Ensure that you have logged into your [Make account](https://www.make.com/).
2. Click **Sign in** at the top to log in to your **Make** account.

   The **Make** dashboard will appear.

![1_Screenshot-Make_signin_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733737804012.png)

### Step 1: Create a new scenario

1. Click **Create a new scenario** at the top right.
2. Click the add (**+**) icon, and a list of available applications appears.
3. In the Search field, type in the app name, Typeform.
4. Select Typeform and choose the desired task you wish to map with Typeform.

   For example, select **Watch Responses** to get triggers when a new response is submitted.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Typeform_Make.gif)

### Step 2: Connecting Typeform

Connect your Typeform account with the new scenario in the Typeform module.

![2_Screenshot-Typeform_watch_new_response](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733740477517.png)

1. Click **Create a connection** and enter the **Connection name**.
2. Click **Save**.
3. Allow Typeform to access your **Make** account by clicking **Accept**.

   Your Typeform account will be connected to **Make**.
4. In the **Limit** field, enter the maximum number of responses that **Make** will return during one execution cycle.
5. Click the **Form ID** dropdown and select the form you want to watch the responses.
6. If you want the data only when specific fields are filled, add the desired fields with the **Add item** in the **Fields** section.
7. In the **Completed** section:

   * Select the **Yes** option to watch only forms that are submitted.
   * Select the **No** option to watch only forms that are not submitted.
   * Select the **Empty** option to watch only forms with empty responses.
8. In the **Query** field, enter the text string to watch only responses that contain the entered text.
9. Click **OK**.
10. In the **Choose where to start** popup, select the date/time from when you want to start watching new responses.
11. Click **OK**.

### Step 3: Connecting Document360

Once you have connected Typeform with **Make**, the next step is to link your **Document360** account.

![3_Screenshot-New_module_typeform](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733740624575.png)

1. On the **Integration Typeform** page, click the **Add another module** (+) option.
2. In the Search field, enter **Document360**.
3. Select **Document360** and select the action you want to perform in **Document360**.

   For example, you can select **Create an article** to create a draft article.
4. In the **Document360** window, select the connection that you have already connected.

   To create a new connection,

   1. Click **Create a connection** and enter the **Connection name**.
   2. Enter your API key and click **Save**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGif-Typeform_Make.gif)

   To generate the API token from the **Document360** portal,
5. Navigate to **Settings** () > **Knowledge base portal**> **Extensions** > **Team collaboration**.
6. On the **Make** extension tile, click **Connect**.
7. Click the **Copy** () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Asana_Make.gif)
8. Head back to the **Make** window and paste the API token in the field.
9. Click the **Article Title** field and select the parameters you want as the title of your **Document360** article.

   For example, you can select the Task name parameter and retrieve the task name as the title of your **Document360** article.
10. Click the **Article Content** field and select the parameters you want as the content of your **Document360** article.

    For example, you can select the Assignee Name, Resource Type, and Due On parameters.
11. From the **Project Category ID** dropdown, select the category where you want the new article to be created.
12. Click **OK**.

### Step 4: Test the scenario

To test the scenario before activating and publishing,

1. Click the **Run once** button at the bottom left to test your scenario.

   The test details appear at the bottom of the page.
2. To test the scenario, create a new task in the associated Typeform project.
3. Once you create the task, a new article will be created in the associated **Document360** category.

   You can verify this with the test details at the bottom of the page. If required, you can also navigate to the **Document360** project and check the newly created article.

### Step 5: Schedule the scenario

1. To schedule your scenarios, enable the toggle at the bottom left.

   Turning on this toggle will run the scenario every 15 minutes.
2. Once done, click **OK** to save.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenShot-Typeform_Make.png)

### Step 6: Activate the scenario

1. Click the **Exit editing** () icon at the top.

   The integration dashboard page will appear.
2. Turn on the **ON/OFF** toggle near the **Edit** option, to activate the scenario.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenShot-Typeform_Make.png)

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="google-docs-and-document360-integration"></a>

## Integrating Google Docs with Document360

**Plans supporting integration of Make extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Many organizations around the world use Google Docs as a document management tool. Google, as a platform, offers a more integrated environment where managing multiple forms of documents and files is rather easy.

---

## Integrating **Document360** with Google Docs

To integrate Google Docs with **Document360**,

1. Ensure that you have logged into your [Make account](https://www.make.com/).
2. Click **Sign in** at the top to log in to your **Make** account.

   The **Make** dashboard will appear.

![1_Screenshot-Make_signin_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733745491436.png)

### Step 1: Create a new scenario

1. Click **Create a new scenario** at the top right.
2. Click the add (**+**) icon, and a list of available applications appears.
3. In the Search field, type in the app name, Google Docs.
4. Select Google Docs and choose the desired task you wish to map with Google Docs.

   For example, select **Watch documents** to monitor the new articles created in the Knowledge base.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Google_docs_Make.gif)

### Step 2: Connecting Google Docs

Connect your Google Docs account with the new scenario in the Google Docs module.

1. Click **Create a connection** and enter the **Connection name** or select a connection name from the dropdown if you have one already.
2. From the **Watch Documents** dropdown, select either **By Created Date** or **By Modified Date**.
3. From the **Choose a Drive** dropdown, select the desired drive folder where you want to create the document.
4. In the **Folder ID** field, choose the folder ID where you wish to store your document.
5. In the **Limit** field, enter the maximum number of results to be worked with during one execution cycle.
6. Click **OK** to save.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-Google_docs_Make.png)

### Step 3: Connecting **Document360**

Once you have connected Google Docs with **Make**, the next step is to link your **Document360** account.

1. On the **Integration Google Docs** page, click the **Add another module** (+) option.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenShot-Google_docs_Make.png)
2. In the Search field, enter **Document360**.
3. Select **Document360** and select the action you want to perform in **Document360**.

   For example, you can select **Create an article** to create a draft article.
4. In the **Document360** window, select the connection that you have already connected.

   To create a new connection,

   1. Click **Create a webhook** and enter the desired webhook name.
   2. Click **Create a connection** and enter the desired connection name.
   3. Enter your API key and click **Save**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGif-Google_docs_Make.gif)

   To generate the API token from the **Document360** portal,
5. Navigate to **Settings** () > **Knowledge base portal**> **Extensions** > **Team collaboration**.
6. On the **Make** extension tile, click **Connect**.
7. Click the **Copy** () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Asana_Make.gif)
8. Head back to the **Make** window and paste the API token in the field.

### Step 4: Test the scenario

To test the scenario before activating and publishing,

1. Click the **Run once** button at the bottom left to test your scenario.

   The test details appear at the bottom of the page.
2. To test the scenario, create a new task in the associated Google Docs project.
3. Once you create the task, a new article will be created in the associated **Document360** category.

   You can verify this with the test details at the bottom of the page. If required, you can also navigate to the **Document360** project and check the newly created article.

### Step 5: Schedule the scenario

1. To schedule your scenarios, enable the toggle at the bottom left.

   Turning on this toggle will run the scenario every 15 minutes.
2. Once done, click **OK** to save.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_ScreenShot-Google_docs_Make.png)

### Step 6: Activate the scenario

1. Click the **Exit editing** () icon at the top.

   The integration dashboard page will appear.
2. Turn on the **ON/OFF** toggle near the **Edit** option, to activate the scenario.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_ScreenShot-Google_docs_Make.png)

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="jira-and-document360-integration"></a>

## Integrating Jira with Document360

**Plans supporting integration of Make extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Jira service desk, a product of Atlassian aims to deliver great service experiences and ensures your employees and customers can get help quickly. Jira provides extensive functionalities for service desk management, analytics, request queues, and integration with major team collaboration platforms.

---

## Integrating Jira with **Document360**

To integrate Jira with **Document360**,

1. Ensure that you have logged into your [Make account](https://www.make.com/).
2. Click **Sign in** at the top to log in to your **Make** account.

   The **Make** dashboard will appear.

![1_Screenshot-Make_signin_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733814317319.png)

### Step 1: Create a new scenario

1. Click **Create a new scenario** at the top right.
2. Click the add (**+**) icon, and a list of available applications appears.
3. In the Search field, type the app name Jira Cloud Platform.
4. Select **Jira Cloud Platform** and choose the task you wish to map with Jira.

   For example, select **Watch Issues** to get triggers when a new response is submitted.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Jira_Make.gif)

### Step 2: Connecting Jira

Connect your Jira account with the new scenario in the Jira module.

1. Click **Create a webhook** and enter the desired **Webhook name**.
2. Click **Create a connection** and enter the **Connection name**.
3. Enter the **Service URL**.
4. Enter the **Username** and **API Token**.
5. Click **Save**.
6. From the **Watch Issues** dropdown select the desired option you want to track.
7. From the **Select a Method** dropdown and select the desired option with which you want to search the issues.
8. If required, select the desired filters in **Filter**, **Expand**, and **Fields**.
9. In the **Limit** field, enter the maximum number of tasks Make will return during one execution cycle.
10. Click **OK**.
11. In the **Choose where to start** popup, select the date/time from when you want to start watching new issues.
12. Click **OK**.

    ![2_Screenshot-Jira_make_popup_window](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1733815745423.png)

    Your Jira project is now connected with Make.

### Step 3: Connecting **Document360**

Once you have connected Jira with **Make**, the next step is to link your **Document360** account.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenShot-Jira_Make.png)

1. On the **Integration Jira** page, click the **Add another module** (+) option.
2. In the Search field, enter **Document360**.
3. Select **Document360** and select the action you want to perform in **Document360**.

   For example, you can select **Create an article** to create a draft article.
4. In the **Document360** window, select the connection that you have already connected.

   To create a new connection,

   1. Click **Create a connection** and enter the **Connection name**.
   2. Enter your API key and click **Save**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Jira_Make.gif)

   To generate the API token from the **Document360** portal,
5. Navigate to **Settings** () > **Knowledge base portal**> **Extensions** > **Team collaboration**.
6. On the **Make** extension tile, click **Connect**.
7. Click the **Copy** () icon to copy the token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Asana_Make.gif)
8. Head back to the **Make** window and paste the API token in the field.
9. Click the **Article Title** field and select the parameters you want as the title of your **Document360** article.

   For example, you can select the Task name parameter and retrieve the task name as the title of your **Document360** article.
10. Click the **Article Content** field and select the parameters you want as the content of your **Document360** article.

    For example, you can select the Assignee Name, Resource Type, and Due On parameters.
11. From the **Project Category ID** dropdown, select the category where you want the new article to be created.
12. Click **OK**.

### Step 4: Test the scenario

To test the scenario before activating and publishing,

1. Click the **Run once** button at the bottom left to test your scenario.

   The test details appear at the bottom of the page.
2. To test the scenario, create a new task in the associated Jira project.
3. Once you create the task, a new article will be created in the associated **Document360** category.

   You can verify this with the test details at the bottom of the page. If required, you can also navigate to the **Document360** project and check the newly created article.

### Step 5: Schedule the scenario

1. To schedule your scenarios, enable the toggle at the bottom left.

   Turning on this toggle will run the scenario immediately as the data arrives.
2. Once done, click **OK** to save.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenShot-Jira_Make.png)

### Step 6: Activate the scenario

1. Click the **Exit editing** () icon at the top.

   The integration dashboard page will appear.
2. Turn on the **ON/OFF** toggle near the **Edit** option, to activate the scenario.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenShot-Jira_Make.png)

Application Programming Interface - A set of rules that allows one software application to communicate with another.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="chrome-extension"></a>

## Chrome

**Plans supporting integration of Chrome extensions with Document360**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Chrome** is a widely used and free cross-platform web browser. The Chrome Web Store offers various extensions to aid in various functions.

> Extensions are the small software programs that enable users to tailor browser functionality and behavior to individual needs or preferences.

The [Document360 extension](https://chromewebstore.google.com/detail/document360/lifhmbmenhhiolpbbahnjicckcnnophl) is now available in the Chrome web store and can be added to the browser.

With the Document360 Google Chrome Extension and access to the API key, we can connect, access, and look up the articles and page categories from your knowledge base within your browser anytime, anywhere.

## Chrome extension: setup

### Adding the Document360 extension in Chrome

1. Open the Chrome browser application on your system and navigate to the [Chrome Web Store](https://chromewebstore.google.com/).
2. Browse or search the Document360 extension and click on it.  
    On the description page, the details can be viewed.
3. Click **Add to Chrome** to add the extension.
4. A pop-up would appear, click **Add extension**.

![1_Screenvideo-Chrome_Extension_Adding.gif](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenvideo-Chrome_Extension_Adding.gif)

You can always manage your extension settings:

5. On the Chrome page, click More()> **Extensions** > **Manage Extensions**, and all the available extensions will be listed.

   > NOTE
   >
   > * You can add or remove extensions in the Chrome browser only when logged in with your Google account.
   > * Also, you’ll be unable to add Chrome extensions as a guest user.
   > * If you want to access the extension in the Incognito window, go to **Manage extensions** and **turn on** the **Allow in Incognito** option.

### **API key configuration**

1. Click on the Document360 icon from the launcher at the top. A side window appears with the required field for the API key.

![5_Screenshot-API_Key.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-API_Key.png)

2. Navigate to the desired Document360 portal.
3. Navigate to Settings ()> **Knowledge base portal** > **Extensions**, and all the available extensions will be listed.
4. In the **Chrome extension**, click **Details**.
5. The **Chrome details** pop-up appears with an **Internal integration token** key.
6. Copy the generated key by clicking on the clipboard () icon.
7. Now paste the key into the Document360 launcher on Chrome and click **Save**.

   Now your Knowledge base would be integrated and available anywhere and anytime on your Chrome browser.

## Feature highlights

**Easy launch and customization**

* Once the Document360 Chrome extension has been successfully integrated using the API key, you can easily launch the Document360 assistant in your Chrome window.
* When you open a new Chrome tab or window, click on the Document360 icon in the extension toolbar at the top to launch it.
* You can also toggle the assistant either to the left or right side of the window. The default mode will be the right side.

![2_ScreenVideo-Document360_Extension.gif](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenVideo-Document360_Extension%282%29.gif)

### **Quick launch label**

* If you close the Document360 assistant, you can find the Document360 quick launch label on the right side of your browser window.
* Click on the label to launch the assistant on the same Chrome tab.
* You can drag the label along the vertical axis and position it in your convenient spot.
* You can also remove the label by hovering your mouse pointer over the label and clicking on theClose (**X**) button.

### **Page Help**

* This is the default tab when you launch the Document360 extension.
* You can find the top-searched articles listed based on your previous searches on the knowledge base.
* You can also search for articles using keywords. Just type in your search term in the field. As you type, the relevant search results for articles will be listed. Select the article, and you can view the entire article in the reader view.

The options available in the reader view are

1. Copy (): Click on the copy icon to copy the content of the entire article to your clipboard.
2. Open in new tab (): This option would open the article location on your knowledge base in a new browser tab.
3. Expand (): This option would expand your reader view screen and not a full-screen view.

![3_Screenshot-PageHelp.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-PageHelp.png)

### **Knowledge base view**

* Click on the **Document360** launcher icon on the Chrome window and select the **Knowledge base** tab in the assistant window.
* This option will give you access to the entirety of the integrated knowledge base. You can browse through the various categories, subcategories, and articles inside the assistant itself.
* This would be an exact copy of the tree-view structure of the integrated knowledge base.
* You can click on the articles and view the content from the reader's point of view.

## **Removing the Document360 extension in Chrome**

To remove the Document360 extension from your Chrome browser, you can either visit the Document360 page in the Chrome Web Store, click on the **Remove from Chrome button**, or click **Remove** again in the prompt.

or  
Right-click on the Document360 launcher icon in the Chrome window, select the **Remove from Chrome** option and click **Remove** in the prompt.

![4_Scrrenvideo-Removing_Doc360.gif](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Scrrenvideo-Removing_Doc360.gif)

---

## FAQ

**What can be accessed through the Document360 Google Chrome extension?**

You can access articles and page categories from your Document360 knowledge base directly in the Chrome browser. The extension provides a search feature, allows you to view articles, and offers quick navigation through your knowledge base structure.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="crowdin"></a>

## Crowdin

**Plans supporting Crowdin extension**

| Professional | Business | Enterprise |
| --- | --- | --- |
| **✗** | Add-on | ✔ |

Crowdin is a cloud-based localization management platform that streamlines the translation process, making it more efficient. By integrating Crowdin with Document360, you can automate and enhance the localization of your multilingual knowledge base, combining both machine and human translation to ensure quality and accuracy.

**Prerequisite**

Before starting the integration, ensure that you have an active Crowdin account. If you don't have one, sign up using valid credentials.

---

## Basic setup guide

### Creating a project in Crowdin

To use the Crowdin platform as a translation partner with Document360 for content translation, ensure you are a registered user of Crowdin on an enterprise account.

1. Log in to your [Crowdin enterprise account](https://accounts.crowdin.com/workspace/choose?continue=%2Fenterprise) and go to your Crowdin workspace.
2. Click **Create Project** on the right of the screen to initiate the setup.
3. In the project field, enter the name of your project.

> NOTE
>
> We recommend having project names be the same to make the **Push to Crowdin** option work seamlessly in Document360. If you choose to have different names in Document360 and Crowdin, follow the below steps.
>
> 1. Create a project in Document360 and Crowdin with the same names.
> 2. Enable the extension for Crowdin in Document360 by creating the Crowdin API key. The project name must be the same to validate the API key. Document360 will not allow the storage of invalid API keys.
> 3. Now, you can choose to change the names.

4. Next, select the source language of your project.

> NOTE
>
> Similar to the project address, the source language cannot be changed once submitted.

5. Select the target languages that are added to the versions in your project.
6. Choose a workflow that maps out the flow of content within your project.
7. Click **CREATE PROJECT**.

### 2_Screenvideo-Creating_a_Project_in_crowdin.gif

### Document360 integration with the Crowdin project

To integrate Document360 with your Crowdin project follow the steps below.

1. Go to Settings ()> **Knowledge base portal** > **API Tokens**.
2. Click **New API Token** or **Create API token** if this is the first token you are creating.
3. Enter the **Token name** in the field.
4. Select the options required in the **Allowed Method(s)** field (GET, POST, PUT, DELETE).
5. Click **Generate** and copy the generated API token.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Crowdin_extension.gif)
6. Next, return to the Crowdin integration webpage.
7. Select the created Crowdin project, and you will be taken to the project dashboard.
8. On the dashboard side menu, go to **Integration.**
9. From the list of integration options available, select the **Document360** application.
10. Now, the application requires an API token from Document360. **Paste** the copied API token.
11. Click **Log in with Document360.**

    ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Crowdin.png)

> NOTE
>
> Machine translations are enabled for each project on **Crowdin**, with **Crowdin Translate** as the default translation engine. If you want to change the translation engines, it is required to configure them before the project members can use them. Some of the other translation engines supported by Crowdin are
>
> * MT Engine IDs
> * Microsoft Translator
> * Yandex Translate
> * DeepL Translator
> * Watson (IBM) Translator
> * ModernMT
> * Amazon Translate
> * Google Translate
> * Google Cloud AutoML Translation
>
> [Click here](https://support.crowdin.com/configuring-machine-translation-engines/#:~:text=By%20default%2C%20machine%20translations%20are,suggestions%20in%20the%20project%20settings.) to learn more about how to configure machine translation engines on Crowdin.

### Acquiring API token from Crowdin

From your Crowdin workspace, select the Crowdin project configured with your Document360 knowledge base.

1. From the top right corner, click **Profile** > **Account settings**.
2. Select the **Access tokens**, and in the **Personal Access Tokens** section, click **New Token**.
3. Enter the **token name** and select **All scopes.**
4. Click **Create**.
5. Your access token has been created. **Copy** the generated token.

### Integrating with Document360

1. Head back to **Document360**, navigate to Settings ()> **Knowledge base portal** > **Extensions**
2. Under the **Translation & Browser extension** tab, select **Crowdin**.
3. **Paste** the copied access token in the API key section.
4. Enter the organization name from your Crowdin account.
5. Click **Save**, and you are ready to go.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGif-Crowdin.gif)

You can now use the **Push to Crowdin** option from Document360.

### Feature Highlights

#### Sync categories and articles to Crowdin for translation

You can sync the types and articles from your Document360 project to Crowdin for translation in the Crowdin workspace.

> NOTE
>
> To sync articles seamlessly between Document360 and Crowdin workspace, ensure the project name is the same.

Log in to your Crowdin account and select the Crowdin project configured with your knowledge base.

1. On the dashboard side menu, navigate to **Integration**.
2. You can view the **Crowdin project** and the Document360 project side-by-side.
3. On the Document360 side, you can view the categories and articles from your connected knowledge base.
4. You can search for articles using the search bar.
5. Select the categories and articles you'd like to sync with your Crowdin project for translation.
6. Click the **SYNC TO** option in the Document360 section.

> NOTE
>
> Each article synced with the Crowdin project would have 2 files.
>
> 1. The article content file, mostly in markdown or HTML format.
> 2. The article title file, which is a .txt file.

## Push to Crowdin from Document360

* After you've integrated your Document360 project with your Crowdin project and synced your categories and articles, you can directly use the **Push to Crowdin** feature on Document360.
* For instance, you have synched and translated your articles on your knowledge base using Crowdin. Later, you may make some changes or update the content of your article. Instead of visiting your Crowdin workspace, you can directly click on Push to Crowdin from your Document360 article editor.
* Click on the **Crowdin icon** on top of the article editor. You can find it next to the **See contributor** option.

**Default language**

In the dropdown **Crowdin Sync** info, you can view the time of the **Last push to Crowdin** and the **Push to Crowdin** button.

**Non-Default languages**

* In the dropdown Crowdin Sync info, you can view the time of the Last translation sync from Crowdin, the time of the Last push to Crowdin, and the **Push to Crowdin** button.
* Click the **Push to Crowdin** button, and the latest article content will be synched to your Crowdin project.

> NOTE
>
> Only the categories and articles already synced with the Crowdin project would be able to use the 'Push to Crowdin' feature.

#### **Timestamp feature**

You can now view the timestamp of the translation actions performed on the specific article.

* **Last translation sync from Crowdin**: The timestamp of the recent translation and Push to Document360 action performed from the Crowdin platform.
* **Last push to Crowdin**: The timestamp of the recent Push to Crowdin action from the Document360 side

### Translating your connected Knowledge base articles

* From your Crowdin platform, select the Crowdin project configured with your Document360 knowledge base. On the **Project home**, you can find details about your project.
* You can view the current translation status, make sure any translations are ongoing, and you can also pause the translation.
* Below is the **Home** tab; under the **Translation** section, you can see the list of target languages for your project. Also, you can find individual **progress indicators** adjacent to them.
* If you click on any language, you will be taken to a page that shows a detailed view of the categories and articles pushed to Crowdin from Document360 for translation.
* You can invite members from your team or any external agencies to collaborate on the Crowdin platform. They can directly edit or review the machine-translated content before pushing it back to the Document360 project.

---

## FAQ

**Does the Document360 subscription include Crowdin translation service?**

No, the Document360 subscription does not include the Crowdin translation service. However, you can integrate Document360 with Crowdin for translation purposes.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="phrase"></a>

## Phrase

**Plans supporting Phrase extension**

| Professional | Business | Enterprise |
| --- | --- | --- |
| **✗** | Add-on | ✔ |

Integrating the Phrase extension with Document360 allows you to translate your content into other languages with just a few simple steps. This upgrade facilitates high accuracy, speed, and scalability in your translations. This can lead to the requirement of fewer resources, quicker business effects, and higher customer engagement.

---

## Setting up Phrase Translation Service

Follow the steps to set up the Phrase translation.

1. Navigate to Settings () > **Knowledge base portal** > **Extensions** in the Knowledge base portal.
2. Locate **Phrase** under the **Translation & Browser** section and click **Connect** on the **Phrase** tile.
3. Click **Create New Configuration** to configure the translation service for the available workspace(s).
4. Paste the generated API token from your Phrase account and click **Validate**.

   For detailed instructions on generating an API token in Phrase, whether you have a free account or another type, please refer to the [help article](https://support.phrase.com/hc/en-us/articles/5808341130268-Generate-API-Access-Token-Strings).
5. Select the workspaces where you want to deploy the Phrase translation service.
6. Once done, click **Create**.

> **NOTE**
>
> * **Resync:** The Resync option is used to update the language changes that occurred in the workspace. If you are editing the default language of the workspace, then the translation will not be modified immediately. Then you need to click **Edit configuration > Resync**. Then the Resync function will ensure that the translations are updated to reflect these changes.

![1_ScreenGIF-Setting_up_Phrase_Integration_](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Setting_up_Phrase_Integration_.gif)

---

## Language Configuration

Follow the steps to select the default language to translate the content to the desired language(s).

1. Navigate to **Localization & workspaces** to view the existing workspaces from the Knowledge base portal.
2. Click **Edit** () to change or designate the default language and the language to which you want the articles translated.
3. Click **More** (•••) to the language that you want to edit.
4. Click **Set as default** to enable the selected language to be the default language.
5. Turn on or turn off the **Enable right to left** toggle to change the script orientation.

> NOTE
>
> Script orientation refers to the direction in which text is read and written, such as from left to right (LTR) or from right to left (RTL).
>
> Turn on the **Enable right to left** toggle to change the LTR (Left to Right) script to the RTL (Right to Left) or vice versa.

6. Click **Update** to save the changes.

![2_Screenshot-Language_configuration_localization&Workspace](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Language_configuration_localization&Workspace.png)

---

## Translation Configuration

Follow the steps to configure the translation.

1. Navigate to Settings ()> **Knowledge base portal** > **Extensions** in the Knowledge base portal.
2. Locate **Phrase** and click **Details**.
3. Select the desired Workspace for which you want to configure the translation.
4. Select the language from which you want to translate from the **Translate from** drop-down.
5. Choose the language you want to translate the content from the **Translate to** drop-down.
6. Choose the articles for translation by selecting the checkbox. You can choose an entire category by selecting the checkbox against the category.
7. Click **Translate**.

   > NOTE
   >
   > Here selected articles will be switched over to the Advanced WYSIWYG editor upon translation and cannot be changed back. You can choose to continue or click Continue to terminate the operation.

8. You can view the status of the translation in the **Status** column.
9. Click the **Refresh** () icon to view the article's translation status.
10. You can filter the list of articles based on the status of the article as given below.

    * **Yet to initiate:** Articles that are yet to be translated.
    * **Translated:** Articles that are translated.
    * **Failed:** Failed translations.
    * **In progress:** Article translation is in progress.

![3_Screenshot-Translation_configuration_refresh_filter_translate](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Translation_configuration_refresh_filter_translate.png)

> **NOTE**  
> The translation process can be enabled for single or multiple workspaces.

## Preview Translated Content

1. Navigate to Documentation () and change the workspace language to which the content was translated.
2. Open the specific article and click ( ) **Preview** to preview it if it has not been published.
3. Click **View in knowledge base** (  ) to view the published article, if published.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Phrase_extension.gif)

> NOTE
>
> To use the Phrase translation service extension in Document360, you must subscribe to it. For subscription details, visit Pricing or Request a Demo on the Phrase website.

---

## FAQ

**Can I translate content into any language I choose?**

No, you can only translate content into the languages available in your respective project.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="general-project-settings"></a>

## General project settings

**Plans supporting access to general settings in knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Project settings** page in Document360 allows you to configure various aspects of your knowledge base portal, ensuring that it meets the specific needs of your project and team. From defining project details to customizing editor preferences, managing file formats, and setting analytics rules, these settings give you control over how your knowledge base operates and interacts with external tools.

---

## Accessing the Project settings page

To access the project settings, follow these steps:

1. Navigate to ****Settings** ()** > ****Knowledge base portal**** > ****General****.

### Knowledge base details

2. Enter your project name in the **Project name** field.
3. Select your country from the **Country** dropdown menu.

### Remember state

4. Turn on the **Remember state** toggle to retain and restore the user interface (UI) state from your last interaction within the knowledge base portal.

   For example, if you are working on a specific article and navigate away to check the project settings, when you return to the ****Documentation**** section in the left navigation bar, you will land directly on the article you were working on.

> NOTE
>
> The **Remember state** toggle is enabled by default.

### Editor

5. Choose your default editor from the following options:

   * Select **Markdown** and, if needed, select the **Show line numbers in markdown editor** checkbox to display line numbers in the editor.
   * Select **Advanced WYSIWYG editor** and, if needed, select the **Show outline view in advanced WYSIWYG editor** checkbox.

> NOTE
>
> All the new articles will be created based on these editor choices.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-General_Project_settings_page_!.png)

### Documentation

6. Turn on the **Default review reminder** toggle to enable automatic reminders. Then, enter the number of days after which the reminder should occur.

### Drive settings

7. Choose **Allow all media formats** to permit uploading any media format in the drive.
8. Select **Choose allowed media formats** to restrict uploads to specific media formats.
9. Click **Add**.
10. In the **Add allowed format** panel, enter the **Media type** and **Extension**.
11. To add another media format, click **Add media type**.
12. Once finished, click **Save**.

### Analytics settings

13. To exclude certain IP addresses from project analytics, enter the **Description** and the desired **IP address**.
14. Click the  icon to add the IP restriction.

    A toggle will be created for each IP.
15. Turn off the toggle to remove the restriction.
16. Click the **More ()** icon, then select **Edit** () to update the description or **Delete** () to remove the IP restriction.

### Support access

17. Turn on **Support Access** toggle to grant the support team access to your account for troubleshooting, support, or testing purposes.

> NOTE
>
> To delete your project, please contact our [support](https://document360.com/support/) team.

18. Once done, click **Save** to save the changes.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-General_Project_settings_page_2.png)

---

### FAQs

#### Why should I enable or disable the Remember state feature?

* Enabling Remember state is beneficial for team members who want to keep their last activity within Document360, making it easier to continue their work without losing context.
* Disabling Remember state will reset the view back to the default starting point, which can be useful if you prefer a fresh start every time you navigate back to a section.

**Example:**

* **When enabled:** If you navigate from an article in the ****Documentation**()** section to ****Analytics**()**, then back to the ****Documentation**()** section, you’ll be directed straight to the previously edited article.
* **When disabled:** After switching from the ****Documentation**()** section to ****Analytics**()** and returning, you’ll start from the first article or category in ****Documentation**()**.

#### What scenarios does Remember state apply to in Document360?

1. **Filter**  
   When users switch between modules like ****Drive**()** and ****Analytics**()**, filters they’ve applied are retained for consistent data display.

   **Example:** You’re analyzing articles in Analytics with a custom date range filter. If you navigate to ****Drive**()** and then return to ****Analytics**()**, your custom date range filter remains applied, ensuring the data view remains relevant.
2. **Category manager**   
   Users often expand the category to view subcategories and articles. Remember state retains the category manager’s last position, making it easier to pick up where you left off.

   **Example:** While exploring subcategories in ****Documentation**()**, you expand a category and navigate to ****Analytics**()**. When you return to ****Documentation**()**, the category manager remains expanded in the same position, maintaining your navigation context.
3. **Workspace dropdown**  
   For team members working across multiple workspaces, Remember state preserves the selected workspace even when navigating through other sections.

   **Example:** Suppose you are in ****Analytics**()** under the Beta workspace. You switch to workspace V1, explore the ****Drive**()** section, and then return to ****Analytics**()**. With Remember state enabled, you’ll land back in ****Analytics**()** under workspace V1, maintaining your workspace continuity.

<a id="team-auditing"></a>

## Team auditing

**Plans supporting access to team auditing settings in knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Team auditing** feature allows you to track the actions performed by your team accounts within your Document360 project. For example, you can monitor when a team member adds a new article, updates an existing one, or changes settings in the knowledge base portal. This feature helps ensure accountability, as it logs who performed each action and when, making it easy to trace specific activities, such as restoring an article that was mistakenly deleted or reviewing changes made during a product release.

The **Audit configuration** feature allows you to selectively monitor key actions across your project, helping you stay informed without tracking unnecessary data. This feature is especially useful in projects that require oversight of sensitive information or strict compliance.

For example, a project manager wants to monitor when new articles are published or existing articles are updated, so they turn on the audit configuration for **Documentation editor** events only.

> **NOTE**
>
> Only the **Owner**, **Admin**, and users with a **custom role** who have access to team auditing can view and update the team auditing feature.

---

## Accessing team auditing

1. Navigate to **Settings** () > **Knowledge base portal** > **Team auditing** in the Knowledge base portal.

   By default, **Team auditing** tab will be selected.

   The activity data for all team accounts, including the event, who performed it, the date and time, and the language will appear.

> NOTE
>
> Only 20 audit records are displayed at one instance. Scroll and click **Load more** to view the next set of 20 entries.

2. Use the filters to narrow down the data:

   1. **Events:** View actions performed in specific areas of the project.
   2. **Audit date:** View actions from time period such as 1 year, 3 months, 30 days, 7 days, or set a custom date range.
   3. **Activity by user:** View actions performed by specific team accounts.
3. Click **Refresh** at the top to get the latest updates.
4. Click **Export CSV** to download the report to your local device.

> NOTE
>
> You can use Microsoft Excel, OpenOffice Calc, Google Docs, or other CSV tools to open the exported CSV file.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Auditing_and_Activity_tracking.gif)

---

## Setting up the audit configuration

To set up your audit configuration and tailor what you want to monitor:

1. Navigate to **Settings** () > **Knowledge base portal** > **Team auditing** in the Knowledge base portal.
2. Go to the **Audit configuration** tab.
3. Turn on the **All events** toggle to monitor all project-related events.
4. If you want to monitor only specific modules or events, turn on the toggle for the desired event category from the following modules:

   **a. Documentation editor**

   Tracks events related to documentation editor, such as:

   1. Article visibility changed
   2. Article settings updated
   3. Article slug updated
   4. Article title updated
   5. Article published
   6. Article created
   7. Article renamed
   8. Article deleted
   9. Article forked
   10. Article version deleted
   11. Bulk delete article versions
   12. Updated translation status
   13. Articles reordered
   14. Article contributors updated
   15. Article workflow status updated
   16. Article workflow due date updated
   17. Article workflow assignee updated
   18. Category created
   19. Category type updated
   20. Category settings updated
   21. Category slug changed
   22. Category contributors updated
   23. Category deleted
   24. Category renamed
   25. Categories reordered
   26. Category published
   27. Category forked
   28. Category version deleted
   29. Bulk delete category versions
   30. Category workflow status updated
   31. Category workflow due date updated
   32. Category workflow assignee updated
   33. Category visibility changed
   34. Article review reminder status updated
   35. Article pushed to crowdin
   36. Categories/Articles restored
   37. Categories/Articles permanently deleted
   38. Recycle bin emptied
   39. Shared article created
   40. Share link generated
   41. Share link deleted
   42. Clone article created
   43. Removed reference article
   44. Added glossary
   45. Updated glossary
   46. Deleted glossary
   47. Imported glossary
   48. Multiple shared article created
   49. Article publish later canceled
   50. Article scheduled for publish

   **b. Drive**

   Track events related to Drive actions, such as:

   1. Folder added
   2. Folder renamed
   3. Folder deleted
   4. File(s) added
   5. File updated
   6. File(s) deleted

   **c. Knowledge base portal settings**

   Tracks portal-specific activities, such as:

   1. Workspace updated
   2. Workspace deleted
   3. Workspace created
   4. Workspace display order changed
   5. Plan tier changed
   6. Payment details updated
   7. Project general settings updated
   8. Backup created
   9. Backup restored
   10. Notification channel deleted
   11. Notification channel created
   12. Notification channel updated
   13. Addons purchased
   14. Subscription created
   15. API token added
   16. API token deleted
   17. Extension token generated
   18. Extension token deleted
   19. Crowdin token added
   20. Crowdin token deleted
   21. Email domain deleted
   22. Email domain added
   23. Email address added
   24. Email user name added
   25. Email address updated
   26. Email user name updated
   27. Display workspaces as menu
   28. Subscription cancellation initiated

   **d. Knowledge base site settings**

   Covers site-specific activities, such as:

   1. Site design settings updated
   2. Custom JavaScript updated
   3. Custom CSS updated
   4. Article settings updated
   5. Project sub-domain updated
   6. Integration created
   7. Integration deleted
   8. Integration updated
   9. Home page builder restored
   10. Home page builder settings updated
   11. Robots.txt updated
   12. Site domain updated
   13. Cookie consent enabled
   14. Cookie consent disabled
   15. Cookie consent updated
   16. Smart bar added
   17. Smart bar updated
   18. Smart bar enabled
   19. Smart bar disabled
   20. Smart bar deleted
   21. Read receipt rule created
   22. Read receipt rule updated
   23. Read receipt rule deleted
   24. Ticket deflector deleted
   25. Ticket deflector added
   26. Ticket deflector updated
   27. Ticket deflector helpdesk added
   28. Ticket deflector helpdesk updated
   29. Ticket deflector helpdesk deleted
   30. Article redirection rule added
   31. Article redirect rule updated
   32. Article redirection rule(s) deleted
   33. Redirect rule(s) exported to CSV
   34. Redirect rules import requested
   35. Meta description generated
   36. Meta details updated
   37. Knowledge base builder updated
   38. Knowledge base builder published
   39. KB site 2.0 published
   40. KB site 2.0 preview created

   **e. Knowledge base widget settings**

   Tracks widget-related actions, such as:

   1. Knowledge base widget settings updated
   2. URL mapping created
   3. URL mapping updated
   4. URL mapping deleted
   5. Knowledge base widget settings deleted
   6. Knowledge base widget settings created

   **f. Users & security settings**

   Includes user management activities, such as:

   1. Site visibility changed
   2. Role added
   3. Role updated
   4. Role deleted
   5. Security group added
   6. Security group updated
   7. Security group deleted
   8. Content access added
   9. Site access added
   10. Content access updated
   11. Site access updated
   12. Content access removed
   13. Site access removed
   14. Team account added
   15. Team account updated
   16. Team account deleted
   17. IP restrictions updated
   18. IP restriction added
   19. IP restriction deleted
   20. Self sign up settings updated
   21. Import readers requested
   22. Import team account requested
   23. Export team account(s) to CSV
   24. Export reader(s) to CSV
   25. SSO configuration added
   26. SSO configuration updated
   27. SSO configuration deleted
   28. SSO users invited
   29. JWT created
   30. JWT regenerated
   31. JWT saved
   32. JWT updated
   33. JWT deleted
   34. Inheritance settings updated
   35. Reader account updated
   36. Reader account created
   37. Reader account deleted
   38. Convert to reader
   39. Convert to SSO team account
   40. Convert to SSO reader
   41. Convert to team account

   **g. Tools settings**

   Tracks actions such as:

   1. Project exported
   2. Project imported
   3. External project import requested
   4. Export PDF requested
   5. Export pdf content template added
   6. Export pdf content template updated
   7. Export pdf content template deleted
   8. Export pdf design template added
   9. Export pdf design template deleted
   10. Export pdf design template updated
   11. Article review reminder created
   12. Article review reminder updated
   13. Article review reminder deleted
   14. Content reuse variable added
   15. Content reuse variable updated
   16. Content reuse variable deleted
   17. Content reuse snippet Added
   18. Content reuse snippet updated
   19. Content reuse snippet deleted
   20. Article template added
   21. Article template updated
   22. Article template deleted
   23. Tag Added
   24. Tag Updated
   25. Tag Deleted
   26. Article imported
   27. Workflow status added
   28. Workflow status updated
   29. Workflow status deleted
   30. Workflow status reordered
   31. Find and replace
   32. Added glossary term suggestion
   33. Content reuse glossary suggested
   34. Updated glossary term suggestion
   35. Export pdf password removed

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Setting_up_the_audit_configuration.png)

---

### FAQs

**What is team auditing in the knowledge base portal?**

Team auditing allows you to track the actions performed by your team accounts within your Document360 project, such as adding or updating articles and changing settings.

**How do I export a specific team account's auditing records?**

To export the audit data for a specific team account, follow these steps:

1. Navigate to **Settings** () > **Knowledge base portal** > **Team auditing** in the Knowledge base portal.

   By default, **Team auditing** tab will be selected.
2. In the **Activity by user** dropdown, select the desired team account and click **Apply**.
3. In the **Event** dropdown, choose the required events and click **Apply**.
4. In the **Audit date** dropdown, choose the date range.

   The audit data for the selected team account will be listed.
5. Click **Export CSV** to download the data as a CSV file.

**How frequently is the audit data updated?**

Audit data is updated in real-time. You can click the Refresh button to ensure you are viewing the latest activities.

**Can I view actions performed by specific team accounts?**

Yes, you can filter the audit data to view actions performed by specific team accounts.

**Can I restrict access to team auditing data for certain team members?**

Yes, access to team auditing can be restricted based on user roles and permissions within the Document360 project.

**Can I recover deleted articles or content through team auditing?**

Team auditing only tracks actions taken, it does not provide recovery options. To recover deleted content, refer to the Document360 [backup and restore](/help/docs/backup-restore) or [version history](/help/docs/revision-history) features.

**Can I monitor specific events instead of all project-related events?**

Yes, turn on the toggle for specific event categories to monitor only those events.

**Can I track changes made to the knowledge base site settings?**

Yes, you can monitor site-specific activities like custom CSS updates, enabling cookie consent, etc.

**Is it possible to track actions related to Drive activities?**

Yes, you can monitor Drive-related activities such as folder additions, deletions, and file updates.

**Why is the article creation event missing or showing the old name in Team auditing after a Word import?**

If the article name is manually updated during the Word import process, this change will not be captured in the Team auditing, and the original name of the Word file will be reflected. To ensure the correct article name is reflected in auditing logs, avoid renaming the article during the import process. Instead, rename it after the import is complete.

If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

<a id="localization-getting-started"></a>

## Localization - Getting started

**Plans supporting localization settings in Knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Localization is the process of transforming and translating the content, look, and feel of a product or service to a specific market or locale. In most cases, the audience is classified based on language, region, or more. In reality, localization is a business's key to unlocking an entirely new revenue center and widening its brand reach in the global market.

---

Having a global clientele for your business necessitates having a localized language website and knowledge base. This would eliminate many obstacles that your customers encounter when interacting with a single-language website for support.

> NOTE
>
> * Localization will be available in all plans. You can also purchase additional languages localization as an add-on.
> * In Document360, if you have a default language of your knowledge base as English, you can also add support articles in a few other languages, like Spanish and Japanese.
> * The reader would choose to switch between the different languages using a dropdown at the top right section of your page.
> * If you have translated the articles in the respective languages by manual or machine translation, upon selection, the support articles will be displayed in the chosen languages.

### Complete localization

A localized Document360 knowledge base would  constitute the respective language's specific functionalities, articles, and controls. This involves translating the content from the original language and modifying it to better suit the target audience. In addition, the graphics, color, aesthetics, fonts, and images can be customized accordingly.

Apart from the content and visual elements, there are other parameters like units of measure, currencies, local formats for addresses, dates, communication addresses, and more.

A fully localized knowledge base resonates with your diverse users by incorporating culturally relevant nuances, making it feel familiar instead of simply using machine translators and replacing the English words with translated text.

A multilingual Document360 knowledge base could automatically detect and load in a customer's preferred language (based on the customer's login location or browser location preferences).

### FAQ(s)

**What is the localization of a knowledge base?**

Localization of a knowledge base refers to the process of adapting and translating content in your product's documentation to suit the language, culture, and preferences of different target audiences in various regions.

**Why is it important to localize our product's knowledge base?**

Localizing your knowledge base enhances the user experience by providing content in the user's native language, making it easier for them to understand and use your product. It also demonstrates your commitment to serving a global customer base and reducing the churn rate.

**What content should be localized in a knowledge base?**

Typically, all customer-facing content, including articles, FAQs, user guides, smart bars, cookie consent, controls, and interface text, should be localized to ensure consistency and clarity for users in different regions.

**How do I decide which languages to prioritize for localization?**

Document360 recommends you prioritize languages based on your customer demographics, market demand, and potential growth opportunities in specific regions. Analyze your customer's data and feedback to make informed decisions.

**Can I use machine translation for knowledge base localization?**

While the machine translation tools offered by Document360 can be a starting point, it's recommended to have human translators review and refine the content to ensure accuracy and maintain the intended meaning.

**How do I maintain consistency across localized knowledge base content?**

Document360 recommends the implementation of style guides, glossaries, and translation memory to maintain consistent terminology and writing conventions across different languages.

**What challenges should I anticipate during knowledge base localization?**

Some challenges include cultural nuances, technical jargon, and context-specific references that may not directly translate. A well-planned localization strategy can help overcome these challenges. You can also use third-party translation integration, such as Crowdin, with your Document360 project.

> For more information, read the article on [Crowdin integrating with Document360](/help/docs/crowdin).

**How often should I update the localized knowledge base content?**

Document360 recommends you keep localized content up-to-date with the original source content. Regularly review and update translated articles to reflect changes and improvements. Use the "**Review reminder**" feature to set up regular notifications.

**Should I use separate knowledge base workspaces for each language or have a single multilingual knowledge base workspace?**

This depends on your resources and user needs. Document360 recommends the use of a single multilingual knowledge base workspace. It is more manageable, and Document360 offers an array of security and access features for better control and customization.

**How do I measure the success of my knowledge base localization efforts?**

Use metrics like user engagement, performance analytics, geography metrics, support ticket reduction, customer satisfaction, and feedback from users in different regions to evaluate the effectiveness of your knowledge base localization strategy.

<a id="setting-up-a-multi-lingual-knowledge-base"></a>

## Setting up a Multi-lingual knowledge base

**Plans supporting localization settings in Knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In Document360, you can add multiple languages to a single project version or create a language-specific Knowledge base.

## Available languages

Document360 supports a variety of languages for localization using the Document360 machine translation. The languages supported by Document360 are:

**Supported languages**

1. Afrikaans [af]
2. Arabic [ar]
3. Arabic (Egypt) [ar-eg]
4. Chinese [zh]
5. Chinese (Simplified, People's Republic of China) [zh-cn]
6. Chinese (Traditional) [zh-hant]
7. Chinese (Traditional, Taiwan) [zh-tw]
8. Czech [cs]
9. Danish [da]
10. Dutch [nl]
11. English [en]
12. English (UK) [en-gb]
13. English (US) [en-us]
14. Estonian [et]
15. Fijian [fj]
16. Filipino [fil]
17. Finnish [fi]
18. French [fr]
19. French (Canada) [fr-ca]
20. Georgian [ka]
21. German [de]
22. Greek [el]
23. Hebrew [he]
24. Hungarian [hu]
25. Icelandic [is]
26. Indonesian [id]
27. Italian [it]
28. Japanese [ja]
29. Korean [ko]
30. Latvian [lv]
31. Lithuanian[lt]
32. Malagasy[mg]
33. Mongolian[mn]
34. Norwegian [no]
35. Polish [pl]
36. Portuguese [pt]
37. Portuguese (Brazil) [pt-br]
38. Romanian [ro]
39. Russian [ru]
40. Slovakian [sk]
41. Slovenian[sl]
42. Spanish [es]
43. Spanish (Mexico) [es-mx]
44. Swedish [sv]
45. Thai [th]
46. Turkish [tr]
47. Ukrainian [uk]
48. Vietnamese [vi]

## Adding multiple languages to a single version

* From the Knowledge base portal, go to **Settings** > **Knowledge base portal** > **Localization & Workspaces**.
* In the **Localization & Workspaces** tab, you can find the list of versions available in the project.
* There are **two** ways to add a new language to the project version.

### Method 1

1. Click **Edit** (🖉) on the right, and the **Edit workspace** blade appears.
2. Click the **New language** dropdown, and a list of languages appears.
3. Enter the desired language or keyword in the **Search languages** field, and the result is populated.
4. Select the checkbox for the desired language(s) and click **Apply**.
5. Once done, click **Update** at the bottom of the blade.

For more settings related to a language, you can also use More options (•••) adjacent to the language name.

* **Set as default**: Select this option to set the corresponding language as the default language for your knowledge base site.
* **Edit display name**: Use this option to update the display name for your workspace. The updated name will be shown on the knowledge base site when the corresponding language is selected. You can set a custom display name for your workspace in each of the available languages.
* **Right to left**: Most languages are written from left to right. However, there are a handful of languages written in the opposite direction. By enabling this, article content in the HTML editor and reader view (Knowledge base site) would start on the right and end on the left.
* **Hide**: Hides the language from the knowledge base. Hidden languages are indicated by strikethrough in the Knowledge base portal for reference.
* **Delete**: Delete the language from the selected list.

> NOTE
>
> You cannot hide or delete a default language.

![1_Screenvideo-Editing_Lang_Method_1.gif](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_GIF-Multi-lingial-workspace-edit(1).gif)

### Method 2

1. Click **Add new language**() adjacent to the **Edit** (🖉) icon.
2. Select the check box for the desired language(s) and click **Add.**
3. Enter the desired language or keyword in the **Filter languages** field, and the result is populated.
4. All the categories and articles from your default language are available in the new language(s). However, these articles and categories must be manually translated using machine translation (HTML editor only) or with extensions like **Crowdin**.

![To add a new language to a workspace](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Multilingual_Knowledge_base.gif)

> NOTE
>
> While selecting a language for your workspace, all languages other than English will be displayed in their native script.

---

## **FAQ(s)**

**How many languages does Document360 support?**

Document360 supports a total of 49 languages for localization. In the **Enterprise, Business, and Professional plans**, you are provided with 5, 3, and 2 languages respectively. Additional languages can be purchased separately.

> To know more, visit [**pricing plans.**](https://document360.com/pricing/)

**Why does content from some published articles in the default language not appear in the editor for the same article in the secondary language?**

When a new article is created and content is added in the default language, the article will appear in the secondary language, but the content will not be automatically carried over. To translate the content, use the **All articles** section to bulk translate the articles from the default language to the secondary language.

An online library where users can find information about a product, service, department, or topic. It helps users self-serve by providing answers and guidance.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The public-facing website where end-users can access articles and find answers to their questions.

<a id="localization-variables"></a>

## Localization variables

**Plans supporting localization settings in Knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Localization variables provide additional text controls that appear across articles in the reader's view. A localization variable is a text element you can configure, and this text appears consistently throughout your project based on the selected language. These variables will automatically display pre-translated content when you add a language to a workspace.

Imagine you have readers across different regions and want them to see article headers, feedback prompts, or search bar text in their native language. By configuring localization variables, you can ensure a seamless and language-specific experience for each user on the Knowledge base site.

---

### Localizing the text appearing in the knowledge base site

To view and edit localization variables:

1. Navigate to **Settings** () > **Knowledge base portal** > **Localization & Workspaces** > **Localization variables** in the Knowledge base portal.
2. Choose the desired language in the **Select language** section.
3. In the right section, you’ll find variable accordions, such as:

**Eddy AI**

Eddy AI accordion includes variables such as:

**ASSISTIVE SEARCH**

* Hey, I am
* How can I help you?
* Ask
* Facilitating knowledge discovery through conversational intelligence
* Is working diligently to provide you the accurate answer
* Source articles
* Feedback - Yes
* Feedback - No
* Provide more context or information so that I can better understand and assist you
* No results found
* Answer copied
* Is working on your request
* Thank you for your feedback
* We're sorry that the information did not meet your expectations.
* Failed to submit your feedback
* Search Limit Exceeded. Please upgrade the plan.
* Continue conversation with
* AI can make mistakes. Please verify important information
* Generated answer
* Back to search
* Hit enter to Ask
* Ask question
* Chat with
* or enter Keywords
* Go back to conversation
* New conversation
* Powered by

**SUMMARIZER**

* Article summary
* Did you find this summary helpful?
* Summarized
* Summary not available for the article
* Suggestions for improvements
* Optional

**RELATED ARTICLES IN KB SITE**

* Suggested

**Accessibility**

Accessibility accordion includes variables such as:

* Listen
* Listening
* Paused
* Player
* Loading
* Something went wrong. Please try again.

**Advanced search**

Advanced search includes variables such as:

* More article filters
* Category
* Date
* Days
* Clear all
* Clear
* Apply
* Last
* Workspace
* Workspaces
* Language
* Languages
* No matching results were found
* Having trouble finding what you need
* Check your search for typos
* Try clearing some filters
* Try a different search term
* What are you looking for?
* Custom range
* Results found for
* Keyword
* Search glossary terms
* Next
* Previous
* Search category titles
* Enter Keywords

**Article header**

Article header includes variables such as:

* Updated on
* Published on
* Read time
* Contributors
* Print
* Share
* Edit article
* Dark
* Light
* System theme
* Sub categories
* Category view
* Article link copied to clipboard
* Filters
* No data found
* Follow
* Unfollow

**Article right**

Article right includes variables such as:

* In this article
* Tags
* Files

**Article bottom**

Article bottom includes variables such as:

* Previous article
* Next article
* Related articles

**Category manager**

Category manager includes variables such as:

* New
* Updated
* Custom
* Deprecated

**General**

General includes variables such as:

* Search
* View results in page
* Contents
* Tags
* Back
* Articles
* Contributor
* Whats new
* Article
* Last month
* Last week
* Last 24 hours
* Linked Tag
* Glossary
* Published/Updated
* Activity
* Updated
* No glossary found
* Contributed
* Powered by

**Ticket deflector**

Ticket deflector accordion includes variables such as:

* Back
* Cancel
* Question
* Change question
* Change answer
* Solved my issue
* Not solved my issue
* No questions found
* Did not help
* Close
* Search not found
* Search result
* No search performed
* Search again
* Select file
* File size limit
* File count limit
* Files not allowed
* More than 2MB size
* File selected
* Get article content
* Failed to get article
* Processing your request
* Request not submitted
* Enter comment
* Valid phone number
* Valid email
* Valid name
* Refresh article
* Show full article
* Open article
* Preview submit

**Feedback**

Feedback accordion includes variables such as:

* Was this article helpful?
* Yes
* No
* Help us to improve article
* Submit
* Thank you for your feedback
* Enter your feedback here
* Optional
* Please enter a valid email
* Notify me about updates
* Email
* Submit
* Email
* Cancel
* Character limit
* Need more information (Cannot be editable)
* Difficult to understand (Cannot be editable)
* Missing/broken link (Cannot be editable)
* Inaccurate or irrelevant content (Cannot be editable)
* Others (Cannot be editable)
* Thanks for going extra mile
* Information wasn't what you needed

**Export PDF**

Export PDF accordion includes variables such as:

* PDF downloaded successfully
* Preparing your PDF for download
* Export PDF
* Export Articles
* PDF Templates
* Search for category & article
* The requested PDF will be delivered to your email
* No category and articles found

**Read receipt**

Read receipt accordion includes variables such as:

* Acknowledgment is required
* Click to review and confirm
* Acknowledgment status
* Required
* Acknowledged
* Acknowledgment required
* Awaiting your acknowledgment
* Acknowledged on
* You have successfully acknowledged this article on
* Your acknowledgment is required upon reading
* I confirm that I have read and understood the information above
* Thank you for confirming that you have read this article!
* Awesome!!! you are up to date with your reads
* We'll notify you of any new acknowledgments required in the future.
* Looks like you have some reading to do!
* Please read the 'Required' articles and submit your acknowledgment.

4. Expand the desired accordion and update the variable's text.
5. Click **Save**.

> NOTE
>
> * Any changes to these variables will be reflected across all workspaces of your project that use the specified language.
> * Changes may take up to 15 minutes to appear on your Knowledge base site due to caching.
> * For projects with multiple languages, update the localization variable text manually for each language.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Overview_page_of_Localization_variables.png)

---

### FAQs

**How do I change the variable text for the search bar based on the selected language?**

To update the search bar text based on the selected language:

1. Navigate to **Settings** () > **Knowledge base portal** > **Localization & Workspaces** > **Localization variables** in the Knowledge base portal.
2. Select your desired language from the language list.
3. Expand the **General** accordion and enter the new text in the **Search** field.
4. Click **Save**.

**How do I rename the "In this article" text on the Knowledge base site (previously "Table of Contents")?**

To rename the "**In this article**" text:

1. Navigate to **Settings () > Knowledge Base Portal > Localization & Workspaces > Localization Variables** in the Knowledge Base portal.
2. Select your desired language from the language list.
3. Expand the **Article right** accordion and enter your desired text in the “**In this article”** field.
4. Click **Save**.

<a id="workspaces"></a>

## Workspaces

**Plans supporting access to workspace settings in knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 workspaces allow you to create and manage multiple distinct knowledge bases within a single project. This flexibility is especially valuable for organizations with diverse audiences or documentation needs, enabling you to organize content that’s tailored to specific users or product areas. Workspaces keep your documentation organized, accessible, and relevant—no matter the complexity of your knowledge base.

## Defining workspaces and their role

When you purchase a Document360 plan, you’re provided with a single project that serves as your knowledge base repository. A project can contain all of your documentation, making it easy to manage and maintain content in one place. Think of it as the central hub for your knowledge base content, whether you have a single product or multiple offerings.

Within your Document360 project, you can create one or more workspaces to better organize your documentation based on audience, product lines, or other criteria.

A workspace is essentially a specialized area within your project that can house content for a particular group or use case. For example:

* If you’re managing documentation for a single SaaS product, one workspace may suffice.
* If you have multiple products or need separate documentation sets for external customers, internal users, and support teams, multiple workspaces can be more efficient.

The number of workspaces you can create depends on your Document360 plan.

---

## Benefits of using workspaces

Workspaces bring several benefits that can improve both content organization and user experience:

* **Relevant Information**: By separating documentation into specific workspaces, you ensure each audience only sees content that is relevant to them. This makes it easier for users to find the information they need.
* **Better Organization**: You can segment your knowledge base into well-defined areas, making it easier for team members to manage and update content.
* **Team Collaboration**: With workspaces, your team can collaborate more effectively, assigning peer reviews, tracking updates, and providing feedback within designated areas.

---

## Use cases of workspaces

Here are a few scenarios for the user of workspaces:

### Use case 1: Product-specific documentation

Imagine you’re a writer for a SaaS company with multiple products, such as a CRM, a project management tool, and an analytics platform. Instead of purchasing separate Document360 projects for each product, you could create a workspace for each product within a single project. This allows you to manage all documentation in one place, but with clear boundaries for each product’s knowledge base.

### Use case 2: Audience-specific documentation

Consider a SaaS product that has different documentation needs for developers, end-users, and administrators. By setting up separate workspaces for each audience, you can ensure that each group accesses content relevant to their role, avoiding confusion and unnecessary complexity.

### Use case 3: Internal and external knowledge bases

If you’re creating both internal documentation (for your support or development teams) and external documentation (for customers), multiple workspaces make it easy to keep each set of content separate. This structure allows you to control access permissions, ensuring that only designated users can view internal documents while keeping customer-facing content public.

---

## Starting with Workspaces

When you create a new project in Document360, a default workspace titled **v1** is automatically created. You can start building your knowledge base in this workspace immediately or create additional workspaces as your documentation needs evolve.

Using multiple workspaces allows you to keep your documentation streamlined, targeted, and well-organized. This way, every user—from internal teams to end customers—can access relevant information quickly and efficiently.

---

## Adding a new workspace

To add a new workspace,

1. In the Knowledge base portal, navigate to **Settings** () **>** **Knowledge base portal** **>** **Localization & Workspaces** **>** **Localization & Workspaces****.**
2. Click the **Add workspace** button from the top right corner.
3. In the **Add new workspace** popup, enter the required details.

   1. Select the Workspace type - **Knowledge base docs site** or **API documentation workspace**
   2. In the **Name** field, enter your desired name for your new workspace in your preferred language.

      > NOTE
      >
      > The **Name** field has a character limit of 30 characters. You can only use alphanumeric characters and hyphens.
   3. The **Slug URL** field will be auto-populated based on the workspace name you provided in the **Name** field. You can further customize the URL of your workspace based on your requirements.
4. Next, select the **Workspace status** for your new workspace.

   1. **Main workspace**: The **Main workspace** is the default workspace users will see when they visit your knowledge base site.

      > NOTE
      >
      > The Main workspace should be public and cannot be deprecated.
   2. **beta**: Select **beta** to indicate that the workspace is still in progress.
   3. **public**: Select **public** for workspaces that should be visible to users.
   4. **deprecated**: Select **deprecated** to indicate the workspace is old and contains out-of-date information.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Adding_workspaces.gif)

### Base workspace

While creating a new workspace, you can choose to either create a new workspace or copy an existing workspace from the same project.

#### Create a new workspace

If you select **Create a new workspace**, you will create an empty workspace that does not contain any content.

#### Copy existing workspace

If you select **Copy existing workspace**, you can copy the contents of an existing workspace to your new workspace.

1. Select the workspace you wish to copy from the list of existing workspaces.
2. Click on **Choose categories (optional)** to select specific categories of the existing category. Only the contents of the selected categories will be copied to the new workspace.
3. Select either **New** or **Existing** for **Internal links**.

   1. If you select **New**, the article’s link will point to the article version created in the new workspace.
   2. If you select **Existing**, the article’s link will point to the original article version in the existing workspace.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Base_workspace.gif)

### Languages

The default language of your project will be assigned as the default language of your new workspace as well. To add more languages, click on the **New language** dropdown. From the dropdown, search for the desired language(s) and select the checkbox next to the language name.

For more settings related to a language, click the **More options** (•••) icon next to the language name.

* **Set as default**: Select this option to set the corresponding language as the default language for your knowledge base site.
* **Edit display name**: Use this option to update the display name for your workspace. The updated name will be shown on the knowledge base site when the corresponding language is selected. You can set a custom display name for your workspace in each of the available languages.
* **Right to left**: Enable this toggle for languages that follow a **right-to-left** script (Arabic, Hebrew). By enabling this toggle, the article’s content will start from the right and continue to the left in the knowledge base portal as well as the knowledge base site.
* **Hide**: Select this option to hide the language from the knowledge base. Hidden languages are indicated by strikethrough in the Knowledge base portal for reference.
* **Remove**: Select this option to remove the language from your knowledge base.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Language_workspace.gif)

Once you complete customizing the details of your new workspace, click the **Add** button at the bottom right to finish creating the new workspace.

---

## Purchasing workspaces from Localization & Workspaces

1. In the Knowledge base portal, navigate to **Settings** () **>** **Knowledge base portal** **>** **Localization & Workspaces** **>** **Localization & Workspaces****.**
2. Click **buy more** on the right side of the screen.

> NOTE
>
> The **buy more** link is available only for users assigned the Owner role in projects.

3. Add or remove workspaces in the **Purchase add-on** window. The corresponding cost will be displayed as **Amount due**.
4. Click **Confirm Payment** to proceed with the payment. Once the payment is processed, a payment success message will display, and the additional workspaces will be added to your project successfully.
5. Click **Download** invoice to download the invoice for the payment done.

> NOTE
>
> You can also purchase workspaces from the Billing section in Document360 settings. To learn more, read the article on [**Purchasing add-ons**](/help/docs/add-ons).

## Troubleshooting

### Encountering 404 Page not found error when navigating to a secondary workspace

**Error**: 404 Page not found error

A 404 error can occur for various reasons, including missing or restricted content. If you're experiencing this issue while navigating to a workspace or an article, it may be due to workspace visibility settings or the absence of published articles.

> NOTE
>
> For other potential causes of 404 errors, refer to the [404 Page](/help/docs/404-page) article.

![A 404 error page with a person searching for a missing page illustration.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Troubleshooting_404_page_not_found_error.png)

**Steps to resolve:**

This error may occur due to one of the following reasons:

1. Check if the workspace is set to **Public**:

   1. Navigate to **Settings** () **>** **Knowledge base portal** **>** **Localization & Workspaces** **>** **Localization & Workspaces****.**
   2. Locate the respective workspace and click the **Edit** () icon.
   3. In the **Choose workspace status** section, select the **Public** checkbox.
   4. Click **Update**.

      ![Setting a workspace as "Public" in the Knowledge base](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenGIF-Troubleshooting_404_error_steps_to_resolve.gif)
2. No articles are published in the workspace.
3. All articles in the workspace are hidden.

   Ensure at least one article is published and visible on the Knowledge base site.

---

### FAQs

**I am trying to set a workspace as the main workspace, but the Main workspace checkbox is disabled. What do I do?**

To set a workspace as the main workspace, the workspace also needs to be set to public. To enable the Main workspace checkbox, first select the public checkbox. Once you select the **public** checkbox, the Main workspace checkbox will automatically be enabled.

**How many workspaces are available for the various subscription plans?**

Document360 has four subscription plans for users: **Free**, **Professional**, **Business**, and **Enterprise**.

* **Free**, **Professional**, and **Business** plan users have 1 workspace.
* **Enterprise** plan users have 2 workspaces.
* **Professional** and **Business** plan users can purchase 1 additional workspace at US$99/month.
* **Enterprise** plan users can purchase 2 additional workspaces at US$199/month.

**How do I reorder my workspaces?**

To reorder your workspaces, hold and drag the drag handle next to the workspace name. Using the drag handle, move the workspace to the desired location.

**How do I edit a workspace?**

Once you navigate to the **Localization & Workspaces** page in **Settings** ()> **Knowledge base portal**, hover over the workspace you wish to edit. Click the **Edit** () icon that appears at the right side of your screen to edit the workspace. You can edit the following properties of a workspace:

* Workspace name
* Workspace URL
* Workspace status

You can also add or delete workspace languages while editing a workspace.

**How do I delete a workspace?**

Similar to editing a workspace, navigate to the **Localization & Workspaces** page in **Settings** ()> **Knowledge base portal** and hover over the workspace you wish to delete. Click the **Delete** () icon that appears at the right side of your screen to delete the workspace. Note that the delete option will be disable for the Main workspace.

> NOTE
>
> Articles from a deleted workspace will appear as broken links.

**How do I recover a deleted workspace?**

You can recover a deleted workspace by following these steps:

1. Go to **Settings** ()> **Knowledge base portal** > **Backup & Restore** in the Knowledge base portal.
2. Find the desired backup, click the **Restore options** dropdown, and select **Documentation**.
3. In the **Restore documentation** panel, choose the workspace you want to restore.
4. Click **Restore**.

> NOTE
>
> Backup and Restore features are available only on Business and Enterprise plans.

**I have multiple workspaces added to my knowledge base site. How do I display them as a dropdown menu?**

In the Localization and workspaces page, locate the toggle named **Display workspaces as a menu (only public workspaces)**. To display your workspaces as a dropdown menu, set the toggle to **OFF**.

<a id="backup-restore"></a>

## Backup and restore

**Plans supporting access to backup & restore settings in knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 automatically backs up your project's data daily at 00:00 UTC. However, you can also perform manual backups at any time. Additionally, you can restore your project to a previous state from any available backup. The following elements of your Knowledge base can be restored:

* **Documentation**
* **API documentation**
* **Homepage builder**
* **Custom CSS**
* **Custom JavaScript**

> If a team member accidentally deletes or modifies a category in your documentation, you can restore the affected documentation from the most recent backup to recover the lost or altered content.

---

## Creating a manual backup

To create a manual backup, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base portal** > **Backup and Restore** in the Knowledge base portal.
2. Click the **New backup** to initiate a new backup.

   The **Backup name** panel will appear.
3. Enter your desired backup name and click **Backup**.

   Once the backup is complete, it will be added to the backup log.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Creating_a_manual_backup.gif)

---

## Restoring from a Backup

To restore from the backup, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base portal** > **Backup and Restore** in the Knowledge base portal.
2. On the desired backup, click the **Restore** **options** dropdown and select the elements you wish to restore:

   * For **Documentation**, **API documentation**, and **Homepage builder**, select the checkboxes for the options you want to restore, then click **Restore**.
   * For **Custom CSS** and **Custom JavaScript**, compare the backup version with the current version. Click **Restore** to restore the backup version.
3. Click **Yes** in the confirmation prompt.

   The restore process will run in the background, and a **Backup restored** message will appear once it’s complete.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Restoring_a_Backup.png)

---

## Restore options

### 1. Documentation

Restores your project documentation to the state when the backup was created.

1. Select specific workspaces, languages, categories, or articles to restore.
2. Turn on the **Select all** toggle to restore the entire documentation.
3. In the **Restore documentation** panel, hover over any article or category, and the **View** option will appear. Click **View** to preview the backup content before restoring it.

**Example:** To retrieve documentation from a recently deleted language:

1. Navigate to **Settings** () > **Knowledge base portal** > **Backup and Restore** in the Knowledge base portal.
2. Click the **Restore** option and select **Documentation**.
3. Choose the desired workspace and language, then click **Restore**.

> NOTE
>
> * When you restore an existing workspace/language/category/article, it is updated with the backup content.
> * When you restore a deleted workspace/language/category/article, it is added as a new workspace/language/category/article.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Restore_Documentation.gif)

---

### 2. API documentation

Restores your API documentation to the state when the backup was created.

1. Select specific workspaces, languages, categories, or articles.
2. Turn on the **Select all** toggle to restore the entire API documentation.
3. Hover over any article/category in the **Restore API documentation** panel to preview its backup content using the **View** option.
4. Click **Restore**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Restore_API_Documentation.png)

---

### 3. Homepage builder

1. Restores all features of the **Homepage builder**, including:

* **Navigations**: Header & Footer
* **Main Pages**: Home, Documentation, Login
* **Error Pages**: 404 page, Access denied page, Unauthorized page, IP restrictions

2. Select the desired workspaces and languages.
3. Turn on the **Select all** toggle to select all workspaces and languages.

**Example:** To retrieve the Home page of a recently deleted language:

1. Navigate to **Settings** () > **Knowledge base portal** > **Backup and Restore** in the Knowledge base portal.
2. Click the **Restore** option and select **Homepage builder**.
3. Select the desired workspace and language, and click **Restore**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Restore_Homepage_Builder.png)

---

**4. Custom CSS**

Restores the custom CSS of your Knowledge base site to the state when the backup was created.

* Compare the backup version of the custom CSS with the current version, with changes highlighted.
* Click the **Copy code snippet** ()icon next to the respective version to copy the CSS code.

**Example:** If multiple team members modify the custom CSS, resulting in overwritten snippets, you can restore the previous version by following these steps:

1. Navigate to **Settings** () > **Knowledge base portal** > **Backup and Restore** in the Knowledge base portal.
2. Click the **Restore** option and select **Custom CSS**.
3. Compare the backup and the current version.
4. Click **Restore** to retrieve the recently changed CSS snippet.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Restore_Custom_CSS.png)

---

### 5. Custom JavaScript

Restores the custom JavaScript of your Knowledge base site to the state when the backup was created.

* Compare the backup version of the custom JavaScript with the current version, with changes highlighted.
* Click the **Copy code snippet** ()icon next to the respective version to copy the JavaScript code.

**Example:** If multiple team members modify the custom JavaScript, resulting in overwritten snippets, to restore the previous version by following these steps:

1. Navigate to **Settings** ()> **Knowledge base portal** > **Backup and Restore**.
2. Click the **Restore** option and select **Custom JavaScript**.
3. Compare the backup version with the current version.
4. Click **Restore** to retrieve the earlier JavaScript snippet.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Custom%20JavaScript.png)

---

### FAQs

**Are backups created after every project update, or do I need to trigger them manually?**

  

Backups are created automatically every day at 00:00 UTC, but they are not triggered after each individual project update. For important changes, you may want to manually create a backup to ensure you have the most recent version of your data saved.

**Can I perform manual backups at any time?**

Yes, you can perform manual backups at any time.

**How long are backups stored, and can I delete older backups?**

  

Backups are stored for up to 90 days, after which they are automatically deleted. There is no option to manually delete older backups.

**What elements of the knowledge base can be restored from a backup?**

You can restore Documentation, API documentation, Homepage builder, Custom CSS, and Custom JavaScript.

**Is it possible to restore specific elements from a backup?**

Yes, you can select specific elements such as Documentation, API documentation, and Homepage builder to restore.

<a id="notifications"></a>

## Notifications

**Plans supporting access to notification settings in Knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In Document360, you can set up notifications for project changes and updates through email (SMTP), Slack, Microsoft Teams, and webhooks. These are referred to as **Notification channels**. Before receiving any alerts, ensure that you configure and authenticate these channels.

For instance, imagine a project manager overseeing multiple contributors in a documentation project. They want to stay informed about every content update or modification made by their team members. By configuring Slack as a notification channel, the manager receives real-time updates directly within their team’s Slack workspace, helping them stay on top of changes without constantly checking the platform.

---

## Accessing notification channels

To configure notification channels, navigate to **Settings**()> **Knowledge base portal** > **Notifications** > **Notification channels**in the Knowledge base portal.

Here, you will find a list of active channels that are receiving notifications from Document360. You can edit or delete channels as needed. To add a new channel, click **New channel**.

> **NOTE**
>
> By default, an email channel (SMTP) is automatically configured and cannot be deleted. However, you can customize the email configuration.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Notification_channel_overview_page.png)

### Adding notification channels

Document360 currently supports the following notification channels:

* [Webhook notification channel](/help/docs/webhook-notification-channel)
* [Slack notification channel](/help/docs/slack-notification-channel)
* [Microsoft Teams notification channel](/help/docs/microsoft-teams-notification-channel)
* [SMTP notification channel](/help/docs/smtp-email-notification-channel)

<a id="webhook-notification-channel"></a>

## Webhook notification channel

**Plans supporting access to notification settings in knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

A **Webhook** is a method of automatically sending real-time data from one application to another when specific events occur. Webhooks in Document360 allow you to send notifications to other applications, keeping your team updated on changes in the Knowledge base portal, site, or widget.

For instance, your support team uses a communication tool like Slack. By setting up a Webhook, you can instantly notify the team when an article is updated, ensuring everyone has the latest information without needing to manually check for updates.

---

## Setting up a Webhook notification channel

To configure a Webhook notification channel in Document360, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base portal** > **Notifications** in the Knowledge base portal.

   By default, the **Notification channels** tab will be selected.
2. Click **New channel**.
3. In the **Available channels** panel, select **Webhook** and click **Next**.

   The **Channel configuration** panel will appear.
4. In the **Friendly name** field, enter a unique name for your Webhook channel.
5. In the **Request method** dropdown, select either **POST** or **PUT**, depending on how you want to send the data.
6. In the **Webhook URL** field, enter the URL of the application where you want to send notifications.
7. Choose the desired message format from the **Request content** dropdown.
8. If additional headers are needed, click **Add new** () under **Default headers** and add them.
9. Optionally, enter the **Authorization key** if the receiving application requires authentication.
10. Click **Save**.

> NOTE
>
> For more information, read the [Request header](https://developer.mozilla.org/en-US/docs/Glossary/Request_header) help article.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScrenGIF-Setting_up_the_Webhook_notification_Channel.gif)

Once you save, a new Webhook notification channel with your specified name is created. Now, navigate to the [**Notification mapping**](/help/docs/notification-mapping) tab to map configurations with your Webhook application based on your requirements.

<a id="slack-notification-channel"></a>

## Slack notification channel

**Plans supporting access to notification settings in knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Slack is a collaboration platform that provides a centralized space for team communication, file sharing, and project collaboration. It integrates with various third-party applications, making it a versatile tool for teams.

With Document360, you can share notifications through Slack and configure them to suit different needs. Notifications from the Knowledge base portal, Knowledge base site, and Knowledge base widget can be configured to appear in a designated Slack channel.

For example, a customer support team might set up Slack notifications for new articles or updates to key knowledge base documents, allowing team members to stay informed in real-time without leaving Slack.

---

## Setting up Slack notification channel

Configuring Slack in Document360 involves three main steps:

### Step 1: Creating a new app in Slack

1. If you are new to [Slack](https://slack.com/intl/en-in/), create an account and set up a workspace.
2. If you already have an account, [log in](https://slack.com/intl/en-in/signin#/signin) and navigate to your existing app.

### Step 2: Get the webhook URL

1. Open the [Slack API](https://<span class=) and select **Create New App**.

   Your apps will appear in a list.
2. Select the desired app for which you want to enable notifications.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Slack_YourApps_.png)

3. Go to **Features** > **Activate Incoming Webhooks** andturn on the **toggle ON**.

   In the **Webhook URLs for your Workspace** section, the desired Webhook URL will be listed.
4. Click **Copy** to copy the webhook URL.

![4_Screenshot-Slack_webhook_Link.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Slack_webhook_Link.png)

#### Generating a New webhook

If no webhooks are listed:

1. Click **New Webhook for Your Workspace**.
2. Choose the channel you want notifications to appear in and click **Allow**.
3. The webhook will now appear in the list.

### Step 3: Setting up the configuration in Document360

To setup the configuration in Document360:

1. Navigate to **Settings** () > **Knowledge base portal** > **Notification channels** in the Knowledge base portal.
2. Click **New channel**.

   The **Channel configuration** blade will appear.
3. Select **Slack** and click **Next**.
4. In the **Friendly name** field, enter the desired channel name.
5. In the **Webhook URL** field, paste the **Webhook URL** you copied from Slack.
6. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Slack_notification_channel.gif)

Your new Slack notification channel is created. Navigate to the [**Notification mapping**](/help/docs/notification-mapping) tab to link specific notifications to the Slack channel, to ensure the appropriate alerts are sent to the designated team members.

<a id="microsoft-teams-notification-channel"></a>

## Microsoft Teams notification channel

**Plans supporting access to notification settings in knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Microsoft Teams is a collaborative platform that allows Document360 users to stay updated on important changes through direct notifications within a Teams channel. Notifications for the Knowledge base portal, site, and widget can be sent directly to your team’s chosen Teams channel, keeping everyone informed without needing to constantly check Document360.

For example, if your team relies on Teams for daily updates, you can configure notifications to alert them whenever an article is published or updated in the knowledge base.

---

## Setting up the Microsoft Teams notification channel

Configuring Microsoft Teams notifications in Document360 involves three steps:

* [Creating a channel in Microsoft Teams](/help/docs/microsoft-teams-notification-channel#creating-a-channel-in-microsoft-teams)
* [Obtaining the webhook URL](/help/docs/microsoft-teams-notification-channel#get-the-webhook-url)
* [Setting up the configuration in Document360](/help/docs/microsoft-teams-notification-channel#setup-the-configuration-in-document360)

### Step 1: Creating a channel in Microsoft Teams

1. Open **Microsoft Teams**.
2. Go to **Teams** (), select the **More** (⋯) icon next to the team where you want to add the channel.
3. Click **Add channel** to create a new channel.
4. Enter the channel name and click **Add**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Creating_a_channel_in_Microsoft_teams.png)

### Step 2: Obtaining the Webhook URL

1. In the newly created channel, click the **More** (⋯) icon and select **Manage channel**.
2. In the **Settings** tab, click **Edit**.
3. In the search bar, type **Incoming webhook** and click **Add**.
4. Enter a name for your Incoming webhook connection.
5. Optionally, click **Upload image** to upload an image for the webhook.
6. Click **Create** to generate the webhook URL.
7. Click the **Copy** () icon to save the webhook URL to your clipboard.
8. Click **Done**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGIF-Getting_the_Webhook_URL.gif)

*Image source: Microsoft teams*

### Step 3: Setting up the Configuration in Document360

1. Navigate to **Settings** () > **Knowledge base portal** > **Notification channels** in the Knowledge base portal.
2. Click **New channel**.
3. In the **Available channels** panel, select **Microsoft Teams** and click **Next**.

   The **Channel configuration** blade will appear.
4. Select **Microsoft Teams** and click **Next**.
5. Enter a name for this channel in the **Friendly name** field.
6. In the **Webhook URL** field, paste the copied webhook link from Microsoft Teams.
7. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Settings_up_the_configuration_in_Document360.gif)

Your Microsoft Teams notification channel is now set up. Next, go to the [**Notification mapping**](/help/docs/notification-mapping) tab to map specific configurations for sending notifications to the Teams channel as needed.

---

### FAQs

**How do I confirm that notifications are being sent to Microsoft Teams?**

After setting up the Microsoft Teams notification channel, you can test it by mapping a sample notification or enabling a test article update. Check the Teams channel to verify that notifications are arriving as expected. If they aren’t, double-check the webhook URL and permissions in the Teams settings.

**Can I customize which types of notifications are sent to Microsoft Teams?**

Yes, you can select specific notification types in the **Notification mapping** tab in Document360. Here, you can choose which events (e.g., new article published, article updated) will trigger notifications in the Teams channel.

**What should I do if I get an authorization error in Teams?**

Authorization errors often occur if the webhook URL is outdated or permissions are not configured correctly. Try generating a new webhook URL in Microsoft Teams and updating it in Document360. Ensure that the channel has the necessary permissions to receive notifications.

**How do I disable notifications for specific events in Microsoft Teams?**

To disable notifications for specific events, go to the **Notification mapping** tab in Document360, and unselect the types of notifications you no longer wish to receive in Microsoft Teams. This allows you to manage notification frequency and relevance effectively.

**Can I use different Teams channels for different types of notifications?**

Yes, you can set up multiple Teams channels for notifications by creating separate channels in Microsoft Teams and configuring each with its own webhook in Document360. Each channel can then be assigned different types of notifications through **Notification mapping**.

<a id="smtp-email-notification-channel"></a>

## SMTP notification channel

**Plans supporting access to notification settings in knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

SMTP (Simple Mail Transfer Protocol) is a standard protocol for transmitting email messages. In Document360, you can configure SMTP to send email notifications to designated addresses, keeping your team informed about critical updates or changes within your projects. Notifications can be sent from the Knowledge base portal, Knowledge base site, and Knowledge base widget.

For instance, your team wants to receive email notifications whenever there’s an update in a critical Knowledge base article. By configuring the SMTP channel, you can ensure that all team members are instantly alerted to changes, allowing them to stay informed and act promptly.

---

## Setting up the SMTP notification channel

To set the SMTP notification channel, follow the steps below:

1. Navigate to **Settings ()** > **Knowledge base portal** > **Notifications** in the Knowledge base portal.

   The **Notification channels** tab will be selected by default.
2. Click **New channel**.
3. In the **Available channels** panel, select **SMTP** and click **Next**.

   The **Channel configuration** panel will appear.
4. In the **Friendly name** field, enter the desired name for your SMTP channel.
5. In the **Email to** field, enter the email addresses to receive notifications.

> NOTE
>
> * Separate multiple email addresses with a semicolon (;) and no spaces.
> * Do not add a semicolon after the last email address.
>
>   **Example**: xyz@gmail.com;abc@gmail.com;mno@gmail.com

6. Optionally, enter any additional email addresses for the recipients.
7. Optionally, enter any additional email addresses for the recipients.
8. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-setting_up_the_SMTP_notification_Channel.gif)

Your new SMTP notification channel is now set up. To complete the configuration, navigate to the [**Notification mapping**](/help/docs/notification-mapping) tab to map specific events that should trigger email notifications to this SMTP channel.

<a id="notification-mapping"></a>

## Notification mapping

**Plans supporting access to notification settings in knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Notification mapping in Document360 helps your team stay in the loop on critical events, ensuring seamless collaboration and prompt actions. By configuring notifications, you can alert team members about specific updates, reviews, or changes across various modules like documentation, user security, and analytics. This setup keeps everyone aligned without needing to check manually for updates.

---

## Mapping Notification channels to events

To map notification channels to event, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base portal** > **Notifications** in the Knowledge base portal.
2. Select the **Notification mapping** tab.

> NOTE
>
> By default, all events are turned off.

3. Turn on the **All events** toggle to enable notifications for all events.
4. To receive notifications for a specific module, turn on its corresponding toggle.
5. Expand the module and enable individual events to receive notifications for only those selected events.

   > **Example**: Turn on the **Documentation editor** module to receive all editor related notifications. Alternatively, expand the module and turn on the **Article published** toggle alone to receive notifications specifically when an article is published.
6. Click **Map to channel** to map each event to their respective channels individually.
7. Click the  icon next to each individual event to map a notification channel.

> NOTE
>
> If an event notification is enabled, it must have at least one channel assigned.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Notification_mapping_in_the_Knowledge_base_portal.png)

### Analytics weekly report mail

The project owners can enable the **Analytics** toggle to receive a weekly analytical report for their project. To set this up:

1. Navigate to **Settings** () > **Knowledge base portal** > **Notifications** in the Knowledge base portal.
2. Select the **Notification mapping** tab.
3. Expand the **Analytics** accordion and enable the **Analytics weekly mail** toggle.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Analytics_toggle_in_the_Notification_mapping.png)

---

## Notification events

You can choose to receive notifications for the following events.

**Documentation editor**

The **Documentation editor** module includes several key events that trigger notifications based on changes within articles. These events include:

| Event | Function and use |
| --- | --- |
| Article visibility changed | Notifies users when the visibility settings of an article are altered, affecting who can see it. |
| Article settings updated | Alerts when the settings of an article are modified, ensuring the article is configured correctly. |
| Article slug updated | Signals when the URL-friendly name (slug) of an article is changed, impacting how it is accessed. |
| Article title updated | Notifies users when the title of an article is changed, ensuring the title reflects the content. |
| Article published | Alerts users when an article is published, making it available for readers. |
| Article created | Signals when a new article is created, allowing users to start adding content. |
| Article renamed | Notifies users when an article is renamed, reflecting changes in its title. |
| Article deleted | Alerts when an article is deleted, indicating it is no longer available. |
| Article forked | Alerts when an article is forked, creating a new version based on the original. |
| Article version deleted | Notifies users when a specific version of an article is deleted, affecting version history. |
| Bulk delete article versions | Alerts when multiple article versions are deleted at once, streamlining version management. |
| Updated translation status | Signals when the status of an article's translation is updated, ensuring accurate localization. |
| Articles reordered | Notifies users when the order of articles is changed, affecting how they are displayed. |
| Article contributors updated | Alerts when the contributors for an article are modified, ensuring accurate credit. |
| Article workflow status updated | Signals when the status of an article’s workflow is changed, affecting its review process. |
| Article workflow due date updated | Notifies users when the due date for an article’s workflow is modified, keeping deadlines clear. |
| Article workflow assignee updated | Alerts when the person assigned to an article’s workflow changes, ensuring proper accountability. |
| Category created | Signals when a new category is created, helping organize articles effectively. |
| Category type updated | Notifies users when the type of a category is changed, affecting how articles are classified. |
| Category settings updated | Alerts when settings for a category are modified, ensuring proper organization and visibility. |
| Category slug changed | Signals when the URL-friendly name (slug) of a category is altered, impacting how it is accessed. |
| Category contributors updated | Notifies users when contributors for a category are changed, ensuring proper credit is given. |
| Category deleted | Alerts when a category is deleted, indicating that it and its articles are no longer available. |
| Category renamed | Signals when a category is renamed, reflecting changes in its title. |
| Categories reordered | Notifies users when the order of categories is changed, affecting their display in the interface. |
| Category published | Alerts when a category is published, making it available for use with articles. |
| Category forked | Signals when a category is forked, creating a new version based on the original category. |
| Category version deleted | Notifies users when a specific version of a category is deleted, affecting version history. |
| Bulk delete category versions | Alerts when multiple category versions are deleted at once, streamlining version management. |
| Category workflow status updated | Signals when the status of a category's workflow is changed, impacting its review process. |
| Category workflow due date updated | Notifies users when the due date for a category’s workflow is modified, keeping deadlines clear. |
| Category workflow assignee updated | Alerts when the person assigned to a category's workflow changes, ensuring proper accountability. |
| Category visibility changed | Notifies users when the visibility settings of a category are altered, affecting who can see it. |
| Article review reminder status updated | Signals when the status of an article review reminder is updated, ensuring reviews are tracked. |
| Article pushed to Crowdin | Alerts users when an article is sent to Crowdin extension for translation, facilitating localization efforts. |
| Categories/Articles restored | Notifies users when categories or articles are restored from deletion, making them available again. |
| Categories/Articles permanently deleted | Signals when categories or articles are permanently deleted, indicating they are no longer retrievable. |
| Recycle bin emptied | Alerts users when the recycle bin is cleared, permanently removing all deleted items. |
| Shared article created | Notifies users when a shared article is created, allowing collaboration on content. |
| Clone article created | Signals when a clone of an article is created, enabling users to duplicate and modify content easily. |
| Removed reference article | Alerts users when a reference article is removed, indicating changes in linked content. |
| Multiple shared articles created | Notifies users when several shared articles are created at once, enhancing collaboration. |
| Article publish later canceled | Signals when a previously scheduled article publish is canceled, affecting its availability. |
| Article scheduled for publish | Alerts users when an article is scheduled for future publishing, ensuring timely releases. |
| Share link deleted | Notifies users when a private share link for an article is deleted, impacting access for collaborators. |
| Share link generated | Signals when a new private share link for an article is created, facilitating collaboration on content. |

**Drive**

The Drive module includes several key events that trigger notifications based on changes within drive. These events include:

| Event | Function and use |
| --- | --- |
| Folder added | Notifies users when a new folder is created, keeping the team updated on resource organization. |
| Folder renamed | Alerts users when a folder's name is changed, helping them locate files easily. |
| Folder deleted | Notifies users when a folder is deleted, so they understand changes in organization. |
| File(s) added | Alerts users when new files are added, keeping them informed about available resources. |
| File(s) updated | Notifies users when existing files are changed, important for tracking updates. |
| File(s) deleted | Alerts users when files are removed, ensuring they know about missing resources. |

**Knowledge base portal settings**

The Knowledge base portal settings module includes several key events that trigger notifications based on changes within Knowledge base portal. These events include:

| Event | Function and use |
| --- | --- |
| Workspace updated | Notifies users when changes are made to the settings or details of a workspace, keeping everyone informed. |
| Workspace deleted | Alerts users when a workspace is deleted, indicating it is no longer available for use. |
| Workspace created | Signals when a new workspace is created, providing a new area for organizing projects and content. |
| Workspace display order changed | Notifies users when the order of workspaces in the interface is changed, affecting how they are organized visually. |
| Plan tier changed | Alerts users when the subscription plan for a workspace is upgraded or downgraded, affecting features and limits. |
| Payment details updated | Signals when the payment information for a workspace is updated, ensuring billing is accurate. |
| Project general settings updated | Notifies users when general settings for a project within a workspace are changed, ensuring proper configuration. |
| Backup created | Alerts users when a backup of the workspace is created, allowing for data recovery if needed. |
| Backup restored | Signals when a backup of the workspace is restored, recovering previous data and settings. |
| Notification channel deleted | Notifies users when a notification channel is deleted, affecting how updates are communicated. |
| Notification channel created | Alerts users when a new notification channel is created, providing a way to receive updates and alerts. |
| Notification channel updated | Signals when an existing notification channel is modified, ensuring communication preferences are current. |
| Addons purchased | Notifies users when additional features or addons are purchased for a workspace, enhancing functionality. |
| Subscription created | Alerts users when a new subscription is created for a workspace, enabling access to services and features. |
| API token added | Signals when a new API token is added, allowing for secure access to workspace resources through integrations. |
| API token deleted | Notifies users when an API token is deleted, removing access for integrations linked to that token. |
| Extension token generated | Alerts users when an extension token is created, enabling additional functionality or integrations. |
| Extension token deleted | Signals when an extension token is deleted, affecting the associated features or integrations. |
| Crowdin token added | Notifies users when a Crowdin token is added, facilitating translation and localization processes. |
| Crowdin token deleted | Alerts users when a Crowdin token is removed, affecting translation access and capabilities. |
| Display workspaces as menu | Signals when the workspaces are set to be displayed in a menu format, enhancing navigation and organization. |

**Knowledge base site settings**

The **Knowledge base site settings** module includes several key events that trigger notifications based on changes within Knowledge base site. These events include:

| Event | Function and use |
| --- | --- |
| Site design settings updated | Notifies users when the design settings of the site are changed, affecting its appearance and layout. |
| Custom JavaScript updated | Alerts users when custom JavaScript code is updated, allowing for enhanced site functionality. |
| Custom CSS updated | Signals when custom CSS styles are updated, changing the visual presentation of the site. |
| Article settings updated | Notifies users when settings related to articles are changed, impacting how content is displayed. |
| Project sub-domain updated | Alerts users when the sub-domain for the project is updated, changing the website’s URL structure. |
| Integration created | Signals when a new integration is established with another service, enhancing capabilities. |
| Integration deleted | Notifies users when an integration is removed, stopping data sharing with that service. |
| Integration updated | Alerts users when an existing integration is modified, ensuring connections remain effective. |
| Home page builder restored | Notifies users when the home page builder is restored to a previous version, allowing for revisions. |
| Home page builder settings updated | Signals when settings for the home page builder are updated, affecting layout and content display. |
| Robots.txt updated | Alerts users when the robots.txt file is updated, impacting how search engines crawl the site. |
| Site domain updated | Notifies users when the main domain of the site is changed, affecting the site's accessibility. |
| Cookie consent enabled | Signals when cookie consent is enabled, indicating compliance with privacy regulations. |
| Cookie consent disabled | Notifies users when cookie consent is disabled, impacting user privacy preferences. |
| Cookie consent updated | Alerts users when cookie consent settings are modified, changing user consent options. |
| Smart bar added | Notifies users when a smart bar is added to the site, providing quick access to features. |
| Smart bar updated | Signals when the smart bar's settings or content are updated, improving user interaction. |
| Smart bar enabled | Alerts users when the smart bar is enabled, making it visible on the site for user access. |
| Smart bar disabled | Notifies users when the smart bar is disabled, removing it from the site view. |
| Smart bar deleted | Signals when the smart bar is permanently removed, discontinuing its functionality. |
| Ticket deflector deleted | Alerts users when a ticket deflector feature is deleted, impacting support request management. |
| Ticket deflector added | Notifies users when a new ticket deflector is added, helping to manage support queries effectively. |
| Ticket deflector updated | Signals when an existing ticket deflector is modified, ensuring it works as intended. |
| Ticket deflector helpdesk added | Notifies users when a helpdesk is added to the ticket deflector, providing users with support options. |
| Ticket deflector helpdesk updated | Alerts users when the helpdesk settings in the ticket deflector are updated for better support. |
| Ticket deflector helpdesk deleted | Notifies users when a helpdesk is removed from the ticket deflector, changing support options. |
| Article redirection rule added | Signals when a new article redirection rule is created, guiding users to the correct content. |
| Article redirect rule updated | Alerts users when an existing article redirect rule is modified, ensuring proper content navigation. |
| Article redirection rule(s) deleted | Notifies users when article redirection rules are deleted, potentially affecting content access. |
| Redirect rule(s) exported to CSV | Signals when redirect rules are exported to a CSV file, allowing for data analysis or backup. |
| Redirect rules import requested | Notifies users when a request is made to import redirect rules, updating site navigation. |
| Meta description generated | Alerts users when a meta description for articles is generated, improving SEO visibility. |
| Meta details updated | Signals when meta details for articles are updated, enhancing search engine optimization. |
| Knowledge base builder updated | Notifies users when updates are made to the knowledge base builder, affecting content creation tools. |
| Knowledge base builder published | Alerts users when the knowledge base builder is published, making it available for users. |
| Read receipt rule created | Notifies users when a read receipt rule is created, tracking when articles are viewed. |
| Read receipt rule updated | Signals when an existing read receipt rule is modified, adjusting tracking settings. |
| Read receipt rule deleted | Alerts users when a read receipt rule is deleted, ceasing tracking of article views. |

**Knowledge base widget settings**

The Knowledge base widget settings module includes several key events that trigger notifications based on changes within Knowledge base widget. These events include:

| Event | Function and use |
| --- | --- |
| Knowledge base widget settings updated | Notifies users when the settings for the knowledge base widget are changed, affecting its behavior. |
| URL mapping created | Alerts users when a new URL mapping is created, enabling specific links to direct to content correctly. |
| URL mapping updated | Signals when an existing URL mapping is modified, ensuring links direct users to the intended content. |
| URL mapping deleted | Notifies users when a URL mapping is removed, which may affect how certain links function. |
| Knowledge base widget settings deleted | Alerts users when the settings for the knowledge base widget are deleted, stopping its functionality. |
| Knowledge base widget settings created | Notifies users when new settings for the knowledge base widget are established, enabling its use. |

**Users & Security settings**

The **Users & Security settings** module includes several key events:

| Event | Function and use |
| --- | --- |
| Site visibility changed | Notifies when the visibility settings of the site are altered, affecting who can access the site. |
| Role added | Signals when a new user role is created, allowing for better management of user permissions. |
| Role updated | Alerts users when an existing role's permissions are modified, ensuring up-to-date access control. |
| Role deleted | Notifies when a user role is removed, indicating changes in the available roles for users. |
| Security group added | Alerts when a new security group is created, enabling better organization of users and permissions. |
| Security group updated | Notifies users when an existing security group's settings are changed, ensuring current access control. |
| Security group deleted | Signals when a security group is removed, clarifying the organization of user permissions. |
| Content access added | Notifies when new permissions for accessing specific content are granted, enhancing content security. |
| Site access added | Alerts users when access to the site is granted to new users or groups, facilitating collaboration. |
| Content access updated | Notifies users when existing content access permissions are modified, keeping access controls current. |
| Site access updated | Alerts when site access permissions are changed for users or groups, ensuring proper access management. |
| Content access removed | Signals when permissions to access specific content are revoked, helping maintain content security. |
| Site access removed | Notifies users when site access is revoked for users or groups, ensuring security and control. |
| Team account added | Alerts when a new team account is created, facilitating collaborative work within the organization. |
| Team account updated | Notifies users when changes are made to an existing team account, ensuring accurate team management. |
| Team account deleted | Signals when a team account is removed, clarifying available team structures. |
| IP restrictions updated | Notifies users when the IP address restrictions are modified, enhancing site security. |
| IP restriction added | Alerts when a new IP restriction is added, controlling which IPs can access the site. |
| IP restriction deleted | Signals when an IP restriction is removed, indicating a change in access control for specific IPs. |
| Self sign-up settings updated | Notifies users when the settings for self-sign-up are changed, affecting how users register. |
| Import readers requested | Signals when a request to import new readers is made, helping manage reader access. |
| Import team account requested | Alerts when a request to import team accounts is initiated, facilitating user management. |
| Export team account(s) to CSV | Notifies users when team account data is exported to CSV, providing an easy way to analyze account details. |
| Export reader(s) to CSV | Signals when reader data is exported to CSV, making it easier to manage reader information. |
| SSO configuration added | Notifies users when a new Single Sign-On (SSO) configuration is created, streamlining user authentication. |
| SSO configuration updated | Alerts users when an existing SSO configuration is modified, ensuring up-to-date authentication settings. |
| SSO configuration deleted | Signals when an SSO configuration is removed, indicating a change in authentication options. |
| SSO users invited | Notifies users when invitations are sent to users for SSO access, facilitating user onboarding. |
| JWT created | Alerts when a new JSON Web Token (JWT) is generated, enabling secure user sessions. |
| JWT regenerated | Signals when an existing JWT is regenerated, ensuring continued secure access. |
| JWT saved | Notifies users when a JWT is saved for future use, maintaining secure authentication processes. |
| JWT updated | Alerts users when an existing JWT is modified, keeping authentication secure. |
| JWT deleted | Signals when a JWT is removed, indicating a change in authentication status. |
| Inheritance settings updated | Notifies users when inheritance settings for permissions are modified, ensuring proper access control. |
| Convert to reader | Alerts when a user account is converted to a reader, changing their access level. |
| Convert to SSO team account | Notifies when a user is converted to an SSO team account, allowing for easier authentication. |
| Convert to SSO reader | Signals when a user is converted to an SSO reader, streamlining their access to content. |
| Convert to team account | Alerts when a user is converted to a team account, changing their permissions and access levels. |

**Tools settings**

The **Tools settings** module includes several key events:

| Event | Function and use |
| --- | --- |
| Project exported | Notifies when a project is successfully exported, allowing tracking of project backups. |
| Project imported | Alerts when a project is imported, indicating that external content has been successfully integrated. |
| External project import requested | Notifies the team when a request is made to import an external project, helping them manage incoming content. |
| Export PDF requested | Signals when a request to export project content as a PDF is initiated, keeping the team informed of document outputs. |
| Export PDF content template added | Notifies when a new PDF content template is added, allowing for consistent document formatting. |
| Export PDF content template updated | Alerts users when an existing PDF content template is modified, ensuring everyone uses the latest format. |
| Export PDF content template deleted | Signals when a PDF content template is removed, helping maintain clarity on available document formats. |
| Export PDF design template added | Notifies when a new design template for PDFs is created, aiding in visual consistency for exported documents. |
| Export PDF design template deleted | Alerts users when a PDF design template is deleted, ensuring they know which formats are no longer available. |
| Export PDF design template updated | Signals when a PDF design template is changed, keeping the team informed of design updates. |
| Article review reminder created | Notifies when a reminder for reviewing an article is set, helping ensure timely content evaluations. |
| Article review reminder updated | Alerts users when an existing review reminder is changed, keeping the team updated on review schedules. |
| Article review reminder deleted | Signals when a review reminder is removed, indicating a change in the article evaluation process. |
| Content reuse variable added | Notifies when a new content reuse variable is created, enabling the team to streamline content management. |
| Content reuse variable updated | Alerts users when a content reuse variable is modified, ensuring the latest variables are in use. |
| Content reuse variable deleted | Signals when a content reuse variable is removed, keeping the team informed about available content management options. |
| Content reuse snippet added | Notifies when a new content reuse snippet is created, helping enhance content consistency and efficiency. |
| Content reuse snippet updated | Alerts users when an existing snippet is modified, ensuring everyone has access to the latest content. |
| Content reuse snippet deleted | Signals when a content reuse snippet is removed, clarifying available content management tools. |
| Article template added | Notifies when a new article template is created, promoting consistent article formatting. |
| Article template updated | Alerts users when an article template is modified, ensuring that the latest formatting is used. |
| Article template deleted | Signals when an article template is removed, indicating changes in available formatting options. |
| Tag added | Notifies when a new tag is created, helping in organizing content for easier searching and filtering. |
| Tag updated | Alerts users when an existing tag is modified, keeping the tagging system current and effective. |
| Tag deleted | Signals when a tag is removed, clarifying the tagging system's available categories. |
| Article imported | Notifies when an article is successfully imported, indicating that new content is added to the knowledge base. |
| Workflow status added | Alerts users when a new workflow status is created, providing more options for managing content workflows. |
| Workflow status updated | Notifies when an existing workflow status is modified, ensuring users are aware of the latest workflow options. |
| Workflow status deleted | Signals when a workflow status is removed, keeping the workflow management system clear and up to date. |
| Workflow status reordered | Notifies users when workflow statuses are reordered, helping them understand the new workflow sequence. |
| Update feedback assignee | Alerts users when feedback is reassigned to a different team member, ensuring accountability in content review. |
| Update feedback status | Notifies when the status of feedback is changed, keeping the team updated on the review process. |
| Find and replace | Alerts users when the find and replace function is executed, ensuring changes in content are tracked. |
| Content reuse glossary suggested | Notifies users when a suggestion for a content reuse glossary is made, promoting efficient content management. |
| Export PDF password removed | Signals when the password protection on an exported PDF is removed, indicating changes in document security. |

**Knowledge site**

The Knowledge base site module includes several key events:

| Event | Function and use |
| --- | --- |
| Feedback received | Notifies the team when feedback is submitted by users, helping them understand user opinions. |
| Reader email updated | Alerts users when a reader's email address is changed, ensuring that communication remains effective. |
| Reader self-registration | Notifies the team when a new reader registers themselves, keeping them updated on the growing user base. |
| Like received | Alerts users when an article receives a "like," indicating positive feedback and popularity. |
| Dislike received | Notifies users when an article receives a "dislike," signaling areas for improvement based on user feedback. |

**AI notifications**

The **AI notifications** module includes a key event:

| Event | Function and use |
| --- | --- |
| Credit usage alert | Notifies users when their AI credits are low, important for keeping the service running smoothly. |

**Analytics**

The Analytics module includes a key event:

| Event | Function and use |
| --- | --- |
| Analytics weekly metrics | Notifies users when weekly analytics reports are available, useful for tracking performance. |

**All comments notification**

| Event | Function and use |
| --- | --- |
| All comments notifications | Alerts contributors whenever inline comments are added to articles they have contributed to, ensuring feedback is communicated promptly. |

---

### FAQs

#### **How do I get notified in Microsoft Teams whenever articles are published?**

To get notified in Microsoft Teams whenever articles are published, follow the step below:

1. Navigate to **Settings** () > **Knowledge base portal** > **Notifications** > **Notification mapping** in the Knowledge base portal.
2. Expand the **Documentation editor** accordion and enable the **Article published** toggle.
3. Ensure **Microsoft Teams** is configured as a Notification channel.

   If not, click the  icon next to the **Article published** toggle and enable the **Microsoft Teams** channel.

> NOTE
>
> For more information, read the article on [Microsoft Team notification channel](/help/docs/microsoft-teams-notification-channel).

#### **How do I get notified when my project is exported to Slack?**

To get notified when your project is exported to Slack, follow the step below:

1. Navigate to **Settings** () > **Knowledge base portal** > **Notifications** > **Notification mapping** in the Knowledge base portal.
2. Expand the **Tools settings** accordion and enable the **Project exported** toggle.
3. Ensure **Slack** is configured as a Notification channel.

   If not, click the  icon next to **Project exported** and enable the **Slack** channel.

> NOTE
>
> For more information, read the article on [Slack notification channel](/help/docs/slack-notification-channel).

#### **How do I get notified when a new team account is added via email?**

To get notified when a new team account is added via email, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base portal** > **Notifications** > **Notification mapping** in the Knowledge base portal.
2. Expand the **Users & Security settings** accordion and enable the **Team account added** toggle.
3. Ensure your SMTP channel is configured as a Notification channel.

   If not, click the  icon next to **Team account added** and enable the **SMTP** channel.

> NOTE
>
> For more information, read the article on [SMTP notification channel](/help/docs/smtp-email-notification-channel).

#### **How do I get notified when Eddy AI credit usage decreases?**

To receive alerts for your Eddy AI credit usage, follow these steps:

1. Navigate to **Settings** () > **Knowledge base portal** > **Notifications** > **Notification mapping** in the Knowledge base portal.
2. In the **Eddy AI notifications** accordion, enable the **Credit usage alert** toggle.

Once enabled, Document360 will notify your configured channels when the credit balance falls to 20%, 10%, or when the balance expires.

#### **How can contributors be notified of inline comments on articles?**

1. Navigate to **Settings** () > **Knowledge base portal** > **Notifications** > **Notification mapping** in the Knowledge base portal.
2. Enable the **All comments notification** toggle.

Now, all contributors will receive email notifications whenever inline comments are added to articles they have contributed to.

#### **Why am I not receiving email notifications for article creation?**

If you're not receiving email notifications when a new article is created, please ensure that the **Article created** notification toggled is enabled in your Knowledge base portal. To verify and activate this setting:

1. Navigate to **Settings** () > **Knowledge base portal** > **Notifications** > **Notification mapping** in the Knowledge base portal.
2. In the **Notification mapping** tab, expand the **Documentation editor** section.
3. Turn on the **Article created** toggle.

Once this setting is enabled, the designated email addresses configured should receive notifications upon the creation of new articles.

If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

> NOTE
>
> If an article is created using the [Word import](/help/docs/importing-articles-from-a-docx-file) feature, the **Article created** email notification will not be triggered.

<a id="notification-history"></a>

## Notification history

**Plans supporting access to notification settings in knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 tracks the history of notifications sent to your configured channels, making it easy to monitor delivery statuses and troubleshoot any failures. This ensures your team can stay on top of important alerts, like system updates or error notifications.

For example, if your team uses Slack for real-time alerts, you can check the **Notification history** to verify whether critical updates were successfully delivered. In case of failure, you can quickly identify and resolve the issue.

---

## Managing Notification history

To access and manage the Notification history:

1. Navigate to **Settings** () > **Knowledge base portal** > **Notification** in the Knowledge base portal.

   By default, the **Notification channels** tab will be selected.
2. Go to the **Notification history** tab.

   A list of past notifications will appear.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Notification_history_overview_page.png)

### Understanding the Notification history

The Notification history provides a detailed breakdown of each notification sent. Here’s what you’ll see:

1. **Channel name:** The channel through which the notification was sent, such as Slack, Webhook, SMTP, or Microsoft Teams.
2. **Status:** The delivery status of the notification, either **Success** or **Failure**.
3. **Submitted on:** The date the notification event was triggered.
4. **Sent on:** The date the notification was actually sent.
5. **History:** Click **View details** to see the email or message that was sent to the user.

Each notification shows details like the channel it was sent to, its delivery status, the submission and sent dates, and event details, enabling you to track notification delivery within a specific timeframe.

<a id="send-notifications-from-custom-email-domain"></a>

## Email domain

**Plans supporting access to email domain settings in the knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Configuring a custom email domain in Document360 allows your organization to send notifications from a branded email address, improving recognition and trust among your readers while reinforcing your branding strategy.

By default, notification emails are sent from `support@document360.com` to team accounts and readers. To make customer notifications more personalized, you can set up emails to be sent from an address like `support@yourcompany.com`, making it easier for recipients to identify and trust the sender.

To enable this feature, you’ll need to configure your DNS entries with your provider to point to Document360.

---

### Prerequisites

* Ensure you have access to a DNS provider such as [GoDaddy](https://www.godaddy.com/en-in), [Hostinger](https://www.hostinger.in), [Namecheap](https://www.namecheap.com), etc.
* This custom email domain feature is available only in the **Enterprise plan**.

---

### Configuring a Custom Email domain

To configure a custom email domain, follow these steps:

1. Navigate to **Settings** () > **Knowledge base portal** > **Notifications** in the Knowledge base portal.

   By default, the **Notification channels** tab will be selected.
2. Select the **Email Domain** tab.
3. In the **Domain name** field, enter your custom email domain (e.g., `yourcompany.com`).
4. Click **Add Domain**. This will generate the DNS records needed for configuration.

**Adding DNS records**

5. Open your DNS provider’s website in a separate tab to add the required MX and TXT records.

> NOTE
>
> Ensure you add the DNS records provided by Document360 to your domain registrar (e.g., GoDaddy, Hostinger). Adding these records will not override existing MX records.

6. Copy the configuration details from the **Setting up your custom email domain** section in Document360 and paste them into your DNS provider’s settings.
7. Return to the **Email domain** page in Document360.
8. Select the **I’ve added the records** checkbox, then click **Verify & Save**.

   Once the MX and TXT records are verified, an **Email Domain Verified** message will appear.
9. After verification, enter your custom sender information:

   1. **Email field:** Enter the desired “From” email address (e.g., `support@yourcompany.com`).
   2. **Name field:** Enter the sender name (e.g., `Your Company Support`).

After setup, emails will be sent from the configured domain with the specified “From” email address and sender name.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Email_domain.png)

---

#### Troubleshooting

If your custom email domain configuration is still inactive after 24 hours, try the following steps:

1. Verify that the MX and TXT records were saved on the domain host.
2. Ensure the MX and TXT information on the domain host matches the records provided by Document360.
3. If issues persist, delete the records on the domain host and re-add them.

For further assistance, please contact us at `support@document360.com`.

---

### FAQs

**What is the purpose of MX records, and how do they work?**

MX (Mail Exchange) records are DNS entries that route emails sent to your domain to the correct mail servers. They define the mail servers responsible for handling your email and their priority order. For example, if one mail server is unavailable, emails are sent to the next server in line based on priority (a lower number indicates higher priority).

**Example:**  
If your domain has the following MX records:

* `10 mail1.example.com`
* `20 mail2.example.com`

Emails are routed first to `mail1.example.com` and then to `mail2.example.com` if the primary server is down.

**How are TXT records used in email authentication?**

TXT (Text) records are DNS entries that store text-based information linked to a domain. They serve multiple purposes, such as verifying domain ownership, setting up email security policies like SPF, DKIM, and DMARC, and providing general domain-related information.

Example: **SPF** (Sender Policy Framework), a TXT record specifies which mail servers are authorized to send emails on behalf of your domain, helping to prevent spoofing.

**SPF Example Record:** `v=spf1 include:_spf.google.com ~all`

By implementing TXT records, you can protect your domain from phishing, spoofing, and unauthorized email usage.

<a id="how-to-use-postman"></a>

## How to use Postman?

**Plans supporting access to API token settings in knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Postman is an API platform for building and using APIs. Linking your Document360 project with Postman is easy and can be completed in a few minutes. You can use the on-premises or web-based Postman.

> NOTE
>
> For more information regarding Postman application, read the following articles.
>
> * [How to download Postman application?](https://www.postman.com/downloads/)
> * [How to install and update Postman application?](https://learning.postman.com/docs/getting-started/installation-and-updates/)
> * [How to use Postman?](https://learning.postman.com/docs/)
> * [FAQs in Postman](https://www.google.com/search?q=FAQs+in+Postman%3F&rlz=1C1CHBD_enIN1119IN1119&oq=FAQs+in+Postman%3F&gs_lcrp=EgZjaHJvbWUqBggAEEUYOzIGCAAQRRg7MgoIARAAGIAEGKIE0gEHNjI5ajBqN6gCALACAA&sourceid=chrome&ie=UTF-8)

---

## **Linking your Document360 project in Postman**

The below steps are based on the on-premises Postman application.

1. Open the **Postman** application.
2. In the **My Workspace** section, click on the **Import** button.

   An **Import** popup window appears.
3. Enter the below URL in the field.  
   <https://apihub.document360.io/swagger/v2/swagger.json>

   The **Choose how to import your API** pop-up will appear with two options.
4. Select the desired option

   * Postman Collection (default)
   * OpenAPI 3.0 with a Postman Collection
5. Click the **Import** button.

   Once the import is done, the action will create a sample request for each endpoint, allowing you to make the request quickly.

   ![Steps to link your Document360 project in Postman](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_ScreenGif-Postman.gif)

### **Authentication in Postman - Generating an API token**

1. In the tree view, expand **Document360 Customer API**.
2. Under the **Authorization** tab, set the **Auth Type** to API Key from the dropdown.
3. Enter the desired variable in the **Key** field.
4. Enter the API token in the Value field. For generating an API token, read the article on [Generating token](https://apidocs.document360.com/apidocs/api-token).

   > NOTE
   >
   > **Generating an API token**
   >
   > a. Navigate to **Settings** > **Knowledge Base portal** > **API tokens**.
   >
   > b. Create the desired API token and copy the token.
   >
   > (or) Copy the token from an existing token.

![Steps for authorization in Postman after importing Document360 project](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/11_ScreenShot-Postman.png)

1. In the left navigation bar, go to **Environments**.
2. From the left navigation pane, click on **Create Environments**.
3. Under the **Variables** column, type a variable name, for instance, ‘base\_URL,’ and set the **Type** to default.
4. Enter `https://apihub.document360.io` in the **INITIAL VALUE** and **CURRENT VALUE** fields for the base URL.
5. Click on the **Save** button.

   The project authentication is completed. Now you can easily access all the available endpoints and perform various actions.

   ![Steps to authenticate Document360 project](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_ScreenShot-Postman.png)

### **Use cases**

With the help of Postman, you can perform various actions in Document360.

Here are a few basic use cases for your reference

* [How to create and publish an article?](https://apidocs.document360.com/v2/docs/how-to-create-and-publish-an-article)
* [How to update a published article?](https://apidocs.document360.com/v2/docs/how-to-update-a-published-article)
* [How to update SEO details?](https://apidocs.document360.com/v2/docs/how-to-update-seo-details)

---

### FAQ(s)

**What should I do if my Postman session ends after refreshing the page?**

If your Postman session ends after refreshing the page, you will need to authenticate again. Follow the steps provided in the article to re-authenticate.

<a id="how-to-use-swagger"></a>

## How to use Swagger?

**Plans supporting access to API token settings in knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Swagger is an interface description language that describes RESTful APIs expressed using JSON. It allows you to create interactive, machine and human-readable [API documentation](https://document360.com/blog/api-documentation/). It helps you visualize and interact with the API's resources without any implementation logic. It is a web-based application.

---

## **Swagger documentation site**

1. Open the [Swagger documentation site](https://apihub.document360.io/).
2. To authenticate the documentation, click **Authorize**.  
   The **Available authorizations** panel will appear.
3. Enter the API token in the **Value** field.

   > NOTE
   >
   > You can select an existing token, or you can generate a new token as per your requirement. To generate a new token, follow the below steps
   >
   > * Go to **Settings** > **API tokens** in the Knowledge Base portal.
   > * Type a name for the API token in the **Enter token name**.
   > * Select the required HTTP method(s). You have four methods under **Allowed method(s)**: **GET**, **PUT**, **POST** and **DELETE**.
   > * You can only use the generated token for the selected method(s). It cannot be used to perform other methods.
   > * Click **Copy** to copy the API token.
4. Click the **Authorize** button.
5. Once done, click the **Close** button.  
   The authorization is done successfully.

   ![Image showing authorize panel in Swagger](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/17_ScreenShot-Swagger.png)

   > NOTE
   >
   > If you wish to change to a different token, click **Authorize** > **Logout** > enter your **API token** > **Authorize** > **Close**.

### GET

* The **GET** method is used to retrieve information.
* Below is an example of **GET** action, to retrieve all records about the team account.

![Image showing GET action in Swagger](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/12_ScreenShot-Swagger_Get.png)

1. Fill the marked fields and click the **Execute** button.

   The information about the team account will be available under the **Responses** section.

![Image showing GET action in Swagger](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/13_ScreenShot-Swagger_Get.png)

### POST

* The **POST** method is used to add an item.
* Below is an example of a **POST** action, to add a team account to a project.

![Image showing POST action in Swagger](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/14_ScreenShot-Swagger_Post.png)

1. You should add the team account information such as email\_id, first\_name, and last\_name to add a user to the project.  
   The team account will be added to the project.
2. Click the **Execute** button.  
   The addition of the team account will be successful if the status is 200 and the success is true.

### PUT

* The **PUT** method is used to update an existing item.
* Below is an example of **PUT** action, to update a user role in the project.

![Image showing PUT action in Swagger](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/15_ScreenShot-Swagger_Put.png)

1. Enter the userId in the marked field.
2. Update the user role with the number mentioned for the user role syntax. The numbers for the respective roles are as follows:

   * 1 → Administrator
   * 2 → Editor
   * 3 → Draft Writer
   * 4 → Reader
   * 7 → Owner
3. Once done, click on the **Execute** button.

   The update of the user is successful if the status is 200 and the success is true.

### DELETE

* The **DELETE** method is used to delete an item.
* Below is an example of a **DELETE** action, to delete a userId.

1. Enter the userId in the marked field.
2. Once done, click on the **Execute** button.  
   If the status is 200 and the success is true, the userId will be successfully deleted.

   ![Image showing DELETE action in Swagger](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/16_ScreenShot-Swagger_Delete.png)

> NOTE
>
> It is mandatory to enter the content in the field that are marked \***required**.

 For more information, refer to the following blogs

1. [Ultimate guide to create an API documentation with examples](https://document360.com/blog/api-documentation/)
2. [Feature spotlight – API in Document360](https://www.google.com/search?q=Feature+spotlight+%E2%80%93+API+in+Document360&rlz=1C1CHBD_enIN1119IN1119&oq=Feature+spotlight+%E2%80%93+API+in+Document360&gs_lcrp=EgZjaHJvbWUyBggAEEUYOTIGCAEQRRg80gEHNDI5ajBqN6gCALACAA&sourceid=chrome&ie=UTF-8)

   ---

   ## FAQ(s)

   **What should I do if refreshing the page ends my session?**

   If you refresh the page, the session might end, and you will have to authenticate again. Follow the steps provided for authentication.

   **How should I format fields that require a specific character?**

   You must use an underscore wherever required. For example, use “email\_id” instead of “email id.” Using spaces will result in an error.

<a id="full-portal-search"></a>

## Portal search

**Plans supporting portal search**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Full portal search** is a dedicated space to search the entire project content, files, tags, users, content tools, and settings. Perform a combined search across all the workspaces and languages simultaneously.

---

## Accessing the full portal search

1. Click on the **Search** () icon to the right of the top navigation bar.
2. Enter the desired keyword and use the **All** dropdown at the left of the search bar to apply the desired module to narrow down the results.

   There are five sub-modules and one combined module (**All**) in the Full portal search.

   * [All](/help/docs/full-portal-search)
   * [Article](/docs/article-full-portal-search)
   * [Drive file](/docs/drive-full-portal-search)
   * [Users & Groups](/docs/users-groups-full-portal-search)
   * [Tags](/docs/tags-full-portal-search)
   * [Settings](/docs/settings-full-portal-search)

> NOTE
>
> Press the **Escape** button to retract this screen.

     Only five results of each search will be displayed.

3. To view more results, click the **More articles** option below the displayed results.
4. If needed, you can apply the **Filter** ()option on the top right.
5. To preview, click on the desired search item.
6. Click on the **Go to article** option at the top to navigate to the desired article.

   ![Perform full portal search to find the desired item.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Full_portal_search.gif)

---

### FAQ(s)

**What can I search using the full portal search, and is the search keyword highlighted in the results?**

The full portal search applies to article/category pages, Drive files, Users & Groups, Tags, Content tools, and Settings. The search keyword is highlighted in the search results on the Search page.

**Why isn't my analytics information appearing in the full portal search results?**

The full portal search does not include data from the Analytics sections in the Knowledge base portal. However, the settings module will display the information related to Analytics in the search results.

<a id="article-full-portal-search"></a>

## Article-portal search

**Plans supporting portal search**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Articles - Full portal search** acts as a dedicated space to search the entire project's articles and category pages. Perform a combined search across all the workspaces and languages simultaneously.

---

## Accessing the articles through full portal search

1. Click on the **Search** () icon to the right of the top navigation bar.

   > NOTE
   >
   > Press the **Escape** button to retract this screen.
2. Click on the **All** drop down to the left of the search bar and select **Articles**.
3. Type in the keyword to perform a search.
4. The articles/page categories matching the search item will be displayed as you type the keyword.

   The search result will display the following information:

* Article title
* Breadcrumb
* Article workspace
* Language
* Status of the article

5. You can apply filters from the **Filter** () option available on the right side below the navigation bar.
6. To preview, click on the desired search result.
7. Click on the full screen() icon to expand the preview. Click the previous (**<**) or next (**>**) button to navigate between the search result articles.
8. Click on the **Go to article** optionat the top of the preview to navigate to the article.

   ![Perform full portal search to navigate to the article module.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGif-Article_full_portal_search.gif)

---

## Filters

#### a. Workspace/Language

Click on the dropdown and select the **Workspaces(s)** and **Language(s)** for the search results. The language selection can be found when the Workspace dropdown is further expanded. If you want to search across all the available workspaces(s) and language(s), either select the **Workspace** checkbox or don't apply this filter.

#### b. Visibility

Filter the search results based on the visibility state of the article. There are three selections available, **None, Visible,** and **Hidden**. The **None** would be the default selection which would mean no filter is applied.

#### c. Status

Filter the search results based on the article status. There are four statuses available, **None, New article, Draft,** and **Published**. The **None** status would be the default selection which means no filter is applied.

#### d. Contributors

Filter the search results based on the article contributors. Click the **Contributors** dropdown and the list of contributors appear. Use the search by username field to search for the desired contributors.

#### e. Tags

Users can apply this filter to narrow down the article/category page associated with the specific tag(s). Use the search tags bar to find the tag required. Users can select multiple tags.

#### f. Updated on

Users can filter the results using the Updated date range. The selections available are **7 days, 30 days, 3 months, 1 year,** and **custom date** range selection.  
  
Select the desired filter and click **Apply.** The articles will be narrowed down based on the selection. To clear the existing filters, and reset the search, click the **Clear** button.

<a id="drive-full-portal-search"></a>

## Drive-portal search

**Plans supporting portal search**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Drive - Full portal search** acts as a dedicated space to search through the files from the entire Drive on the project.

---

## **Accessing the Drive - Full portal search page**

1. Click on the **Search** () icon to the right of the top navigation bar.

   > NOTE
   >
   > Press the **Escape** button to retract this screen.
2. From the **All** dropdown available to the left of the search bar, select **Drive**.
3. Type in the search keyword in the search bar.

   The result(s) matching the search keyword will be displayed in **List view**.

> NOTE
>
> **List view** can be changed to **Grid view** by clicking on the grid () icon available to the right of the **Filter** option below the navigation bar.

   The search results would display the following information about the file

* **Name**
* **Dependencies**
* **Updated on**
* **Updated by**
* **Size**
* **Tags**

4. Click on the file name or the eye () icon to the right to open the **File details** pane.

   In the **File details** pane**,** file location, size, type, uploaded date, uploaded by and tags (if any) will be displayed.
5. Click on **View** **dependencies** to view the instances where the particular file has been used in the article/category page.

   When you click on the dependent article/category page, you will be redirected to the article/category page in the Editor.

   ![Perform search through the files from the entire drive on the project.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Drive_full_portal_search.gif)

   ---

   ## Filters

   #### **a. Status**

   You can filter the file search results by selecting any one from **All files, Deleted files,** or **Starred files**. The default selection would be **All files.**

   #### **b. Type**

   Narrow down the search results based on the filter type selected. The filter options available are **Images, Word, Excel, PPT, PDF, ZIP, Video, Audio,** and **Others**. Team members can select more than one file type for the filter.

   #### **c. Uploaded by**

   Filter the search result by selecting the team member account(s) who have uploaded the files.

   #### **d. Tags**

   You can apply this filter to narrow down the files associated with the specific tag(s). Use the search tags bar to find the tag required and if needed, you can select multiple tags.

   #### **e. Uploaded**

   You can filter the results using the **Upload date** range. The selections available are **7 days, 30 days, 3 months, 1 year,** and **custom date** range selection.

   Once the filter selection is made, click **Apply**. To clear any existing filters and reset the search, click **Clear**.

<a id="users-groups-full-portal-search"></a>

## Users & groups-portal search

**Plans supporting portal search**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Users & Groups - Full portal search** page serves as a dedicated space to search team accounts, team account groups, readers, and reader groups in the knowledge base project.

---

## **Accessing the Users & Groups - Full portal search page**

1. Click on the **Search** () icon to the right of the top navigation bar.

   > NOTE
   >
   > Press the **Escape** button to retract this screen.
2. From the **All** dropdown available to the left of the search bar, select **Users & Groups**.
3. Type in the search keyword in the search bar.  
   The search results will display two tabs, **Team accounts & groups** and **Readers & groups**.  
   In the **Team accounts & groups** tab, you can find the Name, Portal role, and Login activity of the team accounts and groups relevant to your search term.

   **Team account**
4. Click on the desired team account to open the **View access permissions** panel to view the portal role and content role.
5. Click **Manage permissions** at the top to open the Team account page.

   **Team account groups**
6. Click on the desired team account group to open the **View access permissions** panel to view the portal role and content role.
7. Click **View associated team members** to open the Team account group page.

   ![To perform search for team accounts and groups and readers/groups.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenGif-Users&Groups_Search.gif)

   In the **Readers & groups** tab, you can find the Name and login activity of the reader and reader group relevant to your search term.  
     
   **Readers**
8. Click on the desired reader, and it will navigate to the **Readers** page.

   **Readers & groups**
9. To view and manage the readers associated with the reader group and the content access, click on the **View associated readers**.

   ![To perform search through readers and groups section in users and groups tab.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_ScreenGif-Readers&Groups_Search.gif)

---

## Filters

![Find the filter option available in users and groups module to filter your search.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-users-and-groups-filter.png)

#### 1. Type

You can filter your search based on the type of the team account. The options available are **All entity**, **Team account**, **Team account groups**, **Reader** and  **Reader Groups**. The default selection would be **All entity**.

#### **2. Last logged in**

You can filter your search based on the last login date. The options available are **All**, **7 days**, **30 days**, **3 months**, **1 year,** and **Custom date**. The default selection would be **All**.  
  
Once the filter selection is made, click **Apply**. To clear any existing filters and reset the search, click **Clear**.

<a id="tags-full-portal-search"></a>

## Tags-portal search

**Plans supporting portal search**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Tags - Full portal search** page serves as a dedicated space to search through and view the **Tags** page in the knowledge base project. Team members can also view the dependency information of the tags.

---

## **Accessing the Tags - Full portal search page**

1. Click on the **Search** () icon to the right of the top navigation bar.

   > NOTE
   >
   > Press the **Escape** button to retract this screen.
2. From the **All** dropdown available to the left of the search bar, select **Tags**.
3. Type the search keyword in the search bar.

    The results relevant to your search will be displayed showing the following information

* Tag name
* Dependency in articles
* Dependency in category pages
* Dependency in drive file

  4. To view the detailed breakdown of the dependency information, click on the intended tag to open the **Tag Dependency** panel.

    The articles/category page dependency shows the following information

* Article/category page name
* Version
* Language
* Contributor
* Current status indicator
* Publish date

5. Click on the article/page category to open the documentation editor.  
     
   The File dependency shows the following information

* File thumbnail (Only for image files)
* Filename and format

6. Click on the **Download** option to download the file onto the device’s local storage.
7. To remove dependencies from articles, category pages, and files in drive or from all of them, select the desired checkbox available to the left of the panel.
8. Once the selection is made, click on the **Remove dependencies** button available at the bottom of the panel.
9. To close the panel, click **Cancel**.

   ![To perform search to find tags in articles, category pages or files in drive.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_ScreenGif-Tags_Full_portal_search.gif)

<a id="settings-full-portal-search"></a>

## Settings-portal search

**Plans supporting portal search**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Settings - Full portal search** page serves as a dedicated space to search through various features and settings available on the knowledge base portal.

---

## **Accessing the Settings - Full portal search page**

1. Click on the **Search** () icon to the right of the top navigation bar.

   > **NOTE**
   >
   > Press the **Escape** button to retract this screen.
2. From the **All** dropdown available to the left of the search bar, select **Settings**.
3. All settings your team account can access will be displayed.

    The settings are grouped under

* Knowledge base portal
* Knowledge base site
* Users & Security

4. Type the search keyword in the search bar.  
   The results will be displayed in **Grid view**.  
     
   The search results will display the following information

* Setting/feature name
* Feature icon
* Short description of the setting/feature

5. Click on the intended setting and it will navigate to the respective settings page.

   ![To perform search through the settings panel in the portal.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_ScreenGif-Settings_search.gif)

<a id="custom-domain-mapping"></a>

## Custom domain mapping

**Plans supporting custom domain mapping**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

When you create a new project in Document360, the system automatically generates a default web address for your knowledge base, like `project-name.document360.com`. However, you can create a more personalized web address, that reflects your brand and preference by editing the default web address or setting up a custom domain, such as `help.yourcompany.com`, which makes it easier for users to find and remember your site.

To access the custom domain mapping option, navigate to **Settings()** > **Knowledge base site** > **Custom domain**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Custom_domain_mapping.png)

> NOTE
>
> A new Document360 project will use the project name as the domain. For example, if you have named your project as **Project Greenfield**, the autogenerated domain by Document360 will be **project-greenfield.document360.com**.

## Editing a default domain

To edit the default web address,

1. Navigate to the **Custom domain** page in Document360 settings.
2. Click the **Edit** icon next to the default web address.
3. Enter your preferred domain in the available field.

   * If your preferred domain is unavailable, the **Update** button will be disabled. You will need to try a different domain.
   * If your preferred domain is available, the **Update** button will be enabled.
4. Click **Update** to update the web address of your **Knowledge base site**.

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1729603511681.png)

---

## Creating a custom domain

To create a custom domain for your Knowledge base site instead of the default domain provided by Document360, you need to:

1. [**Adding custom domain in Document360**](/docs/custom-domain-mapping#add-domain-in-document360)
2. [**Configuring the CNAME in your domain registrar**](/docs/custom-domain-mapping#setting-up-your-cname)
3. [**Verifying the custom domain in Document360**](/docs/custom-domain-mapping#verify)

### Adding a custom domain in Document360

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1729689317870.png)

1. Navigate to **Settings ()** > **Knowledge base site** > **Custom domain** > **Custom domain mapping**.
2. Enter the custom domain in the **Domain configuration** field.
3. Click **Add domain.**

![17_Screenshot-Domain_configuration_adding_domain](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1729689397597.png)

4. Once the custom domain has finished setting up and configuration is complete, the records for the custom domain will be generated, and you will be notified in the Knowledge base portal.

### Configuring the CNAME record in your domain registrar

Once the domain is added in Document360, you'll need to configure a **CNAME** record within your **domain registrar** to link your custom domain to Document360’s servers.

To configure the CNAME record,

1. Log in to the domain registrar where you purchased your domain (e.g., GoDaddy, Namecheap, Google Domains).
2. In the domain management panel, navigate to DNS settings.
3. Add a new CNAME in the DNS settings.

   1. Enter your preferred custom domain in the Name/Host field (e.g., `help.yourcompany.com`).
   2. Enter the CNAME provided by Document360 in the Points to/Value field.
4. Enter the details for any other relevant fields and save the new CNAME.

#### Example for configuring a CNAME record

This is an example to demonstrate the CNAME mapping for domains registered with Hostinger.  
![11_Screenshot-Nameservers_example](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1729715917903.png)

1. Go to Hostinger's domain manage page.
2. Open the Domains section and select your domain.
3. Now click on the **DNS/Nameservers** on the left and select the **DNS records** tab.
4. Choose the type of record from the dropdown (CNAME).
5. Paste the value copied from Document360 in the **Points to** field.
6. Add the TTL (Time-To-Live) value and click on the **Add record** button.

![12_Screenshot-DNS_record_mapping_in_hostinger](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1729715957848.png)

#### Common domain registrars

Below is a list of some common domain registrars:

* **NameCheap** - [Support article](https://www.namecheap.com/support/knowledgebase/article.aspx/434/2237/how-do-i-set-up-host-records-for-a-domain/)
* **Domain.com** - [Support article](https://www.domain.com/help/article/dns-management-how-to-update-dns-records)
* **Google Domains** - [Support article](https://support.google.com/a/answer/47283)
* **Dreamhost** - [Support article](https://help.dreamhost.com/hc/en-us/articles/360035516812-Adding-custom-DNS-records)
* **Hover** - [Support article](https://help.hover.com/hc/en-us/articles/217282457-Managing-DNS-records-)
* **GoDaddy** - [Support article](https://in.godaddy.com/help/add-a-cname-record-19236)
* **Cloudflare** - [Support article](https://community.cloudflare.com/t/how-do-i-add-a-cname-record/59)
* **Bluehost** - [Support article](https://www.bluehost.com/hosting/help/cname)

---

### Verifying the custom domain in Document360

After you configure the CNAME, follow the below steps to complete the custom domain mapping configuration.

1. Go back to Document360’s **Custom domain** settings.
2. Select the checkbox that says, "**I've added the records**".
3. Click the **Verify** button, and the verification process is initiated.
4. If the verification is successful, you will get a success toast message.

NOTE

If there is any issue in configuring the custom domain, check the [**Troubleshooting**](/docs/custom-domain-mapping#troubleshooting) steps in the below section of this article.

After mapping the custom domain, click the **Go to your knowledge base site** icon to view the change in the site URL.

---

### Post mapping issues

**'Deceptive site ahead' message while accessing the site after successful custom domain mapping.**

![13_Screenshot-Deceptive_site_ahead_warning](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/13_Screenshot-Deceptive_site_ahead_warning.png)

This means that Google has flagged the custom domain you have mapped as unsafe for browsing.

* To **check the flagged status**, use the [Safe Browsing site status](https://transparencyreport.google.com/safe-browsing/search) by Google.
* Type in your mapped domain and check if there are any issues.
* Resolve and fix the issues detected (Phishing attacks, malware-infested, violating community guidelines, etc.).
* Submit a review request from Google Search Console. Google will update the status and remove the warning from your website.

Here is a help article from [**Google support**](https://support.google.com/chrome/answer/99020?hl=en&co=GENIE.Platform%3DDesktop).

![8_Screenshot-Troubleshooting_site_status](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1730023063313.png)

---

## Load balancer

A **load balancer** distributes incoming traffic evenly across multiple servers, ensuring that your Knowledge base site remains fast and reliable, even during high traffic periods. This helps prevent any single server from being overloaded and enhances the overall performance and security of your site.

Upgrading the load balancer can provide additional benefits, such as improved security features and better traffic management.

### Upgrading the load balancer

1. Navigate to **Settings ()** > **Knowledge base site**> **Custom domain** > **Custom domain mapping**.
2. Click **Upgrade**.
3. Verify the custom domain mapping configuration in Document360.
4. Copy the CNAME record generated in Document360.
5. Set up the CNAME record in your domain registrar.
6. Verify the custom domain mapping configuration in Document360.

> NOTE
>
> * This upgrade does not cause any downtime. However, we recommend this upgrade during your off-business hours
> * This upgrade is entirely free of cost
>
> Please contact our [support team](mailto:support@document360.com) for assistance.

---

## Configuring a custom domain for Apex domains

When configuring a custom domain for Document360, you may want to use your Apex domain (root domain), such as **abc.com** without a subdomain like **www****.** While configuring subdomains is straightforward, configuring Apex domains requires some extra steps, especially regarding DNS records.

**DNS flattening** is a method that allows you to use a **CNAME record** at the Apex (root) domain level, which not all domain registrars support. If your registrar does not support DNS flattening, you won’t be able to add a CNAME record for your Apex domain.

### Configuring Apex Domains

If your domain registrar doesn't support DNS flattening (for example, GoDaddy), you can opt for a **DNS provider** that does, such as **Cloudflare**. Cloudflare offers free plans that include DNS flattening, enabling you to configure your custom domain for the Apex domain successfully.

For example, let’s say you're using GoDaddy, which does not support DNS flattening. In this case, switching to a DNS provider like Cloudflare will allow you to add a CNAME record for your Apex domain.

> NOTE
>
> For more information, read the article on [**CNAME Flatting**](CNAME flattening)from Cloudflare.

### Using a custom SSL certificate

Use the SSL certificate provided by Document360 for your domain to ensure secure connections, as it offers automatic and seamless renewal for a smooth experience. Provide the following details to process your request to install a custom SSL certificate:

* **Common Name (CN)**: The fully qualified domain name for the certificate.
* **Organization (O)**: The legal name of your organization.
* **Organizational Unit (OU)**: The department or division within your organization.

> NOTE
>
> The certificate is typically valid for 90 days. You will have to renew the certificate on time and provide us with the updated certificate so we can install it on your domain.

---

## Troubleshooting

### Domain verification failed

If you are having issues verifying your custom domain, ensure that the [**CNAME**](/docs/custom-domain-mapping#cname) matches the domain host.

![7_Screenshot-Troubleshooting_invalid_record](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1729966781926.png)

There are chances for any other record to be mapped in the place of CNAME (such as AAAA records). This would also cause an error.

**Suggestion**: To view your domain's CNAME, and other DNS information, use [Digwebinterface](https://www.digwebinterface.com/) or [Google's DNS lookup](https://toolbox.googleapps.com/apps/dig/), or any other DNS lookup tool available on the web  
![9_Screenshot-Troubleshooting_digwebinterface](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1729967027700.png)

NOTE

For security reasons, some domain registrars can mask/restrict the DNS records from being discovered on the DNS lookup tools. One such example is **Cloudflare**.  
 In such cases, you can contact your domain registrar for more information.

Once the correct CNAME is mapped; it might take up to 24 hours for successful mapping.

---

### Wait time after DNS records are updated

If the CNAME match, and the domain verification issue persists, the TTL (Time-To-Live) can be a possible reason.

If you're updating an existing DNS Record value, it may take time for the configured TTL to reflect globally. If the TTL is set to 3600 for a DNS record; then, it may take up to 1 hour (3600 seconds) to reflect the DNS record value for the DNS Name server globally.

---

### CAA restriction set by the domain registrar

Some domain registrars set a restriction that the SSL certificate should be provisioned by the specific CAs (Certificate Authority).

For **example**, if a CAA DNS record has a value of 0 issues "letsencrypt.org", then only the Let's Encrypt (CA) will be able to generate a certificate for the particular custom domain. Other Certificate Authorities (DigiCert in our case) would see this configuration and would deny generating an SSL certificate.

Check if you have any CAA records configured in the DNS configuration for the custom domain.

---

### Resolving the “This site can’t be reached” error while accessing the Knowledge base site

While accessing the Knowledge base site, you might encounter errors such as “This site can’t be reached”. In such cases, follow the below troubleshooting steps:

1. Verify when the record was configured and confirm whether it was added immediately after receiving the required values.
2. Ensure propagation has been completed. (DNS records typically take 2-4 hours to propagate, but it is advisable to wait 24 hours for the changes to fully take effect.) If 24 hours have passed, move to the next step.
3. Use the Google Dig tool to verify the DNS records. Check for any duplicate entries associated with the same hostname.

   a. If duplicate records are found, remove them and test again.

   b. If no duplicates exist, proceed to the next step.
4. Check the CAA record entries in <https://dnschecker.org/>
5. If there are any CAA entries for the domain, ensure that CAA entries for our SSL providers are also added.
6. Our SSL providers are Lets Encrypt, Digicert, and Google.
7. Add the following CAA records for SSL providers:

   @ IN CAA 0 issue [digicert.com](http://digicert.com)

   @ IN CAA 0 issue [letsencrypt.org](http://letsencrypt.org)

   @ IN CAA 0 issue [pki.goog](http://pki.goog)

---

### Resolving errors such as “Your connection is not private” or “Your connection is not secure” while accessing the Knowledge base site

This error typically occurs due to the following reasons:

1. **Issue: SSL certificate expired**

1. Check if the SSL certificate has expired.
2. Visit the Knowledge base site and click the **View site information** option in the URL bar.
3. Click **Connection is secure** to view the SSL certificate details.

**B. If the SSL Certificate has not expired, then try the below troubleshooting steps:**

1. Try accessing the site from a different browser to rule out browser-specific issues.
2. Disable any website extensions in your browser and check again.
3. Verify if all users are experiencing the same issue to identify if it is user-specific or system-wide.
4. Clear your browser cache or switch to another browser, as this often resolves the problem.

**C. VPN connection**

1. Disable your VPN and try accessing the site again:
2. If disabling the VPN resolves the issue, the VPN might be causing the problem.
3. Contact your IT team for further assistance.

**D. DNS records issue**

There may be issues with the DNS resolver if the DNS records have not been updated successfully.

1. Use a DNS checker (e.g., [DNS Checker](https://dnschecker.org/)) to verify the DNS records.
2. Confirm if all the records have been updated successfully.
3. If the records are not properly synced, contact your DNS provider or domain registrar to ensure the DNS zone is correctly configured and synced for the domain.

If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

---

### FAQs

#### Do I need an SSL certificate to configure a custom domain?

Document360 automatically provides an SSL certificate for your custom domain when you map it to your project. You do not need to purchase an additional SSL certificate. However, if you prefer to use your own SSL certificate instead of the one provided by Document360, please reach out to our support team at [support@document360.com](mailto:support@document360.com).

#### Will the custom domain URL reflect in the invitation email sent to readers?

Yes, if the invitation email is sent to readers after the custom domain has been successfully mapped, the email links will point to the custom domain.

#### What do I do if the CNAME is not verified after updating the DNS?

If the CNAME is not verified after updating the DNS, you will have to reconfigure your custom domain.

* Remove the current custom domain configuration.
* Re-add the custom domain and update the CNAME on your DNS.
* Ensure the CNAME is verified to complete the setup.

#### Can I configure two custom domains for a single Knowledge base site?

No, it is not possible to configure two custom domains for a single KB site. However, you can set up a redirection from one domain to the other. This way, visitors to the first domain will be redirected to the second domain.

#### Can I set up multiple domains for a single project in Document360?

Currently, Document360 supports only one custom domain per project.

#### What is a Naked Domain?

A naked domain is a domain that does not include the "www" prefix. For example, if the domain is `example.com`, that's a naked domain, whereas `www.example.com` is not.

By default, most domains will have the "www" subdomain, but a naked domain like `yourcompany.com` doesn't include this subdomain.

#### What is a domain registrar?

A **domain registrar** is a company where you purchase and manage your website’s domain name (e.g., GoDaddy, Namecheap, or Google Domains). This is where you'll update the settings for your custom domain to connect it to Document360.

#### What is a CNAME record?

A **CNAME (Canonical Name) record** is a type of DNS setting (DNS, or Domain Name System, is like the internet’s address book, directing users to the right web server). The CNAME connects your custom domain (e.g., `help.yourcompany.com`) to another address, like the default domain provided by Document360. This ensures that when someone types your custom domain, they are taken to your Knowledge base sight.

#### Why do I need to upgrade to the new load balancer?

* It implements SSL offloading, reducing the load on servers, and improving security by handling SSL encryption/decryption at the load balancer level.
* It includes a web application firewall (WAF) for protection against common web attacks such as SQL injection and cross-site scripting.
* It utilizes dynamic traffic management algorithms for optimal traffic distribution and improved performance.

We strongly recommend upgrading to this advanced solution for improved security and reliability.

#### Is it possible to create a separate domain for each version of my project?

No, it is not currently possible to assign separate domains to individual versions. When you create a new version, you can only customize the path within the existing domain.

A Canonical Name record maps a subdomain to its main domain for hosting purposes.

A Canonical Name record maps a subdomain to its main domain for hosting purposes.

A Canonical Name record maps a subdomain to its main domain for hosting purposes.

The duration, specified in seconds, that a DNS record is cached before the server queries for an updated value. For example, a TTL of 600 seconds means the record will be cached for 10 minutes.

A server that stores information about a domain, such as its address, mail settings, and other DNS records, and responds to queries about this information.

A Certification Authority Authorization (CAA) is a DNS record that specifies authorized certificate authorities for a domain, enhancing security.

<a id="document360-on-a-sub-folder"></a>

## Hosting Document360 on a sub-directory

**Plans supporting hosting Document360 on a sub-directory**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## **What is subfolder hosting?**

Subfolder hosting is a type of website hierarchy under a root domain that uses folders to organize content on a website. A subfolder is the same as a subdirectory; the names can be used interchangeably.

The subfolder/subdirectory comes after the root directory or domain name in a URL.

> **For example**, Document360’s root domain is `document360.com`. So, a subfolder/subdirectory path URL might be `document360.com/docs/`.

Most companies host their documentation under a subfolder/subdirectory on their website domain.

> **For example**: `example.com/docs`, `example.com/support`, etc.

This is because hosting a knowledge base on a subdirectory/subfolder of a website (`example.com/docs`) rather than a subdomain (`docs.example.com`) is better for Search Engine Optimization (SEO).

> NOTE
>
> Subfolder/subdirectory hosting can be enabled for **Document360 provided domains** and mapped **custom domains**.

---

## Enabling Subfolder hosting

To enable the subfolder hosting for your project,

1. Navigate to **Settings** () > **Knowledge base site** > **Custom domain** > **Subfolder hosting** tab in the Knowledge base portal.
2. By default, the Subfolder path is set to **/docs**.
3. Turn on the toggle next to "This documentation is hosted on a sub folder."

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Subfolder_hosting_tab_in_settings.png)

### Custom Subfolder paths

You can also set up your knowledge base on subfolder/subdirectory paths other than `/docs`.

> **For example**, `/help`, `/support`, etc.

1. Navigate to **Settings** () > **Knowledge base site** > **Custom domain** > **Subfolder hosting** tab in the Knowledge base portal.

   By default, the **Subfolder path** is set to **/docs**.
2. Clear the **Subfolder path** field and enter your custom subfolder path (**For example,** `/help`).
3. Click on the **Update** button on the right.
4. This new custom subfolder will only work if the subfolder hosting setting is enabled in your project.

When setting up other paths, add the languages associated with each workspace in your project. This configuration varies depending on the different web servers.

> **NOTE**
>
> For projects configured with custom domain and subfolder hosting, the **Article preview** option is not supported yet.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Custom_domain_subfolder_path.png)

### Custom Site API paths

> For your information (FYI)
>
> The Custom Site API paths feature is available only in KB site 2.0 projects. To migrate from KB site 1.0 to KB site 2.0, read the article on [KB site 2.0 migration](/help/docs/kb-site-20-migration).

By default, the Site API path is set to `/api`. You can customize the **Site API path** as well from the **Subfolder hosting** tab in the custom domain settings.

For example, `/docs-api`, `/api-docs`, etc.

> CAUTION
>
> For **KB site 2.0** projects, subfolder hosting will work only when both the **Subfolder path** as well as the **Site API path** have been defined.

1. Navigate to **Settings** () > **Knowledge base site** > **Custom domain** > **Subfolder hosting** tab in the Knowledge base portal.
2. By default, the **Site API path** is set to **/api**.
3. Clear the **Site API path** field and enter your custom site API path (**For example,** `/docs-api`).
4. Click on the **Update** button on the right.
5. This new custom site API path will only work if the subfolder hosting setting is enabled in your project.

> NOTE
>
> The Custom **Site API path** is not the path for **API Documentation**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Custom_domain_site_api_path.png)

---

## Web servers

Here are some of the commonly used web servers

* **Apache HTTP server**
* **Nginx server**
* **ASP.NET Core server**
* **Microsoft - IIS server**
* **OpenResty server**
* **LiteSpeed server**
* **Cloudflare server**

> NOTE
>
> **What is a web server?**  
> A web server stores and delivers the content for a website – such as text, images, video, and application data – to clients that request it. The most common type of client is a web browser program.

---

## What happens next?

Once the web server is successfully configured, your knowledge base site will be live on your custom subfolder/subdirectory. However, the existing URL for your project will serve the requests.

> **For example,** `example.document360.io` and `example.com/docs` (if `/docs` is your folder path) will point to the Knowledge base site.

This will cause duplicate content in Search engines (Google, Bing, etc.). For this, you will need to enable a URL redirect.

> NOTE
>
> To enable the redirect from `example.document360.io` to `example.com/docs`, please contact us at [**support@document360.com**](mailto:support@document360.com).

---

### FAQs

#### What is a Canonical URL?

A canonical URL is the official link that tells search engines which version of a page to index and display in search results when there are multiple URLs for the same content. This helps prevent duplicate content issues and ensures the preferred URL is ranked properly in search results.

For example:

If your page is accessible through multiple URLs, such as:

* `https://example.com/page`
* `https://www.example.com/page`
* `https://example.com/page?utm=123`

You can set one of them (e.g., `https://www.example.com/page`) as the canonical URL to signal search engines to prioritize it.

#### How can I configure the canonical URL in Document360?

You can use the Canonical domain setting to globally replace the project subdomain with your specified domain for canonical URLs in all articles. This is particularly useful if you want to signal to search engines to index your custom domain (e.g., `www.yourdomain.com`) instead of the Document360 domain.

To change the canonical URL globally, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base site** > **Custom domain** > **Subfolder hosting** tab in the Knowledge base portal.
2. Under **Subfolder hosting**tab, locate the **Canonical domain** option.
3. Enter your desired domain (e.g., `https://www.yourdomain.com`).
4. Click **Save**to save your changes.

<a id="nginx-server"></a>

## Nginx server - Subfolder hosting

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Nginx is an open-source web server. To know more, visit the [**Nginx documentation**](https://nginx.org/en/docs/)

---

## Setting up a subfolder/subdirectory

**Example:**

> NOTE
>
> Replace the example domain with your own document360 provided domain/custom domain.
>
> * Example domain represented using `example.document360.io`
> * Subfolder/subdirectory path (/docs) represented as `example.document360.io/docs`

1. Add the following location blocks in your Nginx configuration file (`/etc/nginx/default`).

```
location /docs {
    proxy_pass https://example.document360.io/docs;
    proxy_set_header Host example.document360.io;
    proxy_set_header X-Real-IP $remote_addr;
    proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
    proxy_set_header X-Forwarded-Proto $scheme;
    proxy_set_header "requested-by" "proxy";
    proxy_ssl_server_name   on;
}
```

Plain text

Copy

2. Restart the Nginx web server
3. For example, if you are using Nginx on Linux, then use the command  
   `$ sudo systemctl restart nginx`

> NOTE
>
> If you are on KB Site 2.0 and wish to host your Knowledge base as a subfolder, you have to define the Subfolder path as well as the Site API path.

---

### To setup on other than '/docs' path

* You can set up your knowledge base on subdirectory paths other than `/docs`.  
  For example, `/help`, `/support`, etc.
* When setting up other paths, add the languages associated with each Workspace.
* A few more lines need to be added to achieve this. Restart the server once done.

**Example:**

> NOTE
>
> Replace the Document360 provided domain and the subdirectory domain with your own domains. Also, replace the workspace name, subfolder path, and language with your requirements.
>
> * Document360 provided domain represented as `example.document360.io`
> * Workspace name represented as `/v1/`
> * Subfolder path represented as `/help/`
> * Language represented as `/he` for Hebrew.

```
location /help {
    proxy_pass https://example.document360.io/docs;
    proxy_set_header Host example.document360.io;
    proxy_set_header X-Real-IP $remote_addr;
    proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
    proxy_set_header X-Forwarded-Proto $scheme;
    proxy_set_header "requested-by" "proxy";
    proxy_ssl_server_name   on;

    sub_filter "v1/docs/" "v1/help/";
    sub_filter "docs/he/" "/help/he";
    sub_filter "/docs/" "/help/";
    sub_filter_once off;
}

```

Plain text

Copy

1. Restart the Nginx web server
2. For example, if you are using Nginx on Linux, then use the command  
   `$ sudo systemctl restart nginx`

---

### To enable the workspaces dropdown

If you want to enable the workspace dropdown navigation for your project when you host in a custom subdirectory and path, add the following codes for each of the workspaces available in your project.

**Example:**

Let's assume there are two workspaces available in your project, **v1** and **v2**. In that case, you must add two code blocks, one for each Workspace.

> NOTE
>
> Replace the Document360 provided domain and the subdirectory domain with your own domains. Also, replace the workspace name, subfolder path, and language with your requirements.
>
> * Document360 provided domain represented as `example.document360.io`
> * Workspace name represented as `/v1/`,`/v2/`
> * Subfolder path represented as `/help/`
> * Language represented as `/he` for Hebrew.

```
location /v2/help {
    proxy_pass https://example.document360.io/v2/docs;
    proxy_set_header Host example.document360.io;
    proxy_set_header X-Real-IP $remote_addr;
    proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
    proxy_set_header X-Forwarded-Proto $scheme;
    proxy_set_header "requested-by" "proxy";
    proxy_ssl_server_name   on;

    sub_filter "v2/docs/" "v2/help/";
    sub_filter "docs/he/" "/help/he";
    sub_filter "/docs/" "/help/";
    sub_filter_once off;
}
-----------------------------------------------------
location /v1/help {
    proxy_pass https://example.document360.io/v1/docs;
    proxy_set_header Host example.document360.io;
    proxy_set_header X-Real-IP $remote_addr;
    proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
    proxy_set_header X-Forwarded-Proto $scheme;
    proxy_set_header "requested-by" "proxy";
    proxy_ssl_server_name   on;

    sub_filter "v1/docs/" "v1/help/";
    sub_filter "docs/he/" "/help/he";
    sub_filter "/docs/" "/help/";
    sub_filter_once off;
}
-----------------------------------------------------
location = /v2/docs {
    return 301 /v2/help;
}
-----------------------------------------------------
location = /v1/docs {
    return 301 /v1/help;
}

```

Plain text

Copy

> NOTE
>
> If you want your readers to navigate between the different public workspaces of your project from the dropdown (on mouse click), add the location block for all available workspaces.

1. Restart the Nginx web server
2. For example, if you are using Nginx on Linux, then use the command  
   `$ sudo systemctl restart nginx`

---

## Helpful Links

Here are a few external links that may help you understand the Nginx server **location blocks** in detail:

* [NGINX Docs: Configuring NGINX and NGINX Plus as a Web Server](https://docs.nginx.com/nginx/admin-guide/web-server/web-server/)
* [DigitalOcean: Understanding Nginx Server and Location Block Selection Algorithms](https://www.digitalocean.com/community/tutorials/understanding-nginx-server-and-location-block-selection-algorithms)

---

## Sitemap generation

**Example:**

> NOTE
>
> Replace the example domain with your own document360 provided domain/custom domain.
>
> * Example domain represented using `example.document360.io`
> * The sitemap prefix remains the same except for the language code (en, fr, de, etc.)  `example.document360.io/sitemap.xml.en`

```
location /sitemap.xml.en {
proxy_pass https://example.document360.io/sitemap.xml.en;
proxy_set_header Host example.document360.io;
proxy_set_header X-Real-IP $remote_addr;
proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
proxy_set_header X-Forwarded-Proto $scheme;
proxy_set_header "requested-by" "proxy";
proxy_ssl_server_name   on;
```

Plain text

Copy

---

## Home page hosted on a subfolder

To host your project's home page on a custom subdirectory/subfolder path, add the following codes for each of the home page workspaces available in your project.

**Example:**

Let's assume there are two workspaces available in your project, **V1** and **V2**. In that case, you must add two code blocks, one for each Workspace.

> NOTE
>
> Replace the Document360 provided domain and the subdirectory domain with your own domains. Also, replace the workspace name, subfolder path, and language with your requirements.

* Document360 provided domain represented as `example.document360.io`
* Workspace name represented as `/v1/`,`/v2/`

```
location =/v1 {
proxy_pass https://example.document360.io/;
proxy_set_header Host example.document360.io;
proxy_set_header X-Real-IP $remote_addr;
proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
proxy_set_header X-Forwarded-Proto $scheme;
proxy_set_header "requested-by" "proxy";
proxy_ssl_server_name   on;
}
location =/v2 {
proxy_pass https://example.document360.io/;
proxy_set_header Host example.document360.io;
proxy_set_header X-Real-IP $remote_addr;
proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
proxy_set_header X-Forwarded-Proto $scheme;
proxy_set_header "requested-by" "proxy";
proxy_ssl_server_name   on;
}
location /v1/en {
  return 301 /v1;
}
location /v2/en {
  return 301 /v2;
}
```

Plain text

Copy

> PRO TIP
>
> The equal sign can be used if the location needs to match the exact request URI. When this modifier is matched, the search stops right here. For more information, [**click here**](https://docs.nginx.com/nginx/admin-guide/web-server/web-server/#locations)**.**
>
> **Example:** `location =/help {`

2. Restart the Nginx web server
3. For example, if you are using Nginx on Linux, then use the command  
   `$ sudo systemctl restart nginx`

**Knowledge base site home page**

The default home page for a knowledge base site appears at the root directory (For example, `example.document360.io`). If the project contains a Workspace and language-specific home page, the slug following the root directory would be /<workspace\_name>/<language\_code>. (For example,`example.document360.io/v2/he`)

---

## What happens next?

Once you have successfully configured the web server, your knowledge base site is live on your custom subfolder/subdirectory. However, the existing URL for your project will serve the requests.

> **For example,** `example.document360.io` and `example.com/docs` (if `/docs` is your folder path) will point to the knowledge base site.

This may cause duplicate content in search engines (Google, Bing, etc.). A redirect from the Document360 project sub-domain to your custom domain will be required to prevent this.

> NOTE
>
> To enable the redirect from `example.document360.io` to `example.com/docs`, please contact us at [**support@document360.com**](mailto:support@document360.com).

---

## Troubleshooting

This section provides step-by-step guidance to troubleshoot common challenges you may face during the NGINX setup process. From subfolder hosting issues to failed configuration tests, each solution is designed to help you quickly identify and resolve potential roadblocks, ensuring a smooth and efficient server configuration.

### Resolving invalid location directive in NGINX

**Error:** nginx: [emerg] "location" directive is not allowed here

This error occurs when a location directive is placed outside its valid context, such as outside the server block. In NGINX, location blocks must be defined within a server block.

**Steps to resolve:**

1. Ensure that the location block is placed correctly within the server block. Refer to the below sample block:

   ```
   server {
       listen 80;
       server_name example.com;
       location /docs {
           proxy_pass https://example.document360.io/docs;
           proxy_set_header Host example.document360.io;
       }
   }
   ```

   nginx

   Copy
2. To avoid this issue, do not place location directives in the global `http` context or outside the `server` context.
3. If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

### Certbot package availability issue

**Error:** No package Certbot available

This issue often occurs when the EPEL repository (required for Certbot installation on RHEL-based distributions) is not enabled, or the package manager is unable to locate Certbot on RHEL-based distributions.

**Steps to resolve:**

1. Enable the EPEL repository by using the below code:

   ```
   sudo yum install epel-release
   ```

   nginx

   Copy
2. Update the repository cache and try installing Certbot again by using the below code:

   ```
   sudo yum install certbot
   ```

   nginx

   Copy
3. Ensure your instance has internet access to fetch the repository files. If the problem persists, verify the repository configuration files in `/etc/yum.repos.d/`.
4. If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

### NGINX configuration test issue

**Error:** NGINX configuration test failed

This issue occurs when there is a syntax error in the NGINX configuration file.

**Steps to resolv**e:

1. Run the configuration test command:

   ```
   sudo nginx -t
   ```

   nginx

   Copy
2. Review the error message and the line number like the example shown below:

   ```
   nginx: [emerg] invalid parameter "proxy_pas" in /etc/nginx/sites-enabled/example:22
   nginx: configuration file /etc/nginx/nginx.conf test failed
   ```

   nginx

   Copy
3. Open the specified file `/etc/nginx/sites-enabled/example` and fix the configuration issue. For example:

   ```
   # Incorrect
   proxy_pas https://example.com;

   # Correct
   proxy_pass https://example.com;
   ```

   nginx

   Copy
4. Once the configuration issue is fixed, restart NGINX:

   ```
   sudo systemctl restart nginx
   ```

   nginx

   Copy
5. If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

### SSL certificate issue

**Error:** SSL certificate not working

This issue may occur due to an incorrect NGINX SSL configuration or when there is an issue with the installed certificate. The certificate details such as domain and expiry date might not match the configuration details.

**Steps to resolve:**

1. Verify the certificate files by using the below code:

   ```
   openssl x509 -in /etc/letsencrypt/live/yourdomain.com/fullchain.pem -text -noout
   ```

   nginx

   Copy
2. Ensure that your configuration matches the certificate details, such as domain and expiry date.
3. Ensure the NGINX SSL configuration is correct. Refer to the below code as an example:

   ```
   server {
       listen 443 ssl;
       server_name yourdomain.com;
       
       ssl_certificate /etc/letsencrypt/live/yourdomain.com/fullchain.pem;
       ssl_certificate_key /etc/letsencrypt/live/yourdomain.com/privkey.pem;
   }
   ```

   nginx

   Copy
4. Once done, restart NGINX using the below code:

   ```
   sudo systemctl restart nginx
   ```

   nginx

   Copy
5. If the issue persists after following these steps, please contact the Document360 support team for further assistance: [Contact Document360 Support](https://document360.com/support/)

---

### FAQ

**Why is my site home page not available?**

Once you have designed the project’s home page using the site builder, ensure that you have published it. Confirm the home page is live and accessible to the intended audience.

<a id="aspnet-core-server"></a>

## ASP.NET Core server

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Hosting a knowledge base in a subfolder offers a seamless way to integrate documentation into your existing website structure. For example, setting up a subfolder path like `/help` allows users to access your knowledge base directly within your domain, such as `example.document360.io/help`.

To get started, ensure you replace the example domain in the configurations with your own Document360 provided domain or your custom domain.

---

### Setting up a sub folder path

1. Install the [**ASP.Net Core package**](https://www.nuget.org/packages/Microsoft.AspNetCore.Proxy/)**.**
2. In the `Standard.cs` file, configure the `method` as follows:

```
public void Configure(IApplicationBuilder app, IHostingEnvironment env)
        {
            /// ...
            app.MapWhen(ctx => ctx.Request.Path.StartsWithSegments("/docs"),
                builder => builder.RunProxy(new ProxyOptions() {
                    Scheme = "https",
                    Host="example.document360.io"
            }));
            
           /// ...

```

Plain text

Copy

> NOTE
>
> If you are on KB Site 2.0, and wish to host your Knowledge base as a subfolder, you have to define the Subfolder path as well as the Site API path.

---

## What happens next?

Once you have successfully configured the web server, your knowledge base site is now live on your custom subfolder/subdirectory. However, the existing URL for your project will serve the requests.

> **For example,** `example.document360.io` and `example.com/docs` (if `/docs` is your folder path) will point to the knowledge base site.

This will cause duplicate content in Search engines (Google, Bing, etc.). For this, you will need to enable a URL redirect. Enabling a URL redirect prevents search engines like Google or Bing from indexing duplicate content, which can negatively impact your site's search rankings.

> NOTE
>
> To enable the redirect from `example.document360.io` to `example.com/docs`, please contact us at [**support@document360.com**](mailto:support@document360.com).

<a id="microsoft-iis-server"></a>

## Microsoft - IIS server

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Hosting a knowledge base in a subfolder offers a seamless way to integrate documentation into your existing website structure. For example, setting up a subfolder path like `/help` allows users to access your knowledge base directly within your domain, such as `example.document360.io/help`.

To get started, ensure you replace the example domain in the configurations with your own Document360 provided domain or your custom domain.

---

### Pre-requisites

* [**Application Request Routing module**](https://www.iis.net/downloads/microsoft/application-request-routing) for IIS
* [**URL Rewrite Module**](https://iis-umbraco.azurewebsites.net/downloads/microsoft/url-rewrite) for IIS

---

## Setting up a sub-folder path

1. Install the [**URL Rewrite module for IIS Server**](https://www.iis.net/downloads/microsoft/url-rewrite)
2. Install the Application Request Routing module, and ensure it is enabled.
3. Add the following rewrite rule in `web.config` to rewrite contents from your documentation at `/help`.

```
<?xml version="1.0" encoding="UTF-8"?>
<configuration>
    <system.webServer>
        <rewrite>
            <rules>
                <rule name="ReverseProxy_HomePage" enabled="true" stopProcessing="true">
                    <match url="^help$" />
                    <action type="Rewrite" url="https://example.document360.io/v1" />
                    <serverVariables>
                        <set name="HTTP_requested_by" value="proxy" />
                        <set name="HTTP_X_ORIGINAL_ACCEPT_ENCODING" value="{HTTP_ACCEPT_ENCODING}" />
                        <set name="HTTP_ACCEPT_ENCODING" value="" />
                    </serverVariables>
                </rule>
        <rule name="ReverseProxy_DocsPage" enabled="true" stopProcessing="true">
                    <match url="^help/(.*)" />
                    <action type="Rewrite" url="https://example.document360.io/help/{R:1}" />
                    <serverVariables>
                        <set name="HTTP_requested_by" value="proxy" />
                        <set name="HTTP_X_ORIGINAL_ACCEPT_ENCODING" value="{HTTP_ACCEPT_ENCODING}" />
                        <set name="HTTP_ACCEPT_ENCODING" value="" />
                    </serverVariables>
                </rule>
            </rules>
            <outboundRules>
                <rule name="RestoreAcceptEncoding" preCondition="NeedsRestoringAcceptEncoding">
                    <match serverVariable="HTTP_ACCEPT_ENCODING" pattern="^(.*)" />
                    <action type="Rewrite" value="{HTTP_X_ORIGINAL_ACCEPT_ENCODING}" />
                </rule>
        <rule name="RewriteLinksToSourceDomain1" preCondition="ResponseIsHtml">
                    <match filterByTags="None" pattern="^https://example.document360.io/(.*)" />
                    <action type="Rewrite" value="https://example.com/{R:1}" />
                </rule>
        <rule name="RewriteLinksToSourceDomain2" preCondition="ResponseIsHtml">
                    <match filterByTags="None" pattern="&quot;/help&quot;" />
                    <action type="Rewrite" value="&quot;/help&quot;" />
                </rule>
        <rule name="RewriteLinksToSourceDomain3" preCondition="ResponseIsHtml" patternSyntax="ECMAScript">
                    <match filterByTags="A" pattern="(.*)/docs/(.*)" />
                    <action type="Rewrite" value="/help/{R:2}" />
                </rule>
                <preConditions>
        <preCondition name="ResponseIsHtml">
                        <add input="{RESPONSE_CONTENT_TYPE}" pattern="^text/html" />
                    </preCondition>
                    <preCondition name="NeedsRestoringAcceptEncoding">
                        <add input="{HTTP_X_ORIGINAL_ACCEPT_ENCODING}" pattern=" .+" />
                    </preCondition>
                </preConditions>
            </outboundRules>
        </rewrite>
    </system.webServer>  
</configuration>

```

XML

Copy

The `web.config` file is located in your IIS root directory. Make sure to back up the file before making changes.

> NOTE
>
> If you are on KB Site 2.0, and wish to host your Knowledge base as a subfolder, you have to define the Subfolder path as well as the Site API path.

---

## What happens next?

Once you have successfully configured the web server, your knowledge base site is live on your custom subfolder/subdirectory.

However, the existing URL for your project will serve the requests.

> **For example,** `example.document360.io` and `example.com/help` (if `/help` is your folder path) will point to the Knowledge base site.
>
> Remember to replace `example.document360.io` and `example.com/help` with your domain. For example, `yourcompany.document360.io` and `yourcompany.com/help`.

This will cause duplicate content in Search engines (Google, Bing, and more.). For this, you will need to enable a URL redirect. Enabling a URL redirect prevents search engines like Google or Bing from indexing duplicate content, which can negatively impact your site's search rankings.

> NOTE
>
> To enable the redirect from `example.document360.io` to your custom subfolder `example.com/help`, please contact us at [**support@document360.com**](mailto:support@document360.com).

---

### FAQs

**What is Internet Information Services (IIS)?**

IIS is a flexible, secure web server created by Microsoft for hosting websites, applications, and services on Windows. It supports protocols like HTTP, HTTPS, FTP, and more, making it widely used for web hosting and application deployment in Windows environments.

**What is the Application Request Routing (ARR) module?**

The ARR module is an IIS extension that enables load balancing, routing requests to different servers based on rules, and improving application performance.

**What is the URL Rewrite module in IIS?**

This IIS module allows you to create rules for modifying URLs, enabling custom paths for accessing content or redirecting users seamlessly.

**What is the purpose of the** `web.config` **file in IIS?**

The `web.config` file stores configuration settings for applications running on IIS, such as URL rewrite rules, security settings, and server behavior.

The public-facing website where end-users can access articles and find answers to their questions.

<a id="apache-http-server"></a>

## Apache HTTP server

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Apache HTTP** web server, also known as Apache server, is a free, open-source web server. Apache is highly flexible and customizable. You can easily enable or disable various functionalities.

> NOTE
>
> Replace the example domain with your document360 provided domain/custom domain.
>
> * Example domain represented using `example.document360.io`
> * Subfolder/subdirectory path (/v1) represented as `example.document360.io/v1`
> * Subfolder/subdirectory home page path (/help) represented as `example.document360.io/help`

### Setting up a sub folder path

Ensure the following Apache server modules are enabled. These modules are part of the Apache server installation.  
 • proxy  
 • proxy\_http  
 • headers  
 • substitute  
 • proxy\_html  
 Run the following bash command to enable the modules:

```
    sudo a2enmod proxy proxy_http headers substitute proxy_html
```

Bash

Copy

#### Home page

1. Configure the following Virtual Host configuration location blocks.

For example,

* **Location Block** - Proxy all requests where the path starts from "/help".

This block will proxy requests for the home page.

```
<Location /help>
   ProxyPreserveHost off
   RequestHeader set Host example.document360.io
   RequestHeader set requested-by proxy
   RequestHeader unset Accept-Encoding
   ProxyPass https://example.document360.io/v1
   ProxyPassReverse https://example.document360.io/v1



   AddOutputFilterByType SUBSTITUTE text/html
   substitute 's|href="/docs|href="/help|ni'
   substitute 's|href="/v1/docs|href="/help|ni'
   substitute 's|href="https://example.document360.io/docs|href="https://docs.example.com/help|ni'
</Location>
```

Plain text

Copy

**Redirect block to fix article preview links for sub folder hosting**

2. The article preview links in Document360 portal contain the workspace and language slug in the URL.

For example,

* **Article URL**: `docs.example.com/getting-started`
* **Preview links in the Knowledge base portal**: `docs.example.com/v1/en/getting-started`

You can either add one more location block to handle `/v1/en` path, (or) have a redirect set from `/v1/en` to `/`.

Please refer to the code snippet below for setting the redirect:

```
RewriteEngine on
RewriteRule ^v1/en$ / [R=301,L,NC]
```

Bash

Copy

You should install the `rewrite` module for the redirection to work. Use the following code to install the `rewrite` module.

> `sudo a2enmod rewrite`

#### Article/Category pages

3. Configure the following Virtual Host configuration location blocks.

For example,

* **Location Block** - Proxy all requests where path starts from "**/help/**"

This block will proxy requests for all the article/category pages.

```
<Location /help/>
   ProxyPreserveHost off
   RequestHeader set Host example.document360.io
   RequestHeader set requested-by proxy
   ProxyPass https://example.document360.io/docs/
   ProxyPassReverse https://example.document360.io/docs/



   AddOutputFilterByType SUBSTITUTE text/html
   substitute 's|href="/docs|href="/help|ni'
   substitute 's|href="/v1/docs|href="/help|ni'
   substitute 's|href="https://example.document360.io/docs|href="https://docs.example.com/help|ni'
</Location>
```

Plain text

Copy

4. Restart the Apache server

> **For example**, If you are using Nginx on Linux, then use the command  
> `$ sudo systemctl restart nginx`

> NOTE
>
> If you are on KB Site 2.0, and wish to host your Knowledge base as a subfolder, you have to define the Subfolder path as well as the Site API path.

---

## Sitemap generation

> NOTE
>
> Replace the example domain with your document360 provided domain/custom domain.
>
> * Example domain represented using `example.document360.io`
> * The sitemap prefix remains the same except for the language code (en, fr, de, etc.)  `example.document360.io/sitemap.xml.en`

```
<Location /sitemap.xml.en>
    RequestHeader set Host example.document360.io
    RequestHeader set requested-by proxy
    ProxyPass https://example.document360.io/sitemap.xml.en
    ProxyPassReverse https://example.document360.io/sitemap.xml.en
</Location>
```

Bash

Copy

---

## What happens next?

Once you have successfully configured the web server, your knowledge base site is live on your custom subfolder/subdirectory.

However, the existing URL for your project will serve the requests.

> **For example,** `example.document360.io` and `example.com/docs` (if `/docs` is your folder path) will point to the knowledge base site.

This will cause duplicate content in Search engines (Google, Bing, etc.). For this, you will need to enable a URL redirect.

> NOTE
>
> To enable the redirect from `example.document360.io` to `example.com/docs`, please contact us at [**support@document360.com**](mailto:support@document360.com).

<a id="reader-self-registration"></a>

## Readers self registration

**Plans supporting for Readers self-registration**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

NOTE

The **Self-registration** feature in Document360 is available only when the Knowledge base site access is set to **Private** or **Mixed**.

## Readers self-registration

Self-registration lets users create their own reader accounts without needing an invitation from a project team member. To enable self-registration, share your knowledge base URL with users, allowing them to create their accounts independently.

Once registered, readers are automatically added to the **Readers** list. Project members with access to **User & Security** settings can edit or remove these readers as needed.

### Self-register on a Knowledge base site

1. Go to your Knowledge base site.
2. Click **Sign up** at the bottom of the login screen.

   ![User self registration step](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/new%20account(1).png)
3. Enter your **First name**, **Last name**, and **Email**.
4. Click **Sign up**.

![10_Screenshot-Self_signup_site_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Self sign up.png)

You will get a confirmation message saying ‘*Account created successfully*’.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/New account created.png)

You will receive an invitation email. Once verified, you can set a password and log in to the knowledge base site.

NOTE

An email only needs to be verified once. After that, it can be used across multiple projects.

---

## Accessing the Reader self-registration option

1. Navigate to Settings () **> Users & Security > Readers & groups** in the knowledge base portal.

   The **Readers & groups** overview page appears.
2. Select the **Reader self-registration** tab.

   ![User self registration step](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1731477666955.png)
3. If the **Enable Self-Registration** toggle is turned off, the page will be empty. You can have a private or mixed knowledge base without enabling the self-registration feature.
4. If the **Enable Self-Registration** toggle is turned on, you’ll see the following options:

   1. **Add to default reader group -** This is an optional field.

      Newly self-registered readers are automatically grouped under the selected default reader group(s). If a reader’s email domain is already mapped to an existing reader group, they will be assigned to that group.

      To assign a default reader group:

      1. On the **Domain Readers Self-Registration** page, click inside the **Default Reader Group** field to see the list of available reader groups.
      2. Select one or more reader groups as the default for new self-registered readers.
      3. The selected groups will appear in the field.
      4. To remove a reader group, click the cross ‘**X**’ icon next to the group name.
      5. Click **Save** when done.
   2. **Restrict registration by domain -** This is an optional field.

      You can configure your Document360 knowledge base to allow or block self-registrations based on a user’s email domain.

      * **Allow Self-Registration from Specific Domains:**  
        To restrict self-registration to employees of a specific organization, set up a domain restriction.  
        Example: Add the company’s email domain (e.g., `@examplecorp.com`) and set the status to **Allow**.
      * **Block Self-Registration from Specific Domains:**  
        To block unauthorized users, add specific domains to the block list.  
        Example: Add general email domains (e.g., `@genericmail.com`) and set the status to **Block**.

---

## Adding a domain restriction

1. Navigate to Settings () **> Users & Security > Readers & groups** > **Reader self-registration** tab in the knowledge base portal.
2. Scroll down to the **Domain Restriction** section.
3. In the **Domain Name** field, enter the domain you wish to allow or block (e.g., everything after the **@** symbol, like `@genericmail.com` or `@randomdomain.com`).
4. Select one of the following options:

   * **Allow (Whitelist)**: Permits users with the specified domain emails to self-register. All other users will be unable to register.
   * **Block (Blacklist)**: Prevents users with the specified domain emails from self-registering. If only blocked domains are listed, self-registration will be disabled for all users.
5. Assign **Added reader groups** to each domain by selecting one or more groups from the dropdown menu.

   * To remove a selected reader group, click the '🗙' icon next to it.
   * Click Save () to confirm. Alternatively, click () to clear the entries in the line.
   * Click Remove () to delete the line completely.
6. Click **Add domain** to include additional domain restrictions as needed.

> NOTE
>
> If both the Default Reader Group(s) and the domain-specific Reader Group(s) are enabled, the domain-specific settings will take precedence over the default reader groups.

---

## FAQs

**What happens if no default reader group is selected?**

If no default reader group is selected, self-registered readers will have unrestricted access to the entire knowledge base, without any group-specific restrictions.

**What access do readers with multiple group memberships get?**

When a reader is part of multiple groups, the highest level of access for each content item is granted.

For instance, if a reader belongs to Group A (which has access to all languages in workspace 'V1') and Group B (which has access to only English in 'V1'), the reader will receive access to all languages in workspace 'V1'.

**Does individual content access override reader group access?**

No, individual content access does not override group access. The reader always receives the highest privilege from both individual and group settings.

For example, if a reader is individually set to access only English in workspace 'V2' but is also part of a group that has access to all languages in 'V2', the reader will have access to all languages in 'V2'.

**How is reader access prioritized?**

Access is determined by the highest privilege assigned at each content level. Readers only gain access to the content they have been specifically granted.

**Why is self-registration not working for my project?**

Self-registration does not function as expected when SSO (Single Sign-On) is enabled because SSO bypasses the Document360 login page, where self-registration typically occurs. Self-registration with domain configuration is designed for use on the Document360 login page only.

<a id="managing-reviewer-accounts"></a>

## Managing reviewer accounts

**Plans supporting access to reviewer role settings in knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Reviewer** role in Document360 lets users review content without editing or making changes. This role is designed to streamline content review by granting specific permissions to Reviewers. The **Reviewer** role will only have access to the **Documentation** module, allowing access to view articles and categories, add comments to articles, and update the article's workflow status.

## Creating a Reviewer account

You can create a Reviewer account by assigning the Reviewer role during team account creation. Here's how:

1. Navigate to **Settings** ()> **Users & security** > **Team accounts & groups**.
2. Click **Create** > **Team account** to open the new team account creation window.
3. Enter the email address of the user to be added.
4. In the **Portal role** dropdown, select **Reviewer**. The content role will automatically be set to **Reviewer**.
5. Alternatively, if another portal role is selected (e.g., **Owner**, **Admin**), you can manually assign the **Reviewer** role in the content role dropdown.
6. Assign content access permissions based on the articles or categories the Reviewer needs to access.
7. Click **New team account** to finish adding the Reviewer account.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Create_new_revieiwer_account.png)

### Bulk Importing Reviewers

You can import multiple Reviewer accounts at once by using the bulk import feature:

1. Navigate to **Settings** () > **Users & security** > **Team accounts & groups** in the Knowledge base portal.
2. Select **Add > Import Team Accounts**.
3. Select the **Reviewer** account type.
4. Select the **SSO account** checkbox to include them as SSO reviewer accounts.
5. Download the sample import format by clicking **Download template**.
6. Prepare a CSV file with the email addresses of the users to be added.
7. Drag and drop the file or click **Click to upload** to upload the CSV file from your local storage.
8. Assign the desired portal and content roles.
9. Click **Import** to complete the process.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_ScreenGIF-Importing_reviewer_roles.gif)

---

## Reviewer permissions and access

Once a user is assigned the Reviewer role, they will have access to the **Documentation** module and can interact with articles and categories based on their permissions.

> NOTE
>
> Reviewers can only review one article at a time. When a Reviewer begins reviewing an article, other users will see a banner stating, "Reviewer [Name] is currently reviewing the article."

Reviewers can:

* View articles in **Draft mode** or in the state determined by the workflow.
* Add comments to the article, including inline comments.
* Update the workflow status of an article.
* Set due dates and manage workflow assignments.
* Bulk update workflow statuses and manage assignments across multiple articles from the Workflow assignments page.

> NOTE
>
> When a workflow status is set to **Read only**, no team accounts, including those with the Reviewer role, can add comments to an article.

---

## Managing Reviewer accounts

You can update or modify existing Reviewer accounts through the **Team accounts & groups** section. Reviewers can also be converted to **Readers** or **SSO Readers**, and vice versa.

### To edit or delete a Reviewer

1. Navigate to **Settings** ()> **Users & security** > **Team accounts & groups**.
2. Locate the user you wish to modify, then select **Edit** or **Delete** when you hover your cursor over the user.

### To convert a Reviewer to a reader account

1. Navigate to **Settings** () > **Users & security** > **Team accounts & groups**.
2. Select the checkbox next to the user you wish to modify.
3. Click **Convert to reader**.
4. Assign the desired content access permissions from the **Content access** dropdown.
5. As an optional step, map the user to any existing reader groups from the **Map with existing reader group** dropdown.
6. Click **Confirm** to convert the Reviewer to a reader account.

### Purchasing reviewer account as add-ons

To purchase reviewer accounts as add-on, follow the below steps:

1. Navigate to **Settings** ()> **Knowledge base portal** > **Billing** in the Knowledge base portal.
2. Click the **Purchase add-on** in the **My plan** tab.

   The **Purchase add-on** panel will appear.
3. In the **User management** section, add the number of **Reviewer account** you need.
4. Click **Confirm payment**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Adding_Reviewer_role_As_Add-ons_.png)

---

## Reviewer role functionality

The Reviewer role is meant to make the content review process easier by letting users give feedback on articles without changing the content. Reviewers can access articles in **Draft mode** to leave comments, suggest edits, and update the article's status in the workflow. This role is helpful for teams that want to include valuable input from experts or stakeholders while ensuring the content remains unchanged until it's ready for final approval.

### Reviewing an article

To start reviewing an article,

1. Navigate to the article from the **Category & article** pane.
2. Click the **Start Review** button at the top right of the editor.

To add a comment,

1. Highlight the desired text and click on the floating Comment (  ) icon.
2. Enter your comment, then either click Post or press **Ctrl+Enter** to submit.

When you’ve completed your review, click **Mark as Reviewed** at the top right.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_GIF-Reviewing_an_article.gif)

To update the workflow status,

1. Click the Workflow status dropdown at the top of the editor.
2. Select the appropriate workflow status for the article.
3. To set a due date for the workflow status, click the **Set due date** icon and choose the desired date from the calendar.
4. To assign the workflow status to a user, click the **Assign** icon and search for the team account.
5. Once done, click **Set status** to apply the changes.

---

### FAQs

#### How many Reviewer accounts are included in each plan?

* Professional: 5 Reviewers
* Business: 10 Reviewers
* Enterprise: 20 Reviewers

#### Can Reviewers edit articles?

No, Reviewers can only leave comments and update workflow statuses. They do not have permissions to edit the content directly.

#### Can Reviewers access all articles in the knowledge base?

Reviewers can only access articles that they have been given permission to review. Their access is usually restricted to specific categories or articles.

<a id="account-locked"></a>

## Account locked

**Plans allowing users to change password**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

When you try to log in with an incorrect password five times in a row, your account will be temporarily locked for 30 minutes due to security reasons.

If this happens, you will see the following message: **Account locked due to multiple failed attempts! Please try again after 30 minutes.**

## Resetting your password

If you forgot your password, follow these steps to reset it:

1. On the Document360 login page, click **Forgot password?**
2. Enter your associated email address and click **Send**.
3. Check your inbox for a password reset email.
4. Click **Reset Password** in the email. You will be redirected to the password reset page.
5. Enter your new password in the **Password** field and confirm it by typing it again in the **Confirm password** field.
6. Click **Reset** to complete the process. Your password has now been successfully reset.

> NOTE
>
> Password changes apply to your entire account and are not project-specific.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Account_locked_forgot_password.png)

## New password requirements

Your new password must meet the following criteria:

* At least 8 characters long.
* Contains at least 1 uppercase letter.
* Contains at least 1 lowercase letter.
* Contains at least 1 number.
* Contains at least 1 special character.

## Changing your current password

If you know your current password and wish to change it, visit the [Change password article](https://docs.document360.com/v3/docs/change-password) for instructions.

<a id="block-inheritance"></a>

## Block inheritance

**Plans supporting block inheritance in the knowledge base portal**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

  

## Block inheritance

The **Block inheritance** feature allows you to restrict content access for team accounts, even if they have inherited permissions from a higher content level. With this, you can prevent users or teams from accessing certain content, regardless of their inherited access rights. This would allow only specific team accounts and team account groups to access a content level (workspace/language/category/article).

### Content access at Workspace level

For example, you have six inherited team accounts in workspace V1 and want to provide access only to one team account and yourself.

1. Navigate to **Settings** () > **Users & Security** > **Content access**.
2. Click on the respective workspace.
3. Turn on the **Block inherited account** toggle in the **Manage content access tab**.

   Now, all the other inherited team accounts that cannot access workspace V1, will not be displayed and only those team accounts that have content access will be displayed.

   ![Showing block inheritance at workspace level](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Block_inheritance.gif)

### Disable inheritance for a category or an article

1. Navigate to Documentation () and hover the mouse pointer over the desired category/article in the category manager.
2. Click on the **More** (•••) icon that appears next to the category/article name.
3. Click on **Security**, then choose **Knowledge base portal** Access control.
4. The **Assign control access : Knowledge base portal** blade appears with the list of team accounts and team account groups that have access to the selected content level.
5. Turn on the **Block inherited account** toggle and only the accounts which are not inherited will display.

   By default, the team account performing this action would be selected and cannot be removed.
6. Click on the **Assign article access** to provide content access to a specific team account.
7. Select the desired team account(s) and click **Apply.**
8. Once you have made changes, click **Close.**

   ![To block inheritance at content level](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Block_inheritence.gif)

#### What happens after removing inheritance?

After removing inheritance for a content level, only the team accounts and team account groups in the content access list can access that content level (workspace/language/category/article). Later, you can also provide access to the desired team accounts and team account groups.

---

## Allow inheritance

If you want to provide access to all the inherited team accounts and team account groups, turn off the **Block inherited account** toggle.

### Enable inheritance for a category or an article

1. Navigate to Documentation () and hover the mouse pointer over the desired category/article in the category manager.
2. Click on the **More** (•••) icon that appears next to the category/article name.
3. Click on **Security**, then choose **Knowledge base portal Access control**.
4. The **Assign control access : Knowledge base portal** blade appears with the list of team accounts and team account groups that have access to the selected content level.
5. Turn off the **Block inherited account** toggle and click **Yes** in the **Allow inheritance** prompt.
6. Once you have made changes, click **Close.**

   ![To enable inheritance for a category or a page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGif-Block_inheritance.gif)

   ---

## FAQs

**What happens when I disable inheritance for a category or article?**

When you disable inheritance, only the team accounts and groups listed in the content access list can access that category or article.

**Is the team account performing the action automatically selected when blocking inheritance?**

Yes, the team account performing the action will be automatically selected and cannot be removed.

<a id="ip-restriction"></a>

## IP restriction

**Plans supporting access to IP restriction settings in Knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**IP restriction** provides additional security for the knowledge base by restricting or allowing access to user-designated IP addresses.

> NOTE
>
> This is a project-level setting. When a specific IP restriction is enabled, it applies across all the workspaces and languages available in that project.

Document360 supports both **IPv4** and **IPv6** (Unicast addresses) IP addresses.

---

## IP restriction page

1. From the Knowledge base portal, navigate to Settings () > **User & Security** > **IP restriction**.

   The IP restriction overview page will appear.
2. The following information about IP restrictions will be displayed

   * **Friendly name** - A name with which you can identify the IP restriction. This field does not have any character limit.
   * **IP address** - The individual IP address or an IP range added for restriction. (Supports **IPv4** and **IPv6**)
   * **Allow/Block** IP - The restriction applied to the respective IP address or range to allow or block the IP restrictions.
   * **Remove** - You can delete the IP restriction by using the Remove () icon.
   * **Save** - You can save the IP restriction using the Save () icon.

   ![Image showing IP restriction overview page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/54_ScreenShot-IP_restriction.png)

### Adding IP restriction

1. Click **Add IP address** on the IP restriction overview page.
2. Add a name for the IP restriction in the **Friendly name** field (mandatory).
3. Add an individual IP address or an IP address range in the **IP address** field.

   IP address range would involve the start-to-end range.  
   For example, 79.15.135.189 - 79.15.135.229
4. Click the Save () icon.
5. To reset the details entered, click on the Reset () icon.

   ![Image showing options and fields on IP restriction page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1725352385689.png)

The newly added IP restriction will be added to the list and will be available on the IP restriction overview page.

(or)

5. Click **Add my current IP address** to add saved IP restrictions.

Supported IPv6 formats:

Here are some examples of IPv6 formats that are supported

* 2001:0db8:85a3:0000:0000:8a2e:0370:7334  ✅
* 2001:0db8:85a3::8a2e:0370:7334  ❌
* 2001:db8:85a3:0:0:8a2e:370:7334  ✅

### Allow/Block IP address

You can find two options, **Allow** and **Block** on the IP restriction overview page.

1. Select **Allow** for the required IP addresses you wish to permit to access the Knowledge base site.
2. Select **Block** for the required IP address you wish to restrict the access to the Knowledge base site.

> NOTE
>
> If you enter the same IP address for both the permissions, **Allow** and **Block**, or if you try to add the same IP more than once, you will get a warning popup saying ‘*A restriction with this IP address already exists’*.

### Delete an IP restriction

The IP restrictions can be deleted by clicking on the **Delete** () icon to the right of the IP address field.

A popup saying **IP restriction deleted** will appear.

> NOTE
>
> You must be very careful when performing the **delete** action. The IP restriction record, once deleted, cannot be recovered.

---

## FAQ(s)

**What is an IP address?**

**IP** address stands for Internet protocol address. It is an identifying number associated with a specific computer or computer network. The IP address allows the computers to send and receive information when connected to the internet.

**What is an IPv4 format?**

An IPv4 address consists of four numbers, each containing one to three digits, with a single **dot** (.) separating each number or set of digits. The four numbers can range from **0** to **255**.

For example, 49.206.113.170

**What is an IPv6 format?**

An IPv6 offers a vastly expanded address space, using 128-bit addresses compared to IPv4's 32-bit, which means it can support an almost unlimited number of unique IP addresses. Usually shown as sequences of hexadecimal digits, separated by a colon ( : ). Each group is up to four hexadecimal digits long, and each address comprises up to eight groups (octet).

> For example, FE38:DCE3:124C:C1A2:BA03:6745:EF1C:683D
>
> * **Starting IPv6 Address**: The lowest possible IPv6 address is 0000:0000:0000:0000:0000:0000:0000:0000
> * **Ending IPv6 Address**: The highest possible IPv6 address is ffff:ffff:ffff:ffff:ffff:ffff:ffff:ffff

**What is an IPv6 unicast address?**

A unicast address in IPv6 identifies a single network interface among a group of devices. When data is sent to a unicast address, it is explicitly delivered to that intended recipient, ensuring direct point-to-point communication on the network. This contrasts with multicast and anycast addresses, which serve different communication purposes in IPv6.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="single-sign-on-sso"></a>

## Single Sign-On (SSO)

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## What is SSO?

As the term suggests, **Single Sign-On** or **SSO** allows for user authentication and access to multiple applications or websites with a single login event. In simple terms, this feature can be referred to as One-time login.

A user logging into any application or website with the SSO feature enabled would be able to log on to other applications listed by the Service provider without the user having to key in their login credential every single time for each of the applications.

---

## Reasons to configure Single Sign-On (SSO) in your project

There are several reasons why SSO is considered an important feature:

1. **Improved security**: SSO can help improve security by reducing the number of places where user credentials are stored and making it more difficult for attackers to access sensitive information.
2. **Increased productivity**: SSO can help increase productivity by allowing users to access the systems and applications they need quickly and easily without remembering multiple usernames and passwords.
3. **Better user experience**: SSO can help improve the user experience by reducing the number of times users are prompted to enter their credentials, which can be frustrating and time-consuming.
4. **Simplified IT management**: SSO can help simplify IT management by reducing the number of places where user credentials are stored and making managing access to systems and applications more accessible.
5. **Compliance**: Some industries and sectors have regulations and compliance requirements that demand SSO implementation.
6. **Reduced IT costs**: SSO can help reduce IT costs by reducing the need for additional hardware, software, and support required to manage multiple authentication systems.

In summary, SSO can improve security, increase productivity, enhance the user experience, simplify IT management, support compliance, and reduce IT costs.

---

## How does SSO work?

Most websites or web applications like Document360, referred to as **Service providers**, have a dedicated, secure, and centralized database for user information and credentials.

To facilitate the Single Sign-On feature, an external entity, the **Identity Provider** or **IdP**, is brought in to ease the user experience in accessing the web application by authenticating the user's credentials and authorizing the access to the 'Service provider'.

Here’s a sequential rundown on how the Single Sign-on (SSO) feature works

1. The user visits the intended Service provider or application domain sign-in page
2. Redirection takes place to the Identity Provider (IdP) login page
3. The user signs in with the correct credentials
4. The IdP domain matches the user information and sends an **Access token** or **ID token** to the Service Provider
5. The validation of the Access/ID token with user information is thriving on the Service provider’s end
6. A trust relationship is established between the IdP and the Service provider

As the authentication is successful, the user is now authorized to access SSO-enabled applications within the service provider without the whole process of Signing in for each instance.

Document360 allows you to configure multiple SSO options simultaneously. This means you can set up single sign-on using various identity providers for your team and readers. For example, you might use one IdP for internal employees and another for external customers or partners. This gives your team and readers the flexibility to choose their preferred IdP for accessing both the knowledge base portal and site.

---

## What is an IdP?

Identity Provider (IdP) is an external entity that stores and manages the identity information of users; the IdP also authenticates the users by facilitating the Single Sign-On (SSO) feature. Identity Provider handles users' credentials to log in to web applications, file servers, systems, and other digital services. Any single entity the IdP stores is called a ‘**principal**.’

Here are some IdP you can configure with Document360

* **Okta**
* **Entra ID**
* **Google**
* **ADFS**
* **OneLogin**

---

## SSO Standards on Document360

Single Sign-On feature is established with two broad standard protocols adopted by Document360.

![sso_in_knowledge_base_Document360-1200x683](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/sso_in_knowledge_base_Document360-1200x683.jpg)

### **SAML 2.0**

* [**Enabling SAML SSO on Document360**](https://docs.document360.com/docs/enabling-saml-sso)
* [**Removing a configured SAML SSO**](https://docs.document360.com/docs/removing-a-configured-saml-sso)
* **Using Okta as IdP:** [**Configuring SAML SSO with Okta**](https://docs.document360.com/docs/saml-sso-with-okta)
* **Using Entra ID as IdP:** [**Configuring SAML SSO with Entra ID**](https://docs.document360.com/docs/saml-sso-with-entra)
* **Using Google as IdP:** [**Configuring SAML SSO with Google**](https://docs.document360.com/docs/google-sso-saml-configuration)
* **Using OneLogin as IdP:** [**Configuring SAML SSO with OneLogin**](https://docs.document360.com/docs/saml-sso-with-onelogin)
* **Using ADFS as IdP:** [**Configuring SAML SSO with ADFS**](https://docs.document360.com/docs/saml-sso-with-adfs)
* **Using other IdPs:** [**Configuring SAML SSO with Other IdPs**](https://docs.document360.com/docs/saml-sso-with-other-configurations)

---

### **OpenId Connect**

* [**Enabling OpenID SSO on Document360**](https://docs.document360.com/docs/enabling-openid-sso)
* [**Removing a configured OpenID SSO**](https://docs.document360.com/docs/removing-a-configured-openid-sso)
* **Using Okta as IdP:** [**Configuring OpenID SSO with Okta**](https://docs.document360.com/docs/okta-with-openid-sso)
* **Using Auth0 as IdP:** [**Configuring OpenID SSO with Auth0**](https://docs.document360.com/docs/auth0-with-openid-sso)
* **Using ADFS as IdP:** [**Configuring OpenID SSO with ADFS**](https://docs.document360.com/docs/adfs-with-openid-sso)
* **Using other IdPs:** [**Configuring OpenID SSO with Other IdPs**](https://docs.document360.com/docs/other-configurations-with-openid-sso)

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

<a id="login-using-sso-knowledge-base-portal"></a>

## Login using SSO - Knowledge base portal

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Single Sign-On (SSO)** allows you to access Document360's Knowledge base portal using your existing credentials from another identity provider (IdP). This eliminates the need to remember multiple passwords.

## Logging in using SSO

To log in to the Knowledge base portal using SSO:

1. Open your web browser and enter the **URL** of the Document360 **Knowledge base portal** you want to access.
2. In the **Email or Subdomain** field, enter your email address or domain name.
3. Once you've entered your email or domain, click the **Continue with SSO** button.
4. You will be redirected to your IdP's login page. Enter your credentials to authenticate.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-KBportal_login_using_SSO.png)

After successful authentication, you'll be automatically logged into Document360's Knowledge base portal.

## IdP initiated sign-in

If the **Allow IdP initiated sign-in** option was enabled during the SSO configuration process, you can also log in directly from your IdP's dashboard. This means you don't need to visit the Document360 Knowledge base portal first. Simply navigate to your IdP's dashboard and look for the Document360 application. Click on it to initiate the login process.

By following these steps, you can easily and securely access Document360's Knowledge base portal using your existing SSO credentials.

---

## Troubleshooting

If you encounter issues while logging in to the Knowledge base portal using SSO, refer to the following common errors and their solutions:

### User access not assigned in IdP

**Error:** Sorry, but we’re having trouble signing you in. Your administrator has configured the application Document360 to block users unless they are specifically granted (assigned) access to the application.

This error indicates that users are not assigned to the Document360 application in the Identity Provider (IdP).

![Error message indicating trouble signing into Document360 due to access restrictions.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Troubleshooting_user_access_not_assigned_idp.png)

**Steps to resolve:**

To resolve this issue,

1. Log in to the identity provider’s portal.
2. In the identity provider’s portal, navigate to **Applications,** and select the Document360 application.
3. Add the required users or groups to the Document360 application.

Once the users are added, they should be able to access Document360 without encountering the error.

### No projects associated with email address

**Error:** There are no projects associated with this email address. Please contact your Project administrator.

This error indicates that the user’s account is not linked to any project in Document360. This can happen if the user has not been added, or has been removed to Document360, but their account is linked to the Identity Provider (IdP).

![A user receives a message about no projects associated with their email address.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Troubleshooting_no_project_associated.png)

**Steps to resolve:**

To resolve this issue,

1. Log in to the ****Knowledge base portal**** as an administrator.
2. Select the project where the user needs access.
3. Navigate to ****Settings**** > ****Users & security**** > **Team accounts & groups**.
4. Check if you have added the user as an SSO account.

   * If the user's account exists but is not an SSO account, select the checkbox next to their account and click **Convert to SSO account** option.
   * If the user is not listed as an SSO account, click **Add** > **Team account** and select the **SSO user** checkbox while creating the account.

### Email address missing in SAML/ODIC response

**Error:** Email address is missing in SAML/ODIC response, please check your SSO configuration or contact support.

This error typically occurs when the **email** or **name** attributes in the SAML/ODIC response are not configured correctly in the Identity Provider (IdP). These attributes are case-sensitive, so it is important to ensure they match exactly as specified in the configuration.

![User receives an error message about missing email address for SSO login.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Troubleshooting_email_address_missing_in_saml_odic.png)

**Steps to resolve**:

To resolve this issue,

**Check attribute mapping in the Identity Provider (IdP)**

1. Log in to your Identity Provider (IdP) as an administrator.
2. Verify that the attributes for **email** and **name** are mapped correctly.
3. Confirm that the attribute names match exactly as specified in the Document360 documentation. For example,

   * Correct: “**email**” and “**name**”.
   * Incorrect: “**Email**”, “**EMAIL**”, “**Name**”, or “**NAME**”.

**Update SSO configuration in Document360**

1. Log in to the ****Knowledge base portal**** as an administrator.
2. Select the project where the SSO is configured.
3. Navigate to **Settings** > **Users & security** > SAML/OpenID.
4. Select **Edit** () for the existing configuration.
5. Navigate to the **IdP configurations** section and ensure the mapped attributes in Document360 correspond to those configured in the IdP.
6. Save the updated configuration.

Now, test the SSO login to confirm that the issue is resolved.

### Single sign-on is not enabled for this email

**Error**: An error occurred while handling the request and ‘Single sign-on isn’t enabled for this email’

This error indicates that the user's email is not correctly configured in the Identity Provider (IdP) or in Document360.

**Steps to resolve:**

To resolve this issue,

1. Log in to the identity provider’s portal.
2. In the identity provider’s portal, navigate to **Applications,** and select the Document360 application.
3. Check if the team accounts/readers are added to the Document360 application.
4. If the team account/reader is missing, add them and assign the necessary permissions.

Next, check if the SSO configuration has been completed correctly in Document360. To verify if the SSO configuration are correct, check the details from the [**SAML**](/help/docs/saml) and [**OpenID**](/help/docs/openid) articles.

If the issue persists, please contact the [Document360 support team](mailto:support@document360.com) with the screenshots of the IdP configuration and Document360 SSO configuration.

### Unable to login via SSO

**Error**: Single Sign-on is not enabled for this subdomain

This error occurs when the incorrect subdomain or knowledge base portal link is used during login. It commonly happens if the project is hosted on one domain (e.g., **US**) but is being accessed through a different domain (e.g., **EU**).

![Login screen for Document360 with SSO option and subdomain input field.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Troubleshooting_sso_not_enabled.png)

**Steps to resolve**:

**Verify Your Subdomain and Portal URL**

* Ensure you are using the **correct subdomain** and accessing the right Document360 portal.
* If your project is hosted in the **US domain**, use: [**https://portal.us.document360.io/**](https://portal.us.document360.io/)
* If your project is hosted in the **EU domain**, use: [**https://portal.document360.io/**](https://portal.document360.io/)

**Check Your Subdomain**

* Navigate to ****Settings**** > ****Knowledge base portal**** > ****Custom domain**.**
* In the Custom domain page, you can view your project link. If your project link is `https://test1.document360.io`, then your subdomain is **"test1"**.
* You can also find your subdomain on the **Configure the Service Provider (SP)** page under from your **SSO Configuration**.

### SSO login failure

**Error**: This page isn’t working - identity.us.document360.io is currently unable to handle this request. HTTP ERROR 500.

This issue occurs due to a change in the identity certificate. The signing certificate for authentication is rotated every three months, and if the updated certificate is not configured correctly in the Identity Provider (IDP), authentication may fail.

![Error message indicating the page is not working due to HTTP error 500.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Troubleshooting_sso_http_error_500.png)

**Steps to resolve**:

Follow these steps to resolve the issue:

1. Ensure that you configure the **metadata URL** correctly in the **Identity Provider (IdP)**. This URL is available on the **SSO page** in Document360 and reflects the latest signing certificate information.
2. If the issue persists, contact [**support@document360.com**](mailto:support@document360.com) for assistance.

---

### FAQs

#### Why can't I access a project despite being granted access?

If you're unable to access a project, it could be because you are added as an SSO user for some projects and a non-SSO user for others. Please ensure you are using the correct login credentials (non-SSO for non-SSO projects).

If the issue persists, contact our [support team](https://support.kovai.co/a/tickets/support@document360.com) for further assistance.

#### **Why am I encountering a 500 error when using SSO authentication to access my Knowledge base portal?**

If SSO authentication is causing a 500 error, it may be due to an outdated SAML certificate. First, check if your site is set to public, as SSO authentication is typically used for secure access. Updating the SAML certificate on your end should resolve the issue.

<a id="login-using-sso-knowledge-base-site"></a>

## Login using SSO - Knowledge base site

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Single Sign-On (SSO)** allows you to access Document360's Knowledge base site using your existing credentials from another identity provider (IdP). This eliminates the need to remember multiple passwords.

## Logging in using SSO

To log in to the Knowledge base site using SSO:

1. Open your web browser and enter the **URL** of the Document360 **Knowledge base site** you want to access.
2. You'll be presented with a list of available SSO login buttons (e.g., "Login using Google," "Login using Azure AD"). Choose the one that matches your IdP.
3. You will be redirected to your IdP's login page. Enter your credentials to authenticate.

> NOTE
>
> The specific SSO login buttons may vary depending on the available configurations.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-KBsite_login_using_SSO.png)

After successful authentication, you'll be automatically logged into Document360's Knowledge base site.

## IdP Initiated Sign-In

If the **Allow IdP initiated Sign-In** option was enabled during the SSO configuration process, you can also log in directly from your IdP's dashboard. This means you don't need to visit the Document360 Knowledge base site first. Simply navigate to your IdP's dashboard and look for the Document360 application. Click on it to initiate the login process.

By following these steps, you can easily and securely access Document360's Knowledge base site using your existing SSO credentials.

<a id="inviting-or-adding-sso-users"></a>

## Inviting or Adding SSO users

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Once you've successfully configured **Enterprise Single Sign-On** (**SSO**) using either **SAML** or **OpenID** for your project, you are ready to leverage the benefits of SSO for your users. This means that users can access your project using their existing credentials from a trusted identity provider (**IdP**), such as **Okta**, **Azure AD**, or **Google Workspace**. This eliminates the need for users to remember separate passwords for your project and simplifies the login process.

You can now:

* **Add new team accounts as SSO users**: If you have new users who want to join your project, you can directly add them as SSO users. This means they will be required to authenticate using their SSO credentials.
* **Invite existing users**: If you've already added users to your project, you can invite them to use SSO. This involves sending them an invitation.

## Adding a new team account as an SSO user

Adding a new team account as an SSO user follows the same process as [adding a new team account](/help/docs/managing-team-account) in Document360, with one extra step.

1. In the **Knowledge base portal**, navigate to **Settings** > **Users & security** > **Team accounts & groups**.
2. In the **Team account** tab, click **Create** > **Team account**.
3. In the **Create team account** window, in the **Basic details** section, add the email ID of the user you wish to add in the **Email** field.

   > NOTE
   >
   > The email address for a new team account must match the domain specified in the SSO configuration.
4. Click the **SSO user** checkbox.
5. In the **Select SSO** dropdown, select the SSO configuration you wish to assign to the user.
6. Select the **Skip invitation email** checkbox if you do not wish to send the invitation email to the user.

Once you select the desired SSO configuration for the user, follow the same steps as [adding a new team account](/help/docs/managing-team-account) to finish adding an SSO user.

> NOTE
>
> **Owner** and **Admin** are the only project roles that are allowed to add new team accounts to project.

---

## Inviting an existing user

Once you have configured single sign-on for your Document360 project, you can invite existing users to login to the project using SSO.

To invite an existing user,

1. Log in to your Document360 account and navigate to the project in which you want to invite users.
2. Navigate to **Settings** > **Users & security** > **SAML/OpenID.**
3. Click the **Edit** () icon which appears when you hover over the SSO configuration to which you want to invite users.
4. Navigate to the **More settings** tab in the SSO configuration window.
5. In the **Convert existing team and reader accounts to SSO** section, select either the **All users** or the **Selected users only** radio button.

   1. **All users**: Selecting this option will invite all the users added to the project.
   2. **Selected users only**: Selecting this option will open a list of users added to your project. To invite a user, select the checkbox next to the user’s name.
6. Once you have selected the users, click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Invite_users_to_SSO.png)

Once a team member has been added, they will receive an invitation email with their login details.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Invitation_email_sample.png)

NOTE

When you invite an existing Document360 user to become an SSO user in your project, an additional user account is added. The user’s team account will continue to exist along with a SSO user account.

---

## Deleting an SSO user

If an SSO user account is no longer required, you can delete it from the **Team accounts & groups** page.

1. Log in to your Document360 account and navigate to the project in which you want to delete users.
2. Navigate to **Settings** > **Users & security** > **Team accounts & groups.**
3. Click the **Delete** () icon which appears when you hover over the team account you wish to delete.

   > NOTE
   >
   > You can identify SSO user accounts using the SSO label next to their email ID.
4. Click **Yes** in the **Delete** confirmation popup.

> NOTE
>
> If an email ID was added as a team account and an SSO user, deleting the SSO user will not delete the team account associated with the email ID.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Delete_SSO_user.png)

---

## FAQ

**Why am I not able to create an SSO reader account?**

If a user has already been added to the project as an SSO reader account you will not be able to add the same user again. The **Create reader account** button will be disabled automatically when you check the SSO user checkbox.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

<a id="mapping-an-existing-sso-configuration-to-other-projects"></a>

## Mapping an existing SSO configuration to other projects

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

If you have created an SSO configuration (SAML or OpenID) for your project, you can map the same to other Document360 projects you manage from your account.

1. Log in to your Document360 account and navigate to the project in which you want to map the existing SSO configuration.
2. Navigate to **Settings** > **Users & security** > **SAML/OpenID.**
3. Click **Create SSO.**
4. Select the appropriate identity provider in the **Choose your Identity Provider (IdP)** page.

   > NOTE
   >
   > The identity provider of the new SSO configuration should be the same as the identity provider of the existing SSO configuration.
5. Select either SAML or OpenID based on your existing configuration in the **Configure the Service Provider (SP)** page and click **Next**.

   > NOTE
   >
   > The SSO protocol (SAML/OpenID) of the new SSO configuration should be the same as the SSO protocol of the existing SSO configuration.
6. Select the existing configuration from the **Configure an existing connection** **(Optional)** dropdown and click **Next**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Select_existing_SSO_dropdown.png)

7. Finish setting up the SSO in the **More settings** page and click **Create**.

The new SSO configuration will be created based on the existing SSO configuration selected from the dropdown.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

<a id="disable-document360-login-page"></a>

## Disable Document360 login page

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

If you have only SSO users and no regular team accounts added to your Document360 project, you can choose to disable the Document360 common login page. This will redirect users directly to the SSO login page when they access Document360.

> CAUTION
>
> Do not disable the common login page if you have both SSO users and regular team accounts added to your project. Regular team accounts will not be able to log in to the Document360 accounts if this setting is toggled on.

## Disabling the Document360 login page

To disable the Document360 common login page,

1. Log in to your Document360 account and navigate to the project for which you wish to disable the common login page.
2. Navigate to **Settings** > **Users & security** > **SAML/OpenID.**
3. Click the  **Settings** button on the top right next to the **Create SSO** button.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-SSO_settings_page_settings_button.png)
4. In the Settings popup, turn the **Disable Document360 login page** toggle **ON**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Disable_D360_login_page_toggle.png)
5. Click **Save.**

The standard login page bypass can be enabled in the SSO settings page for both standards (SAML or OpenID).

## FAQs

**What will happen when I turn ON the Disable Document360 login page toggle?**

When the **Disable Document360 login page** toggle is turned **ON**, users will only see the single sign on (**SSO**) options in the login page. Users will not be able to login using their email and password combination.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

<a id="auto-assign-reader-group"></a>

## Auto assign reader group

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Make it easier for readers to join your knowledge base using the Auto assign reader group option. This automatically gives access to readers who have signed in with an identity provider, so you don't have to invite them manually.

---

## Automatically assigning SSO readers

To automatically assign SSO readers to your knowledge base,

1. Log in to your Document360 account and navigate to the project in which you want to automatically assign SSO readers.
2. Navigate to **Settings** > **Users & security** > **SAML/OpenID.**
3. Click the **Edit** () icon which appears when you hover over the SSO configuration for which you want to automatically assign reader groups.
4. Navigate to the **More settings** tab in the SSO configuration window.
5. Toggle **ON** the **Auto assign reader group** option.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Auto_assign_reader_groups_toggle.png)

6. Search and select the reader groups you want to automatically assign to your knowledge base.
7. Click **Save**.

> NOTE
>
> To use the Auto assign reader group feature, you need to have existing reader groups. If you have not created any reader groups, you can create them from **Settings** > **Users & security** > **Reader & groups** > **Reader groups**.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

<a id="convert-to-sso-account"></a>

## Convert to SSO account

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

## Convert Document360 account to SSO account

Single Sign-On or SSO allows user authentication and access to multiple applications or websites with a single login event. You can login to your SSO account with your SSO credentials to access the portal/site. You can easily convert your Document360 account(s) to SSO account(s) without altering the roles and access. This option simplifies and speeds up the conversion process for team accounts and readers.

> NOTE
>
> User type conversion is applicable only in SAML and OpenID configured projects.

---

### Converting regular Document360 team account(s) to SSO account(s)

1. Go to **Settings** > **Users & Security** > **Team accounts & groups** > **Team account** in your Document360 knowledge base portal.
2. Select the checkbox of the desired team account(s).
3. Click the **Convert to SSO account** option above the list of team accounts.

   ![Image showing the way to access Convert to SSO account option in Documnet360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/39_ScreenShot-SSO_conversion.png)

   An **Account convert** confirmation popup appears.
4. Select the checkbox and click the **Yes** button.

   ![Image showing Account convert popup for converting to SSO account](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/40_ScreenShot-SSO_conversion.png)

> NOTE
>
> * When a team account is converted to an SSO account, all their contributions will be retained. However, the previous contributions of the team account will appear as **Anonymous**.
> * The Team account that performs the conversion cannot convert their own Document360 account to SSO account.
> * If you convert a Document360 owner account to SSO account, both the regular Document360 account and the SSO account will be available to that owner account. As a result, there will be two accounts for the same user.

---

### Converting regular Document360 reader(s) to SSO reader(s)

1. Navigate to **Settings** > **Users & Security** > **Readers & groups** > **Readers** in your Document360 knowledge base portal.
2. Select the checkbox of the desired reader(s).
3. Click the **Convert to SSO account** option above the list of readers.

   ![Image showing the way to access Convert to SSO account option in Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/41_ScreenShot-SSO_conversion.png)

   An **Account convert** confirmation popup appears.
4. Select the checkbox and click the **Proceed** button.

   ![Image showing Account convert popup in Document360](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/42_ScreenShot-SSO_conversion.png)

> NOTE
>
> SSO account cannot be converted to Document360 account.

---

## FAQ(s)

**Who can perform the conversion of a Document360 account to an SSO account?**

The Owner(s) and Admin(s) can perform this conversion of the Document360 account to an SSO account. Team accounts with the **Manage team accounts** can also perform this action.

**Can we perform user-type conversion in JWT configured projects?**

No, you cannot perform user-type conversion in JWT configured projects. This conversion is applicable only in SAML and OpenID configured projects.

**I mistakenly converted one or more Document360 team accounts or readers to SSO accounts. How can I fix this?**

There is no straightforward workaround for this scenario. However, you can rectify this by deleting the SSO account and adding the regular Document360 account manually. Ensure that you replicate the roles and access correctly.

<a id="team-account-idle-timeout"></a>

## Sign out idle SSO team account

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The **Sign out idle SSO team account** feature is designed to enhance security within Document360 projects by automatically logging out Single Sign-On (SSO) team accounts are idle. A team account is considered to be idle when the account has not performed any action inside the Knowledge base portal for a predefined time interval. This proactive measure mitigates the risk of unauthorized access and ensures the confidentiality of sensitive information. This setting is applicable only for SAML and OpenID configurations.

#### Key Benefits:

• **Enhanced Security**: Prevent unauthorized access to your project by automatically logging out idle SSO team accounts.  
 • **Effortless Management**: Streamline account management by setting idle timeout durations tailored to your project's needs.

## How to enable the 'Sign out idle SSO team account' option?

You can enable the **Sign out idle SSO team account** option on the SSO settings page.

1. From the Knowledge base portal, navigate to **Settings > Users & Security** > **SAML/OpenID**.
2. Click the **Edit** () icon which appears when you hover over an existing SSO configuration.
3. Navigate to the **More settings** tab in the SSO configuration window.
4. Turn **ON** the **Sign out idle SSO team account** toggle.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Sign_out_idle_SSO_team_account(1).png)

5. Enter the desired idle timeout duration in the **Timeout duration** field in the **hours:minutes** format.
6. Once you have made changes, click **Save**.

> NOTE
>
> This setting is applicable only for SSO team accounts. Document360 team accounts will not get affected.

---

## FAQs

#### What happens if a user is logged out due to inactivity?

Idle SSO team accounts will be required to log in again to access the Knowledge Base portal.

#### Is there a default idle timeout duration?

Yes, the default duration is 2 hours, but it can be adjusted to suit your project's requirements.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

<a id="saml"></a>

## SAML

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**SAML 2.0** is an open standard protocol that allows users to access multiple web-based applications with a single set of credentials. This provides a more secure and convenient way for users to access **Document360**. With **SAML 2.0** enabled, Document360 users can log in to the platform using their existing credentials from an identity provider (IdP). Document360 supports the configuration of multiple single sign-on (SSO) endpoints, allowing both team accounts and readers to log in using their preferred identity provider.

## Supported identity providers

Document360 supports the following identity providers (**IdP**):

* **Okta**
* **Entra ID**
* **Google**
* **Auth0**
* **ADFS**
* **OneLogin**
* **Others**

---

## Configuring SSO using SAML

1. Log in to your Document360 account and navigate to your desired project.
2. Navigate to ****Settings** (****)** > ****Users & security**** > **SAML/OpenID.**
3. Click **Create SSO.**
4. Select an identity provider from the **Choose your Identity Provider (IdP)** page.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Create_SSO_Choose_idp_page.png)
5. Select SAML from the **Configure the Service Provider (SP)** page.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-SSO_configuration_configure_sp.png)
6. Using the details provided in the **Configure the Service Provider (SP)** page, configure the Document360 application with the previously selected identity provider.
7. Using the details provided by the identity provider, setup the SSO configuration in Document360 on the **Configure the Identity Provider (IdP)** page.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-SSO_configuration_configure_idp.png)

Once you have successfully completed the SSO configuration based on the SAML protocol, you can invite members from your project to the configured SSO application.

Now, users can login to Document360 either using their email and password or using **SSO**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-SSO_configuration_document360_login_page.png)

## Troubleshooting

If you encounter issues during the SAML SSO setup or login, refer to the following common errors and their solutions:

### Invalid SAML request (Untrusted key)

**Error:** An error was encountered while handling the remote login - Invalid SAML Request SAML signature is valid but uses an untrusted key. This error occurs when the SAML certificate uploaded to Document360 is inactive.

![A person falls while riding a bicycle, indicating a login error message.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Troubleshooting_issue_untrusted_key.png)

**Steps to resolve:**

To resolve this issue,

**Download the active SAML certificate**

1. Access your IdP.
2. Download the currently active SAML certificate.

**Re-upload the certificate in Document360**

1. In Document360, navigate to ****Settings** (****)** > ****Users & security**** > **SAML/OpenID.**
2. Click **Edit** for the relevant SSO configuration.
3. Under **Configure the Identity Provider (IdP)** section, locate the **SAML Certificate** field.
4. Click **Browse** to upload the new, active certificate.

Uploading the active certificate should resolve the issue.

### SAML message signature is invalid

**Error**:

* SignatureInvalid: SAML message signature is invalid.
* AssertionSignatureInvalid: SAML Assertion signature is invalid.
* Invalid SAML Request: SAML signature is valid but uses an untrusted key.

This error occurs when an incorrect or expired SAML certificate is uploaded to Document360.

**Steps to resolve**:

**Ensure the certificate is valid**:

1. Check if the uploaded certificate is **active and not expired**.
2. If needed, generate a new certificate in the **Identity Provider (IdP)**.

**Re-upload the correct certificate in Document360**:

1. In Document360, navigate to ****Settings** (****)** > ****Users & security**** > **SAML/OpenID.**
2. Click **Edit** for the relevant SSO configuration.
3. Under **Configure the Identity Provider (IdP)** section, locate the **SAML Certificate** field.
4. Click **Browse** to upload the new, active certificate.

**Capture Logs for Further Analysis (if issue persists)**

1. Add the [**SAML Tracer**](https://addons.mozilla.org/en-US/firefox/addon/saml-tracer/) extension to your browser.
2. Open **SAML Tracer** before starting the SSO login flow.
3. Perform the action that triggers the SSO process (e.g., clicking **Continue with SSO**).
4. SAML Tracer will record all network requests.
5. **Right-click** in the **SAML Tracer** window.
6. Select **Export** or save the logs in a suitable format.

For further assistance, contact the [**Document360 support team**](mailto:support@document360.io) with:

* **Screenshots** of your IdP configuration.
* **The uploaded SAML certificate details**.
* **SAML Tracer logs**.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

<a id="saml-sso-with-okta"></a>

## SAML SSO with Okta

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**Okta** is an **Identity Provider (IdP)** that simplifies user access management by allowing users to sign in to multiple applications with a single set of credentials. This article demonstrates how to configure SSO between Okta and Document360, enabling your users to access Document360 using their Okta credentials. Please note that only users with **Owner** or **Admin** as **Project role** can configure SSO in Document360.

> PRO TIP
>
> It is recommended to open **Document360** and **Okta** in two separate tabs/browser windows, since configuring SSO in Document360 will require you to switch between Okta and Document360 multiple times.

## Sign up for Okta

Access to an Okta account is a pre-requisite for configuring single sign-on in Document360 with Okta. To sign up for Okta,

1. Navigate to <https://developer.okta.com/signup/> and complete the signup process.
2. After signing up, you would receive an email with your **login credentials** and an **account****activation link** on your registered email.
3. Once you click on the activation link, you will be redirected to the **Okta Domain** login page.
4. Login with your credentials.
5. Once you login, you will be redirected to the Okta developer console.

## Adding an application

To create a **Document360 SSO configuration** using **Okta**, you must create a new application on Okta. To create a new application ok Okta,

1. Log in to Okta using the credentials used while creating an Okta account.
2. Switch to the admin user role by clicking on **Admin** at the top right next to your profile name.
3. From the left navigation list page, expand the **Applications** dropdown, and click **Applications**.
4. In the **Applications** page, click the **Create App Integration** button.
5. In the **Create a new app integration** popup, select **SAML 2.0** as the **Sign-in method** and click **Next**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_GIF-Okta_create_app_integration.gif)

### Creating a SAML integration

Next, you will be redirected to the **Create SAML Integration** page.

#### General Settings

1. In the **General Settings** tab, enter the name of your new application in the **App name** field.
2. Browse and upload a logo for your application in the **Add logo** field if required.
3. Next, you can check the App visibility checkbox if required.
4. Click on the **Next** button to navigate to the **Configure SAML** tab.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Okta_general_settings.png)

#### Configure SAML

In the Configure SAML tab, you will require the parameters provided on the **Configure the Service Provider (SP)** page in Document360.

1. To access the **Configure the Service Provider (SP)** page, navigate to **Settings** > **Users & security** > **SAML/OpenID** in Document360.
2. Click the **Create SSO** button, select **Okta** in the **Choose your Identity Provider (IdP)** page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Choose_idp_okta.png)

3. This will redirect you to the **Configure the Service Provider (SP)** page, which will display the parameters required to complete the SAML configuration on **Okta**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Okta_document360_parameters.png)

| Document360 | Okta |
| --- | --- |
| Callback path | Single sign-on URL |
| Service provider entity id | Audience URI (SP Entity ID) |

4. Enter the parameters from **Document360** to **Okta** based on the above table.
5. Select **EmailAddress** from the **Name ID format** dropdown menu.
6. Select **Email** from the **Application username** dropdown menu.
7. Update the **Attribute Statements** field based on the below table. You will have to add two additional rows to enter all the details from the below table.

   | **Name** | **Name format** | **Value** |
   | --- | --- | --- |
   | urn:oasis:names:tc:SAML:2.0:nameid | URI Reference | user.email |
   | name | Unspecified | user.email |
   | email | Unspecified | user.email |

   > NOTE
   >
   > Email and name parameters are case sensitive.
8. Click **Next** to navigate to the **Feedback** page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Okta_configure_saml.png)

#### Feedback

The feedback page is for providing information to Okta about how you configure the application. Select the **This is an internal app that we have created** checkbox and click **Finish**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Okta_feedback.png)

You have now successfully configured your application on Okta. Next, you will complete the configuration on **Document360** using the information from the application on Okta.

---

## Okta to Document360 SAML SSO configuration

### SAML setup instructions on Okta

1. On the Okta dashboard, click on the **Applications** dropdown and select **Applications**.
2. On the **Applications** page, select the active application you want to configure on Document360.
3. Click the **Sign On** tab.
4. Click the **View SAML setup instructions** button

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_GIF-Okta_app_signon_setup_instructions.gif)

The parameters needed to be configured will open in a new webpage.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Okta_setup_instructions_page.png)

### SSO configuration on Document360

1. Switch to the Document360 page you had opened, displaying the **Configure the Service Provider (SP) page.**
2. Click **Next** to Navigate to the **Configure the Identity Provider (IdP)** page.
3. Complete the fields in the **Configure the Identity Provider (IdP)** page using the setup instructions from Okta.

| Document360 | Okta |
| --- | --- |
| Sign on URL | Identity Provider Single Sign-On URL |
| Entity ID | Identity Provider Issuer |
| SAML certificate | X.509 Certificate |

4. Download the **X.509 Certificate** from Okta and attach the downloaded **okta.cert** file in the **SAML certificate** field on Document360.
5. Next, turn on/off the **Allow IdP initiated sign in** toggle as per your project requirements.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Okta_document360_configuration.png)

6. Once done, click the **Next** button to navigate to the **More settings** page.
7. In the **More settings** page, enter the desired name for the SSO configuration in the **SSO name** field.
8. Enter the text you would like to show users for the login button in the **Customize login button** text.
9. Toggle on/off the **Auto assign reader group** and **Sign out idle SSO team account** toggles based on your requirements.
10. Invite all your users or selected users using the **Convert existing team and reader accounts to SSO** radio buttons.
11. Click **Create** to complete the SSO configuration setup.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Okta_document360_configuration_save.png)

The **SSO configuration based on the SAML** protocol will be configured using **Okta** successfully.

<a id="saml-sso-with-entra"></a>

## SAML SSO with Entra

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You can configure Document360's **SAML Single Sign-On** (SSO) with the **Microsoft Entra** as the Identity provider. Please note that only users with **Owner** or **Admin** as **Project role** can configure SSO in Document360.

> PRO TIP
>
> It is recommended to open **Document360** and **Entra** in two separate tabs/browser windows, since configuring SSO in Document360 will require you to switch between Okta and Document360 multiple times.

## Adding an application in the Azure portal

### Accessing the Azure AD portal

![Accessing the azure Active Directory portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Image_2-ScreenGIF-Azure_Active_Directory_Portal_access.gif)

1. Log in to your Microsoft Azure account.
2. Click on **Portal** available on the top-right of the window.
3. You would be redirected to the portal (**Link**: <https://portal.azure.com/#home>).

### Adding your application

The 'Own application' is called 'Customer application' in this document.

1. Log in to your Azure account and visit the Azure portal page.
2. From here click on the **+ New application** option and select **Non-gallery application.**
3. Type in the name of your application and click on the **Add** button at the bottom.
4. Now you would get a window with the **Project name**, **Application ID**, and the **Project ID.**
5. In the **Getting started** section, select the **Set up single on** option.

   > These are the three selections provided
   >
   > * SAML
   > * Password-based
   > * Linked SSO
6. Select the **SAML** option, and you can find the five segregated SAML configurations.
7. You can read a detailed walkthrough of the process in the [**Azure AD configuration guide**](https://docs.microsoft.com/en-us/azure/active-directory/manage-apps/add-application-portal-setup-sso)**.**

![Adding new application in the Azure Active Directory portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Image_3-ScreenGIF-Azure_Active_Directory_adding_new_application.gif)

### Configuring SAML in your identity provider

1. Open Document360 in a separate tab or window.
2. Navigate to **Settings > Users & security > SAML/OpenID** in Document360.
3. Click the **Create SSO** button.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Settings_create_sso(2).png)

4. Select **Entra ID** as your Identity Provider (IdP) to navigate to the **Configure the Service Provider (SP)** page automatically.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Choose_idp_entra.png)

5. In the **Configure the Service Provider (SP)** page, you'll find the required parameters to configure your SAML integration in the Identity Provider.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Configure_sp_saml_generic.png)

| Azure AD fields | Document360 portal |
| --- | --- |
| Identifier (Entity ID) | Service provider entity id |
| Reply URL (Assertion Consumer Service URL) | Callback path |
| Sign on URL | https://identity.document360.io (the login page) |
| Logout URL | Signed out callback path |

5. Copy these from Document360, switch to the Azure AD portal.
6. On the **Set up Sign-On with SAML** page, click the **Edit** icon on the right and paste the data in the corresponding fields defined in the above table.

![Image_4-Screenshot-Azure_AD_SAML_configurations](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Image_4-Screenshot-Azure_AD_SAML_configurations.jpg)

5. Click on the **Save** icon at the top after you've entered all the mandatory fields

---

### Document360 SSO configuration

Finally, complete the SSO configuration in Document360:

1. Return to the Document360 tab/window displaying the **Configure the Service Provider (SP)** page and click **Next** to navigate to the **Configure the Identity Provider (IdP)** page.
2. Enter the corresponding values from your Identity Provider:

| Document360 portal fields | Azure AD portal values |
| --- | --- |
| Sign On URL | Login URL |
| Entity ID | Azure AD identifier |
| Sign Out URL | Logout URL |
| SAML certificate | Download Certificate (Base64) from Azure AD side and upload in Document360 |

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Configure_idp_saml_generic.png)

3. Toggle on/off the **Allow IdP initiated sign in** option based on your project requirements.
4. Click **Next** to proceed to the **More settings** page.

### More Settings

In the **More settings** page, configure the following:

* **SSO name**: Enter a name for the SSO configuration.
* **Customize login button**: Enter the text for the login button displayed to users.
* **Auto assign reader group**: Toggle on/off as needed.
* **Sign out idle SSO team account**: Toggle on/off based on your requirements.
* Choose whether to invite existing team and reader accounts to SSO.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-Create_SSO_more_settings_generic(2).png)

6. Click **Create** to complete the SSO configuration.

## Other configuration settings in the Azure AD portal

1. You can always edit the **User Attributes & Claims** section
2. You can either **Add a new claim** or **Add a group claim** as well
3. In the **SAML signing certificate** section, you can add **New certificates** or even **Import certificates**
4. Multiple notification email addresses can also be added
5. Once all the fields have been configured, click on the **Test** option and Log to Document360 using the credentials the user has added to the registered application

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

<a id="google-sso-saml-configuration"></a>

## SAML SSO with Google

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Log in to your Document360 account and select the project for which you wish to configure **Google SAML Single Sign-On** with your **Google Workspace** account. Next, log in to your Google Workspace account. If you don’t have a Google Workspace account, you can create one at <https://workspace.google.com/.> Once you have logged in to your Google workplace account, navigate to the admin console using the **Admin** button at the top right. Please note that only users with **Owner** or **Admin** as **Project role** can configure SSO in Document360.

> PRO TIP
>
> It is recommended to open **Document360** and **Google Workspace** in two separate tabs/browser windows, since configuring SSO in Document360 will require you to switch between Okta and Document360 multiple times.

---

## Adding a custom SAML app on Google

1. On the admin console home page, click on the **Apps** option and select the **SAML apps** option.
2. Click on **Add app** and in the dropdown, select **Add custom SAML app.**
3. In the **App details**, enter any name for your app and click on **Continue.**
4. Next, you will find the **SSO URL, Entity ID details**, and the **Certificate.**
5. Make a note of these details, since you will need them while accessing the **Configure the Identity Provider (IdP)** page on Document360.
6. In the Certificate section, click on the Download icon to save the certificate (.pem format) in your computer's local storage.
7. You will have to upload this certificate later in the **Configure the Identity Provider (IdP)** page in Document360.

![41_Screenshot-Google-user-access-service-status](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/41_Screenshot-Google-user-access-service-status.jpg)

8. In **User access**, the **Service status** will by default be **OFF for everyone**.  You must manually change it to **ON for everyone** to work.

![42_Screenshot-Google-user-access-changing-service-status](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/42_Screenshot-Google-user-access-changing-service-status.jpg)

After configuring it on the Google side, here's how your SAML app would look.

![44-Screenshot_Replace_file_Google_SSO_SAML](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/44-Screenshot_Replace_file_Google_SSO_SAML.jpg)

---

## Service Provider configuration

To configure Single Sign-On (SSO), you need **Service Provider (SP)** details such as ACS URL and entity ID. These details will be available in the **Create SSO** window on **Document360**. To navigate to the **Create SSO** window,

1. Go to **Settings** > **Users & Security** > **SAML/OpenID.**
2. Click the **Create SSO** button.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Settings_create_sso(2).png)

3. In the **Choose your Identity Provider (IdP)** page, select **Google** as the identity provider.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Choose_idp_google.png)

4. Next, from the **Configure the Service Provider (SP)** page, copy the following parameters.

| Google custom SAML app | Document360 SSO SAML settings |
| --- | --- |
| ACS URL | Callback path |
| Entity ID | Service provider entity Id |
| Start URL (optional) |  |

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Configure_sp_saml_generic.png)

5. Switch to the **Google workspace tab** and paste the parameters onto the Google custom SAML app page.
6. In **Name ID format** select **EMAIL** from the dropdown
7. In **Name ID** select **Basic Information > Primary email**
8. Click on the **Continue** button

### Attributes

Add and select user fields in Google Directory, then map them to service provider attributes. Add the following attributes.

| Google Directory attributes | App attributes |
| --- | --- |
| Primary email | name |
| Primary email | email |
| Primary email | urn:oasis:names:tc:SAML:2.0:nameid |

Click on the **Add Mapping** button each time you add an attribute, and when you're done, click on the **Finish** button.

---

## Identity Provider configuration

1. Switch back to the Document360 window, to the **Configure the Service Provider (SP)** page, and click **Next** to navigate to the **Configure the Identity Provider (IdP)** page.
2. In the **Configure the Identity Provider (IdP)** page, add the information you had noted down earlier from the **Google custom SAML app** page.

| Document360 SSO settings | Info from Google custom SAML app |
| --- | --- |
| Sign on URL | SSO URL |
| Entity id | Entity ID |
| Sign Out URL (Optional) | NA |
| SAML Certificate | Certificate (Upload the recent .pem file you downloaded from Google) |

3. Next, turn on/off the **Allow IdP initiated sign in** toggle as per your project requirements.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Okta_document360_configuration.png)

4. Once done, click the **Next** button to navigate to the **More settings** page.
5. In the **More settings** page, enter the desired name for the SSO configuration in the **SSO name** field.
6. Enter the text you would like to show users for the login button in the **Customize login button** text.
7. Toggle on/off the **Auto assign reader group** and **Sign out idle SSO team account** toggles based on your requirements.
8. Invite all your users or selected users using the **Convert existing team and reader accounts to SSO** radio buttons.
9. Click **Create** to complete the SSO configuration setup.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Create_SSO_more_settings_generic.png)

The **SSO configuration based on the SAML** protocol will be configured using **Okta** successfully.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

<a id="saml-sso-with-onelogin"></a>

## SAML SSO with OneLogin

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

This guide will walk you through the steps to configure Single Sign-On (SSO) in Document360 using OneLogin as the Identity Provider (IdP) based on the SAML protocol. Access to a OneLogin account is required. Please note that only users with **Owner** or **Admin** as **Project role** can configure SSO in Document360.

> PRO TIP
>
> It is recommended to open **Document360** and **OneLogin** in two separate tabs/browser windows, since configuring SSO in Document360 will require you to switch between Okta and Document360 multiple times.

## Adding an Application in OneLogin

To create a Document360 SSO configuration using OneLogin, follow these steps:

1. Log in to your OneLogin Admin Portal using your credentials.
2. On the top menu, select **Applications**.
3. Click **Add App**.
4. In the search bar, type "SAML" and select **SAML Custom Connector (Advanced)** from the list.
5. Name your application (e.g., "Document360 SSO") and click **Save**.

## Configuring SAML in OneLogin

Next, you will need to configure SAML settings in OneLogin using parameters from Document360:

1. Open Document360 in a separate tab or window.
2. Navigate to **Settings** > **Users & security** > **SAML/OpenID** in Document360.
3. Click the **Create SSO** button.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Settings_create_sso(2).png)
4. Select **OneLogin** as your identity provider in the **Choose your Identity Provider (IdP)** page to navigate to the **Configure the Service Provider (SP)** page automatically.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Choose_idp_onelogin.png)
5. In the **Configure the Service Provider (SP)** page, you'll find the required parameters to configure your SAML integration in the Identity Provider.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Configure_sp_saml_generic.png)
6. Switch to the **OneLogin** tab/window and navigate to the **Configuration** tab of your new application.
7. In the **Configuration** tab, enter the following values from Document360, and click **Save**.

   | OneLogin | Document360 |
   | --- | --- |
   | Audience (EntityID) | Service provider entity id |
   | Recipient | Callback path |
   | ACS (Consumer) URL Validator | Callback path |
   | ACS (Consumer) URL | Callback path |

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Configuration_tab.png)
8. Next, navigate to the **Parameters** tab, and click on the + icon to configure the following parameters:

   | Field Name | Value |
   | --- | --- |
   | urn:oasis:names:tc:SAML:2.0:nameid | Email |
   | email | Email |
   | name | Email |

   > NOTE
   >
   > While creating the parameters, check the **Include in SAML assertion** checkbox.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Parameters_tab.png)
9. Once you’re done configuring the parameters, click **Save**.
10. Navigate to the **SSO** tab and click on **View Details** to download the **X.509 Certificate**. Also, copy the values of the **Issuer URL** and **SAML 2.0 Endpoint (HTTP)**.

    > NOTE
    >
    > Before downloading the X.509 Certificate, select **SHA256** from the **SHA fingerprint** dropdown, and select the download format as **X.509.PEM**.

    ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-SSO_tab.png)

## Document360 SSO Configuration

Finally, complete the SSO configuration in Document360:

1. Return to the Document360 tab/window displaying the **Configure the Service Provider (SP)** page and click **Next** to navigate to the **Configure the Identity Provider (IdP)** page.
2. Enter the corresponding values from your Identity Provider:

| **Identity Provider** | **Document360** |
| --- | --- |
| Issuer URL | Entity id |
| SAML 2.0 Endpoint (HTTP) | Sign on URL |
| Downloaded SAML Certificate (X.509) | SAML Certificate |

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Configure_idp_saml_generic.png)

3. Toggle on/off the **Allow IdP initiated sign in** option based on your project requirements.
4. Click **Next** to proceed to the More Settings page.

## More Settings

In the **More settings** page, configure the following:

* **SSO name**: Enter a name for the SSO configuration.
* **Customize login button**: Enter the text for the login button displayed to users.
* **Auto assign reader group**: Toggle on/off as needed.
* **Sign out idle SSO team account**: Toggle on/off based on your requirements.
* Choose whether to invite existing team and reader accounts to SSO.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-Create_SSO_more_settings_generic(2).png)

5. Click **Create** to complete the SSO configuration.

<a id="saml-sso-with-adfs"></a>

## SAML SSO with ADFS

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Before setting up Single Sign-On (SSO) between Document360 and ADFS using the SAML protocol, ensure you have administrative access to both Document360 and the ADFS server. Please note that only users with **Owner** or **Admin** as **Project role** can configure SSO in Document360.

> PRO TIP
>
> It is recommended to open **Document360** and **ADFS** in two separate tabs/browser windows, since configuring SSO in Document360 will require you to switch between Okta and Document360 multiple times.

## Adding an Application in ADFS

You'll need to create a new SAML application in ADFS:

1. Log in to the ADFS Management console on your ADFS server.
2. In the **ADFS Management** console, navigate to **Relying Party Trusts**.
3. Right-click **Relying Party Trusts** and select **Add Relying Party Trust**.
4. In the **Add Relying Party Trust Wizard**, choose **Claims aware** and click **Start**.
5. Select **Enter data about the relying party manually** and click **Next**.
6. Provide a display name (e.g., "Document360 SAML SSO") and click **Next**.
7. In the **Configure Certificate** step, click **Next** (you can skip this if not using a certificate).
8. Under **Configure URL**, select **Enable support for the SAML 2.0 WebSSO protocol**.

## Document360 Service Provider (SP) Configuration

Next, you will need to configure ADFS with the Service Provider (SP) details provided by Document360:

1. Open Document360 in a separate tab or window.
2. Navigate to **Settings > Users & security > SAML/OpenID** in Document360.
3. Click the **Create SSO** button.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Settings_create_sso(2).png)

4. Select **ADFS** as your Identity Provider (IdP) to navigate to the **Configure the Service Provider (SP)** page automatically.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Choose_idp_adfs(1).png)

5. On the **Configure the Service Provider (SP) page,** choose **SAML** as the protocol.
6. You will be directed to the **Configure the Service Provider (SP)** page, which contains the following values:

   * **Subdomain name**: The unique subdomain of your Document360 instance (e.g., yourcompany.document360.io).
   * **Callback path**: The URI where users will be redirected after signing in.
   * **Signed out callback path**: The URI where users will be redirected after signing out.
   * **Metadata path**: The URL where the SAML metadata for Document360 can be retrieved.
   * **Service provider entity ID**: The unique identifier for the Document360 service provider.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Configure_sp_saml_generic.png)

7. Enter these values into the corresponding fields in the **Configure URL** and **Identifiers** steps in ADFS:

   * **Relying Party Identifier**: Use the **Service provider entity ID** provided by Document360.
   * **Sign-On URL**: Enter the **Callback path**.
   * **Sign-Out URL**: Enter the **Signed out callback path**.
   * **Relying Party Trust Identifier**: Use the **Subdomain name**.
   * **Metadata URL**: Enter the **Metadata path** to configure ADFS to retrieve the SAML metadata from Document360 automatically.
8. Click **Next** and complete the remaining steps in the wizard, such as setting up multi-factor authentication if required and permitting all users to access the application.
9. Review your settings and click **Next** to add the relying party trust.
10. On the final screen, check the box for **Open the Edit Claim Rules dialog** and click **Close**.

## Configuring Claim Rules

1. In the **Edit Claim Rules** dialog, click **Add Rule**.
2. Select **Send LDAP Attributes as Claims** as the rule template and click **Next**.
3. Provide a name for the claim rule (e.g., "Send LDAP Attributes").
4. Configure the following:

   * **Attribute Store**: Select **Active Directory**.
   * **Mapping**:

     + **LDAP Attribute**: User-Principal-Name | **Outgoing Claim Type**: Name ID
     + **LDAP Attribute**: E-Mail-Addresses | **Outgoing Claim Type**: Email
     + **LDAP Attribute**: Display-Name | **Outgoing Claim Type**: Name
5. Click **Finish** to add the rule.
6. Click **Apply** to save your changes and close the dialog.

## Document360 SAML SSO Configuration

Now, configure the SSO settings in Document360:

1. Return to the Document360 tab/window displaying the **Configure the Service Provider (SP)** page and click **Next** to navigate to the **Configure the Identity Provider (IdP)** page.
2. Enter the corresponding values from your ADFS configuration:

| **ADFS** | **Document360** |
| --- | --- |
| SAML Sign-On URL | Identity Provider Single Sign-On URL |
| Identifier (Entity ID) | Identity Provider Issuer |
| X.509 Certificate | SAML Certificate |

3. Download the X.509 Certificate from ADFS and upload it to Document360 in the **SAML Certificate** field.
4. Toggle on/off the **Allow IdP initiated sign in** option based on your project needs.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Configure_idp_saml_generic.png)

5. Click **Next** to proceed to the **More settings** page.

### More Settings

In the **More settings** page, configure the following:

* **SSO name**: Enter a name for the SSO configuration.
* **Customize login button**: Enter the text for the login button displayed to users.
* **Auto assign reader group**: Toggle on/off as needed.
* **Sign out idle SSO team account**: Toggle on/off based on your requirements.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-Create_SSO_more_settings_generic(2).png)

6. Click **Create** to complete the SAML SSO configuration.

<a id="saml-sso-with-other-configurations"></a>

## SAML SSO with other configurations

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

To configure Single Sign-On (SSO) between Document360 and any Identity Provider (IdP) not listed explicitly in Document360, ensure you have the necessary credentials and access to both Document360 and your chosen IdP. Please note that only users with **Owner** or **Admin** as **Project role** can configure SSO in Document360.

> PRO TIP
>
> It is recommended to open **Document360** and your **Identity Provider (IdP)** in two separate tabs/browser windows, since configuring SSO in Document360 will require you to switch between Okta and Document360 multiple times.

## Adding an Application in your Identity Provider

You must create a new SAML application in your Identity Provider:

1. Log in to your Identity Provider's admin console using your credentials.
2. Locate the section where you can create or manage applications (often labeled as **Applications**, **Enterprise Applications**, or similar).
3. Select the option to create a new application.
4. Configure the basic settings for the new application:

   * **Application Name**: Enter a name, e.g., "Document360 SSO".
   * **Application Type**: Select **SAML 2.0** as the sign-in method.
5. Save your application settings.

## Configuring SAML in your Identity Provider

Next, you will need to configure SAML settings in your Identity Provider using parameters from Document360:

1. Open Document360 in a separate tab or window.
2. Navigate to **Settings > Users & security > SAML/OpenID** in Document360.
3. Click the **Create SSO** button.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Settings_create_sso(2).png)

4. Select **Others** as your Identity Provider (IdP) to navigate to the **Configure the Service Provider (SP)** page automatically.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Choose_idp_others(1).png)

5. In the **Configure the Service Provider (SP)** page, you'll find the required parameters to configure your SAML integration in the Identity Provider.

In your Identity Provider's SAML configuration:

* **Single Sign-On URL**: Enter the **Callback path** from Document360.
* **Entity ID**: Enter the **Service provider entity ID** from Document360.
* **Audience URI**: This is typically the **Service provider entity ID** or **Single Sign-On URL** provided by Document360.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Configure_sp_saml_generic.png)

### Attribute Mapping

You may need to configure attribute statements for your Identity Provider:

| **Attribute Name** | **Value** |
| --- | --- |
| **NameID** | [user.email](http://user.email) or user ID |
| **email** | [user.email](http://user.email) |
| **name** | [user.name](http://user.name) |

Configure these values as required by your Identity Provider. Note that the case of attribute names may be important.

### Feedback and Additional Configuration

Some Identity Providers may ask for feedback or additional information:

1. Provide any additional configuration details as required by your Identity Provider.
2. Review your settings and save the SAML configuration.

## Document360 SSO Configuration

Finally, complete the SSO configuration in Document360:

1. Return to the Document360 tab/window displaying the **Configure the Service Provider (SP)** page and click **Next** to navigate to the **Configure the Identity Provider (IdP)** page.
2. Enter the corresponding values from your Identity Provider:

| **Identity Provider** | **Document360** |
| --- | --- |
| Single Sign-On URL | Identity Provider Single Sign-On URL |
| Entity ID | Identity Provider Issuer |
| SAML Certificate (X.509) | SAML Certificate |

3. Download the X.509 Certificate from your Identity Provider and upload it to Document360.
4. Toggle on/off the **Allow IdP initiated sign in** option based on your project requirements.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Configure_idp_saml_generic.png)

5. Click **Next** to proceed to the **More settings** page.

### More Settings

In the **More settings** page, configure the following:

* **SSO name**: Enter a name for the SSO configuration.
* **Customize login button**: Enter the text for the login button displayed to users.
* **Auto assign reader group**: Toggle on/off as needed.
* **Sign out idle SSO team account**: Toggle on/off based on your requirements.
* Choose whether to invite existing team and reader accounts to SSO.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-Create_SSO_more_settings_generic(2).png)

6. Click **Create** to complete the SSO configuration.

The SSO configuration will now be set up in Document360 using your selected Identity Provider.

<a id="idp-initiated-login"></a>

## Identity Provider (IdP) initiated sign in

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Identity Provider (IdP) initiated sign in is now available for the SSO conigured based on the SAML protocol in Document360. Following are the Identity Providers (IdPs) that support this feature:

* **Okta**
* **Entra ID**
* **Google Workspace**
* **OneLogin**
* **ADFS**

---

## Enabling the IdP-initiated sign in

1. Choose your desired project and go to the Knowledge base portal.
2. Navigate to **Settings** > **Users & security** > **SAML/OpenID.**
3. Click the **Edit** () icon which appears when you hover over an existing SSO configuration.
4. Navigate to the **IdP configurations** page in the SSO configuration window.
5. Turn **ON** the **Allow IdP initiated sign in** toggle.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Idp-initiated_sign_in_toggle.png)

> NOTE
>
> You can also enable the **Allow IdP initiated sign in** toggle while setting up a new SSO configuration on the **Configure the Identity Provider (IdP)** page.

---

### How does IdP-initiated sign in work?

1. Once the "**Allow IdP initiated sign in**" is switched on, an exclusive IdP-initiated sign-on URL is obtained from the IdP and shared with the SSO users.
2. The SSO users can use the link to log in to the Identity Provider's dashboard.
3. The SSO user then selects the configured projects and access Document360 directly.

---

## FAQs

**What are the identity providers supported by Document360?**

The following is the list of most commonly supported identity providers supported by Document360:

* Okta
* Microsoft Entra
* Google Workspaces
* OneLogin
* ADFS

Please note that the above list is not exhaustive.

**Why am I receiving an error when trying to access Document360 from the Okta dashboard?**

This error occurs because the option "Allow IdP initiated sign in" is not enabled in Document360. You need to enable this option to allow users to log in from the Okta dashboard.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="removing-a-configured-saml-sso"></a>

## Removing a configured SAML SSO

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

SSO configurations can be deleted easily with a single click from Document360 settings.

1. Choose your desired project and go to the Knowledge base portal.
2. Navigate to **Settings** > **Users & security** > **SAML/OpenID.**
3. Click the **Delete** () icon which appears when you hover over an existing SSO configuration.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-SSO_configuration_delete_icon.png)

4. Once you click **Delete,** a **Delete SSO confirmation** popup will appear.
5. Click **Proceed** to successfully delete the SSO configuration.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-SSO_configuration_delete_confimation_popup.png)

> NOTE
>
> When you delete an existing SSO configuration, any users associated with the SSO configuration will also be deleted.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

<a id="openid"></a>

## OpenID

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

**OpenID Connect (OIDC)** is an open standard authentication protocol that allows users to log in to multiple web-based applications using a single set of credentials. It's built on top of the OAuth 2.0 authorization framework. With **OpenID** enabled, Document360 users can log in to the platform using their existing credentials from an identity provider (IdP). This eliminates the need for users to remember multiple passwords and reduces the risk of unauthorized access. Document360 supports the configuration of multiple single sign-on (SSO) endpoints, allowing both team accounts and readers to log in using their preferred identity provider.

## Supported identity providers

Document360 supports the following identity providers (**IdP**):

* **Okta**
* **Entra ID**
* **Google**
* **Auth0**
* **ADFS**
* **OneLogin**
* **Others**

---

## Configuring SSO using OpenID

1. Log in to your Document360 account and navigate to your desired project.
2. Navigate to ****Settings** (****)** > ****Users & security**** > **SAML/OpenID.**
3. Click **Create SSO.**
4. Select an identity provider from the **Choose your Identity Provider (IdP)** page.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Create_SSO_Choose_idp_page.png)
5. Select **OpenID** from the **Configure the Service Provider (SP)** page.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Configure_sp_openid_generic.png)
6. Using the details provided in the **Configure the Service Provider (SP)** page, configure the Document360 application with the previously selected identity provider.
7. Using the details provided by the identity provider, setup the SSO configuration in Document360 on the **Configure the Identity Provider (IdP)** page.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Configure_idp_openid_generic.png)

Once you have successfully completed the SSO configuration based on the **OpenID** protocol, you can invite members from your project to the configured SSO application.

Now, users can login to Document360 either using their email and password or using **SSO**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-SSO_configuration_document360_login_page.png)

## Troubleshooting

If you encounter issues during the OpenID SSO setup or login, refer to the following common errors and their solutions:

### Authority URL configuration error

**Error:** IDX20803: Unable to obtain configuration from: 'System.String'

This error typically occurs due to an incorrect or misconfigured Authority URL in the OpenID SSO configuration.

**Steps to resolve:**

To resolve this issue,

**Identify the Correct Authority URL**

1. Access the discovery document specific to your Identity Provider (IdP) by using the following URL format: `https://<domain>/.well-known/openid-configuration`
2. For example, if you're using Auth0, it might look like: `https://your-domain.auth0.com/.well-known/openid-configuration`
3. Open this URL in a web browser to view the discovery document.

![OpenID configuration JSON showing issuer and supported response modes.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Troubleshooting_authority_url_configuration_error.png)

**Retrieve and update the Authority URL in Document360**

1. In the discovery document, locate the field labeled `"issuer"`.
2. Copy the value of this field; this is your correct Authority URL.
3. Log in to your Document360 project.
4. Navigate to ****Settings** (****)** > ****Users & security**** > **SAML/OpenID.**
5. Click **Edit** on your existing OpenID SSO configuration and navigate to the **Configure the Identity Provider (IdP)** page.
6. In the **Authority** field, paste the copied URL.

![Configuration settings for SSO with highlighted authority field and steps for Okta setup.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Troubleshooting_authority_url_field.png)

**Verify and test the configuration**

* Ensure there are no trailing spaces or incorrect characters in the Authority URL.
* Save the configuration.
* Attempt to log in using SSO to verify that the issue is resolved.

If the problem persists after following these steps, consider checking for network issues or firewall settings that might block access to the Identity Provider's configuration endpoint. Additionally, ensure that your Identity Provider's SSL certificates are valid and not expired, as this can also cause connectivity issues.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

<a id="okta-with-openid-sso"></a>

## Okta with OpenID SSO

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Before setting up Single Sign-On (SSO) between Document360 and Okta using the OpenID protocol, ensure you have administrative access to Okta. Please note that only users with **Owner** or **Admin** as **Project role** can configure SSO in Document360.

> PRO TIP
>
> It is recommended to open **Document360** and **Okta** in two separate tabs/browser windows since configuring SSO in Document360 will require you to switch between Okta and Document360 multiple times.

## Sign up for Okta

Access to an Okta account is required for configuring SSO with Document360. If you don't have an account:

1. Navigate to [Okta Developer Sign-Up](https://developer.okta.com/signup/) and complete the sign-up process.

## Adding an Application in Okta

To create a Document360 SSO configuration using Okta, follow these steps:

1. Log in to Okta using your account credentials.
2. Switch to the admin user role by clicking on **Admin** at the top right next to your profile name.
3. From the left navigation list, expand the **Applications** dropdown and click **Applications**.
4. On the **Applications** page, click the **Create App Integration** button.
5. In the **Create a new app integration** popup, select **OIDC - OpenID Connect** as the **Sign-in method** and choose **Web Application** as the **Application type**, then click **Next**.

## Document360 Service Provider (SP) Configuration

Next, you will need to configure Okta with the Service Provider (SP) details provided by Document360:

1. Open Document360 in a separate tab or window.
2. Navigate to **Settings** > **Users & security** > **SAML/OpenID** in Document360.
3. Click the **Create SSO** button.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Settings_create_sso(1).png)

4. Select **Okta** as your identity provider to automatically navigate to the **Configure the Service Provider (SP)** page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Choose_idp_okta.png)

5. In the **Configure the Service Provider (SP)**, select the **OpenID** radio button.
6. The **Configure the Service Provider (SP)** page contains the following values:

   * **Subdomain name**
   * **Sign in redirect URI**
   * **Sign out redirect URI**
7. In the **New Web App Integration** page onOkta:

   * **Sign-in redirect URIs**: Enter the **Sign in redirect URI** provided by Document360.
   * **Sign-out redirect URIs**: Enter the **Sign out redirect URI** provided by Document360.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Okta_new_web_app_integration.png)

## Document360 OpenID SSO Configuration

Now, configure the SSO settings in Document360:

1. Return to the Document360 tab/window displaying the **Configure the Service Provider (SP)** page.
2. Click **Next** to navigate to the **Configure the Identity Provider (IdP)** page and enter the corresponding values from your Okta configuration:

| **Okta** | **Document360** |
| --- | --- |
| Client ID | Client ID |
| Client Secret | Client Secret |
| Issuer URI | Authority |

> NOTE
>
> To find the Issuer URI in Okta, navigate to **Security** > **API.**

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Okta_client_id_secret.png)

3. Ensure that the **Client ID** and **Client Secret** match the values generated in Okta.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Configure_idp_openid_generic(1).png)

4. Toggle on/off the **Allow IdP initiated sign in** option based on your project needs.
5. Click **Next** to proceed to the **More settings** page.

### More Settings

In the **More settings** page, configure the following:

* **SSO name**: Enter a name for the SSO configuration.
* **Customize login button**: Enter the text for the login button displayed to users.
* **Auto assign reader group**: Toggle on/off as needed.
* **Sign out idle SSO team account**: Toggle on/off based on your requirements.
* Choose whether to invite existing team and reader accounts to SSO.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-Create_SSO_more_settings_generic(1).png)

6. Click **Create** to complete the OpenID SSO configuration.

<a id="auth0-with-openid-sso"></a>

## Auth0 with OpenID SSO

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Access to a Auth0 account is required for configuring single sign-on in Document360 with Auth0. Please note that only users with **Owner** or **Admin** as **Project role** can configure SSO in Document360.

> PRO TIP
>
> It is recommended to open **Document360** and **Auth0** in two separate tabs/browser windows, since configuring SSO in Document360 will require you to switch between Okta and Document360 multiple times.

To sign up for Microsoft Entra:

1. Navigate to the <https://auth0.com/signup> and sign in.
2. If you don't have an account, follow the prompts to create one.

## Creating an application in Auth0

![12_ScreenGIF-Auth0-sign-in-and-create-application-min](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/12_ScreenGIF-Auth0-sign-in-and-create-application-min.gif)

1. After successful Login with Auth0, you can find the Applications menu on the left-hand side menus
2. Click on **Application** > **Create application**
3. Type in your **Application name** and choose an application type as **Regular Web Applications** and click on the **Create** button

## Configure Auth0 OpenID with Document360

Next, you will need to configure ADFS with the Service Provider (SP) details provided by Document360:

1. Open Document360 in a separate tab or window.
2. Navigate to **Settings** > **Users & security** > **SAML/OpenID** in Document360.
3. Click the **Create SSO** button.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Settings_create_sso(1).png)

4. Select **Others** as your Identity Provider (IdP) on the **Choose your Identity Provider (IdP)** page to navigate to the **Configure the Service Provider (SP)** page in Document360.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Choose_idp_others.png)

5. Choose **OpenID** as the protocol in the **Configure the Service Provider (SP)** page in Document360.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Configure_sp_openid_generic.png)

This page will provide the required parameters for configuring OpenID in your Identity Provider. In your Identity Provider's OpenID configuration:

* **Sign in redirect URI**: Paste this in the **Application Login URI** and **Allowed Callback URLs** fields.
* **Sign out redirect URI**: Paste this this in the **Allowed Logout URLs** field.

![17_Screenshot-Auth0-configurations-Login-URI-Logout-URI](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/17_Screenshot-Auth0-configurations-Login-URI-Logout-URI.jpg)

Once you have entered all the required fields, click the **Save changes** button at the end of the page.

## Document360 OpenID SSO Configuration

Now, configure the SSO settings in Document360:

1. Return to the Document360 tab/window displaying the **Configure the Service Provider (SP)** page and click Next to navigate to the **Configure the Identity Provider (IdP)** page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Configure_idp_openid_generic.png)

2. Enter the corresponding values from your Identity Provider:

| Document360 | Identity provider |
| --- | --- |
| Client ID | Client ID |
| Client Secret | Client Secret |
| Authority | Domain |

![39_Screenshot-OpenID_with-Auth0_basic_information](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/39_Screenshot-OpenID_with-Auth0_basic_information.jpg)

3. Toggle on/off the **Allow IdP initiated sign in** option based on your project needs.
4. Click **Next** to proceed to the **More settings** page.

### More Settings

In the **More settings** page, configure the following:

* **SSO name**: Enter a name for the SSO configuration.
* **Customize login button**: Enter the text for the login button displayed to users.
* **Auto assign reader group**: Toggle on/off as needed.
* **Sign out idle SSO team account**: Toggle on/off based on your requirements.
* Choose whether to invite existing team and reader accounts to SSO.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-Create_SSO_more_settings_generic.png)

6. Click **Create** to complete the OpenID SSO configuration.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

<a id="adfs-with-openid-sso"></a>

## ADFS with OpenID SSO

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Before setting up Single Sign-On (SSO) between Document360 and ADFS using the OpenID protocol, ensure you have administrative access to both Document360 and the ADFS server. Please note that only users with **Owner** or **Admin** as **Project role** can configure SSO in Document360.

> PRO TIP
>
> It is recommended to open **Document360** and **ADFS** in two separate tabs/browser windows, since configuring SSO in Document360 will require you to switch between Okta and Document360 multiple times.

## Adding an Application in ADFS

You'll need to create a new OpenID application in ADFS:

1. Log in to the ADFS Management console on your ADFS server.
2. In the **ADFS Management** console, navigate to **Relying Party Trusts**.
3. Right-click **Relying Party Trusts** and select **Add Relying Party Trust**.
4. In the **Add Relying Party Trust Wizard**, choose **Claims aware** and click **Start**.
5. Select **Enter data about the relying party manually** and click **Next**.
6. Provide a display name (e.g., "Document360 OpenID SSO") and click **Next**.
7. In the **Configure Certificate** step, click **Next** (you can skip this if not using a certificate).

## Document360 Service Provider (SP) Configuration

Next, you will need to configure ADFS with the Service Provider (SP) details provided by Document360:

1. Open Document360 in a separate tab or window.
2. Navigate to **Settings** > **Users & security** > **SAML/OpenID** in Document360.
3. Click the **Create SSO** button.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Settings_create_sso(1).png)

4. Select **ADFS** as your identity provider to automatically navigate to the **Configure the Service Provider (SP)** page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Choose_idp_adfs.png)

5. In the **Configure the Service Provider (SP)**, select the **OpenID** radio button.
6. The **Configure the Service Provider (SP)** page contains the following values:

   * Choose **OpenID** as the protocol.
   * **Subdomain name**
   * **Sign in redirect URI**
   * **Sign out redirect URI**

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Configure_sp_openid_generic(1).png)

7. Switch to the **ADFS Management console tab/window** and enter these values into the corresponding fields in the **Configure URL** step:

   * **Relying Party Identifier**: Use the **Subdomain name** provided by Document360.
   * **Sign-On URL**: Enter the **Sign in redirect URI**.
   * **Sign-Out URL**: Enter the **Sign out redirect URI**.
8. Click **Next** and complete the remaining steps in the wizard, such as setting up multi-factor authentication if required and permitting all users to access the application.
9. Review your settings and click **Next** to add the relying party trust.
10. On the final screen, check the box for **Open the Edit Claim Rules dialog** and click **Close**.

## Configuring Claim Rules

1. In the **Edit Claim Rules** dialog, click **Add Rule**.
2. Select **Send LDAP Attributes as Claims** as the rule template and click **Next**.
3. Provide a name for the claim rule (e.g., "Send LDAP Attributes").
4. Configure the following:

   * **Attribute Store**: Select **Active Directory**.
   * **Mapping**:

     + **LDAP Attribute**: User-Principal-Name | **Outgoing Claim Type**: Name ID
     + **LDAP Attribute**: E-Mail-Addresses | **Outgoing Claim Type**: Email
     + **LDAP Attribute**: Display-Name | **Outgoing Claim Type**: Name
5. Click **Finish** to add the rule.
6. Click **Apply** to save your changes and close the dialog.

## Document360 OpenID SSO Configuration

Now, configure the SSO settings in Document360:

1. Return to the Document360 tab/window displaying the **Configure the Service Provider (SP)** page.
2. Click **Next** to navigate to the **Configure the Identity Provider (IdP)** page and enter the corresponding values from your ADFS configuration:

| **ADFS** | **Document360** |
| --- | --- |
| Client Identifier (Client ID) | Client ID |
| Client Secret | Client Secret |
| Issuer URL | Authority (Authorization URL or Endpoint) |

3. Ensure that the **Client Identifier** matches the **Relying Party Identifier** configured in ADFS.
4. Toggle on/off the **Allow IdP initiated sign in** option based on your project needs.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Configure_idp_openid_generic(1).png)

3. Click **Next** to proceed to the **More settings** page.

### More Settings

In the **More settings** page, configure the following:

* **SSO name**: Enter a name for the SSO configuration.
* **Customize login button**: Enter the text for the login button displayed to users.
* **Auto assign reader group**: Toggle on/off as needed.
* **Sign out idle SSO team account**: Toggle on/off based on your requirements.
* Choose whether to invite existing team and reader accounts to SSO.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-Create_SSO_more_settings_generic(1).png)

6. Click **Create** to complete the OpenID SSO configuration.

<a id="other-configurations-with-openid-sso"></a>

## Other configurations with OpenID SSO

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Before setting up Single Sign-On (SSO) between Document360 and an OpenID Identity Provider (IdP) not explicitly listed in Document360, ensure you have access to both Document360 and your chosen IdP. Please note that only users with **Owner** or **Admin** as **Project role** can configure SSO in Document360.

> PRO TIP
>
> It is recommended to open **Document360** and the **Identity Provider (IdP)** in two separate tabs/browser windows, since configuring SSO in Document360 will require you to switch between Okta and Document360 multiple times.

## Adding an Application in Your Identity Provider

You'll need to create a new OpenID application in your Identity Provider:

1. Log in to your Identity Provider's admin console using your credentials.
2. Navigate to the section where you can create or manage applications (often labeled as **Applications**, **Enterprise Applications**, or similar).
3. Select the option to create a new application.
4. Set up the basic settings for your new application:

   * **Application Name**: Enter a name, e.g., "Document360 OpenID SSO".
   * **Application Type**: Select **OpenID Connect** as the sign-in method.
5. Save your application settings.

## Configuring OpenID in Your Identity Provider

You will need to configure OpenID settings in your Identity Provider using parameters from Document360:

1. Open Document360 in a separate tab or window.
2. Navigate to **Settings > Users & security > SAML/OpenID** in Document360.
3. Click the **Create SSO** button.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Settings_create_sso.png)

4. Select **Others** as your Identity Provider (IdP) on the **Choose your Identity Provider (IdP)** page to navigate to the **Configure the Service Provider (SP)** page in Document360.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Choose_idp_others.png)

5. Choose **OpenID** as the protocol in the **Configure the Service Provider (SP)** page in Document360.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Configure_sp_openid_generic.png)

This page will provide the required parameters for configuring OpenID in your Identity Provider. In your Identity Provider's OpenID configuration:

* **Subdomain name**: Enter the **Subdomain name** provided by Document360.
* **Redirect URI**: Enter the **Sign in redirect URI** and **Sign out redirect URI** provided by Document360.

### Scope and Claims

Ensure that the following scopes and claims are included:

| **Scope** | **Description** |
| --- | --- |
| **openid** | Required for OpenID authentication |
| **email** | Access to the user's email |
| **profile** | Access to the user's basic profile info |

Map the required claims in your Identity Provider:

| **Claim** | **Value** |
| --- | --- |
| **sub** | user ID or identifier |
| **email** | [user.email](http://user.email) |
| **name** | [user.name](http://user.name) |

Review the settings and save your configuration.

## Document360 OpenID SSO Configuration

Now, configure the SSO settings in Document360:

1. Return to the Document360 tab/window displaying the **Configure the Service Provider (SP)** page and click Next to navigate to the **Configure the Identity Provider (IdP)** page.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Configure_idp_openid_generic.png)

2. Enter the corresponding values from your Identity Provider:

| Document360 | Identity provider |
| --- | --- |
| Client ID | Client ID |
| Client Secret | Client Secret |
| Authority | Authorization URL or Endpoint |

3. Enter the requested details in Document360 and upload the necessary certificates or keys, if required.
4. Toggle on/off the **Allow IdP initiated sign in** option based on your project needs.
5. Click **Next** to proceed to the **More settings** page.

### More Settings

In the **More settings** page, configure the following:

* **SSO name**: Enter a name for the SSO configuration.
* **Customize login button**: Enter the text for the login button displayed to users.
* **Auto assign reader group**: Toggle on/off as needed.
* **Sign out idle SSO team account**: Toggle on/off based on your requirements.
* Choose whether to invite existing team and reader accounts to SSO.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-Create_SSO_more_settings_generic.png)

6. Click **Create** to complete the OpenID SSO configuration.

<a id="removing-a-configured-openid-sso"></a>

## Removing a configured OpenID SSO

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

SSO configurations can be deleted easily with a single click from Document360 settings.

1. Choose your desired project and go to the Knowledge base portal.
2. Navigate to **Settings** > **Users & security** > **SAML/OpenID.**
3. Click the **Delete** () icon which appears when you hover over an existing SSO configuration.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-SSO_configuration_delete_icon.png)

4. Once you click **Delete,** a **Delete SSO confirmation** popup will appear.
5. Click **Proceed** to successfully delete the SSO configuration.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-SSO_configuration_delete_confimation_popup.png)

> NOTE
>
> When you delete an existing SSO configuration, any users associated with the SSO configuration will also be deleted.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

<a id="configuring-the-jwt-sso"></a>

## Setting up JWT SSO

**Plans supporting single sign on (SSO)**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

### What is a ****JWT****?

A **JSON Web Token (JWT)** is an encrypted token format that securely transfers data such as credentials (authentication and authorization) between two applications. ****JWT**** is specifically used to authenticate reader logins in Document360. Click here to [**read about JWT**](https://en.wikipedia.org/wiki/JSON_Web_Token)**.**

---

## Enterprise SSO using ****JWT****

Document360 uses an approach similar to **PKCE** (*Proof Key for Code Exchange*, a secure OAuth method) to generate the ****JWT**** token.

The high-level diagram below shows how to achieve ****JWT**** authentication flow in Document360.

![Picture1.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Picture1.png)

### Steps in the ****JWT**** authentication flow

1. When the end-user tries to access the knowledge base configured with ****JWT****, the Document360 knowledge base will redirect the end-user to the login URL that the team account has configured in **Document360 **JWT** settings.**

   Assuming that the configured login URL resides inside the customer application, which will require authentication.
2. By calling the login endpoint in the customer application, it will invoke the login logic, which will send a request with:

   * User details
   * Client ID and client secret to the identity server code generation URL to get the authentication code

     This process is done through the backchannel.
3. The code generation URL will accept the POST requests with the JSON payload shown below:

   The client ID and secret must be sent as a basic authorization header.

Follow this [**link**](https://swagger.io/docs/specification/authentication/basic-authentication/) to find out how the header needs to be formed for basic authentication.

#### JSON payload

```
{
"username": "firstname + lastname",
"firstName": "firstname",
"lastName": "lastname",
"emailId": "user emailId",
"readerGroupIds": ["Obtain from Reader groups overview page in the Document360 portal (Optional)"],
"tokenValidity": 15 //minutes *()*
}
```

JSON

Copy

> NOTE
>
> Ensure correct JSON syntax to avoid configuration errors.

4. The identity server will generate the code based on the user details, client ID, and client secret and return the generated code to the customer application.

   This is done via the backchannel.
5. Once the customer application receives the auth code from the identity server,

   * The customer app will append the code to the callback URL found in the ****JWT** settings** and redirect the user to the callback URL with the code.
   * **For example:** `HTTPS://{project_name}.document360.io/jwt/authorize?code={code}`

> NOTE
>
> The authentication code is a one-time use code and cannot be reused.

4. Once the knowledge base receives the authentication code in the query parameter, it will send the code to the identity server via backchannel for the ID token and access token.
5. Once the knowledge base has received the ID token, it will create a session on behalf of the user mentioned in the earlier user details.

   * By default, this session will be valid for **15 minutes**. Once the session cookie expires, the end-user will be redirected to the login URL (hosted within the customer application) to get a new code, and the flow will repeat.
   * The session renewal will be seamless since the user is already authenticated to the customer application

#### Token validity

The **minimum value** that can be set is **5 minutes**, and the **maximum value** that can be set is **1440 minutes** (1 day).

#### cURL

To test the JWT configuration, you can use the cURL command with the following specifications. The HTTP version should be specified (**HTTP2** over **TLS** and version of **SSL** to **TLS 1.2**. Without this, the cURL would fail.

> NOTE
>
> Unlike other IdP options available (Okta, Azure AD, etc.), the user does not need a separate reader account on Document360. An account on the client application is sufficient.

After enabling the JWT login, the reader can use the client application to log in as a reader account on the Document360 knowledge base site.

NOTE

Currently, Document360 provides an either-or functionality for the SSO standards. Once the IdP is configured using an SSO standard (SAML, OpenID, or JWT) for a project, the user cannot create another simultaneous session.

**For Ex.** If a project is configured in the OpenID standard with Okta as IdP, the SAML and the JWT options would be disabled.

---

## SSO configuration

### Creating a ****JWT****

To create a **JSON Web Token (JWT)**,

1. Log in to the Document360 portal.
2. Go to ****Settings** ()**> ****Users & security**** > ****JWT****.
3. Create a JWT (Client secret) from here by clicking on the **Create JWT** button.
4. Copy the generated client secret by clicking on the **copy** icon and clicking on **Close**.

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-JWT_client_secret.png)

> NOTE
>
> The same generated Client secret will not be available when you revisit this section. If required, the client's secret must be regenerated.

The JWT configuration page with all the data will be available now.

---

### JWT configuration

After a JWT is created, the **JWT configuration page** will be visible.

* **Set up your application:** Copy the **Client ID, Callback URL, Code generation URL, Client secret** and paste it into the appropriate fields in the client application

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-JWT_setup_your_application.png)

* **JWT status**:Turn the **JWT SSO login for readers** on or off using this toggle. If the toggle is set to **off**, readers will not be able to log in to the knowledge base site using their client app credentials.
* **Delete JWT**:Click the **Delete** button to remove the configured JWT. You cannot undo this action.
* **JWT basic configuration**: Paste the login URL obtained from the client's application.

  + Readers will land on the dedicated logout page for JWT SSO readers if a custom logout link is not provided.

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-JWT_basic_configuration.png)

---

### Redirection to other pages instead of the home page

By default, after logging in, users are redirected to the **Home page** of your knowledge base.

* If your **Home page** is unpublished, users will be redirected to the **/docs** page.
* To redirect users to a different page in your knowledge base (other than the **Home** or **/docs** pages), configure the redirection during JWT setup using the following code.

#### URL pattern

```
https://<Knowledge base URL>/jwt/authorize?code=<code>&redirectUrl=<redirect path>
```

Plain text

Copy

#### Parameters

* **Knowledge base URL**: The main URL of your knowledge base site.
* **Code**: The client ID.
* **Redirect URL**: The new URL where you want users to land after login.

#### Example

```
https://example.document360.io/jwt/authorize?code=FOTaS_SW6dLGytQXvrG_rRFGhyPvrDDrgxJAZzYvJcY&redirectUrl=/docs/5-basic-things-to-get-started

```

Plain text

Copy

> NOTE
>
> Document360 will send the **Redirection URL** as `RedirectPath` to the login endpoint. When the login endpoint redirects back to the knowledge base with the authentication code, it should return the **Redirection URL** as a `RedirectUrl` parameter.

---

## Troubleshooting

If you encounter issues during the JWT SSO setup, refer to the following common error and its solution:

### 401-unauthorized error when testing JWT in Postman

**Error**: 401 Unauthorized error

If you encounter a **401 Unauthorized error** while testing JWT (JSON Web Token) using Postman, this typically occurs because the authorization settings are not configured correctly.

**Steps to resolve**:

To resolve this error,

1. In Postman, open the request you are testing.
2. Navigate to the **Authorization** tab.
3. Set the authorization type to **Basic Auth**.
4. In the **Username** field, enter the **Client ID**.
5. In the **Password** field, enter the **Client Secret**.
6. Go to the **Body** tab.
7. Select the **raw** option from the dropdown and ensure the format is set to **JSON**.
8. Add the required JSON payload for the API request.
9. Click **Send** to execute the request.

Check the response for the expected results. If the request is successful, you should receive an **auth code** or token in the response.

---

### FAQs

#### Can I use a single JWT login to support multiple instances of my application on the same Document360 Knowledge base site?

No, currently, Document360 supports a single JWT login configuration per project.

* A common JWT login cannot be shared across multiple instances of your application for the same Document360 knowledge base.
* Each project can only authenticate one JWT application instance at a time.

#### If a configured JWT user logs out of the client application, does that mean they would also be logged out of Document360?

No, the session on Document360 is independent after the initial Single Sign-On. Users can continue using Document360 until the token validity expires, even after logging out of the client application.

**Example:** If the token validity is set to 1 day, the Document360 session will remain active until the token expires. Once it does, the user will be logged out.

#### What are the minimum and the maximum token validity bands?

The **minimum value** that can be set is **5 minutes**, and the **maximum value** that can be set is **1440 minutes** (1 day).

#### Can I provide a value that exceeds the allowed token validity band?

No, if a value outside the range is provided, the system will automatically assign the nearest allowed value:

* **5 minutes** for values below the minimum.
* **1440 minutes** for values above the maximum.

#### What is the difference between JWT and SSO?

You can view a comparison between JWT (JSON Web Token) and SSO (Single Sign-On) in the table below:

| **Aspect** | **JWT** | **SSO** |
| --- | --- | --- |
| **Authentication** | Tokens generated per session/user request. | Centralized authentication across apps. |
| **Token Expiry** | Tokens typically expire after a set period. | No token, session handled by identity provider. |
| **Security** | Requires secure token storage. | More secure, centralized credential storage. |
| **Usage** | Used for stateless, single-use authentication. | Used for multiple applications with single login. |
| **Integration** | Easier to implement in custom apps. | Requires integration with an identity provider. |

#### Can readers log in with OpenID or SAML if JWT is configured for the project?

No, readers cannot log in with OpenID or SAML if JWT is configured for the project. Document360 allows only one SSO standard (JWT, OpenID, or SAML) to be active per project at a time.

#### What features are not supported when JWT is configured for the project?

The following functions are not supported when JWT is configured for the project:

1. **Advanced Settings**: Auto-register SSO and skip the Document360 common sign-in page.
2. **Readers**: Self-registration.

Security Assertion Markup Language (SAML) is a widely used Single Sign-On (SSO) standard that enables secure authentication and authorization by allowing users to log in to multiple applications with a single set of credentials.

<a id="jwt-reader-groups"></a>

## JWT reader groups

**Plans supporting single sign on (SSO)**

| Free | Professional | Business | Enterprise |
| --- | --- | --- | --- |
|  |  |  |  |

**JWT reader accounts** can be associated with any existing reader groups on the Document360 project, and the [**group restrictions**](https://docs.document360.com/docs/managing-reader-groups#creating-a-new-reader-group) can be applied to access specific content in the knowledge base. A JWT reader group is identical to a regular Document360 reader group, inheriting the same restriction settings.

---

## Reader groups in Document360

Reader groups act as assignable permissions that define what users can access in any private **knowledge base**.Readers must log in with their credentials to view private knowledge bases on Document360.

### Example use case

**Scenario**: The sales team needs access to pricing and billing articles but should not have access to API documentation or core technical articles.

**Solution**:

1. Create a reader group in the Document360 private project, granting access only to the pricing category.
2. Assign the sales team members to this reader group.

---

## Reader group IDs

For JWT SSO-enabled projects, users can view and obtain **Reader** **group ID** from **Settings** > **Users and Security** > **Readers & groups** > **Reader groups** tab.

* The **Group Id** is displayed below each reader group.
* A **copy** icon is available on the right to quickly copy the required **Group Id**.
* Paste the copied **Group Id** into the payload to configure it.

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image%28109%29.png)

> NOTE
>
> The **reader** **group ID** is only available for JWT-configured projects and not regular private knowledge base projects.

---

## Enabling JWT reader groups

1. Obtain and copy the **Reader group ID** by following the steps mentioned above.
2. Use the following JSON format to configure the relevant reader group IDs:

```
{
  "username": "firstname + lastname",
  "firstName": "firstname",
  "lastName": "lastname",
  "emailId": "user emailId",
  "readerGroupIds": [
    "26b3812e-7879-4407-b1c9-5755c32b886a",
    "674eadcd-793f-4131-b1e0-c1f055cc83b7"
  ],
  "tokenValidity": 15 //minutes
}
```

JSON

Copy

The **token validity** *(in minutes)* for the JWT reader can also be set in the payload. The **minimum value** that can be set is **5 minutes**, and the **maximum value** that can be set is **1440 minutes** (1 day).

To add multiple group IDs, separate them with commas (`,`).

**Example:**

```
"readerGroupIds": ["26b3812e-7879-4407-b1c9-5755c32b886a", "674eadcd-793f-4131-b1e0-c1f055cc83b7"]
```

JSON

Copy

When a JWT reader authenticates and accesses the private knowledge base, the restrictions defined in their assigned reader group will automatically apply. This ensures the reader can access only the specific project versions, languages, categories, or articles permitted by the reader group's settings.

### Timing of changes to reader group IDs

Changes to Reader Group IDs (additions or deletions) in the payload will take effect only after the current session (token validity) expires.

**Example**: If the token validity is set to 30 minutes and a new Group ID is added, the change will apply only after 30 minutes. The same applies when removing a group ID.

<a id="how-to-enlarge-the-pdf-preview-in-the-article"></a>

## How to enlarge the pdf preview in the article?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Preview size of the PDF files in the article would vary for browsers. However, you can configure the desired width of the PDF file.

> NOTE
>
> This workaround is useful only for articles created using the WYSIWYG editor.

### Solution

To enlarge the pdf preview:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.

   The **CSS** tab is the default selection.
2. Paste the below CSS snippet in the window.

KB Site 1.0

KB Site 2.0

```
.content_block .content_container .content_block_text p * {width: 100%;}
```

CSS

Copy

```
article p object {
    width: 100% !important;
}
```

CSS

Copy

3. Click **Save**.

![Enlarge PDF preview in article GIF](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Enlarge%20PDF%20preview%20in%20article%20GIF.gif)

---

### Outcome

![2_Screenshot-Outcome.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Outcome.png)

<a id="how-to-change-the-color-of-the-hyperlinks-in-dark-mode"></a>

## How to change the color of the hyperlinks in Dark mode?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

When using a dark primary color and viewing the Knowledge Base site in Dark mode, hyperlinks may appear partially visible. The primary color remains consistent across Light and Dark modes. To address this, consider changing the hyperlink color.

### Solution

You can change the color of hyperlinks in the Dark mode. This helps to avoid partially visible hyperlinks in this mode.

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

KB Site 1.0

KB Site 2.0

```
body.dark_theme .content_block .content_container .content_block_text a {color: red !important;}
```

CSS

Copy

```
html[data-bs-theme=dark] d360-article-content a {
    color: red !important;
}
```

CSS

Copy

3. Update the desired color in the above snippet.

> In the above sample snippet, it is red. You can customize it with your desired color.

4. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Update_hyperlink_color_dark_mode.png)

### Outcome

![2_Screenshot_HyperLink_Color_Changes.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot_HyperLink_Color_Changes%281%29.png)

<a id="how-to-change-the-highlighted-search-result-color-in-articles"></a>

## How to change the highlighted search result color in articles?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

When 'Highlight Matching Search Keywords in Articles' is enabled, search keywords within articles are automatically highlighted. By default, the highlight color is yellow. You have the flexibility to customize this color according to your preferences. The following steps will allow you to change the highlight color for search keywords in articles, applicable to both light and dark modes.

### Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. Paste the below CSS snippet in the **CSS** tab.

**For KB Site 1.0,**

```
mark { 
background-color: green; 
color: white; 
}
```

CSS

Copy

**For KB Site 2.0,**

```
.fp-search-content em, .search-content em {
    background-color: #4E1E66;
    color: white;
}
```

CSS

Copy

3. Update the desired color in the above snippet.

> In the above sample snippets, green and purple colors are used with white font. You can customize it with your desired color.

4. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Change%20highlighted%20search%20result%20color%20GIF.gif)

### Outcome

#### Before

Highlighted font with the standard colors offered by Document360 (before customization).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Highlighted%20search%20result%20-%20Before.png)

#### After

Highlighted font after customization with the background color `#4E1E66` and font color `white`.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Highlighted%20search%20result%20-%20After.png)

<a id="how-to-hide-the-project-versions-dropdown-in-the-knowledge-base-site"></a>

## How to hide the project's workspace dropdown in the Knowledge base site?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

If you have access to multiple project workspaces, the workspace dropdown appears at the top left of the knowledge base site. If you want to turn off the workspace selection dropdown option, you can use the below solution.

> NOTE
>
> **How will you navigate between project workspaces without the dropdown?**  
> If you implement the below solution, the user must know the exact URL of the workspace page to access it.

### Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

```
header .header_bottom .header_bottom_nav ul li.versions-selection {
    display: none;
}
```

CSS

Copy

3. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/New_Screenshot-Hifing_project_workspaces_dropdown.png)

### Outcome

![2_Screenshot-hidden_workspace.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-hidden_workspace%281%29.png)

<a id="how-to-add-a-vertical-scrollbar-to-the-code-blocks"></a>

## How to add a vertical scrollbar to the code blocks?

**Plans supporting the use of custom CSS and JS**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

When you have long codes inside the code blocks, the code block consumes more space and increases the article length. It is good to have a vertical scrollbar for the code blocks when their size increases more than a specific pixel. Check the solution below to implement this on your knowledge base site.

---

### Solution

#### To apply vertical scrollbar in specific articles within KB Site 1.0 projects

1. Add the below tag in your article for which you want a scrollbar in code blocks.

   ```
   <div class="scroll">
   ```

   XML

   Copy

2. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
3. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

   ```
   .scroll div.code-toolbar {
   height: 280px;
   overflow-x: hidden !important;
   overflow-y: auto !important;
   }
   ```

   CSS

   Copy

4. Enter the desired pixel size.
5. Click **Save** on the top right.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/16_ScreenShot-Customization.png)

### Outcome

![3_Screenshot-vertical_scrollbar_outcome.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1727784856290.png)

---

#### To apply vertical scrollbar in all articles

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

KB site 1.0

KB site 2.0

```
.code-toolbar pre {
max-height: 300px;
}
```

CSS

Copy

```
article .code-toolbar {
    height: 280px;
    overflow-x: hidden !important;
    overflow-y: auto !important;
}
```

CSS

Copy

1. Enter the desired pixel size.
2. Click **Save**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/17_ScreenShot-Customization.png)

   > NOTE
   >
   > When you use the above snippet, the top icon of the vertical scrollbar in the code block would be hidden.

### Outcome

![3_Screenshot-vertical_scrollbar_outcome.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-vertical_scrollbar_outcome%281%29.png)

<a id="how-to-set-the-default-height-and-width-of-the-embedded-pdf"></a>

## How to set the default height and width of the embedded PDF?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Preview size of the PDF files in the article would vary for browsers. However, you can configure the desired height and width of the PDF file.

### Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

```
object {
height: 500px !important;
width: 500px !important;
}
```

CSS

Copy

3. Update the desired height and weight as per your requirement.
4. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/New_Screenshot-setting%20the%20default%20height%20and%20width%20of%20the%20embedded%20PDF.png)

### Outcome

![2_Screenshot-outcome_set_of_height_&_width.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-outcome_set_of_height_&_width.png)

<a id="how-to-make-the-table-border-bold-in-knowledge-base"></a>

## How to make the table border bold in knowledge base?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

If you wish to make the border of the tables in your knowledge base thicker, you can use the below solution to change the thickness and color of your table border across your knowledge base.

### Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. Paste the below CSS snippet in the CSS tab.

```
table td, table th, table tr {
border: 3px solid #000000 !important;
}
```

CSS

Copy

3. Update the desired thickness and color in the snippet. In the provided example, thickness is **3px** and color code is **000000**.
4. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Make table border bold in KB GIF.gif)

### Outcome

#### Before

By default, the table appears as below  
![2_Screenshot-before_table_border.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-before_table_border.png)

#### After

After updating the Custom CSS, the table appears as below.

![3_Screenshot-after_table_border.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-after_table_border.png)

<a id="how-to-vertically-align-table-contents-at-the-top-in-the-knowledge-base"></a>

## How to vertically align table contents at the top in the Knowledge base?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

If you want to vertically align the table content to the top of your Knowledge base, follow the steps below to easily achieve this using a custom CSS solution.

### Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

```
table td, table th, table tr 
{  
vertical-align: top !important;
}
```

CSS

Copy

3. Update the alignment as needed. In this example, the content is set to align vertically at the top.
4. Click **Save**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_ScreenShot-Customization.png)

### Outcome

#### Before

By default, the table appears as below.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Before_adding_code.png)

#### After

After updating the Custom CSS, the table appears as below.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-After_adding_code.png)

<a id="how-to-restrict-the-readers-from-copying-the-content"></a>

## How to restrict the readers from copying the content?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In general, you can copy the contents of the Knowledge base site easily with the mouse selection and Ctrl+C (or) alternative copy action. In confidential documentation, you would want to restrict the readers from copying the content. You can implement the below solution to restrict readers from copying the content.

By implementing the below solution, the readers can still select the content and perform a copy action (i.e., they can perform mouse selection and press Ctrl+C or perform any copy action). However, the **content will not be copied**.

### Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. Paste the below snippet in the JavaScript window.

KB Site 1.0

KB Site 2.0

```
$(document).ready(function(){
$('.content_block').bind("cut copy paste",function(e) {
e.preventDefault();
});
});
```

JavaScript

Copy

```
$(document).ready(function(){
$('d360-article-content').bind("cut copy paste",function(e) {
e.preventDefault();
});
});
```

JavaScript

Copy

3. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Restrict readers from copying content GIF.gif)

<a id="how-to-keep-dark-mode-for-the-knowledge-base-site-by-default"></a>

## How to keep dark mode for the Knowledge base site by default?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You can use the Light or Dark option at the top of the article to change the theme.  If you want to enable the Dark by default, you can use the below solution.

> NOTE
>
> By default, all articles would be in Light mode.

### Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **JavaScript** tab and paste the following Javascript snippet:

```
$(document).ready(function() {
setTimeout(function() { document.getElementById('darkTheme').click(); }, 100); 
});
```

JavaScript

Copy

3. Click **Save**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGif-Customization.gif)
4. Now, all the articles on your site appear in dark mode by default.

   However, the user can switch to light mode with the **Light** option at the top of the article.
5. If you want the user to view only in dark mode, you can turn off the **theme option** in Article settings.

   a. Navigate to Settings () icon > **Knowledge base site** > **Customize site**.

   b. Under the **Site theme** section, select the **Dark only** option and click **Save** at the top.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_ScreenShot-Customization.png)

<a id="how-to-center-align-the-text-in-markdown"></a>

## How to center align the text in Markdown?

**Plans supporting customization of text in articles**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Achieving center alignment in your article is simple with the 'Align center' option in the toolbar of the WYSIWYG editor. However, in the Markdown editor, all text defaults to **left alignment**.

To center align text in the Markdown editor, follow the workaround below.

### Center align text in Markdown

1. Go to the desired article in the Knowledge base portal.
2. Paste the below code in the desired location where you want the text to appear.

```
<p style="text-align:center;">Text_content</p>
```

Plain text

Copy

3. Replace the 'Text\_content' with your desired text.

> **For example:**
>
> ```
> <p style="text-align:center;">Sample text with center alignment</p>
> ```
>
> Plain text
>
> Copy

4. The output would be as below

Sample text with center alignment

> NOTE
>
> You can add the basic text formatting such as bold, italic, and strikethrough using the usual syntax for the entire code.
>
> > **For example**,
> >
> > ```
> > ***<p style="text-align:center;">Text with basic formatting applied</p>***
> > ```
> >
> > Plain text
> >
> > Copy
> >
> > **Output**:
> >
> > ***Text with basic formatting applied***

If you want the text to be right aligned, use the following code.

```
<p style="text-align:right;">Text_content</p>
```

Plain text

Copy

---

## Center align Headings in Markdown

You can also center-align Headings in your article by slightly altering the HTML code snippet.  
 Replace the `<p>...</p>` with `<h2>...</h2>`, `<h3>...</h3>`, or `<h4>...</h4>`.

> **For example**, to center align a H3
>
> ```
> <h3 style="text-align:center;">H3 that is center aligned</h3>
> ```
>
> Plain text
>
> Copy
>
> **Output**:
>
> ### H3 that is center aligned

> NOTE
>
> Markdown doesn't have a built-in way to center align text. You can use the HTML tags provided in this article as a workaround within Markdown to achieve this effect.

One of the three editors in Document360, WYSIWYG (What You See Is What You Get) is a content editing tool that shows the final output as writers create and format content.

A lightweight text-to-HTML conversion tool used to format content such as lists, headers, images, videos, and links. Document360 includes a powerful markdown editor as one of its two basic editors.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="how-to-change-the-color-of-the-text-in-markdown"></a>

## How to change the color of the text in Markdown?

**Plans supporting customization of text in articles**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

To change the color of specific text in your articles using Markdown, follow the steps outlined below:

### Solution

1. Navigate to the desired article in the Knowledge base portal (Markdown editor).
2. Paste the below code in the desired location where you want the text to appear in the article.

```
<span style="color:red">
Text content
</span>
```

HTML

Copy

> NOTE
>
> The `<span>` tag is an HTML element, and the `style` attribute is used to apply inline CSS for styling, in this case, setting the text color to red. Markdown does not natively support custom inline styles (like text color) without extensions.

3. Replace “*Text content”* with your desired text.
4. Replace the color with your desired color.

NOTE

The above sample code mentions the color as 'red.'

#### Outcome

Text content

NOTE

If you wish to change the color of specific text in your articles in the WYSIWYG editor, use the 'Text color' option in the toolbar.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

One of the three editors in Document360, WYSIWYG (What You See Is What You Get) is a content editing tool that shows the final output as writers create and format content.

<a id="how-to-change-the-language-name-text-in-code-blocks"></a>

## How to change the language name text in code blocks?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

To maintain consistency and enable ease of use, designate a standard name such as "Example" or "Sample code" for code blocks. By default, the language name is displayed within these blocks. To modify the language name within code blocks, utilize the following workaround:

> NOTE
>
> This action would change the language name in all the code blocks in your knowledge base.

### Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

```
div.code-toolbar>.toolbar .toolbar-item:first-child {
    visibility: hidden;
}
div.code-toolbar>.toolbar .toolbar-item:first-child span:before {
    visibility: visible;
    content: "Example" !important;
}
```

CSS

Copy

3. Replace the text '**Example**' with your desired text.
4. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/New_Screenshot-Changing_the_language_name_text_in_code_blocks.png)

<a id="how-to-change-the-callouts-color-in-dark-mode"></a>

## How to change the callouts color in dark mode?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You can change the callout color in dark mode. Follow the below workaround to change the callout color in dark mode.

#### Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

   ```
   html[data-bs-theme=dark] .infoBox {
     background-color: #ddf7ff !important;   /* Here you can change info box background color (!important is mandatory)*/
     color: #006a8a !important; /* Here you can change info box font color (!important is mandatory)*/
     border-left: 4px solid #006a8a !important; /* Here you can change info box border color (!important is mandatory)*/
   }
   html[data-bs-theme=dark] .errorBox {
     background: #f9e2e4 !important; /* Here you can change error box background color (!important is mandatory)*/
     color: #7e1115 !important; /* Here you can change error box font color (!important is mandatory)*/
     border-left: 4px solid #7e1115 !important; /* Here you can change info box border color (!important is mandatory)*/
   }
   html[data-bs-theme=dark] .warningBox {
     background: #fdf2ce !important; /* Here you can change warning box background color (!important is mandatory)*/
     color: #7f6416 !important; /* Here you can change warning box font color (!important is mandatory)*/
     border-left: 4px solid #7f6416 !important; /* Here you can change info box border color (!important is mandatory)*/
   }
   ```

   CSS

   Copy
3. Update the desired color for the callouts.

> NOTE
>
> color > Text color  
> background-color > Callout box color

4. Click **Save**.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_ScreenShot-Customisation.png)

<a id="how-to-center-align-the-heading-in-the-articles"></a>

## How to center align the heading in the articles?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In Document360, with the help of Custom CSS, you can center-align the headings in the articles.

> NOTE
>
> This action will change the alignment of all the headings (H2, H3, and H4) to center alignment.

### Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

```
H2,H3,H4{
text-align:center;
}
```

CSS

Copy

3. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/New_Screenshot-Center_align_heading_in_articles.png)

<a id="how-to-change-the-color-of-the-table-header"></a>

## How to change the color of the table header?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You can change the table header color to improve the visibility of the header row. Follow the below steps to change the table header color across the knowledge base.

### Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

KB site 1.0

KB site 2.0

```
table th{
background: #70db70; 
}

```

CSS

Copy

```
.editor360-table th {
  background-color: green!important; /*Change the color based on your requirement.*/
}
```

CSS

Copy

3. Update the color as per your requirement.
4. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/New_screenshot-Changing_the_color_of_table_header.png)

### Outcome

#### Before

By default, the table header appears as below.

![2_Screenshot-Before_table header_color.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Before_table%20header_color.png)

---

#### After

After configuring a custom CSS, the table header color is changed to green (`#70db70`).

![3_Screenshot-After_table header_color.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-After_table%20header_color.png)

<a id="how-to-add-accordion-in-markdown"></a>

## How to add accordion in Markdown?

**Plans supporting customizing text in the markdown editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

If you want your content to appear as an accordion in Markdown editor based articles, there is no option to add it using a conventional tool from the menu bar or a straightforward Markdown syntax.

Use the below workaround to add an accordion effortlessly in Markdown editor.

### Solution

1. Go to the desired article and open it in the Markdown editor.
2. Paste the below code in the desired location where you want the accordion to appear

```
<details>
    <summary>Accordion_name</summary>
    <p>Accordion_content</p>
    </details>
```

HTML

Copy

3. Replace the `Accordion_name` text with the desired accordion title/name
4. Replace the `Accordion_content` text with the desired content

If you want to add headings inside the accordian you can use the Heading HTML tags (`<h2>..</h2>, <h3>..</h3>, <h4>..</h4>`) in the `Accordion_content` sections

CAUTION

Heading tags can be used in the summary section of the accordian "`Accordion_name`", but the text alignment might be affected.

### Example

#### Code

```
<details>
    <summary><strong>What is Document360?</strong></summary>
    <p>A well-structured product to create a world-class knowledge base for your customers and employees. Content producers get the power, whereas content consumers get the simplicity.</p>
    <h4>Core parts</h4>
    <ul>
        <li>Knowledge base portal</li>
        <li>Knowledge base site</li>
        <li>Knowledge base widget</li>
        <li>API documentation</li>
    </ul>
</details>
```

HTML

Copy

### Outcome

**What is Document360**

A well-structured product to create a world class knowledge base for your customers and employees. Content producers get the power whereas the Content consumers get the simplicity.

#### Core parts

* Knowledge base portal
* Knowledge base site
* Knowledge base widget
* API documentation

---

## Advanced customizations for accordions

You can enhance the accordion by adding colors, dotted borders, and icons, and setting it to always open. Here’s how to apply these customizations:

### Adding header color to the accordion

To add header color to the accordion in the articles, follow the steps below:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

```
.details-wrapper details[open] summary {
    background-color: yellow !important;
    border-radius: 0.75rem 0.75rem 0rem 0rem !important;
}
.details-wrapper summary {
    background-color: yellow !important;
    border-radius: 0.75rem 0.75rem 0.75rem 0.75rem !important;
}
.details-wrapper details:not([open]) summary {
    background-color: yellow !important;
    border-radius: 0.75rem 0.75rem 0.75rem 0.75rem !important;
}
```

CSS

Copy

3. Click **Save**.

---

### Applying a border color and dotted lines

To apply a border color and dotted lines on hover:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

```
.details-arrow {
    left: 16px !important;
    top: 42% !important;
    transition: revert;
    transform: rotate(317deg);
}
.details-wrapper details {
    border: 1px dotted var(--e360-base-light-gray) !important;
    transition: border 0.3s ease;
}
.details-wrapper details: hover {
    border: 1px solid var(--e360-base-light-gray) !important;
}
.details-wrapper_rendered summary {
    left: 19px;
    position: relative;
}
.details-wrapper details[open]+.details-arrow {
    transform: rotate(45deg);
}
```

CSS

Copy

3. Customize the code above based on your needs.
4. Once done, click **Save**.

---

### Setting an accordion to always open

To keep an accordion always open, modify the `open` attribute directly in the HTML:

```
<details open>
    <summary>Always Open Accordion</summary>
    <p>Content remains visible without user interaction.</p>
</details>
```

XML

Copy

This ensures the content is visible by default.

---

### Adding a plus icon to the accordion header

To add a plus icon that rotates upon opening:

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

   ```
   .details-wrapper details summary::before {
       content: "+";
       display: inline-block;
       margin-right: 10px;
       transition: transform 0.3s ease;
   }
   .details-wrapper details[open] summary::before {
       content: "-";
       transform: rotate(45deg);
   }
   ```

   CSS

   Copy
3. Adjust icons or transitions as preferred.
4. Click **Save**.

---

### FAQs

#### **Can I style an accordion using only Markdown?**

Markdown by itself does not support advanced styling or interactivity like you would find with HTML and CSS. However, you can achieve a simple accordion effect using Markdown’s built-in features, particularly with platforms that support it, such as Document360.

#### **What are the limitations of using Markdown for accordions?**

* **Browser Support:** The `<details>` and `<summary>` elements work in most modern browsers but may not render correctly in all Markdown environments.
* **Styling:** You won’t be able to style the accordion (e.g., colors, borders) beyond the default browser styles.
* **Interactivity:** The interactivity is limited to collapsing and expanding the text without additional animations or design options.

#### **How can I create an accordion using Markdown?**

Using the `<details>` and `<summary>` tags within Markdown is the best way to create a basic accordion without additional CSS or JavaScript. For enhanced styling or features, you would need to resort to HTML and CSS or use a Markdown processor that allows for custom styles.

<a id="how-to-add-extra-space-in-markdown"></a>

## How to add extra space in Markdown?

**Plans supporting customizing text in the markdown editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In Markdown, you can add space between two lines by pressing Enter/Return key. However, this action would add only one empty line. If you want to add extra space between two lines, you can follow the below workaround steps.

### Solution

#### **1. Using HTML Tags**

For more precise control over spacing, you can use HTML tags directly within your Markdown document. For example, you can use the `<br>` tag to insert a line break and create space:

1. Go to the desired Markdown article in the editor.
2. Paste the below code in the location where you want extra space.

```
<br>

```

Plain text

Copy

NOTE

Markdown doesn't have a built-in way to add extra space. You can use the HTML tags provided in this article as a workaround within Markdown to achieve this effect.

3. If you want to add more space, you can add the same code multiple times as per your requirement.

**Input**

```
Line 1
<br>
<br>
Line 2

```

Plain text

Copy

**Outcome**  
Line 1  
  
  
  
  
Line 2

---

#### **2. Adding Non-Breaking Space**

If you want to add extra spaces within a line or between words, you can use the HTML non-breaking space character `&nbsp;`

**Input**

This sentence has extra `&nbsp;` `&nbsp;` `&nbsp;`spaces between some words.

**Outcome**

This sentence has extra         spaces between some words.

A lightweight text-to-HTML conversion tool used to format content such as lists, headers, images, videos, and links. Document360 includes a powerful markdown editor as one of its two basic editors.

<a id="how-to-align-the-image-in-markdown"></a>

## How to align the image in Markdown?

**Plans supporting customizing text in the markdown editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

By default, images are aligned to the left. You would want to change the alignment of certain images in your articles. You can easily perform this action in the WYSIWYG editor with the 'Align' options in the toolbar.  
However, there is no option to align the image in Markdown. However, it is possible using the quick workaround.

Follow the below workaround to keep the image in the desired alignment in Markdown.

## Solution

1. Go to the desired article in the Knowledge base portal.
2. Paste the below code in the desired location in the editor where you want the image to appear.

```
<p style="text-align: center"><img src="https://files.document360.io/filename/folder/subfolder/imagename.png"></p>

```

Plain text

Copy

3. The above code is for center alignment. If you want to keep the alignment as **left** or **right**, replace the term 'center' in the code with 'left' or 'right' as per your requirement.

> * **Right** → `"text-align: right"`
> * **Left** → `"text-align: left"`

4. Replace the URL '`https://files.document360.io/filename/folder/subfolder/imagename.png`' with your desired image URL.

#### Where can I find the URL of an image in Drive?

![1_Screenshot-Updated_align_the_image_in Markdown_drive_screenshot](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Updated_align_the_image_in%20Markdown_drive_screenshot.png)

1. Go to **Drive** and navigate to the folder in which the desired image is available.
2. Click the desired image (or) click ••• (next to the desired image name) > **View details**.
3. **File details** blade appears on the right, and you can find the image URL below the **Size** information.
4. Click the **Copy** icon, and the image URL would be copied.

### Outcome

#### Left alignment

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/doc360.jpg)

#### Center alignment

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/doc360.jpg)

#### Right alignment

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/doc360.jpg)

---

#### Can I add a button, logo, or a clipart and align it in Markdown?

Yes, as long as it is an allowed image file type, you can align it in the Markdown editor.

One of the three editors in Document360, WYSIWYG (What You See Is What You Get) is a content editing tool that shows the final output as writers create and format content.

<a id="how-to-add-a-background-image-for-a-text-content"></a>

## How to add a background image for a text content?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

To add more essence to your text content, you can add a background image. The background image you want to add must be available on the web. If the background image is on your local device, you can upload it to the Drive and utilize the image URL.

### Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. In the Custom CSS tab, paste the below CSS snippet in the window.

```
.bgimg 
{ 
background-image: url("IMAGE_URL"); 
} 
```

CSS

Copy

3. In the above snippet:

   * **Class name** is `.bgimg`. You can replace it as per the requirement.
   * **IMAGE\_URL** - Add your desired background image URL.
4. Click **Save**.
5. Navigate to the desired article and add the following snippet in the editor:

```
<p class="bgimg">Text_content</p> 
```

Markdown

Copy

* **Text\_content** - Add the desired text content.
* **bgimg** - If you change the class name, replicate the same changes in this field.

> NOTE
>
> To add a background image for text in the WYSIWYG or Advanced WYSIWYG editor, simply use the above HTML code in the **Code view ()** of the editor. Replace *Text\_content* with your desired text and click on **Preview** to view the output.

6. The desired background image appears for the text content in your knowledge base.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Add%20background%20image%20to%20text%20GIF.gif)

<a id="how-to-change-the-color-of-the-table-of-contents"></a>

## How to change the color of the table of contents?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You would want to change the color of the table of contents to showcase it better. Follow the below steps to change the color of the table of contents.

### Solution

KB Site 1.0

KB Site 2.0

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. Paste the below code snippet in the **Custom CSS** tab.

```
.content_block .content_container .page-action .article_action_links ul li a
{
color: red !important;
}
```

CSS

Copy

3. In the above snippet, you can replace the color red with any other color of your choice.
4. Click **Save**.

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. Paste the below code snippet in the **Custom CSS** tab to change the color of the table of contents.

```
d360-table-of-content .toc-item .toc-toggle-icon,
d360-table-of-content .toc-item a {
    color: red !important;
}
```

CSS

Copy

3. Paste the below code snippet in the **Custom CSS** tab to change the color of the selected heading in the table of contents.

```
d360-table-of-content .toc-item.selected a {
    color: blue !important;
}
```

CSS

Copy

3. In the above snippets, you can replace the colors with any other color of your choice.
4. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Change color of the ToC GIF.gif)

---

### Outcome

#### Before

The default color of the table of contents is greyand the content actively open will be highlighted in blue color.

![2_Screenshot_Before_color_of_table_of_Content.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot_Before_color_of_table_of_Content.png)

#### After

After updating the code snippet in **Custom CSS**, the color of the table of contents other than the actively open content will be changed to red.

![3_Screenshot_After_color_of_table_of_Content.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot_After_color_of_table_of_Content.png)

<a id="how-to-sort-the-contents-of-a-table"></a>

## How to sort the contents of a table?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Sorting is a great option to have when you provide data artifacts in the table. Follow the below solution to have a sort option for all the tables in your knowledge base.

### Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

```
table th {
    cursor: pointer;
}

table .th-sort-asc::after {
    content: "\25b4";
}

table .th-sort-desc::after {
    content: "\25be";
}

table .th-sort-asc::after,
table .th-sort-desc::after {
    margin-left: 5px;
}

table .th-sort-asc,
table .th-sort-desc {
    background: rgba(0, 0, 0, 0.1);
}
```

CSS

Copy

3. ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGif-Customization.gif)

   Click **Save**.
4. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
5. From the left navigation pane click **JavaScript**.
6. Paste the below code snippet:

```
$( "table" ).addClass("table-sortable");

/**
 * Sorts a HTML table.
 * 
 * @param {HTMLTableElement} table The table to sort
 * @param {number} column The index of the column to sort
 * @param {boolean} asc Determines if the sorting will be in ascending
 */
function sortTableByColumn(table, column, asc = true) {
    const dirModifier = asc ? 1 : -1;
    const tBody = table.tBodies[0];
    const rows = Array.from(tBody.querySelectorAll("tr"));

    // Sort each row
    const sortedRows = rows.sort((a, b) => {
        const aColText = a.querySelector(`td:nth-child(${ column + 1 })`).textContent.trim();
        const bColText = b.querySelector(`td:nth-child(${ column + 1 })`).textContent.trim();

        return aColText > bColText ? (1 * dirModifier) : (-1 * dirModifier);
    });

    // Remove all existing TRs from the table
    while (tBody.firstChild) {
        tBody.removeChild(tBody.firstChild);
    }

    // Re-add the newly sorted rows
    tBody.append(...sortedRows);

    // Remember how the column is currently sorted
    table.querySelectorAll("th").forEach(th => th.classList.remove("th-sort-asc", "th-sort-desc"));
    table.querySelector(`th:nth-child(${ column + 1})`).classList.toggle("th-sort-asc", asc);
    table.querySelector(`th:nth-child(${ column + 1})`).classList.toggle("th-sort-desc", !asc);
}

document.querySelectorAll(".table-sortable th").forEach(headerCell => {
    headerCell.addEventListener("click", () => {
        const tableElement = headerCell.parentElement.parentElement.parentElement;
        const headerIndex = Array.prototype.indexOf.call(headerCell.parentElement.children, headerCell);
        const currentIsAscending = headerCell.classList.contains("th-sort-asc");

        sortTableByColumn(tableElement, headerIndex, !currentIsAscending);
    });
});
```

JavaScript

Copy

6. Click **Save**.

> NOTE
>
> To sort the column of the table, the reader should click the column header, and the sorting is applied. The sort icon in the column header shows the sort type (ascending or descending).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_ScreenGif-Customization.gif)

### Outcome

![1_Screenshot-sort_the_contents_of_a_table.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-sort_the_contents_of_a_table.png)

<a id="how-to-customize-the-hyperlink"></a>

## How to customize the hyperlink size?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You can customize the appearance of some hyperlinks to make them stand out. With the below solution, you can customize the font size of the hyperlink.

---

### Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

   ```
   .CustomLink
   {
   font-size:25px;
   }
   ```

   CSS

   Copy
3. Update the desired font size in the above snippet. The font size is mentioned as `25px` in the above snippet.
4. Click **Save**.
5. ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/14_ScreenShot-Customization.png)Navigate to the desired article and type in the below code in the desired instance.

   ```
   <a class="CustomLink" href="https://www.document360.com/">Document360</a>
   ```

   XML

   Copy

> NOTE
>
> Hyperlink - https://www.document360.com  
> Hyperlink text - Document360

6. Update the hyperlink and hyperlink text in the code.

<a id="how-to-make-all-links-open-in-new-tab"></a>

## How to make all links open in new tab?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

When you insert a hyperlink in the article, an option is available to open the hyperlink in a new tab. There is no option in the Knowledge base portal to open all hyperlinks in knowledge base articles in a new tab. Follow the workaround below to open all the hyperlinks in a new tab.

### Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **JavaScript** tab and paste the following JavaScript snippet:

KB site 1.0

KB site 2.0

```
jQuery(".content_block_text a").attr("target", "_blank");
```

JavaScript

Copy

```
jQuery(".block-article a").attr("target", "_blank");
```

JavaScript

Copy

3. Click **Save**.

> NOTE
>
> All hyperlinks in your article will open in a new tab now.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/New_Screenshot-Make_all_links_open_in_new_tab.png)

<a id="how-to-set-a-default-featured-image-in-knowledge-base"></a>

## How to set a default featured image in knowledge base?

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In Document360, you can add a specific [featured image](/docs/article-seo#how-to-add-a-featured-image) for each article. Sometimes you could have missed adding a featured image. However, if you share the article on social media (such as Facebook, Twitter, LinkedIn, etc.,) without a featured image, then it may pick a random image available in the article. These random images do not make a good thumbnail for your articles often.

If you set a default featured image, it will be shared as the thumbnail for any articles that do not have a featured image. The featured image you want to add must be available on the web. If it is available on your local device, you can upload it to the Drive and utilize the image URL. Follow the below steps to set a default featured image for the articles in your knowledge base project.

---

## Solution

1. Navigate to the Settings () > **Knowledge base site** > **Integrations** in the Knowledge base portal.
2. Go to **Custom HTML** and click **Add**.

   The **Add new integration** panel will appear.
3. Type in a description for the integration and ensure that **In the Header (above</head>)** is selected.
4. Paste the below snippet in the code editor:

```
<meta property="og:image" content="Image_URL" /> 
<meta property="og:image:secure_url" content="Image_URL" /> 
```

XML

Copy

5. In the above snippet, replace the text "Image\_URL" with the URL of your default featured image.

> Sample URL from the Document360 drive: https://cdn.document360.io/8\*\*\*\*\*dd1/Images/Documentation/default\_fi.png

6. Click **Add**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/New_Screenshot-Updated_How_to_det_a_default_feature_image_in_knowledge_base.png)

A centralized, cloud-based storage repository in Document360 for storing and managing all files.

<a id="how-to-add-shadows-to-an-image-in-markdown"></a>

## How to add shadows to an image in Markdown?

**Plans supporting customizing images in the markdown editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Markdown doesn't have a built-in way to add shadows to images, but you can use HTML tags within Markdown to achieve this effect.

### Workaround

#### Sample code

```
<img src="image.jpg" alt="Alt text" style="box-shadow: 3px 3px 3px gray;">

```

HTML

Copy

> Replace the `image.jpg` with your image URL and add the alt text for your image in place of "your-image-description".

In this sample, we're using the `box-shadow` CSS property to add a shadow effect to the image. The `box-shadow` property takes three values: the horizontal offset, vertical offset, and blur radius of the shadow.

In the above sample code, we use a

* Horizontal and vertical offset of **3 pixels**
* Blur radius of **3 pixels**
* Color of the shadow set to **grey**

NOTE

You can also change the shadow color. Just replace "**grey**" with your desired color name.

> Grey has been used in the example because it is the most commonly used shadow color.

### Outcome

#### Without shadow

![1_Screenshot-without_shadow_Featured_image-Health_check_metrics.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-without_shadow_Featured_image-Health_check_metrics.png)

#### With shadow

![Alt text](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-with_shadow_Featured_image-Health_check_metrics.png)

<a id="how-to-add-borders-to-an-image-in-markdown"></a>

## How to add borders to an image in Markdown?

**Plans supporting customizing images in the markdown editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Markdown doesn't have a built-in way to add borders to images, but you can use HTML tags within Markdown to achieve this effect.

### Workaround

#### Sample code

```
<img src= "image.jpg" alt="your-image-description" style="border: 2px solid grey;">

```

HTML

Copy

> Replace the `image.jpg` with your image URL and add the alt text for your image in place of "your-image-description".

You can adjust the border width, style, and color by modifying the style attribute as desired.

In the above sample code, we use the `style` attribute to add the following:

* Border width is **2-pixel**.
* Border style is **solid**.
* Color of the border is set to **grey**.

NOTE

You can change the shadow color of images. Just replace **grey** with your desired color name. For example, blue, green, yellow, and more.  
Grey has been used in the example because it is the most commonly used border color next to **black**.

### Outcome

#### Without border

![1_Screenshot-without_shadow_Featured_image-Health_check_metrics.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-without_shadow_Featured_image-Health_check_metrics%281%29.png)

#### With border

![your-image-description](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-with_shadow_Featured_image-Health_check_metrics%281%29.png)

NOTE

You can also add a shadow to the image using HTML code snippets. Check this article for more information: [How to add shadows to an image in Markdown?](/help/docs/how-to-add-shadows-to-an-image-in-markdown)

<a id="embed-youtube-shorts"></a>

## How to embed YouTube Shorts?

**Plans supporting customizing videos in the markdown editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Using the quick workaround using the iframe (Inline frame) HTML tag, you can embed any YouTube Shorts in your page or article.

NOTE

Paste the following code in your editor and replace the field mentioned below.

* **Video URL**
* **Optimal size** for a Shorts video is **315px x 560px**, but you can change the frame size based on your need. Ensure the aspect ratio is maintained.
* **Frame border** in pixels (px)

### iFrame code

```
<iframe width="315" height="560"
src="https://www.youtube.com/embed/<Shorts_video_code>"
title="YouTube video player"
frameborder="0"
allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share"
allowfullscreen></iframe>


```

HTML

Copy

### Steps to follow

1. Go to [YouTube](https://www.youtube.com/) and click on the desired Shorts video.
2. Copy the video link found in the address bar of your web browser.  
   (or)  
   Click **Share** > **Copy**.
3. Paste the copied video link in the iFrame code mentioned above.
4. Replace the `/shorts/` with `/embed/` in the video URL.

NOTE

At present, YouTube doesn't offer a direct embedding option for Shorts. To embed a Short, simply **replace "shorts" with "embed" in the video URL** after pasting it.  
![ScreenGIF-Replacing_shorts_with_embed](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/ScreenGIF-Replacing_shorts_with_embed.gif)

5. The Shorts video is now embedded in your page or article.

### Code view

```
<iframe width="315" height="560" 
src="https://www.youtube.com/embed/QPOLrbKI5oQ" 
title="YouTube video player" frameborder="0" 
allow="accelerometer; autoplay; clipboard-write; encrypted-media;
gyroscope; picture-in-picture;
web-share"
allowfullscreen></iframe>

```

Plain text

Copy

### Output

<a id="how-to-embed-loom-video"></a>

## How to embed a Loom video?

**Plans supporting customizing videos in the markdown editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You can embed any Loom video in your page or article using the following quick workaround.

### Loom video embedding

1. Go to **Loom** and access your desired video.
2. Click **Share** > **Embed**.
3. Select the **Fixed size** checkbox and choose the desired video size.
4. Click **Copy** embed code, and the video's embed code is copied.
5. Navigate to the Document360 editor.
6. **Paste** the copied embed code.

NOTE

This step can vary with the editors.

* **Markdown editor**: Paste the code in the editor.
* **WYSIWYG editor**: Click **Insert video** > **Embedded code**. Paste the code and click Insert.
* **Advanced WYSIWYG editor**: Click **Insert** > **Video** > **Embed code**. Paste the code and click **Add embed**.

7. The Loom video is now embedded in your article.

### Sample video embed code

```
<iframe width="640" height="339" src="https://www.loom.com/embed/518d972833434cd5af03c13623338fd3" frameborder="0" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe>

```

HTML

Copy

<a id="how-to-embed-an-excel-file"></a>

## How to embed an Excel file?

**Plans supporting embedding Excel file in the editor**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In today’s digital age, visual aids like charts and tables are crucial for conveying complex data effectively. Document360 helps you to embedding Excel files directly into your articles which can enhance clarity and provide readers with interactive data.

Through the process of embedding Excel spreadsheets into your Document360 articles, your documentation becomes more engaging and informative.

---

## Embedding an Excel file

In **Excel,**

1. Open the desired Excel file.
2. Navigate to **File** > **Share** > **Embed**.

   The Embed page appears.
3. Scroll down to **Embed code** and copy the generated HTML code.

![1_ScreenGIF_Copying_the_embed_code](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF_Copying_the_embed_code.gif)

In the **Document360 Knowledge base portal**,

1. Go to the desired article.

   a. If using Markdown: You can paste the copied embed code directly into the editor.

   b. If using Advanced WYSIWYG editor: Switch to **Code view** and paste the copied embed code in the desired editor.
2. The Excel file is now embedded in your article.

---

### Sample code

```
 <iframe width="402" height="346" frameborder="0" scrolling="no" src="https://kovailtd-my.sharepoint.com/personal/manoharan_soundarraj_kovai_co/_layouts/15/Doc.aspx?sourcedoc={39f3b8e9-01f6-4c7c-a3d0-f257a8d43dd7}&action=embedview&wdAllowInteractivity=False&wdHideGridlines=True&wdHideHeaders=True&wdDownloadButton=True&wdInConfigurator=True&wdInConfigurator=True"></iframe>
```

Embedcode

Copy

### Outcome

**Markdown**

![embedding the excel file](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Embedding_coed_in_markdown.png)

**Advanced WYSIWYG editor**

![embedding the excel file](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGID-Embedding_code_in_Advanced_WYSIWYG.gif)

A lightweight text-to-HTML conversion tool used to format content such as lists, headers, images, videos, and links. Document360 includes a powerful markdown editor as one of its two basic editors.

A powerful Document360 editor with rich text editing and Markdown support, offering a visual, flexible experience compared to the Markdown and basic WYSIWYG editors.

<a id="how-to-change-the-color-of-feedback-buttons"></a>

## How to change the color of Feedback buttons?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

The color of the feedback buttons at the article bottom remains grey when you do not hover them. You wish to change and customize the feedback buttons' default color. Perform the following steps to configure the default color of the feedback buttons.

---

## Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

KB site 1.0

KB site 2.0

```
.article-vote-container .actions .btn.yes i {
    background-color: #5ebf83;
    color: white;
}
.article-vote-container .actions .btn.no i {
    background-color: #e67367;
    color: white;
}
.article-vote-container .actions .btn.yes {
    color: #5ebf83;
}
.article-vote-container .actions .btn.no {
    color: #e67367;
}
```

CSS

Copy

> NOTE
>
> * **.btn.yes i** - Background color of the "Yes" (Thumbs up) button.
> * **.btn.yes i** - Color for the word "Yes".
> * **.btn.no i** background color - Background color of the "No" (Thumbs down) button.
> * **.btn.no** - Color for the word "No".
> * **color** - Border color of the button.

```
.article-feedback-action{
  button[aria-label="Yes"]{
    background-color: #5ebf83;
    color: white;
  }
  button[aria-label="No"]{
    background-color: #e67367;
    color: white;
  }
}
```

CSS

Copy

3. Update the color codes as per your requirements.

4. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-CHanging_the_color_of_feedback_buttons.png)

---

### Outcome

#### Before

The color of the feedback buttons appears grey when you aren't hovering over them.

![Overview of Document360 with applied CSS code for the like and dislike buttons in the knowledge base site.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Color_of_feedback_button_before_applying_CSS.png)

---

#### After

After applying the provided CSS code, the feedback buttons will display in the specified color.

![Overview of Document360 with related articles and helpful resources displayed on the page.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Color_of_feedback_button_after_applying_CSS.png)

<a id="how-to-hide-footer-in-mobile-view"></a>

## How to hide footer in mobile view?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

When you have a detailed footer, it appears better only on large screens. In this case, the footer would not feel appealing on smaller screens. So, you would want to remove the knowledge base footer in the mobile view for a better reader experience.

> NOTE
>
> This is applicable only for **custom footer**. For more information, read the article on [Custom footer](/help/docs/custom-footer).

---

## Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click the **CSS** tab and paste the following CSS snippet:

KB site 1.0

KB site 2.0

```
@media screen and (max-width: 469px) {.custom-footer {display: none;}}
```

CSS

Copy

```
@media only screen and (max-width: 767px) {
    site-footer-section {
        display: none;
    }
}
```

CSS

Copy

3. Click **Save** on the top right.

   ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1727778020937.png)

### Outcome

![Image showing before and after images of knowledge base site of hiding footer.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenShot-Customization_hidden_footer.png)

<a id="how-to-change-the-hover-color-of-the-header-options"></a>

## How to change the hover color of the header options?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You may want to customize the hover color for the header options at the top of the article to suit your preferences. Follow the below steps to customize your header options while hovering them.

## Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

KB site 1.0

KB site 2.0

```
header .header_top .header_top_nav ul li a:hover {
color: red !important;
text-decoration: none;
}
```

CSS

Copy

```
a[role="menuitem"]:hover {
    color: red !important;
    text-decoration: none;
}
```

CSS

Copy

3. Update the hover color as per your requirement.
4. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/new_screenshot-Changing_the_hover_color_of_the_article_header_options.png)

### Outcome

#### Before

When you hover over the header menu options, there is no color change.

![Overview of Document360 Knowledge base site's header menu.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Header_Color_before_hovering.png)

---

#### After

When you hover over the header menu options, the color changes to red. This will enhance the user experience.

![Overview of Document360 Knowledge base site's header menu.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Header_Color_while_hovering.png)

<a id="how-to-move-the-related-articles-above-the-feedback-section"></a>

## How to move the related articles above the feedback section?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

When you configured the related articles section to appear at the article bottom, it appears below the feedback section by default. You would want to move the related articles above the feedback section to enhance the user experience. Follow the below steps to move the related articles above the feedback section.

## Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **JavaScript** tab and paste the following JavaScript snippet:

```
window.onload = function () {
$(".content_block_text" ).append("<div class=\"sperator\"><hr></div>");
$('.related-articles-container').appendTo('.content_block_text') ;
}
```

JavaScript

Copy

3. Click **Save**.

> NOTE
>
> The above JavaScript code is only applicable for KB site 1.0.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-moving_related_articles_above_feedback_section_.png)

### Outcome

![1_Screenshot-Related_articles_location_change](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Related_articles_location_change.png)

<a id="how-to-hide-the-change-password-option-for-readers"></a>

## How to hide the change password option for readers?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

In some cases, you would want to restrict the readers from changing the password. Utilize the below workaround in such scenarios.

---

## Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. Paste the below code snippet in the **CSS** tab.

KB Site 1.0

KB Site 2.0

```
header .header_top .user-dropdown-content .user-detail .portal-link a, header .header_top .user-dropdown-content .user-detail .portal-link .changePassword{ 
   display:none; 
 } 
```

CSS

Copy

```
.nav-bar-profile button.dropdown-item:nth-of-type(2) {
    display: none !important;
}
```

CSS

Copy

3. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Change password option for readers GIF.gif)

NOTE

This change applies to all the readers.

---

### Outcome

#### Before

The change password option was available for the readers.  
![13_Screenshot-Before_change_password](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/13_Screenshot-Before_change_password.png)

#### After

The change password option has been removed for the readers.  
![12_Screenshot-After_change_password](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/12_Screenshot-After_change_password.png)

<a id="how-to-hide-the-category-manager"></a>

## How to hide the category manager?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You would want your readers to access only specific articles in some projects. By implementing the below solution, the readers can access the article only when they have the exact URL. The category manager will be hidden.

NOTE

This is a project-specific implementation. All the workspaces will be impacted.

## Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. In the CSS tab, paste the below code snippet:

**For KB Site 1.0,**

```
.left_sidebar{
  display:none !important;
}
.left-sidebar-toggle{
   display:none !important;
}
```

CSS

Copy

**For KB Site 2.0,**

```
site-docs-left-panel-container{
  display:none !important;
}
```

CSS

Copy

3. Click **Save**.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Hide%20category%20manager%20-%20Custom%20CSS%20GIF.gif)

---

### Outcome

#### Before

The category manager was available to the readers.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Hide%20category%20manager%20-%20Before.png)

#### After

The category manager is hidden with the help of the above snippet.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Hide%20category%20manager%20-%20After.png)

<a id="how-to-configure-a-custom-font-in-the-knowledge-base"></a>

## How to configure a custom font in the knowledge base?

**Plans supporting the integration of third party tools in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Document360 provides a list of standard fonts used in documentation. However, you can configure your desired font in the knowledge base. Get the font details and add the font link to the header section in Custom HTML. Then, add the font family details in the Custom CSS.

As a use case, check out the below solution to configure a Google font in Document360.

---

## Solution

The below three steps are involved in configuring the desired Google font in Document360:  
 Step 1: [Get the Google font code details](/help/docs/how-to-configure-a-custom-font-in-the-knowledge-base#get-the-google-font-code-details)  
 Step 2: [Append the code in custom HTML](/help/docs/how-to-configure-a-custom-font-in-the-knowledge-base#append-the-code-in-custom-html)  
 Step 3: [Append the code in custom CSS](/help/docs/how-to-configure-a-custom-font-in-the-knowledge-base#append-the-code-in-custom-css)

> NOTE
>
> You can also configure custom fonts other than the Google Fonts by utilizing the appropriate HTML and CSS code.

### Get the Google font code details

1. Go to [Google fonts](https://fonts.google.com/) webpage.

![3_ScreenGIF-Google_font_custom_header_font](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_ScreenGIF-Google_font_custom_header_font.gif)

2. Select the desired font, and the font page appears with the available styles.
3. At the top right corner, click **Get font** and select **Get embed code**.
4. In the **Web** section, you'll find the embed code specific to your chosen font.
5. **Copy** the code and head back to Document360.

### Append the code in custom HTML

![2_Screenshot-Append_the_code_in_custom_HTML](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Append_the_code_in_custom_HTML.png)

6. In the Document360 portal, go to **Settings** > **Knowledge base site** > **Integrations**.
7. Navigate to **Custom HTML** and click **Add**.
8. Select the `Header (above </head>)` option which will be the default selection.
9. Paste the link in the **Header** section copied in step 5.
10. Once done, click **Add**.

### Append the code in custom CSS

![4_Screenshot-Body_Append_the_code_in_custom_CSSUpdated](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Body_Append_the_code_in_custom_CSS%28Updated%29.gif)

11. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
12. From the left navigation pane, click on the **CSS** tab.
13. Click **Add code snippets** on the top right of the code space.
14. Select the **Change body text font** option, and the below code appears.

```
body, article {
  font-family: "Source Sans Pro", sans-serif;    /*Replace your body font family*/ 
  color: #222222;    /*Font color*/ 
}
```

CSS

Copy

14. In addition to the **body** selector, include the **article** selector in the provided code snippet.
15. Replace the `font-family: "Source Sans Pro", sans-serif;` with the font details copied in step 5. *(CSS rules to specify families)*.
16. Add the desired font color.
17. Click **Save** on the top right.

    ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/15_ScreenShot-Customization.png)

---

### Outcome

![7_Screenshot-Custom_font_outcome](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Custom_font_outcome.png)

<a id="how-to-hide-the-left-navigation-bar-in-knowledge-base-site"></a>

## How to hide the left navigation bar in the knowledge base site?

**Plans supporting the use of custom CSS and JS in knowledge base site**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

You wish to hide the left navigation bar or category manager by default in the Knowledge base site. You can hide this to enhance the readers' experience.  However, readers can enable it by clicking the **Show category** icon adjacent to the article title.

---

## Solution

1. Navigate to **Settings** () > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript** in the Knowledge base portal.
2. From the left navigation pane, click on the **CSS** tab and paste the following CSS snippet:

KB site 1.0

KB site 2.0

```
.left_sidebar {
 display : none;
} 
```

CSS

Copy

```
site-docs-left-panel-container{
display: none !important;
}
```

CSS

Copy

3. Click **Save** on the top right.

1. ![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/11_ScreenShot-Customization.png)

---

### Outcome

#### Before

The left navigation bar or category manager is shown by default.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/12_ScreenShot-Customization.png)

#### After

The left navigation bar or category manager is hidden by default.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/13_ScreenShot-Customization.png)

The public-facing website where end-users can access articles and find answers to their questions.

<a id="plans-and-pricing"></a>

## Plans and pricing

## Plans available in Document360

Document360 offers five unique subscription plans for you to choose from.

* **Professional**
* **Business**
* **Enterprise**
* **Enterprise +**
* **Startup program**

Expand each section to view the features supported by the **Professional**, **Business** and **Enterprise** plans.

#### Knowledge base management

| Features | **Professional** | **Business** | **Enterprise** |
| --- | --- | --- | --- |
| **Editors (Markdown, Advanced WYSIWYG)** | ✔️ | ✔️ | ✔️ |
| **Articles revision history** | ✔️ | ✔️ | ✔️ |
| **Category management** | ✔️ | ✔️ | ✔️ |
| **Workspace** | 1 | 1 | 2 |
| **Sandbox** | ❌ | ❌ | ✔️ |
| **Languages** | 2 | 3 | 5 |
| **Translation credits** | 1 million characters | 2 million characters | 5 million characters |
| **Reusable content snippet** | ✔️ | ✔️ | ✔️ |
| **Glossary management** | ✔️ | ✔️ | ✔️ |
| **Global find and replace** | ✔️ | ✔️ | ✔️ |
| **Tag management** | ✔️ | ✔️ | ✔️ |
| **Public API access** | ❌ | ✔️ | ✔️ |
| **Team accounts** | 5 | 10 | 20 |
| **Reader accounts** | 1000 | 10000 | 10000 |

#### Article management tools

| Features | **Professional** | **Business** | **Enterprise** |
| --- | --- | --- | --- |
| **Article template** | ✔️ | ✔️ | ✔️ |
| **Article bulk actions** | ✔️ | ✔️ | ✔️ |
| **Media dependency viewer** | ✔️ | ✔️ | ✔️ |
| **Review reminders** | ✔️ | ✔️ | ✔️ |
| **Export to PDF** | ✔️ | ✔️ | ✔️ |
| **Import articles** | ✔️ | ✔️ | ✔️ |
| **Feedback manager** | ✔️ | ✔️ | ✔️ |
| **Approval and publishing workflow** | ❌ | ✔️ | ✔️ |

#### AI suite

| Features | **Professional** | **Business** | **Enterprise** |
| --- | --- | --- | --- |
| **AI writer suite** | ✔️ | ✔️ | ✔️ |
| **AI search suite** | ❌ | ✔️ | ✔️ |
| **AI premium suite** | ❌ | ❌ | ✔️ |

#### Infrastructure and compliance

| Features | **Professional** | **Business** | **Enterprise** |
| --- | --- | --- | --- |
| **SSL** | ✔️ | ✔️ | ✔️ |
| **SOC 2 compliance** | ✔️ | ✔️ | ✔️ |
| **Alter notifications** | ✔️ | ✔️ | ✔️ |
| **Datacenter location** | ✔️ | ✔️ | ✔️ |
| **Backup & Restore** | ❌ | ✔️ | ✔️ |
| **Custom email domain** | ❌ | ❌ | ✔️ |
| **Audit logging** | ❌ | ❌ | ✔️ |

#### Self-service knowledge center

| Features | **Professional** | **Business** | **Enterprise** |
| --- | --- | --- | --- |
| **Customize site** | ✔️ | ✔️ | ✔️ |
| **Related articles** | ✔️ | ✔️ | ✔️ |
| **Error pages & Login page** | ✔️ | ✔️ | ✔️ |
| **Article status indicator** | ✔️ | ✔️ | ✔️ |
| **Custom domain** | ✔️ | ✔️ | ✔️ |
| **Custom CSS & JavaScript** | ✔️ | ✔️ | ✔️ |
| **Smart bars** | ✔️ | ✔️ | ✔️ |

#### Reduce customer support

| Features | **Professional** | **Business** | **Enterprise** |
| --- | --- | --- | --- |
| **Knowledge base widget** | ❌ | ✔️ | ✔️ |
| **URL mapping** | ❌ | ✔️ | ✔️ |
| **Ticket deflector** | ❌ | ✔️ | ✔️ |

#### Search

| Features | **Professional** | **Business** | **Enterprise** |
| --- | --- | --- | --- |
| **Advanced search** | ✔️ | ✔️ | ✔️ |
| **Search within attachments** | ❌ | ❌ | ✔️ |

#### Analytics

| Features | **Professional** | **Business** | **Enterprise** |
| --- | --- | --- | --- |
| **Articles & Categories performance metrics** | ✔️ | ✔️ | ✔️ |
| **Country specific visibility** | ✔️ | ✔️ | ✔️ |
| **Search analytics** | ✔️ | ✔️ | ✔️ |
| **User analytics** | ✔️ | ✔️ | ✔️ |
| **Reader analytics** | ✔️ | ✔️ | ✔️ |
| **Feedback analytics** | ✔️ | ✔️ | ✔️ |
| **Eddy analytics** | ❌ | ✔️ | ✔️ |
| **Page not found analytics** | ❌ | ✔️ | ✔️ |
| **Hyperlinks health analytics** | ❌ | ✔️ | ✔️ |

#### Security

| Features | **Professional** | **Business** | **Enterprise** |
| --- | --- | --- | --- |
| **Security groups and roles** | ✔️ | ✔️ | ✔️ |
| **IP restriction** | ❌ | ❌ | ✔️ |
| **Single sign-on (SAML, JWT, OpenID)** | ❌ | ❌ | ✔️ |

#### SEO

| Features | **Professional** | **Business** | **Enterprise** |
| --- | --- | --- | --- |
| **Meta title and description** | ✔️ | ✔️ | ✔️ |
| **Article redirect rules** | ✔️ | ✔️ | ✔️ |
| **Robots.txt** | ✔️ | ✔️ | ✔️ |
| **Automatic sitemap generation** | ✔️ | ✔️ | ✔️ |

#### Storage

| Feature | **Professional** | **Business** | **Enterprise** |
| --- | --- | --- | --- |
| **Drive Storage** | 50GB | 100GB | 500GB |

#### Onboarding and Support

| Feature | **Professional** | **Business** | **Enterprise** |
| --- | --- | --- | --- |
| **Onboarding** | ✔️ | ✔️ | ✔️ |
| **Dedicated CSM** | ❌ | ✔️ | ✔️ |
| **Training & Best Practices** | **add-on** | **add-on** | ✔️ |
| **Support** | 24/5 Support | 24/5 Support | 24/5 Priority support |

#### Extensions

| Feature | **Professional** | **Business** | **Enterprise** |
| --- | --- | --- | --- |
| **Zendesk** | ❌ | ✔️ | ✔️ |
| **Freshdesk** | ❌ | ✔️ | ✔️ |
| **Freshservice** | ❌ | ✔️ | ✔️ |
| **Intercom** | ❌ | ✔️ | ✔️ |
| **Slack** | ❌ | ✔️ | ✔️ |
| **Microsoft teams** | ❌ | ✔️ | ✔️ |
| **Drift** | ❌ | ✔️ | ✔️ |
| **Zapier** | ❌ | ✔️ | ✔️ |
| **Make** | ❌ | ✔️ | ✔️ |
| **GitHub** | ❌ | ✔️ | ✔️ |
| **Crowdin** | ❌ | **add-on** | ✔️ |
| **Phrase** | ❌ | **add-on** | ✔️ |
| **Salesforce** | ❌ | ❌ | **add-on** |

> NOTE
>
> You can purchase additional projects, workspaces, languages, translation credits (1 million characters), storage, team accounts, and readers in any Document360 plan.

### Enterprise+

The **Enterprise +** plan offers dedicated servers for improved performance, enhanced security, and faster load times. It is designed to support scalable operations with high reliability and provides customization options to meet the requirements of larger teams and organizations.

### Startup program

As part of the **Startup program**, you will receive six months of free access to Document360's Business or Enterprise plan. This includes a personalized public site, mentorship, and access to essential resources. After the six-month period, you will be charged 50% of the original plan price for the next six months, based on your selected plan.

---

## Accessing Billing overview page

From the Knowledge base portal, navigate to **Settings** ()> **Knowledge base portal** > **Billing**.

In the Billing section, you can access the following tabs,

* **My plan**: View details of your current plan. You can change your plan by clicking **Change plan** or purchase add-ons by selecting **Purchase add-on**. Use the context menu () to cancel your subscription if needed.
* **Payment information**: Update your credit card and billing address details.
* **Invoice history**: Access your previous invoices, add or remove invoice recipients, and download invoices.

![Billing page - My plan tab](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Billing_page_overview.png)

### How do I change my plan?

> NOTE
>
> Only users with the **Owner** portal role or team accounts assigned **View and Update** permissions for **Billing & invoice** can access and make changes to the plan.

1. From the Knowledge base portal, navigate to **Settings** ()> **Knowledge base portal** > **Billing**, where the **My plan** tab is selected by default.
2. Click **Change plan** to upgrade or downgrade your subscription.

   The available plans in Document360 are:

   * **Professional**
   * **Business**
   * **Enterprise**
3. Select a subscription plan that suits your company's needs and click the **Let’s talk** button. The Document360 support team will contact you to assist with updating your plan.

To read more about changing plans, see [Upgrading your subscription plan](/v3/docs/changing-plans) (or) [Downgrading your subscription plan](/v3/docs/downgrade-your-subscription-plan).

> NOTE
>
> * As of **September 2024**, we have revised our pricing structure. If you are on a legacy pricing plan—meaning you subscribed before this date—you will not be able to change your plan directly through the portal. Upgrading requires assistance from our support team. Please contact the [Document360 support](https://document360.com/support/) to switch to the new pricing plan.
> * As of **November 2024**, support for the Free plan has been discontinued. Existing users on the Free plan will retain access; however, new users can only sign up for the **Professional**, **Business**, or **Enterprise** plans.

---

### FAQs

#### **What happens after my Document360 trial expires?**

Once your Document360 trial expires, you can upgrade to a desired plan. If you do not upgrade your plan, your Document360 project will be put on hold and marked for deletion.

#### **What are the pricing details for each plan in different currencies?**

Depending on where you're located, your subscription pricing may vary. Below is a simple breakdown of how the pricing works in different currencies for each plan. For more information, see <https://document360.com/pricing/>.

---

IMPORTANT

The screenshots used in this article are for illustration purposes, and the pricing figures are recorded as of September 2024. Please check the Document360 [**Pricing page**](https://document360.com/pricing/) for the latest information.

<a id="upgrading-your-plan"></a>

## Upgrading your subscription plan

As your documentation needs grow, upgrading your Document360 plan can provide you with more tools and capabilities to enhance your knowledge base. This article will help you understand the benefits of each upgrade path, allowing you to choose the best plan for your needs.

> NOTE
>
> Only users with the **Owner** portal role or team accounts assigned **View and Update** permissions for **Billing & invoice** can access and make changes to the plan.

You can upgrade your plan from

* [Professional to Business](/help/docs/upgrading-your-plan#professional-to-business)
* [Business to Enterprise](/help/docs/upgrading-your-plan#business-to-enterprise)
* [Professional to Enterprise](/help/docs/upgrading-your-plan#professional-to-enterprise)
* [Legacy plan](/help/docs/upgrading-your-plan#upgrading-for-users-on-legacy-pricing-plans)
* [Legacy free plan](/help/docs/upgrading-your-plan#upgrading-for-users-on-legacy-free-plan)

> NOTE
>
> When you upgrade your subscription, a prorated cost for the remainder of your current billing cycle will be charged. For legacy plans, any applicable prorated cost of the current plan will be added as credits. Upon renewal, your invoice will reflect the new subscription price.

---

## Pricing page

To upgrade your subscription plan,

1. From the Knowledge base portal, navigate to **Settings () > Knowledge base portal > Billing**, where the **My plan** tab is selected by default.
2. Click **Change plan** to view the various plans available in Document360.

   The available plans in Document360 are:

   * **Professional**
   * **Business**
   * **Enterprise**

> NOTE
>
> When you upgrade from the trial version, you will be taken to Pricing page after clicking on Billing. To upgrade from trial version, see [upgrading from trial version](/help/docs/upgrading-from-trial-version).

3. Scroll down to the **Compare plans and features** section to view a detailed comparison of all plans and features.
4. Once you’ve selected your preferred plan, click the **Let’s talk** button.

![Upgrade-downgrade-Pricing](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Change_plan_screen.png)

The Document360 sales team will contact you to assist with upgrading your plan.

---

## Plan comparison

The comparison of features and extra benefits you receive while upgrading your plan are detailed in this section.

### Professional to Business

The Business plan offers more advanced features to improve your workflow, get deeper insights, and enhance the user experience.

#### Enhanced storage and team collaboration

| **Feature** | **Professional** | **Business** | **Benefits of Business Plan** |
| --- | --- | --- | --- |
| **Storage** | 50 GB | 100 GB | Double your storage capacity, allowing for more extensive documentation. |
| **Team Access** | 5 team accounts, 1,000 readers, 5 reviewers | 10 team accounts, 10,000 readers, 10 reviewers | Gain expanded team access, supporting larger collaboration efforts. |

#### Advanced workflow and content management

| **Feature** | **Professional** | **Business** | **Benefits of Business Plan** |
| --- | --- | --- | --- |
| **Workflow Designer** |  |  | Use custom workflows to manage documentation from creation to publishing. |
| **Ticket Deflector** |  |  | Improve customer support by directing users to relevant documentation. |
| **Backup & Restore** |  |  | Gain easy data backup and recovery options to keep your content safe. |

#### Deeper insights and integration

| **Feature** | **Professional** | **Business** | **Benefits of Business Plan** |
| --- | --- | --- | --- |
| **Advanced Analytics** | Basic analytics | Advanced analytics | Unlock deeper insights into content usage and performance with advanced analytics. |
| **Public API** |  |  | Leverage easier integration of Document360 with other tools via public API. |

#### Enhanced AI and search capabilities

| **Feature** | **Professional** | **Business** | **Benefits of Business Plan** |
| --- | --- | --- | --- |
| **AI Credits** |  | 2000 Eddy AI Search credits | Enhanced content discovery with more AI search credits for better accuracy. |

#### Premium features

| **Feature** | **Professional** | **Business** | **Benefits of Business Plan** |
| --- | --- | --- | --- |
| **Custom Branding** |  |  | Personalize your knowledge base to align with your brand's guidelines and identity. |
| **Premium Support** |  |  | Receive faster and more dedicated support from the Document360 team when needed. |
| **Security & Audit logs** |  |  | Ensure the safety of your data with regular security checks and audits. |
| **Custom Email Domain** |  |  | Use your own email domain for all communications, enhancing professionalism and trust. |

### Business to Enterprise

The Enterprise plan is for large organizations with complex documentation needs. It offers the most comprehensive tools and support.

#### Maximum storage and team access

| **Feature** | **Business** | **Enterprise** | **Benefits of Enterprise Plan** |
| --- | --- | --- | --- |
| **Maximum Storage** | 100 GB | 500 GB | Increased storage for extensive documentation and media. |
| **Team Collaboration** | 10 team accounts, 10,000 readers, 10 reviewers | 20 team accounts, 10,000 readers, 20 reviewers | Enhanced collaboration capabilities for larger teams. |

#### Exclusive advanced features

| **Feature** | **Business** | **Enterprise** | **Benefits of Enterprise Plan** |
| --- | --- | --- | --- |
| **Sandbox Environment** |  |  | Test new ideas in a secure environment without impacting your live knowledge base. |
| **IP Restrictions** |  |  | Control access to your knowledge base based on user location for enhanced security. |
| **Regular Health Checks** |  |  | Routine performance checks to ensure your system operates smoothly. |

#### Comprehensive AI tools

| **Feature** | **Business** | **Enterprise** | **Benefits of Enterprise Plan** |
| --- | --- | --- | --- |
| **AI Capabilities** | Limited | Full suite | Access all Eddy AI features, including premium support for AI Writer and Search. |
| **AI Credits** | 2000 Eddy AI Search credits per month | 5000 Eddy AI Search credits credits per month | Enhanced content discovery with more AI search credits for better accuracy. |

Each upgrade gives you more tools to manage your documentation as your needs grow. For a comprehensive list of features available, check out the [Document360 pricing page](https://document360.com/pricing/). If you're not sure which plan is right for you, our support team is always here to help. You can contact us via email, live chat, or phone for prompt assistance.

### Professional to Enterprise

You will receive all the features available in the [Business](/help/docs/upgrading-your-plan#professional-to-business) as well as the [Enterprise](/help/docs/upgrading-your-plan#business-to-enterprise) plans when you upgrade from Professional to Enterprise plan.

---

## Upgrading for users on legacy pricing plans

As of 31st August 2024, we have revised our pricing structure. If you are on a legacy pricing plan—meaning you subscribed before this date—you will not be able to change your plan directly through the portal. Upgrading requires assistance from our support team.

Here’s how you can proceed:

1. Navigate to the **Billing** page.
2. Select **Change plan**.
3. On the **Change plan** page, click the **Let’s talk** button next to the required plan.
4. Click **Raise Request** on the confirmatory pop-up.

   This will trigger an email request to our support team. They will review your request and guide you through the upgrade process within two working days. They will also handle the transition to the new plan, ensuring a smooth experience.

> NOTE
>
> If you need further assistance or have specific questions about your legacy plan, you can always reach out to our support team via email, live chat, or phone.

## Upgrading for users on legacy free plan

As of November 2024, the Free plan for Document360 has been discontinued. If you were on the Free plan prior to November 2024, you will continue to have access to the Free plan. If you wish to upgrade to one of Document360’s higher tier plans, follow the below steps:

1. From the Knowledge base portal, navigate to **Settings () > Knowledge base portal > Billing**, where the **My plan** tab is selected by default.
2. Click **Change plan** to view the various plans available in Document360.
3. Scroll down to the **Compare plans and features** section to view a detailed comparison of all plans and features.
4. Once you’ve selected your preferred plan, click the **Let’s talk** button.

The Document360 sales team will contact you to assist with upgrading your plan.

---

## FAQs

**What benefits do I get when upgrading to a higher plan?**

Upgrading to a higher plan provides access to additional features, increased storage, enhanced support, and other premium benefits. You can view the full list of features available in each plan on our [pricing page](https://document360.com/pricing/).

**How will my billing change if I upgrade my plan?**

When you upgrade, your billing will adjust to reflect the new plan’s pricing. You’ll be charged either immediately or at the end of your current billing cycle, depending on your billing preferences and company policy.

**Can I try out the higher plan before committing to an upgrade?**

Yes, we offer a trial period for all plans. This allows you to experience the features of the new plan before making a long-term commitment. Check our website or contact support for more details on trial availability.

**What happens to my current data and settings when I upgrade?**

Your current data and settings will be preserved during the upgrade. You will retain access to all existing projects and configurations, and any new features of the upgraded plan will be seamlessly integrated.

**Are there any setup steps required after upgrading?**

Generally, no additional setup is required after upgrading. However, some advanced features may need configuration. We provide guidance and support to help you set up and utilize the new features effectively.

**Will I receive a prorated credit for my current plan if I upgrade mid-cycle?**

Yes, you will receive a prorated credit for the unused portion of your current plan. This credit will be applied to your new plan’s billing, reducing the amount you need to pay.

**Can I upgrade to a higher plan at any time during my billing cycle?**

Yes, you can upgrade to a higher plan at any time during your billing cycle. Your new plan’s features will be available immediately, and the billing adjustment will be made according to your current billing cycle.

**What if I decide to downgrade after upgrading?**

If you decide to downgrade after upgrading, you can do so through your account settings. Keep in mind that downgrading may result in losing access to certain features, and you may be subject to different billing terms. For more information, read the extensive article on downgrade your plan.

<a id="downgrading-your-plan"></a>

## Downgrading your subscription plan

Choosing a lower-tier plan may mean that some key features will no longer be included. This guide will help you understand what happens when you downgrade your Document360 plan. You can downgrade your existing plan or subscription at any point.

> NOTE
>
> Only users with the **Owner** portal role or team accounts assigned **View and Update** permissions for **Billing & invoice** can access and make changes to the plan.

You can downgrade from

* [Enterprise to Business](/help/docs/downgrading-your-plan#enterprise-to-business)
* [Business to Professional](/help/docs/downgrading-your-plan#business-to-professional)
* [Enterprise to Professional](/help/docs/downgrading-your-plan#enterprise-to-professional)

## Pricing page

To downgrade from your current plan,

1. From the Knowledge base portal, navigate to **Settings () > Knowledge base portal > Billing**, where the **My plan** tab is selected by default.
2. Click **Change plan** to view the various plans available in Document360.

   The available plans in Document360 are:

   * **Professional**
   * **Business**
   * **Enterprise**
3. Scroll down to the **Compare plans and features** section to view a detailed comparison of all plans and features.
4. Once you’ve selected your preferred plan, click the **Let’s talk** button.

![Upgrade-downgrade-Pricing](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Change_plan_screen.png)

The Document360 sales team will contact you to assist with downgrading your plan.

> NOTE
>
> If any features from your current plan are not included in a lower-tier plan, the Document360 sales team will inform you about the option to purchase them as add-ons, if available. If these features are not available as add-ons, you will be notified that they will no longer be accessible after the downgrade.

Each subscription plan has different limits on project versions and team accounts. Before downgrading, make sure your current project configuration and usage fit within the limits and features of the new plan. Keep in mind that certain features are only available in higher-tier subscriptions. For details on how a downgrade may affect your limits and features, please refer to our [pricing page](https://document360.com/pricing/).

## Plan comparison

The comparison of features and benefits you may lose while downgrading your plan are detailed in this section.

### Enterprise to Business

When moving from the Enterprise plan to the Business plan, you will need to adapt to some changes in available features and capacities. Here are the changes that will take place:

#### Storage and user access

| Features | Enterprise plan | Business plan | Impact |
| --- | --- | --- | --- |
| **Storage reduction** | 500 GB | 100GB | You will retain your current file storage, but you will not be able to add more files if you've exceeded the new limit. |
| **Team access changes** | 20 | 10 | You will be prompted to choose which team accounts to retain. You can purchase additional accounts to keep all existing ones. |
| **Reader capacity** | Unlimited | 10000 | Any purchased add-on reader count will carry forward. |
| **Reviewers** | 20 | 10 | You will be prompted to choose which reviewers to retain. You can purchase additional reviewer accounts to keep all existing ones. |

#### Feature adjustments

| Feature | Enterprise Plan | Business Plan | Impact |
| --- | --- | --- | --- |
| **AI tools** | All AI features | AI Search (2,000 Credits) | You will retain access to AI features, but with reduced credits. Eddy AI Search will reset to 2,000 credits for the upcoming month. Add-ons will carry forward. |
| **Exclusive features** | Sandbox, IP Restriction | No access | You will lose access to decision trees, the sandbox environment, and IP restrictions. |
| **Security changes** | SSO, Health check, Security and audits logs | Security and audits logs | SSO (SAML/OpenID, JWT) will no longer be available. Health check and migration support services might be limited. |

#### Content and Add-ons

| Feature | Enterprise Plan | Business Plan | Impact |
| --- | --- | --- | --- |
| **Workspace retention** | 2 | 1 | You will be prompted to choose which workspaces to keep. |
| **Language options** | 5 Languages | 3 Languages | You will need to select which languages to retain. |
| **Translation credits** | 5 million Characters | 2 million Characters | Machine Translation credits will carry forward along with language selection. |
| **Extensions** | Salesforce, Crowdin, Phrase included | Salesforce not available | Salesforce extension will no longer be available. Crowdin and Phrase will be available as add-ons. |

### Business to Professional

When downgrading from the Business plan to the Professional plan, you will need to adjust to a more streamlined set of features.

#### Storage and user management

| Features | Business plan | Professional plan | Impact |
| --- | --- | --- | --- |
| **Storage reduction** | 100 GB | 50 GB | You will retain your current file storage, but you will not be able to add more files if you've exceeded the new limit. |
| **Team access changes** | 10 | 5 | You will be prompted to choose which team accounts to retain. You can purchase additional accounts to keep all existing ones. |
| **Reader capacity** | 10000 | 5000 | Top 5,000 or recently logged in will be retained |
| **Reviewers** | 10 | 5 | You will be prompted to choose which reviewers to retain. You can purchase additional reviewer accounts to keep all existing ones. |

#### Features removed

| **Features** | **Business Plan** | **Professional Plan** | **Impact** |
| --- | --- | --- | --- |
| **Workflow Tools** | Workflow designer and assignments available | No workflow designer and assignments | Workflow tools will be removed. You will no longer have access to create or manage workflows. |
| **Analytics** | Advanced analytics features | Basic analytics features only | Advanced analytics will be removed. Only basic metrics will be available. |
| **Integrations** | API tokens and integrations (e.g., Freshdesk, Zendesk) | Limited or no API tokens and fewer integrations | API tokens and certain integrations will be disabled, reducing your ability to connect with third-party tools. |

#### AI and search capabilities

| **Features** | **Business Plan** | **Professional Plan** | **Impact** |
| --- | --- | --- | --- |
| **AI Credits** | 2,000 Eddy AI Search credits | Not supported | Your AI Search credits will be removed, impacting the ability to perform AI-powered search. |
| **Search Features** | Full Eddy AI Assistive Search and article summarizer | Basic search without Eddy AI and summarizer | You will lose access to Eddy AI Assistive Search and article summarization, reducing the search experience. |

### Enterprise to Professional

When you downgrade from Enterprise to Professional plan, you will lose the advanced features from the [Enterprise](/help/docs/downgrading-your-plan#enterprise-to-business) as well as the [Business](/help/docs/downgrading-your-plan#business-to-professional) plans.

## Downgrading for users on legacy pricing plans

As of 31st August 2024, we have revised our pricing structure. If you are on a legacy pricing plan—meaning you subscribed before this date—you will not be able to change your plan directly through the portal. Downgrading requires assistance from our support team.

Here’s how you can proceed:

1. Navigate to the **Billing** page.
2. Select **Change plan**.
3. On the **Change plan** page, click the **Let’s talk** button below the required plan.
4. Click **Raise Request** on the confirmatory pop-up.

   This will trigger a request to our support team. They will review your request and guide you through the downgrade process within two working days. They will also handle the transition to the new plan, ensuring a smooth experience.

> NOTE
>
> If you need further assistance or have specific questions about your legacy plan, you can always reach out to our support team via email, live chat, or phone.

## Important considerations for all downgrades

1. **Data retention**: Your existing data will be retained where possible, but you may lose access to it if it exceeds the lower plan's limits.
2. **Feature access**: You will lose access to features not included in the lower plan immediately upon downgrade.
3. **Add-ons**: Any add-ons you've purchased will be carried forward if they're compatible with the lower plan.
4. **Article Count**: All existing articles will be retained, but you will not be able to create new ones if you've exceeded the limit.
5. **Tags**: Existing tags can be edited/updated/deleted, but you cannot create new tags.
6. **Feedback Manager**: Received feedback will be retained, but the feedback option will be disabled in Article settings & SEO.
7. **PDF Export**: You can continue using the previously created PDF templates for article downloads but cannot create new ones.
8. **Widget**: Only Business and Enterprise plans support up to 10 widgets.
9. **Custom JS/CSS**: Existing code will be retained but cannot be edited or saved.

## Post-downgrade tips

1. **Review your content**: After downgrading, review your knowledge base to ensure your most important content is accessible and properly organized.
2. **Update your workflows**: Adjust your team's processes to work effectively within the new plan's capabilities.
3. **Communicate changes**: Inform your team and users about any changes in features or access that might affect them.
4. **Monitor usage**: Keep an eye on your storage and user limits to ensure you're staying within the new plan's boundaries.
5. **Consider future needs**: If you find the new plan too limiting, remember you can always upgrade again in the future.

Downgrading your plan does not mean a reduction in the quality or performance of the product. By carefully managing your resources and focusing on the most critical content and features, you can continue to maintain an effective knowledge base. If you need help downgrading your Document360 plan or have any questions, our support team is always here to assist you.

---

## FAQs

**What happens to my data if I downgrade my plan?**

When you downgrade your plan, your existing data remains intact. However, you may lose access to certain features or storage limits associated with the higher plan. We recommend reviewing your data and feature usage to ensure compatibility with the new plan.

**Will I lose access to any features after downgrading?**

Yes, downgrading may result in losing access to features specific to the higher plan. We provide a list of features included in each plan so you can understand what you’ll have access to before making the change. For more information, see [Document360 pricing](https://document360.com/pricing/).

**Can I revert to my previous plan if I downgrade and later decide I want the higher plan again?**

Yes, you can upgrade back to your previous plan at any time. However, please note that any features or data limitations of the downgraded plan will apply until you upgrade again.

**How does downgrading affect my billing and payments?**

Upon downgrading, your billing will be adjusted according to the new plan’s pricing. You’ll receive a prorated credit for the unused portion of your previous plan, depending on your billing cycle and company policy.

**Will I lose access to my current projects or articles during the downgrade process?**

No, you will not lose access to your current projects or articles. However, certain features tied to the higher plan may become inaccessible, but your data will remain secure.

**What steps should I take before downgrading to ensure a smooth transition?**

Review the feature list of your new plan, back up any critical data, and assess if you need to adjust your workflows. It’s also helpful to consult our support team if you have any specific concerns about the downgrade.

**Can I downgrade my plan immediately, or is there a waiting period?**

Downgrades are typically processed immediately. When you downgrade a subscription, the prorated cost of the current plan for the remainder of your current billing cycle will be added as credits if applicable. On renewal, your invoice will reflect the new subscription price.

**Will there be any changes to my account settings or configurations after downgrading?**

Your account settings and configurations will remain the same, but you may lose access to certain customization options or integrations available in your previous plan.

**What if I exceed the limits of the new plan after downgrading?**

If you exceed the limits of your new plan, you’ll receive notifications and options to either upgrade back to your previous plan or adjust your usage to comply with the new limits.

**How do I delete my Document360 account?**

If you wish to delete your Document360 account, please reach out to our support team at [support@document360.com](mailto:support@document360.com).

<a id="add-ons"></a>

## Purchasing add-ons

### Available add-ons by plan

Document360 is designed to scale with your projects, offering a range of add-ons to enhance your documentation efforts. Across the **Professional**, **Business**, and **Enterprise** plans, you can purchase additional:

* **Workspaces**
* **Languages**
* **Translation credits (1 million characters)**
* **Storage (1 unit = 50 GB)**
* **Team accounts**
* **Readers (1 unit = 5000 readers)**
* **Limit for PDF export (1 unit = 2GB)**

For **Business** plan users, optional add-ons include:

* **Crowdin extension**
* **Phrase extension**

**Enterprise** plan users can also purchase

* **Salesforce extension**
* **Additional sandbox environment**

These add-ons ensure enhanced flexibility and robustness in your knowledge base setup.

> NOTE
>
> To purchase add-ons, you must have a saved card on your Document360 account. To add a card, go to **Settings ()** > **Knowledge base portal** > **Billing**, and select the **Payment information** tab.

---

### Purchasing add-ons

To purchase add-ons,

1. From the knowledge base portal, go to **Settings ()** > **Knowledge base portal** > **Billing**.

![Billing page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Billing_page_purchase_addon_button.png)

2. On the **My plan** tab, select **Purchase add-on**.

![Purchase add-ons](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Billing_page_purchase_addon_details.png)

3. Select the required add-ons using the + and - buttons.
4. Click **Confirm payment** to make payment.

> NOTE
>
> Customers on the legacy plan can only purchase the following add-ons: Projects, Workspaces, Languages, Translation Credits, Storage, Team Accounts, and Readers. This is available exclusively for online customers. Offline customers can contact our dedicated customer support team for further assistance.

<a id="upgrading-from-trial-version"></a>

## Upgrading from trial version

Document360 offers a 14-day trial period, allowing you to explore all features from every plan. During the trial, you can switch between plans to experience the features available in each tier. You can upgrade to your desired subscription plan at any time during the trial or once the trial ends.

> NOTE
>
> Only **Owner(s)** of the project can access **Billing** features.

---

## Changing your plan during the trial period

During the 14-day trial period, Document360 allows you to switch between plans to explore the features offered in each tier. This flexibility helps you evaluate how different plans align with your requirements.

For example, you can start with the **Enterprise** plan to explore all advanced features and then switch to a lower-tier plan to understand the capabilities available in a more cost-effective option. By simulating the experience of using various plans, you can make an informed decision about which subscription plan best suits your needs. All changes made during the trial are free of charge, and you can upgrade to your desired plan at any point during or after the trial.

From the Knowledge base portal, navigate to ****Settings** ()** > ****Knowledge base portal**** > ****Billing****. On the ****Billing**** page,you can view your current plan, remaining trial duration, and a summary of available features.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Trial_plan_billing_screen.png)

To change your plan during the trial period,

1. On the header menu bar, click the dropdown on the **TRIAL ENDS IN N DAYS** button.
2. Select the **Try other plans** button to open the **Change plan** page. The **Change plan** page will show the available plans.
3. Click **Try now** under the desired plan.

> NOTE
>
> If you select a lower-tier plan, you will be directed to a page that lists the features you will lose access to.

4. If you’re moving to

   * **A lower tier plan**: Select the checkbox to proceed with downgrading and deleting any configurations that are not available in the lower tier plan and click the **Change plan** button.
   * **A higher tier plan**: You will see a success message once your plan is upgraded successfully.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_GIF-Trial_plan_try_other_plans.gif)

Following these steps will successfully change your plan during the trial period.

> NOTE
>
> Alternatively, from the dropdown:
>
> * Click **Buy now** to proceed with a subscription.
> * Click **Book a demo** to schedule a demonstration.
> * Click **Chat with us** to talk to the customer support team.

---

## Subscribing to a Document360 plan

To subscribe to a paid plan during the trial period or after the trial period ends,

1. From the Knowledge base portal, navigate to **Settings () > Knowledge base portal > Billing.**

   On the Billing page, you can view a summary of the features included in your plan and the number of days remaining in your trial.
2. Click **Buy now** to go to the **Upgrade** page, where you can view the available Document360 plans and their costs. Scroll down to the **Compare plans & features** section for a detailed list of all features and their availability in each plan.
3. Once you’ve selected your preferred plan, click the **Let’s talk** button.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_GIF-Trial_plan_buy_plans.gif)

The Document360 sales team will contact you to assist with purchasing a new plan.

## FAQs

**What features are available during the trial period?**

During the trial, you can explore all features and plans offered by Document360 to help you decide which plan best suits your needs.

**Will I lose my data if I downgrade to a lower plan during the trial?**

No, your data will remain intact, but certain features and limits (e.g., workspaces, readers, storage) will be adjusted based on the lower plan.

**Can I extend my trial period?**

In some cases, you may be eligible for an extension. Contact our support team to discuss options for extending your trial.

**What happens when my trial period ends?**

To continue using advanced features after your trial ends, you will need to subscribe to a plan. If you choose not to subscribe, your project will be placed on hold and scheduled for deletion, but you will have time to take action before it's permanently removed.

**Are there any limitations during the trial compared to a paid plan?**

No, the trial offers full access to all features, just like a paid plan, so you can experience the platform's capabilities without restrictions.

**What if I need help during my trial?**

You can access support via the chat option, book a demo, or reach out to our customer support team directly for assistance.

**Will I be charged automatically after the trial ends?**

No, you won’t be charged automatically. You must manually subscribe to a plan before the trial ends to continue using the advanced features.

**Does the pricing vary for subscription plans based on currency?**

Yes, the pricing of subscription plans changes for each currency. Select the desired currency, and the respective pricing for the subscription plans appears.

**Does the pricing vary with the exchange/conversion rate?**

The pricing that appears on the page is fixed. We do not change the pricing for exchange/conversion rates regularly. When there is a pricing change in the future, you will get notified through mail communication well before the new pricing implementation.

<a id="changing-payment-information"></a>

## Changing payment information

## How to change the payment information?

![1_Screenshot-changing_the_payment_information](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Payment information - new.png)

NOTE

The team account that has owner access can access the billing section.

1. From the Knowledge base portal, go to Settings and then click **Billing**.
2. The **My plan** section will be open by default. Navigate to **Payment information** tab.
3. Below the **Credit card** tile, you can change the payment and billing address.

   Here, you can view the primary card.
4. Click **Add another card**, to add a second card for billing.

NOTE

The primary card is used for billing purposes. If the primary card runs out of funds or expires, the second card will be used for renewal.

---

## FAQs

**How can I delete my primary payment card in the billing section?**

You cannot delete your primary card, but you can edit it. Secondary cards can also be edited and deleted.

**How can I delete my secondary card in the billing section?**

To delete a secondary card:

1. Navigate to **Settings > Billing > Payment information**.
2. Hover over your secondary card.
3. Click the **Delete** icon, then confirm by clicking **Delete** in the confirmation popup.

**How can I set my secondary card as my primary card?**

To set a secondary card as your primary card:

1. Go to **Settings > Billing > Payment information**.
2. Hover over your secondary card.
3. Select the **Set as primary** radio button. A confirmation popup will appear.
4. Click **Make Primary** to switch your secondary card to the primary card.

**How do I edit my primary card?**

To edit your primary card:

1. Navigate to **Settings > Billing > Payment information**.
2. Hover over your primary card.
3. Click the **Edit** icon to update the card details.
4. After making the changes, click **Update** to save them.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="february-2025-1112"></a>

## February 2025 - 11.1.2

Document360 version 11.1.2 is now live, introducing an enhanced image viewing experience in the knowledge base site, offering improved usability with zoom, pan, and download options.

---

## Features/Enhancements

### Intuitive image viewer in the Knowledge base site

**Category: Knowledge base site | Enhancement**

The image viewer in the Knowledge base site has been upgraded to provide a more intuitive experience. Now, when you click an image, it opens in a viewer that fits to your screen size, along with zoom in/zoom out and pan functionality. The title bar offers easy access to download the image or follow any embedded URLs.

> For more information, read the article on [**Knowledge base site**](https://docs.document360.com/docs/knowledge-base-site-20).

![Document360 interface showing the enhanced image viewer with highlighted options.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Enhanced_image_viewer_details.png "11_Screenshot-Enhanced_image_viewer.png")

---

> **NOTE**
>
> Minor security updates, bug fixes, and performance improvements have also been implemented across the Knowledge base portal and Knowledge base site.

<a id="january-2025-1111"></a>

## January 2025 - 11.01.1

Document360 version 11.01.1 has been deployed, bringing enhancements to our knowledge management platform. This release introduces automatic unlocking for locked articles, quicker renaming of articles and categories, additional language support for Eddy AI, and improvements to label management and image organization in Document360 Drive.

---

## Enhancements

### Auto-unlock articles when navigating to a different page

**Category: Knowledge base portal | Enhancement**

Articles will now automatically unlock when a user navigates to another page or article. Previously, idle articles remained locked for 15 minutes, requiring others to either wait or request manual unlocking, leading to delays and disrupted collaboration. This improvement ensures editing access is more seamless, reducing wait times and improving workflow efficiency.

---

### Rename articles and categories from the Document tree view

**Category: Content management | Enhancement**

You can now rename your articles and categories directly from the context menu in the Document tree view, without needing to open each item. This improvement makes it quicker and easier to update your content titles.

> To learn more about renaming articles & categories from the context menu, read the articles on [**Managing articles**](https://docs.document360.com/docs/managing-articles#renaming-an-article) & [**Managing categories**](https://docs.document360.com/docs/managing-categories#renaming-a-category).

![Menu options displaying the new 'Rename' option for articles and categories.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Rename_option_context_menu.png)

---

## Other updates

* The AI writer suite and AI search suite now support Brazilian Portuguese (pt-br) along with existing 15 languages.
* The Recent folder in Document360 Drive now displays images in the order of recent uploads, making it easier to find and insert images into articles.
* You can now add labels to articles and page categories individually, and in bulk from the Document list view.

---

> **NOTE**
>
> Minor security updates, bug fixes, and performance improvements have also been implemented across the Knowledge base portal and Knowledge base site.

<a id="december-2024-10121"></a>

## December 2024 - 10.12.1

Document360 version 10.12.1 is now live, bringing new features and enhancements to improve your content management and accessibility. This update includes **Custom pages**, **Tabs in the Advanced WYSIWYG editor**, **AI-generated alt-text for images**, and **Internal labels**. It also introduces **content retention when switching editors** and other improvements to streamline workflows and enhance user experience.

## Features/Enhancements

### Custom pages

**Category: Site builder | Enhancement**

You can now create and manage custom pages within your knowledge base using the new Custom pages feature. A custom page is a standalone page that you can use for various purposes, including informational content, legal and compliance information, and company policies. You can easily add the links to custom pages in your site's header or footer for quick access. Additionally, you can translate these pages into multiple languages using machine translation, making them accessible to a broader audience.

> For more information, read the article on [**Custom pages**](https://docs.document360.com/docs/custom-pages).

---

### Improved article version comparison with color-coded highlights

**Category: Knowledge base portal | Enhancement**

The article version comparison feature in Document360 is now more intuitive and user-friendly. You can easily identify changes with color-coded highlights: added content is marked in **green**, removed content appears in **red with a strikethrough**, and formatting changes are highlighted in **blue**. The new **Swap** button lets you instantly reverse the order of versions being compared, making it easier to focus on specific changes.

> For more information, read the article on [**Revision history**](https://docs.document360.com/docs/revision-history).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_GIF-Article_version_comparison.gif)

---

### Switch to the Advanced WYSIWYG editor without content loss

**Category: Editor | Enhancement**

When you switch from the Markdown or WYSIWYG editor to the Advanced WYSIWYG editor, Document360 now automatically detects unsupported HTML tags and attributes that might affect your content. Unsupported elements are highlighted in the editor, making it easy for you to review and adjust your content without losing any details during conversion.

> For more information, read the article on [**Editor choices in Document360**](https://docs.document360.com/docs/using-the-text-editor#handling-unsupported-html-tags-and-attributes-in-the-advanced-wysiwyg-editor).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_GIF-Unsupported_html_tags.gif)

---

### Ability to label articles for better article management

**Category: Knowledge base portal | Feature**

You can now add labels to articles internally in Document360 to help organize, filter, review, and perform bulk actions within your content library. Labels allow you to mark articles for various purposes, such as assigning them to writers, tracking their status (e.g., "In Progress," "Needs Review"), identifying content for release notes, or categorizing topics, making article management easy.

> For more information, read the article on [**Adding article labels**](https://docs.document360.com/docs/adding-article-labels).

### 

---

### Tabs in the Advanced WYWIWYG editor

**Category**: **Advanced WYSIWYG editor | Enhancement**

The Advanced WYSIWYG editor now includes the tabs feature to help writers organize and present complex information more clearly. This feature adds a row of tabs in the editor, so writers can group related content into sections that readers can easily switch between. This provides a more structured and user-friendly approach for presenting complex or lengthy content, enabling readers to access specific sections without needing to scroll extensively.

> For more information, read the article on [**Tabs in the Advanced WYSIWYG editor**](https://docs.document360.com/docs/tabs-in-the-advanced-wysiwyg-editor).

---

### Citations with source articles for Ask Eddy AI

**Category: Ask Eddy AI | Enhancement**

The Ask Eddy AI feature now includes citations with its responses, linking users to source articles for quick validation of information and further investigation into the topic. Numbered references are supported across internal and external sources, that display titles and short summaries when you hover over the citation. This feature is available in the Knowledge base site, widgets, APIs, and extensions, working in all Eddy AI-supported languages.

> For more information, read the article on [**AI assistive search (Ask Eddy AI)**](https://docs.document360.com/docs/ai-assistive-search-ask-eddy).

![Eddy AI search result highlighting the citations feature, showing the source article for the search results.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Eddy_ai_citations.png "Citations.png")

---

### Generate alt-text for images using Eddy AI

**Category: Eddy AI | Enhancement**

This enhancement automatically generates alt text for images in your articles using Eddy AI. When you upload or insert images, the system provides a suggested alt text, which you can accept, edit, or regenerate. This ensures that your articles are SEO-friendly and meet accessibility standards, saving time and effort in manual alt text creation.

> For more information, read the article on the [**AI alt-text generator**](https://docs.document360.com/docs/ai-alt-text-generator).

---

### Enhancement to Knowledge base site search - Global search

**Category: Knowledge base site | Enhancement**

Experience a significant upgrade with KB Site 2.0, featuring unified search capabilities that now include results from API workspaces. You can seamlessly switch between global and individual workspaces, with search filters displaying **All Workspaces** when in global mode.

> For more information, read the article on [**Search in Knowledge base site**](https://docs.document360.com/docs/search-in-knowledge-base-site).

![Dropdown menu showing workspace and language options in Document360 interface, along with the API docs tab in the search results.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Unified_search_and_filters.png)

> NOTE
>
> This update is available only in **KB Site 2.0.** To preview your knowledge base in KB Site 2.0, go to **Settings** > **Customize site**.

---

### Restrict Eddy AI for selected workspaces, languages, and categories

**Category: Eddy AI | Enhancement**

You can now configure Eddy AI assistive search to focus on specific workspaces, languages, and categories. This update lets you enable Eddy AI responses only for selected content sources, ensuring better control over what Eddy AI uses as source. These changes streamline search results and ensure they reflect only the most relevant content.

> For more information, read the article on [**Adding external sources for AI Assistive search**](https://docs.document360.com/docs/eddy-ai-federated-search).

![Manage AI sources with content access settings and external source options displayed.](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Restrict_eddy_ai.png)

---

### Ability to undo feedback submissions on the Knowledge base site

**Category: Knowledge base site | Enhancement**

You can now undo feedback or toggle between likes and dislikes for greater flexibility in sharing your input. To ensure actionable insights, mandatory comments are required for dislikes. Additionally, users are limited to one feedback entry per article, providing clearer and more consistent content insights.

> For more information, read the article on [**Liking or disliking an article**](https://docs.document360.com/docs/liking-or-disliking-an-article).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_GIF-Undo-feedback.gif)

---

## UI updates

* The Document360 Advanced WYSIWYG editor now includes consistent **8-pixel** block-level spacing for improved readability and organization. Font sizes and top margins for headings adjust dynamically based on viewport size, ensuring a responsive and clean layout. These updates are applied by default and can be easily customized with custom CSS for flexibility across devices and export formats.
* You can now view page categories in the **All articles** list in Document360.
* The left navigation bar has been revamped with new icons for **Dashboard** (), **Documentation** (), **API documentation** (), **Analytics** (), **Widget** (), **Drive** (), and **Settings** ().

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734648003603.png)

* In the Documentation tab, **All articles** (), **Workflow assignments** (), **Starred** (), and **Recycle bin** () have been converted to static icons at the top of the Categories & Articles pane. For API documentation workspaces, **All articles** (), **Recycle bin** (), and **API docs reference** () have been converted to static icons at the top of the Categories & Articles pane.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1734795786548.png)

---

> NOTE
>
> Minor security updates, bug fixes, and performance improvements have also been implemented across the Knowledge base portal and Knowledge base site.

<a id="november-2024-10111"></a>

## November 2024 - 10.11.1

Document360 version 10.11.1 has been deployed, introducing enhancements to our knowledge management platform. Key highlights include the ability to retrieve information from external sources while using Ask Eddy AI and purchasing the Reviewer role as an add-on.

## Features/Enhancements

### Include external sources in Eddy AI search

**Category: Knowledge base site | Enhancement**

You can now index external sources like webpages and sitemaps, allowing Eddy AI to retrieve information beyond your knowledge base. This enhancement provides more comprehensive answers to your queries by including relevant information from multiple sources, improving the overall search experience.

> For more information, read the article on [**Adding external sources for AI Assistive search**](/help/docs/eddy-ai-federated-search).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Manage_external_sources.png)

---

### Reviewer role purchase as add-on

**Category: Reviewer | Enhancement**

Teams can now purchase additional Reviewer roles directly through the Document360 portal, providing large teams the flexibility to scale review processes without upgrading to a higher plan. Additionally, when importing team accounts, Reviewer roles will be automatically recognized and assigned.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Reviewer_role_as_addon.png)

> For more information, read the article on [**Managing Reviewer accounts**](https://docs.document360.com/docs/managing-reviewer-accounts).

---

### Article URLs included in article CSV exports

**Category: Knowledge base portal | Enhancement**

Exporting articles as a CSV file now includes URLs from both the Knowledge base portal and site. This enhancement simplifies navigation by enabling direct access to articles and makes sharing links with your team easier than ever.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Export_article_url.png)

---

### Other updates

* The new **Fit table to page width ()** option automatically resizes tables to fit the width of your window while keeping columns equal.
* The language names in the language selection dropdown menu in the Knowledge base site and Knowledge base portal will now be available in their native scripts.
* Page categories can now be accessed directly from the Document360 Chrome extension.
* If you switch an article to the Advanced WYSIWYG editor, you cannot revert the editor type for that article. However, if you have the **Project Settings - Update** permission, you can set the default editor for future articles from **Settings** > **Knowledge base** **portal** > **General** > **Editor**. For more information, read the article on [**Editor choices in Document360**](/help/docs/using-the-text-editor#switching-between-markdown-wysiwyg-advanced-wysiwyg-editor).

---

> NOTE
>
> Minor security updates, bug fixes, and performance improvements have also been implemented across the Knowledge base portal and Knowledge base site.

<a id="october-2024-10101"></a>

## October 2024 - 10.10.1

Document360 version 10.10.1 has been deployed, introducing enhancements to our knowledge management platform. This update focuses on improving productivity with features like chart generation using Eddy AI and enhancing accessibility with the new text-to-voice feature. Additionally, we've introduced Conversational Eddy AI as chatbot and provided more customization options in the site builder.

## Features/Enhancements

### Conditional content blocks

**Category: Editor | Enhancement**

This feature allows you to customize content visibility based on factors like country, device type, date, IP address, and reader groups. The available conditions will vary depending on the project type, enabling precise content targeting within a single article and enhancing the reader experience without the need for multiple versions.

> For more information, read the article on [**Conditional content blocks**](https://docs.document360.com/docs/conditional-content-blocks).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Conditional_content_blocks.png)

> NOTE
>
> This feature is available only in **KB Site 2.0**. To preview your knowledge base in KB Site 2.0, go to **Settings** > **Customize site**. If you do not see the preview option, please contact the Document360 support team for assistance.

---

### Generate charts from text and tables using Eddy AI

**Category: Editor | Feature**

The AI chart generator allows you to instantly convert selected text or table data into visual charts, such as pie charts or flowcharts, directly within the editor. This feature eliminates the need for third-party tools, streamlining the process of creating visual aids and improving productivity.

> For more information, read the article on [**AI chart generator**](https://docs.document360.com/docs/ai-chart-generator).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_GIF-AI_chart_generator.gif "AI Chart Generator.png")

---

### Listen to articles on the Knowledge base site

**Category: Knowledge base site | Feature**

The Listen feature (Read out loud) allows you to listen to article content, enhancing accessibility for users who prefer listening over reading. It also helps save time by enabling you to consume content while multitasking.

> For more information, read the article on the [**read out loud feature**](https://docs.document360.com/docs/text-to-voice-functionality).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Text_to_voice.png "Text to Voice.png")

> NOTE
>
> This feature is available only in **KB Site 2.0**. To preview your knowledge base in KB Site 2.0, go to **Settings** > **Customize site**. If you do not see the preview option, please contact the Document360 support team for assistance.

---

### Conversational Eddy AI chatbot

**Category: Knowledge base widgets | Enhancement**

This update extends the [Conversational Eddy AI](/help/docs/september-2024-1091#conversational-eddy-ai) feature to chatbots on the Knowledge base site. Previously, Eddy AI did not handle contextual follow-up questions in widgets. With this enhancement, users can now enjoy seamless, context-aware interactions, improving the overall experience.

> For more information, read the article on [**Eddy AI chatbot**](https://docs.document360.com/docs/ai-chatbot).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-AI_chatbot.png "Conversational Eddy AI in widgets.png")

> NOTE
>
> This feature is available only in **KB Site 2.0**. To preview your knowledge base in KB Site 2.0, go to **Settings** > **Customize site**. If you do not see the preview option, please contact the Document360 support team for assistance.

---

### Site builder customization enhancement

**Category: Site builder | Enhancement**

* The Customize site section in KB site 2.0 now provides details on the recommended size, format, and optimal resolution for logos and fav icons. These changes won’t affect your existing logos or fav icons unless you choose to update them.
* You can now customize the Header background color Site builder, allowing you to align your knowledge base with your brand’s visual identity. The foreground color will automatically adjust to ensure readability.

---

### Search for all settings and article content in Portal search

**Category: Portal search | Enhancement**

You can now search for all Document360 content tools, such as the Workflow designer, Templates, Import and export project, and more, directly from the search bar in the knowledge base portal. Previously, you could search across Articles, Drive, Users & Groups, Tags, and Settings, and now, Content tools are included in your search results. This enhancement streamlines your access to all the essential tools and settings within the portal.

> For more information, read the article on [**Full portal search**](https://docs.document360.com/docs/full-portal-search).

---

## UI Updates

* While cloning a category, the category drop-down will be populated with its parent category or sub-category.

---

> NOTE
>
> Minor security updates, bug fixes, and performance improvements have also been implemented across the Knowledge base portal and Knowledge base site.

<a id="september-2024-1091"></a>

## September 2024 - 10.9.1

We’re excited to bring you Document360 version 10.9.1, packed with new features. This update introduces several enhancements, including the ability to preview your knowledge base before migrating to Knowledge base site 2.0, enhanced Conversational Eddy AI, and the introduction of the Reviewer role.

## Features/Enhancements

### Move to the improved Knowledge base site 2.0

**Category: Knowledge base site| Enhancement**

Document360's **Knowledge base site 2.0** is now available for all customers in Standard plan. The new site offers a more user-friendly experience with advanced features and customization options. You can enhance your site with a redesigned content navigator, improved search and filtering, status badges for quick updates, and more. Customers on Knowledge base site 1.0, can now try and migrate to the new knowledge base site. Experience the new version without affecting your existing setup by navigating to **Settings** > **Knowledge base site** > **Customize site**.

> For more information, read the article on [**Knowledge base 2.0 migration**](https://docs.document360.com/docs/kb-site-20-migration).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-KB_Site_Migration_2_0.png)

> For your information (FYI)
>
> Only **Standard plan users** can currently migrate to **KB site 2.0**. Migration plans for other customers are in progress and will be communicated soon.

---

### Conversational Eddy AI

**Category: Eddy AI | Enhancement**

Eddy AI now maintains context from your interactions, to give appropriate responses to your queries. You can converse with Eddy AI to get the information you need faster with lesser effort. By continuously learning from interactions, conversational Eddy can improve its responses, making it an invaluable tool for enhanced user experiences and streamlining communication. You can converse in multiple languages supported by Eddy AI.

> For more information, read the article on [**AI assistive search**](https://docs.document360.com/docs/ai-assistive-search-ask-eddy).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Conversational_eddy_ai.png)

> For your information (FYI)
>
> This feature is available exclusively in **KB Site 2.0**, which is accessible for projects created after June 10th. Navigate to **Settings** > **Customize site** to experience KB Site 2.0, without affecting your existing knowledge base.

---

### Automatically display related articles with Eddy AI

**Category: Editor | Enhancement**

Eddy AI now automatically displays related article suggestions in the KB site based on the contents of the current article and knowledge base. Any manually added related articles will still appear above the related articles suggested by Eddy AI. You can enable the **Dynamic related articles recommendations** toggle from **Settings** > **AI Features** > **Eddy AI**.

> For more information, read the article on [**AI related articles recommender**](https://docs.document360.com/docs/ai-related-articles-recommender).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Dynamic_related_articles.png "Dynamic related articles.png")

---

### **Movable content blocks**

**Category: Editor | Enhancement**

You can now rearrange content blocks in the Advanced WYSIWYG editor by clicking the arrows next to each block. You can also hold and drag the icon to move the content quickly. This will help you rearrange your content flexibly and more intuitively.

> For more information, read the article on [**Movable content blocks**](https://docs.document360.com/docs/movable-blocks-in-advanced-wysiwyg-editor).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Movable_content_blocks.png)

---

### Enhanced analytics for conversational Eddy AI

**Category: Analytics | Enhancement**

Following the support for conversations in Eddy AI, we've enhanced the Analytics module to provide deeper insights into these AI-powered interactions. To have a deeper understanding of Eddy AI conversation, you can filter the conversations by query topic, response status, application, and feedback type. We have also added a new Conversations table, allowing you to analyze query patterns and user feedback across your knowledge base in multiple languages and workspaces.

> For more information, read the article on [**Eddy AI search analytics**](https://docs.document360.com/docs/eddy-ai-search-analytics).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Conversational_eddy_AI_analytivs.png)

> For your information (FYI)
>
> This feature is available exclusively in **KB Site 2.0**, which is accessible for projects created after June 10th. Navigate to **Settings** > **Customize site** to experience KB Site 2.0, without affecting your existing knowledge base.

---

### Introducing Reviewer role with dedicated Reviewer license

**Category: Knowledge base portal | Feature**

You can now add users as Reviewers to the knowledge base portal along with the existing team accounts. Reviewers will have access to add comments to articles and update workflow statuses. This role ensures that users can participate in content review without making any changes to the articles.

> For more information, read the article on [**Managing reviewer accounts**](https://docs.document360.com/docs/managing-reviewer-accounts).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Create_revieiwer_account.png)

---

### Convert reader accounts to team accounts

**Category: Settings | Enhancement**

You can easily convert reader accounts to team accounts with customized permissions in the knowledge base portal, or convert team accounts to reader accounts, restricting access to the knowledge base site only. This enhancement allows for role updates without the need to delete accounts, preserving all original role data. Additionally, you can also perform bulk updates to roles for efficient management. You can also export reader/team account groups as an Excel/CSV file.

> For more information, read the article on [**Managing reader accounts**](https://docs.document360.com/docs/reader-accounts).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Convert_reader_to_team_account.png "Promote reader to team account(1).png")

---

### Enhanced Insert menu

**Category: Editor | Enhancement**

The Insert menu in the advanced WYSIWYG editor now supports search for specific block types. It has also been simplified with the removal of descriptions, making it easier to navigate. These updates are available in both the pinned and unpinned views of the Insert menu.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Updated_insert_menu.png "10_Screenshot-Updated_insert_menu.png")

---

### **Expand & collapse table of content in the Knowledge base site**

**Category: Knowledge base site | Enhancement**

You can now use the expand and collapse the table of contents (ToC) in the Knowledge base site to make it easier to read and navigate large documents. This feature lets you open or close sections of the TOC based on hierarchy, helping you focus on what’s important. You can also pin your most-used sections, so they stay easy to find as you browse.![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Expand_collapse_toc.png "10_Screenshot-Updated_insert_menu.png")

---

## UI Updates

* If you collapse the left navigation category pane, it will persist even when you navigate to a different module and switch back to Documentation tab.
* When saving an article as a template, we have introduced a popup message to rename the template and add a description.
* The **Custom CSS & JavaScript** option has been relocated to the **Customize site** page in Document360 settings. To access this option, navigate to **Settings** > **Knowledge base site** > **Customize site** > **Custom CSS & JavaScript**.

---

> NOTE
>
> Minor security updates, bug fixes, and performance improvements have also been implemented across the Knowledge base portal and Knowledge base site.

<a id="september-2024-1082"></a>

## September 2024 - 10.8.2

Document360 version 10.8.2 has been deployed, introducing enhancements to our knowledge management platform. This update focuses on providing greater flexibility in personalizing Eddy AI. and improving search capabilities within the knowledge base portal

## Features

### Customize Eddy AI

**Category: Eddy AI | Feature**

You now have customization options available for Eddy AI to set the response tone and length to match your brand's voice and style. Choose from various tone options such as professional, friendly, or confident, and select your preferred response length. Enterprise customershave the additional ability to customize Eddy AI's name, allowing for seamless integration with your brand identity. These customizations will be reflected across all Eddy AI features, including assistive search and the AI content suite.

Access these new options in **Settings** > **AI features** > **Customize Eddy AI** to enhance your AI assistant experience.

> For more information, read the article on [**Eddy AI customization**](https://docs.document360.com/docs/ai-customization).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Eddy_customization.png)

---

## Enhancements

Users in team account groups/reader groups will be arranged alphabetically based on their email IDs.

---

> NOTE
>
> Minor security updates, bug fixes, and performance improvements have also been implemented across the Knowledge base portal and Knowledge base site.

<a id="august-2024-1081"></a>

## August 2024 - 10.8.1

Document360 version 10.8.1 has been deployed, introducing enhancements to our knowledge management platform. This update focuses on content organization, AI-powered productivity features, and authentication flexibility.

---

## Features/Enhancements

### Insert FAQs as content blocks

**Category: Editor | Feature**

You can now easily add FAQs to your articles as content blocks from the Insert menu in the Advanced WYSIWYG editor. FAQs will be automatically formatted into an accordion style, helping to distinguish them from regular content. You can customize the FAQ content blocks as per your requirements, by setting the FAQs to be in expanded or collapsed state, customize the border styles, as well as the position of the expand/collapse icon.

> For more information, read the article on [**Advanced WYSIWYG editor**](https://docs.document360.com/docs/advanced-wysiwyg-editor).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-AI_FAQ_generator.png)

---

### Generate FAQs using Eddy AI

**Category: Editor | Feature**

You can now easily generate FAQs for your articles using the FAQ generator. With the click of a button, you can create up to 10 FAQs based on your article content. These FAQs will be automatically formatted using the FAQ content blocks. This feature is available as part of AI writer in the Eddy AI content suite. Users can still manually add/update FAQs.

> For more information, read the article on [**AI FAQ generator**](https://docs.document360.com/docs/ai-faq-generator).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-FAQ_content_blocks.png)

---

### Translate snippets, variables, and glossaries

**Category: Content tools | Feature**

You can now extend Document360's machine translation capabilities to your Variables, Snippets, and Glossary terms. You can seamlessly translate these elements across different languages, ensuring accurate translations throughout your documentation for content reuse elements as well.

> For more information, read the articles on [**Snippets**](https://docs.document360.com/docs/snippets), [**Variables**](https://docs.document360.com/docs/variables) and [**Glossaries**](https://docs.document360.com/docs/editing-and-deleting-glossary-term).

![1_multilingual_translation.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Translation_of_content_reuse_elements.png)

---

### Log in using multiple Single Sign-On (SSO) options

**Category: Authentication | Feature**

![Multiple SSO Endpoints 2](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Create_SSO_Choose_idp_page.png)

You can configure and use multiple SSO options simultaneously, providing greater flexibility in managing access to your knowledge base portal. This feature offers you more control over authentication methods for your team members. You can configure multiple Single Sign-On (SSO) options, including Okta, One-Login, Azure AD, Google Workspace, Auth0, AWS SSO, and any other custom SSO.

> For more information, check the category about [**Single Sign-On features**](https://docs.document360.com/docs/single-sign-on-sso).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1725205525164.png)

---

### Revamped table interactions

**Category: Editor | Feature**

The tables in the Document360 editor have received a visual update. While maintaining the same functionality, the new look and feel include updated bubble menus which immediately show table formatting options along with a visually appealing interface.

> For more information, read the article on [**Tables in the Advanced WYSIWYG editor**](https://docs.document360.com/docs/tables-in-advanced-wysiwyg-editor).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Revamped_tables_in_editor.png "image(161).png")

---

### Enhanced read receipts

**Category: Knowledge base site | Enhancement**

> For your information (FYI)
>
> This feature is available exclusively in **KB Site 2.0**, which is accessible for projects created after June 10th. We're working on migration plans for existing customers and will communicate them soon.

You can now set up read receipt rules in Document360 settings, dynamically controlling reader acknowledgment capabilities for workspaces, categories, and user roles. Additionally, you can also perform bulk operations, managing read receipts for multiple articles at once. These powerful tools are available for all paid plans.

> For more information, read the article on [**Read receipts**](https://docs.document360.com/docs/read-receipt).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Read_receipts_phase_ii.png)

---

### Find unused files to free up Drive storage

**Category: Drive | Enhancement**

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Drive_dependencies_column.png)

Easily identify files stored in your Document360 drive that are not associated with any article, knowledge base customization features (Branding, Main pages, and Error pages), or content reuse features. This can assist you in removing unnecessary files, optimizing storage space, and keeping your drive organized.

> For more information, read the article on [**File dependency viewer**](https://docs.document360.com/help/docs/file-dependency-viewer).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Drive_dependencies_popup.png)

---

### Customize the workspace display name for different languages

**Category: Workspace | Enhancement**

> For your information (FYI)
>
> This feature is available exclusively in **KB Site 2.0**, which is accessible for projects created after June 10th. We're working on migration plans for existing customers and will communicate them soon.

If you have a workspace with multiple languages, you can now manually customize the display name of your workspace for each language. Previously, the default workspace name would appear for all languages. Now, you can ensure that the workspace name is displayed based on the knowledge base site language selection.

> For more information, read the article on [**Setting up a multi-lingual knowledge base**](https://docs.document360.com/docs/setting-up-a-multi-lingual-knowledge-base).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Edit_workspace_display_name.png)

---

### Customize CTA button colors for dark theme

**Category: Site builder | Enhancement**

You can now customize the colour of the Call to action (CTA) button in the site builder separately for both light and dark themes. This will help you visualize the CTA button in both light and dark themes, ensuring a better user experience for your readers.

---

### Autosave for template editing

**Category: Knowledge base portal | Enhancement**

You can now edit templates with greater convenience thanks to the new autosave feature. As you modify templates, your changes are automatically saved in real-time, eliminating the need for manual saves. This feature ensures all your edits are preserved, preventing unexpected content loss.

---

## UI Updates

* We have streamlined comment notification settings by moving them from **General** to **Notifications** along with other notification settings in the knowledge base portal.
* In the Knowledge base site widget, if you choose to display selected categories, only the workspaces from which those categories are selected will appear in the workspace dropdown.

---

> NOTE
>
> Minor security updates, bug fixes, and performance improvements have also been implemented across the knowledge base portal and knowledge base site.

<a id="july-2024-1071"></a>

## July 2024 - 10.7.1

Document360 version 10.7.1 has been deployed, introducing enhancements to our knowledge management platform. This update focuses on search customization and content editing capabilities.

---

## Features/Enhancements

### Control article visibility in Ask Eddy AI search

**Category: Eddy AI | Enhancement**

You can now exclude specific articles from **Ask Eddy AI** searches. To access these new options, navigate to the article settings and look for the new **Search visibility** tab. Enabling this feature will restrict Ask Eddy AI from referencing this article in its responses, but this article can still be accessed from the category manager. For example - You might have both highly technical articles and simplified user guides on the same topic. You could exclude the technical ones from general Eddy AI searches to simplify the responses to user queries.

> NOTE
>
> The Exclude from Knowledge base search checkbox has been moved from the **SEO** tab to the new **Search visibility** tab.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Eddy_restrict_articles.png)

> For more information, read the article on [**excluding articles from search engines**](https://docs.document360.com/docs/excluding-articles-from-searches).

---

### Enhancement to the paste functionality

**Category: Editor | Enhancement**

You can now choose to retain or clear formatting when pasting content from Microsoft Word, including lists, tables, indentations, and fonts. This enhancement saves you time and effort by ensuring consistency in the format and indentation, and automated list management.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Copy_paste_formatting.png)

---

> NOTE
>
> Minor security updates, bug fixes, and performance improvements have also been implemented across the Knowledge base portal and Knowledge base site.

The practice of optimizing content to improve its visibility in search engine results and attract organic traffic. In Document360, Search Engine Optimization (SEO) elements can be added for each article through the article settings.

<a id="july-2024-1062"></a>

## July 2024 - 10.6.2

Document360 version 10.6.2 has been deployed, bringing refinements to our knowledge management platform. This update introduces two key features that enhance user engagement and content management. The new **Follow articles and categories** feature allows users to stay informed about updates to the documentation, while **schedule publishing** enables documentation teams to synchronize their documentation with product release cycles.

### Follow articles and categories

**Category: Knowledge base site | Feature**

> For your information (FYI)
>
> This feature is available exclusively in **KB Site 2.0**, which is accessible for projects created after June 10th. We're working on migration plans for existing customers and will communicate them soon.

Readers can now subscribe to receive email notifications for specific categories or articles they choose to follow. This ensures readers stay informed about new articles and updates to existing content, enhancing engagement and overall experience.

> For more information, read the article on [**Follow articles and categories**](/help/docs/follow-articles-and-categories).

![6_Screenshot-Reader_notification_figma_Screenshot](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Reader_notification_figma_screenshot.png)

---

### Schedule publishing

**Category: Article management | Feature**

You can now schedule the publication date and time for your content in advance. You have the flexibility to schedule a single article or perform bulk scheduling operations for multiple articles at once. This will allow you to effectively plan your publishing schedule for new/updated articles based on your product’s release cycle.

> For more information, read the article on [**Schedule Publishing**](/help/docs/schedule-publishing).

![Schedule_publish.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Schedule_publishing.png)

---

### UI updates

Documentation360’s Gen AI model **Eddy** has been renamed to **Eddy AI**. This change is reflected on the knowledge base site and **Ask Eddy** has been updated to **Ask Eddy AI**.

---

> NOTE
>
> Minor security updates, bug fixes, and performance improvements have also been implemented across the Knowledge base portal and Knowledge base site.

<a id="june-2024-1061"></a>

## June 2024 - 10.6.1

The Document360 team is excited to introduce version 10.6.1. This release enhances the knowledge base experience with several new features and improvements, including the ability to download all articles in a category as PDF in the knowledge base site, share private links to unpublished articles with SMEs for review, enhanced translation capabilities through Phrase integration, and the integration of Eddy AI in the Document360 widget. These updates, along with various other improvements, aim to enhance content creation and management, boost productivity, improve accessibility and user experience, strengthen security measures, and provide more robust analytics across the platform.

---

## Features/Enhancements

### Download specific article categories as PDF

**Category: Content tools | Enhancement**

> For your information (FYI)
>
> This feature is available exclusively in private and mixed projects in **KB Site 2.0**, which is accessible for projects created after June 10th. We're working on migration plans for existing customers and will communicate them soon.

You can now download multiple articles from one or more categories on your knowledge base site as PDFs at the same time in private projects. This update helps you save time, allowing you to download PDFs in bulk, instead of downloading them one at a time. You can also create an offline version of the knowledge base site for easy access.

> For more information, read the article on [**downloading articles from the knowledge base site**](http://docs.document360.com/help/docs/downloading-category-and-article-in-kb-site).

![1_download_category1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-Export_categories_as_PDF.png)

---

### Share a private link to an article

**Category: Categories & article | Enhancement**

> For your information (FYI)
>
> This feature is available exclusively in **KB Site 2.0**, which is accessible for projects created after June 10th. We're working on migration plans for existing customers and will communicate them soon.

You can now share articles using a private link even before publishing the content. This feature allows you to generate a unique link for any article, granting access to the content without associating it with the knowledge base site. This will allow you to send your articles for review to users not associated with the knowledge base portal before you publish them. You can share these private links with external users and regenerate the links at any time to manage access as per your preferences.

> For more information, read the article on [**Share articles via private link**](https://docs.document360.com/help/docs/share-articles-via-private-link).

![shareprivatelink.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-Share_link_for_review_kbportal.png)

---

### Enhanced translation with Phrase integration

**Category: Extensions | Feature**

Document360 now integrates with Phrase, a leading translation service platform. With this integration, you can translate and localize your knowledge base into multiple languages, achieving higher translation accuracy and faster turnaround times with less manual effort. Translate individual articles, multiple articles in a category, or even entire workspaces to your desired language, all with just a few clicks.

> For more information, read the article on [**Phrase Translation**](/help/docs/phrase).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image(129).png "image(129).png")

---

### Integration of Eddy AI in the knowledge base site widget

**Category: Knowledge base widgets | Enhancement**

Eddy AI is now available as a Document360 widget on your knowledge base site. The widget will allow you to access support in multiple languages, such as English (en), French (fr), Spanish (es), German (de), Norwegian (no), and Dutch (nl).

> For more information, read the article on [**knowledge base widgets**](/help/docs/knowledge-base-widget-getting-started).

![1_Screenshot-Eddy_widget_with_multi_lingual_support](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-Eddy_integration_in_widget.png)

---

### Eddy AI’s improved symbol recognition capabilities

**Category: Eddy AI | Enhancement**

Eddy AI can now identify and understand tick () and cross () symbols within tables, significantly improving its ability to interpret structured data. This update enhances Eddy AI's accuracy in analyzing yes/no, true/false, or pass/fail data points in tables.

---

### JWT analytics for KB widget

**Category: Knowledge base widget | Enhancement**

You can now track user interactions and engagement within private and mixed projects secured via JSON Web Token (JWT) authentication. The integration of JWT authentication analytics into the existing analytics framework provides insights into user behavior, content effectiveness, and security compliance when interacting with the knowledge base.

> For more information, read the article on [**Articles analytics**](/help/docs/articles-geography-and-performance).

---

### Effortless content authoring with enhanced slash menu

**Category: Editor | Enhancement**

Use the slash command to boost your productivity with keyboard-only interactions in the Advanced WYSIWYG editor. The enhanced slash menu, which is now organized under the Format, Insert, and Content Reuse tabs, provides a more intuitive user experience. You can also easily access Eddy AI right from the top of the slash menu.

> For more information, read the article on [**Advanced WYSIWYG editor**](/help/docs/advanced-wysiwyg-editor).

![slashcommand.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-Enhanced_slash_menu.png)

---

### Add tags and alt-text during file upload

**Category: File management | Enhancement**

You can now add tags and alt-text descriptions to files right when you upload files to Drive on Document360. This new functionality allows you to organize files with relevant tags and provide accessibility-friendly alt-texts during the upload process itself. You can also apply common tags to multiple files and common alt-texts to multiple images simultaneously.

> For more information, read the article on [**adding folders and files**](/help/docs/adding-folders-and-files).

![tags and alt texts.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-Bulk_add_tags_alt_text.png)

---

### Display user initials as default avatar

**Category: Knowledge base portal | Enhancement**

If you haven't uploaded a display picture to your user profile, you will now see your initials as the default avatar. This change also applies if you decide to remove your existing profile picture. By displaying your initials, we've made it easier for you to identify your presence in the portal.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-User_initails_default_avatar.png "image(145).png")

---

### Display user first and last name for JWT login

**Category: Knowledge base site | Enhancement**

Users logging in to the knowledge base site using JSON Web Token (JWT) authentication will now be able to see their first and last name in their user profile.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-JWT_user_first_last_name.png)

---

### Real-time network connectivity status notification

**Category: Knowledge base portal | Enhancement**

You will now receive a notification at the bottom of your screen on the knowledge base portal if your system is disconnected from the internet. This real-time alert allows you to take immediate action, ensuring no loss of data or interruption to your documentation process. You will also not be able to make any updates to your article until connectivity is restored.

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot-Network_connectivity_notification_color.png)

---

> NOTE
>
> Minor security updates, bug fixes, and performance improvements have also been implemented across the Knowledge base portal and Knowledge base site.

<a id="june-2024-1052"></a>

## June 2024 - 10.5.2

The Document360 team is excited to introduce version 10.5.2 with the addition of a keyboard shortcuts overview page in the Advanced WYSIWYG editor, along with minor bug fixes and performance & security enhancements.

---

## Features & Enhancements

### Keyboard shortcuts overview

**Category: Editor | Enhancement**

Document360 offers a wide variety of keyboard shortcuts for the Advanced WYSIWYG editor, to streamline your editing process, making it faster and efficient. You can now view the keyboard shortcuts with a single click. Simply click on the **More** icon () next to the Publish button in the top-right corner of the editor to view the list of all keyboard shortcuts. The keyboard shortcuts will be displayed based on your operating system (Windows or Mac).

For more information, read the article on [**Advanced WYSIWYG Editor basics**](https://docs.document360.com/docs/advanced-wysiwyg-editor-basics).

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Keyboard_shortcuts_overview_details.png "3_Screenshot-Keyboard shortcuts.png")

---

## Performance improvements & bug fixes

This release includes backend optimizations and bug fixes to provide you with a smoother and more responsive experience. Benefit from improved overall performance, faster response times, improved search performance and a smoother editor experience.

### Security updates

Document360 now provides enhanced security with bot detection and blocking for the knowledge base portal and site, operating in Block mode to prevent unwanted traffic and protect data integrity. Please note that this security enhancement may impact custom automation scripts like URL links or site crawling. Implementing these measures is critical for safeguarding against malicious bot activity.

For more information, read the article on [**Bot management**](/help/docs/bot-management).

<a id="may-2024-1051"></a>

## May 2024 - 10.5.1

The Document360 team is thrilled to introduce Document360 version 10.5.1. This release contains exciting new features such as advanced AI functionalities, optimized search engine, improved PDF template customization, and enhanced comment notifications, alongside several other enhancements and associated UI updates.

---

## Features & Enhancements

### Ask Eddy AI in multiple languages

**Category: AI Features | Feature**

The Ask Eddy AI's search capabilities now extend beyond English to include multiple languages such as French (fr), Spanish (es), German (de), Norwegian (no), and Dutch (nl). Explore content in your preferred language effortlessly. In addition, the Ask Eddy AI API also supports these languages.

> For more information, read the articles on [**AI assistive search**](/help/docs/ai-assistive-search-ask-Eddy AI) and [**Ask Eddy AI API**](/help/docs/ask-Eddy AI-api).

![Portal_Screenshot-Eddy_in_multiple_languages_](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Portal_Screenshot-Eddy_in_multiple_languages_.png)

---

### Eddy AI processes tables, code blocks, and LaTeX

**Category: AI Features | Enhancement**

In addition to the textual content, Ask Eddy AI can now comprehensively extract information from articles, encompassing code blocks, tables, and LaTeX. This enhancement enables Eddy AI to deliver optimized responses to your queries, offering a comprehensive understanding of the article content, helping you access a wider range of information efficiently.

> For more information, read the article on [**AI assistive search**](/help/docs/ai-assistive-search-ask-Eddy AI).

![Portal_Screenshot-Eddy_fetches_more_than_text_](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Portal_Screenshot-Eddy_fetches_more_than_text_.png)

---

### Convert to active/passive voice with AI writer

**Category: AI features | Feature**

Seamlessly transition between active and passive voice using the AI writer while creating content in Document360. This enhancement provides you with more flexibility in crafting content by enhancing the readability metrics and adhering to your style guide.

> For more information, read the article on [**AI writer**](/help/docs/ai-writer).

![Portal_Screenshot-AI_Writer_Split_Sentences](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Portal_Screenshot-AI_Writer_Split_Sentences.png)

---

### Split sentences with AI writer

**Category: AI features | Feature**

The new split sentence feature of the AI writer enhances content readability by intelligently splitting your complex sentences into smaller, more readable segments. This makes your content clearer and more engaging for readers, enhancing their reading experience.

> For more information, read the article on [**AI Writer**](/help/docs/ai-writer).

---

### Optimize search results

**Category:** Site Management **| Enhancement**

Improved search functionalities are introduced that offer more accurate and relevant search results. Enhancements include advanced search operators such as `" "`(double quotes) and `-` (hyphen), synonym support, and inclusion of stop words. These improvements help you to find the exact information you need, saving time and increasing productivity.

> For more information, read the article on [**Search functionality**](/help/docs/dedicated-search-page).

![Portal_Screenshot-Updated_Advanced_Search_enhancement](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Portal_Screenshot-Updated_Advanced_Search_enhancement.png)

---

### Customize PDF templates

**Category: Content tools | Feature**

Explore the updated PDF template features with extended character limits for titles and descriptions. Additionally, there are no character limits for Terms & conditions, offering greater flexibility in document creation. You can choose to display the path to the article/category as breadcrumbs in your PDF’s table of contents. You can also add a background image to the cover page, making your document look more personalized and professional when downloaded as a PDF.

> For more information, read the article on [**Designing a PDF template**](/help/docs/pdf-design-templates).

![1_advancedPDFtemplate](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_advancedPDFtemplate.png)

---

### Include page breaks in PDFs

**Category: Editor | Enhancement**

You can now insert page breaks between content elements in the knowledge base portal with the advanced WYSIWYG editor. With this feature, you can precisely control where content begins and ends on each page when exporting content in PDF format. These page breaks are only reflected in the exported PDF and not on the knowledge base site.

> For more information, read the article on [**Advanced WYSIWYG editor**](/help/docs/advanced-wysiwyg-editor).

![1_pagebreak](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_pagebreak.png)

---

### Receive notification for all comments

**Category: Editor | Enhancement**

Previously, contributors of an article in the Knowledge Base portal received notifications only when they were tagged in an inline comment on their article. With this enhancement, all contributors of the article will receive notifications for all inline comments on that specific article. This streamlines the review process, ensures prompt responses, and fosters collaboration by keeping the contributors informed.

> For more information, read the article on [**Reviewing an article using in-line comments**](/help/docs/reviewing-an-article-inline-comments).

![Portal-Screenshot-Enhanced_Comment_notification_system](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Portal-Screenshot-Enhanced_Comment_notification_system.png)

---

Note

Minor security updates, bug fixes, and performance improvements have also been implemented across the Knowledge base portal and Knowledge base site.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="may-2024-1042"></a>

## May 2024 - 10.4.2

The Document360 team is thrilled to introduce Document360 version 10.4.2. This release note showcases the details of the enhancements and the associated UI changes.

---

## Features/Enhancements

### Enhanced search relevance

**Category: Portal Management | Enhancement**

The search functionality has been enhanced to ensure more accurate and relevant search results. Inspired by extensive research, we've redesigned search to prioritize what matters most to you. The search results are now ranked based on title, tags, slug, breadcrumb, and content, delivering precise responses to your queries.

> For more information, read the article on [**Search in Knowledge base site**](/help/docs/dedicated-search-page).

---

### Inline code

**Category: Editor | UI/UX improvement**

Add code snippets to your article using the **Inline code** function by selecting the Inline Code icon (  ) in the Format section. Alternatively, you can perform this by using slash command or the keyboard shortcut **Ctrl + E**. In addition to the existing code block feature, you can now seamlessly integrate code within your content for better readability and comprehension.

> For more information, read the article on [**Advanced WYSIWYG editor**](/help/docs/advanced-wysiwyg-editor).

![3_Screenshot-inline_code_new_tool](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-inline_code_new_tool.png)

---

### Streamlined editing without emoji interruptions

**Category: Editor | UI/UX improvement**

We've enhanced the editing experience by eliminating interruptions caused by the emoji list that previously appeared when you pressed colon (:) while editing the article. You can still effortlessly insert emojis via the **Insert** (  ) > **Emoji** option located conveniently in the right menu of the Advanced WYSIWYG editor.

<a id="1041-release-note"></a>

## April 2024 - 10.4.1

The Document360 team is thrilled to introduce Document360 v10.4.1. This point release note showcases the details of the new feature and the associated UI changes.

---

## Features/Enhancements

### Eddy AI search analytics

**Category: Analytics | Feature**

Monitor and visualize user queries in Document360 including successful and unsuccessful searches with our new feature, Eddy AI search analytics. This insight enables you to refine and optimize your knowledge base, enhancing user support and satisfaction.

> For more information, read an extensive article on [Eddy AI search analytics](/help/docs/eddy-ai-search-analytics).

![1_Screenshot-New_feature_Eddy_search_analytics_](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-New_feature_Eddy_search_analytics_.png)

---

### Ask Eddy AI API

**Category: AI Features | Feature**

The Ask Eddy AI API is now open for public. You can use this API to seamlessly integrate the Ask Eddy AI functionality into your own applications, customize it to suit your needs, and ensure scalability to accommodate multiple users and systems simultaneously. You can access it from the project version as one of the API endpoints.

> For more information, read the article on [Perform AI assistive search within project version](https://apidocs.document360.com/v2-api/apidocs/perform-ai-assistive-search-ask-eddy-within-project-version).

---

Note

Minor security updates, bug fixes, and performance improvements can also be observed in the Knowledge base portal and Knowledge base site.

<a id="april-2024-minor-release"></a>

## April 2024 - Minor release

Document360 is back with another minor release this April 2024. Let's look at some enhancements and improvements to the Document360 knowledge base.

---

## New Feature(s)

### Multilingual support in the Document360 portal

Now you can explore Document360 not only in English but also in Spanish(es-ES) and Portuguese(pt-BR) as a beta release.

> Read the extensive article on [managing your language preferences](/help/docs/manage-your-language-preferences).

![1_Screenshot-Portal_Localization_mini_release](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Portal_Localization_mini_release.png)

---

<a id="march-2024"></a>

## March 2024

Document360 is back with another monthly release this March 2024. Let's look at some enhancements and improvements to the Document360 knowledge base.

---

## New feature(s)

### 1. Automated Business Glossary

The Automated Business Glossary is one of the Artificial Intelligence (AI) powered features in Document360. It fosters communication and collaboration by clarifying ambiguous terminology. It enables you to compile a list of business terms utilized within your organization, providing clarity and a shared understanding of potentially confusing terms.

![2_Screenshot-Automated_Business_glossary](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Automated_Business_glossary.png)

> Read the extensive article: Using the [Automated Business Glossary](/help/docs/automated-business-glossary)

---

## Enhancement

### UI Enhancement

Document360 2.0 introduces few minor tweaks to the Knowledge base portal with some significant User Interface (UI) enhancements. The latest design exhibits fluidic interactions, a simplified interface, and enhanced user experience.

> Read the extensive article: [UI Enhancement in Knowledge base portal](/help/docs/ui-enhancements)

---

### Feature enhancement

#### 1. Spell Checker:

We've implemented a spell checker in the markdown editor. Simply right-click on a word, and suggestions for corrections will be displayed through your browser's native functions. Click on the suggested correction to apply it as needed.

![5_Screenshot-Markdown_Spell_checker](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Markdown_Spell_checker.png)

---

#### 2. Customize site highlighter:

We've added a feature to highlight elements in the customize site as you click on them, enhancing user experience and making navigation easier.

![4_Screenshot-KB_customize_site_highlighting](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-KB_customize_site_highlighting.gif)

---

#### 3. JWT Filter in Analytics

We've introduced JWT Filters in the analytics section, allowing you to filter JWT readers for better insights and analysis.

![1_Screenshot-Adding_JWT_filters](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Adding_JWT_filters.png)

---

#### 4. Introducing second card payment

Now, you can add a second card in the payment billing section. The primary card is still used for billing, but if it runs out of funds or expires, the system will automatically use the second card for renewal.

> To read more, [Introducing second card payment](/help/docs/changing-payment-information)  
> ![3_Screenshot-Adding_secondary_card](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Adding_secondary_card.png)

---

#### 5. API Documentation

You can now allow your end users to choose multiple Content-type in the GET requests.

![6_Screenshot-API_Documentation](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-API_Documentation.png)

#### 6. Supporting the image percentage

In the Advance WYSIWYG editor, you can provide the inputs of the image in percentage for width and height.

![7_Screenshot-UpdatedImage_percentage](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-%28Updated%29Image_percentage.png)

---

## Improvements

Minor security updates, bug fixes, and performance improvements can also be observed in the Knowledge base portal and Knowledge base site.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="february-2024"></a>

## February 2024

Document360 is back with another monthly release this February 2024. Let's look at some enhancements and improvements to the Document360 knowledge base.

## Enhancements

### 1. Clone or move the articles/category across workspaces.

Now you can clone or move the articles and categories across workspaces.

#### **Clone the article and category**

All cloned articles are considered as New articles.

To experience this, from the Knowledge base portal → Click **•••** (more) option on the desired **category/article**, click the **Clone category**.

A **clone category** window pop-up appears.

1. **Category name:** Desired category name
2. **Workspace:** Select the desired workspace to clone
3. **Category:** Select the desired category or click **Reset** to assign it to the root category

Once done, click **Clone**.

![1_Screenshot-Cloning_the_category](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Cloning_the_category.png)

Security restrictions will be applied based on the destination workspaces / categories.

#### **Moving the article and Category**

1. From the Knowledge base portal, select any desired article, click ••• and **Move to**
2. The **Move article** window appears. Select the desired **workspace** and **category**.
3. Once done, click **Move**.

Security restrictions will be applied based on the destination workspaces / categories.

![2_Screenshot-moving_an_article](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-moving_an_article.png)

While moving, the article status will be the same. Similarly, you can move the category too.

### 2. AI Writer (Eddy AI) - Convert into table

Harness the power of Document360's AI Eddy AI to convert the text into table form.  
Go to the Advanced WYSIWYG editor, select the desired texts, and click **Eddy AI → Convert into table**. Click **Replace** to implement the generated tabular data.

![3_Screen_GIF-AI_Writer_Convert_into_table](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screen_GIF-AI_Writer_Convert_into_table.gif)

### 3. Securing Knowledge base widget authentication using JWT

Now, you can implement an authentication configuration for the widget using JWT, ensuring a secure environment for private and mixed projects.

Navigate to the **Knowledge Base widget**. Select the desired **widget** and configure JWT for your project.

![4_Screenshot-JWT_for_the_Knowledge_base_widget_authentication](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-JWT_for_the_Knowledge_base_widget_authentication.png)

### 4. API Documentation

We added new endpoints in our customer API Drive operations in Document360. These endpoints empower you to perform various actions seamlessly within your Document360 account. The summary of the newly added endpoints is

| Action | Endpoint |
| --- | --- |
| GET | Gets folder information by folder ID |
| GET | Gets file information |
| GET | Drive search - files and folders |
| GET | Get status of the delete file operation |
| GET | Get all media files inserted in the article |
| GET | Gets folders information |
| POST | Add new folder in drive |
| POST | Add file in to drive |
| POST | Add tags in a file using file ID |
| POST | Delete tags from files |
| POST | Copy file from one folder to another |
| PUT | Move a file with file ID |
| PUT | Update a folder with ID |
| DELETE | Delete a folder |
| DELETE | Delete file using file ID |

File size limit for import

You can import the maximum file size is **40MB** per file.

## Improvements

Minor security updates, bug fixes, and performance improvements can also be observed in the Knowledge base portal and site.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

A feature in Document360 that enables users to create independent environments for managing different sets of documentation, such as separate versions or product iterations.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

<a id="january-2024"></a>

## January 2024

Document360 is back with another monthly release this January 2024. Let's look at some enhancements and improvements to the Document360 Knowledge base.

---

## Enhancements

### 1. AI writer (Eddy AI)

#### Convert speech

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image%28111%29.png)

Harness the power of Document360's AI Eddy AI to change the selected text from

* **Direct speech to Indirect speech**  
  (or)
* **Indirect speech to Direct speech**  
  Select the intended text in the Advanced WYSIWYG editor, click **"Eddy AI" > "Convert speech"** in the floating menu, and choose the speech conversion required.

#### Improve it

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image%28112%29.png)

This AI option enhances the quality of the selected content and improves attributes such as

* Grammar
* Semantics
* Clarity
* Phrase structuring
* and more

Select the intended text in the Advanced WYSIWYG editor, click **"Eddy AI" > "Improve it"** in the floating menu.

### 2. Unified search across regular and API workspaces

Now Knowledge base site readers can use the search option to search across multiple available workspaces and API workspaces. You can find a tab "API endpoints" in the same search result window.

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image%28114%29.png)

To enable this feature in "Advanced search," navigate to **Settings > Knowledge base portal > Article settings & SEO > Article settings > Search settings**. Turn on the "Enable advanced search" toggle and check the "Include all workspaces in search" checkbox.

### 3. Quick product support - Issues/Clarifications

A new way to seek Document360's support from your Knowledge base portal. Click on the "Help" icon at the top-left and select "Issue/Clarification" to launch the support request widget in one click.

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image%28117%29.png)

---

## Improvements

* One of the most requested "Insert link" keyboard shortcut is added to the Advanced WYSIWYG editor. Press "**Ctrl + K**" to launch the Insert link pop-up

* Minor security updates, bug fixes, and performance improvements can also be observed in the Knowledge base portal and site.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

The public-facing website where end-users can access articles and find answers to their questions.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="december-2023"></a>

## December 2023

Document360 is back with another monthly release this December 2023. Due to the holiday season, we have moved up our release date from the last week. Let's look at some enhancements and improvements to the Document360 Knowledge base.

---

## Enhancements

### 1. AI Writer -Outline creation

When the author types in a prompt to create a content outline on a specific topic, the "Eddy AI" AI acts similar to other AI content generation platforms and creates an elaborate outline on the mentioned topic with headings and brief abstracts. " You can use the Keyboard shortcut "**Ctrl + Spacebar**" to launch the Eddy AI input.

![1_Screenshot-AI_writer_outline_creation](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-AI_writer_outline_creation.png)

### 2. Reintroducing "Advanced WYSIWYG editor"

We have renamed the "Block editor" to "Advanced WYSIWYG editor" (What You See Is What You Get). The change can be observed in the Knowledge base portal.

![2_Screenshot-Advanced_WYSIWYG_editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Advanced_WYSIWYG_editor.png)

---

## Improvements

Minor security updates, bug fixes, and performance improvements can also be observed in the Knowledge base portal and site.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="november-2023"></a>

## November 2023

Document360 is back with another monthly release this November 2023. Let's look at some enhancements and improvements to the Document360 Knowledge base.

---

## Enhancements

### 1. API Documentation

* API documentation is available as an option in the Backup & Restore section of your project
* Recycle bin is now added for the API documentation project, where users can restore deleted categories and articles
* Earlier, the "Try it" module was only when the server variable was defined "Globally" (Specified next to the "Info" object in the specification file). With the recent enhancement, the "Try it" module is available even if the server variable is mentioned at an endpoint level

### 2. Image formatting - Block editor

We have enhanced the image formatting functionality in the Block editor tool. You can now crop the image with ease using the crop option.  
![1_Screenshot-Block_editor_image_controls](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Block_editor_image_controls.png)

### 3. Custom domain mapping - TXT record no longer required

In the earlier implementation, when you map your custom domain to the Document360 project, CNAME and TXT records will be necessary. As an enhancement, any new domain mapping or editing of an existing mapping only requires CNAME.  
 Read our [**Custom domain mapping**](/help/docs/custom-domain) help article to know more.

### 4. Introduction of Premium support for Document360

All new Document360 customer can avail of Document360's premium support for their project at a nominal price. You can purchase this support addon from the Knowledge base portal's Billing section or by clicking on the promotional banners that appear within the product.

With this offering, you’ll enjoy priority access to expedited support service and response times, ensuring your issues are addressed promptly. Document360 will allocate a dedicated support expert to work closely with you to provide personalized guidance.

For more information on the Premium support, please go through the [**Document360's pricing page**.](https://document360.com/support/#d360-support)

### 5. Other improvements

Minor security updates, bug fixes, and performance improvements can also be observed in the Knowledge base portal and site.

Application Programming Interface - A set of rules that allows one software application to communicate with another.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="august-3"></a>

## August 2023

## Enhancements

### 1. API Documentation

Earlier, the Document360 API documentation tool supported just OpenAPI specification files. From this release, Document360 supports OpenAPI and Postman specification files.

#### Postman specification file

* The Postman specification file should be less than 15 MB
* Only "Basic auth" and "Bearer token" are the supported authorizations in the specification file
* You can upload other authorization files, but then you cannot send requests or use the "Try it" feature

#### OpenAPI specification file

* Document360 now supports anyOf and oneOf in the OpenAPI specification files

---

### 2. Zendesk extension

We have enhanced the Document360 integration on Zendesk with a new look, feel, and more options.

#### What's new

Here is the list of new enhancements compared with the previous integration (Document360 app in the Zendesk window)

* Project workspace and language selection are available at the top
* The Project name is displayed in full and not truncated
* Document360's brand color and styling is observed
* The "Open in Knowledge base" option is moved next to the article title
* Users can create root-level categories and subcategories on the Knowledge base from Zendesk
* If the search did not bring up any results, the "Create a new article" option is displayed
* The article creation module is similar to the Document360 portal interface
* When you link an article in a response chat, a "Linked" label appears next to the article
* The "last updated date" information is now visible in the article
* The Document360 quick-access icon is available in the Zendesk reply section's toolbar

---

### 3. New Document360 (2.0 Design)

Here are some enhancements in the new Document360

#### Analytics

* The "Export as CSV" option is now available on all the "Analytics" modules

#### Editor

* A new look and feel to the menus and tools in the Block editor
* Article settings menus (right side of the window) are now moved to the top of the editor
* Discussions are available at the top next to the "Settings" icon
* Article information such as contributors, attributes, and word count is available when you click on the "i" (Article information) icon next to the article title
* Adding article description is moved next to the article title
* Article analytics, Health check metrics, and Revision history moved inside the "More options" next to the Publish/Edit button at the top

#### Others

* The "Export to PDF" option is now available on articles
* "Configure article settings" added to the publish module. The options available when you expand this section are Tags, SEO description, Related articles, and Status indicator

---

## Improvements

Minor security updates, bug fixes, and performance improvements can also be observed in the Knowledge base portal and Knowledge base site.

<a id="july-2"></a>

## July 2023

## Enhancements

### Import & Export project

We have enhanced the Import and Export functionality by optimizing the project file export. All the new project exports generated can be seamlessly imported to Document360.  If you need to import old project ZIP files exported before **August 12, 2023**, our Document360 support team is here to assist you.

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image%2849%29.png)

Another notable update is that if your Drive capacity utilization exceeds **1 GB**, the "Include media files" option in your export is deactivated. Should you wish to export files larger than 1 GB, please get in touch with Document360 support.

> Kindly contact the [**Document360 support**](mailto:support@document360.com) for further assistance.

  

NOTE

Read the [**Import & Export project**](/help/docs/export-as-zip) help article for more information.

---

## Announcement

### 🎉 Exciting news: Introducing Document360's fresh new look!

We are thrilled to reveal our revamped design and UI for Document360. Get ready for an optimized user experience, sleek navigation flow, and a fresh portal feel.

![1_Screenshot-New_UI_mockup](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-New_UI_mockup.png)

Currently available for customers in all pricing tiers (Standard, Professional, Business, Enterprise and above). Switch between the old and new UI using the toggle at the top of your screen. We invite you to explore the new UI, provide feedback, and shape the Document360 platform.

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image%2850%29.png)

Enjoy the sneak peek into the beta testing phase as we fine-tune the new UI based on your valuable input. Stay tuned for the official launch of the new Document360 in the upcoming months.

### Analytics UI - Enhancement

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image%2851%29.png)

We have introduced a new interface to view and manage your Knowledge base analytics. You can enjoy the updated design with a small catch. Data older than **July 8, 2023,** is not accessible in the New Document360 Analytics, and the option to export data is temporarily unavailable.

![image.png](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image%2852%29.png)

#### What's new!

* You can observe a slight difference in the "**Reads**" and "**Views**" metrics when you switch between the old and the new UI. We have recalibrated the calculation logic for these metrics
* The "**Geography**" and "**Performance**" metrics have been merged and enhanced as a new section called "**Articles**"
* A redefined and elaborate "**Feedback**" section which redirects you to the "Feedback manager" to respond to feedback
* A simplified redesign of the "**Ticket deflector**" tabs
* Overall enhancement of design elements like charts, graphs, and colors

---

### 🚀 Introducing the Document360 "Startup program!" 🚀

![](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/StartUpWithUsGIF.gif)

Unlock incredible discounts with our all-new Startup Program! If your company

* Is **under three years old**
* Has **fewer than 20 employees**
* Not a past or existing customer

Exclusive pricing discount available for Document360's "**Standard**, **Professional**, and **Business**" plans. This offer is valid for your first-year subscription

[![2_Screenshot-New_startup_plan](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-New_startup_plan.png)](https://document360.com/pricing/)

Reach out to our team today to see if you qualify and grab this fantastic opportunity!

[**Explore the "Startup program" ->**](https://document360.com/pricing/)

---

## Improvements

Minor security updates, bug fixes, and performance improvements can also be observed in the Knowledge base portal and Knowledge base site.

<a id="june-3"></a>

## June 2023

## Enhancement

### API Documentation: New API hub command

We have added a new command `apihub:validate` to the existing `apihub` and `apihub:resync` in the D360 NPM package. With the new '**apidocs:validate**' command, you can validate your OAS (OpenAPI Specification) file.

---

## Improvements

#### 1. Insert multiple images in one go

Earlier, you could select and insert one image at a time using the **Insert images > From file picker**. With the new improvement, you can pick and add multiple images using the 'Insert image' tool. This improvement is available in Markdown and Block editor in the article and template module.

#### 2. Other improvements

Minor security updates, bug fixes, and performance improvements can also be observed in the Knowledge base portal and Knowledge base site.

<a id="may-1"></a>

## May 2023

## New Features

### 1. Article title recommender (AI-powered)

The Article title recommender is one of the Artificial Intelligence (AI) powered features in Document360. You can use the title recommender feature when naming or renaming your articles. The feature suggests three titles by assessing the article content and consumes one credit for one article title generation. The **Suggest title** option can be found in the article title section in the editor.

![Screenshot_1-AI_title_recommender_button](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot_1-AI_title_recommender_button.png)

The title recommendation feature is available across all subscription tiers with specific credit limits.  As a prerequisite this feature requires a preprocessed word count of 50 words in the article to generate and recommend titles.

> Read the extensive article: [Using the 'Article title recommender'](/help/docs/ai-title-recommender-for-articles)

---

### 2. Article summarizer (AI-powered)

The Article summarizer is also one of the Artificial Intelligence (AI) powered features in Document360. This feature is useful when the reader does not want to read through a lengthy article. This feature consumes one credit for one article summary.

![Screenshot_2-Article_summarizer_KB_site_view](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot_2-Article_summarizer_KB_site_view.png)

The article summarizer assesses the article content and creates a relative summary of the article in the article's top section for readers. The article summarizer is available across all subscription tiers with specific credit limits. As a prerequisite this feature requires a preprocessed word count of 250 words in the article to generate a summary.

> Read the extensive article: [Understanding the 'Article summarizer'](/help/docs/article-summarizer)

  

NOTE

The **credits** used for article title recommender and article summarizer are two different standalone limits.

---

## Enhancements

### 1. IPv6 supported in IP restrictions

Earlier, only Internet Protocol version 4 (IPv4) was supported in IP restrictions in Document360. From this release Document360  supports **IPv4** and **IPv6** in two modules of the Knowledge base portal

* **Exclude in Analytics**

  > (Settings > Knowledge base portal > General > Analytics (tab) > New IP restriction)
* **Site access IP restriction**

  > (Settings > Users & security > IP restriction > New IP restriction).

---

### 2. SSO login with subdomain

Earlier SSO users in your Document360 could only log in using their Email domains. From this release, SSO users can use their subdomain (default choice) or email domain to single sign on to the Document360 projects.

![Screenshot_1-SSO_updated_login _screen](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Screenshot_1-SSO_updated_login%20_screen.png)

This change is visible in the SSO login screens, where you can use the subdomain or email credentials for authentication. The 'Email domain' field in the **SAML/OpenID basic configuration** section is now optional.

This restriction removal allows a single email domain to be configured for SSO in multiple Document360 projects. However, if you want to be able to view all your project associations as an SSO team account/reader, you have to 'Allow' the domain

> **Note**: The subdomain can also be used to log in for the projects using a custom domain configuration.

---

### 3. Spec file import in the API documentation

Import of 'Specification file' is now supported in the Document360 API documentation tool. Earlier, you could not directly import a spec file; you could only use the URL method.

---

## Improvements

### 1. Extensions - Multi-region support

The following extension is now available for US data center projects. Earlier, this extension was available only for EU data center projects.

* [**Intercom**](/help/docs/intercom-integration)

### 2. Other improvements

* **Mangolian** (**mn**) is now available in the list of languages for Document360 localization
* Minor security updates, bug fixes, and performance improvements can also be observed in the Knowledge base portal and Knowledge base site.

<a id="april-3"></a>

## April 2023

## New feature

### Block editor

We are introducing an all-new editor apart from the two existing editors available (Markdown and WYSIWYG) .

NOTE

The new 'Block editor' is available for all **new customers** and all **new projects** (existing customers). For existing customers/projects, you can expect a rollout of the new editor at the earliest.

The 'Block editor' is hybrid, lightweight, and powerful, with rich text editing capabilities and supports Markdown syntax. It provides a more visual and intuitive experience than the Markdown editor while still being more flexible than the WYSIWYG editor.

You can switch to the new editor from the right-side menu,  **Article settings > Editor**

> Read the extensive article: [**Block editor - Getting started**](/help/docs/block-editor)

---

## UI/UX updates

### "Version"  renamed as "Workspace"

The project "**Version**" has now been renamed as "**Workspace**". This change can be observed in the Knowledge base portal modules.

### "Assistant" renamed as "Widget"

The "**Knowledge base assistant**" has now been renamed as "**Knowledge base widget**". This change can be observed in the 'Settings' and few other modules in the Knowledge base portal.

---

## Enhancement

### 1. API Documentation

#### CI/CD flow in the API documentation

We have added CI/CD flow as a source type in the API documentation. This helps you to resync the spec file without manual effort seamlessly.

> Read the extensive article: [**Generate API documentation with CI/CD flow**](/help/docs/how-to-upload-api-specification-file#how-to-generate-api-documentation-with-cicd-flow)

#### API reference endpoints

API Reference endpoints can now be accessed to perform basic API Documentation functionalities.

---

### 2. Localization

#### Default language selection

Earlier, 'English' was the default language in a workspace, and you cannot change this setting. Now we have introduced the option to set any language as a default language. In your Document360 project's Knowledge base portal go to **Settings > Knowledge base portal > Localization & Workspaces**, and click on the edit icon next to the Workspace. In the available languages, click the ••• option and select "**Set as default**".

#### New languages added

We have added four more languages to the localization and translation feature of Document360.

| Language | Code |
| --- | --- |
| Bulgarian | bg |
| Hungarian | hu |
| Lithuanian | lt |
| Slovenian | sl |
| Turkish | tr |

---

### 3. IdP initiated Single Sign-On (SSO)

Identity Provider (IdP) initiated login is now available for the SAML configuration on Document360. You can enable the "Allow IdP initiated login" toggle from the Knowledge base portal on **Settings > Users & Security > SAML / OpenID > SAML > SAML basic configuration**.

The IdP supported by Document360 for SAML configurations is **Okta**, **Auth0**, and **Azure AD**.  
 An exclusive **IdP initiated sign-on URL** is obtained from the IdP and shared with the SSO users. The SSO users can use the link to log in to the Identity Provider's dashboard, select the configured projects, and access Document360 directly.

> Read the extensive article: [**IdP initiated login**](/help/docs/idp-initiated-login)

---

## Improvements

### 1. Extensions - Multi-region support

The following extension is now available for US data center projects. Earlier, this extension was available only for EU data center projects.

* [**Drift**](/help/docs/drift)

### 2. Other improvements

Minor performance updates, bug fixes, and security improvements can also be observed in the Knowledge base portal and Knowledge base site.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

<a id="march-4"></a>

## March 2023

## Improvements

### 1. Version slug

Now you can update the slug of a project version. This field was previously limited to updates, but now you have complete control. You can also set a redirect rule for the slug changes, as the version slug is an essential element for SEO.

[**Read more →**](/docs/versioning-getting-started#how-to-update-the-version-slug)

---

### 2. URL mapping

We have added a new option, **Settings - URL mapping** in the "Installation & setup" of the Knowledge base assistant settings. This option allows you to define the Knowledge base assistant behavior for URLs that do not have mapping configured. You can display the last opened article/category (or) Page help/Knowledge base tabs in the assistant.  
![6_Screenshot-KB_assistant_settings](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-KB_assistant_settings.png)[**Read more →**](/docs/url-mapping#settings-url-mapping)

---

### 3. Localization languages

We have added the following languages in the localization module:

* Afrikaans [af]
* Arabic (Egypt) [ar-eg]
* Chinese (Simplified, People's Republic of China) [zh-cn]
* Chinese (Traditional, Taiwan) [zh-tw]
* Filipino [fil]
* Georgian [ka]
* Portuguese (Brazil) [pt-br]

---

### Other improvements

Minor performance, bug fixes, and security improvements can also be observed in the Knowledge base portal and Knowledge base site.

The practice of optimizing content to improve its visibility in search engine results and attract organic traffic. In Document360, Search Engine Optimization (SEO) elements can be added for each article through the article settings.

A widget that allows users to search for and find answers from your knowledge base directly within your site or application, without navigating away.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The public-facing website where end-users can access articles and find answers to their questions.

<a id="february-3"></a>

## February 2023

## New features

### 1. API documentation

Document360 now offers the **API documentation** feature, which provides a complete solution for creating and managing your **API references**. This feature makes your API documentation comprehensive, well-structured, and easy to navigate.

The all-important "Try it" option is also available to perform the actions within the Knowledge base site. Check our [supported authorization techniques](https://docs.document360.com/help/docs/try-it#supported-authorization-techniques).  
![1_Screenshot-API_documentation_module](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-API_documentation_module.png)

Dedicated versions of your API documentation can be easily created and managed. This feature provides an intuitive interface for uploading API specification files as URLs, JSON files, and YAML files. You can generate code samples with the available programming languages to help users understand how to use the API. The users can view the responses in a most organized way.

[**Read more →**](/docs/api-documentation-getting-started)

### 2. AI Tag recommender

The AI-powered Tag recommender is now available in Document360. With this feature, you can generate relevant Tags based on the article content. This feature helps to categorize the articles more accurately and improve the searchability of the relevant articles in the Knowledge base. It will also save time for Team accounts who needs assistance in figuring out appropriate tags for the article content.  
![1_Screenshot-AI_tag_recommender](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-AI_tag_recommender.png)

* Go to the desired article in the Knowledge base portal
* Click **Article settings** and expand **Tags**
* You can find the **Tags recommended** section

[**Read more →**](/help/docs/ai-tag-recommender)

### 3. Content Security Policy (CSP)

We have added the CSP (Content Security Policy) to enhance the security of your Knowledge base. CSP helps to manage and prevent the external CSS, scripts, and frames embedded in your Knowledge base.

This feature uses the `Content-Security-Policy` response header to restrict the resource loading from external domains and allow resources only from the configured list of domains for each source.  
![1_Screenshot_Content_security_policy](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot_Content_security_policy.png)

* Go to **Settings** → **Users & Security** → **Security**
* Turn on the **Enable content security policy** toggle
* You can find the following source fields:

  + Style source
  + Script source
  + Frame source
* Type in the desired domain URLs in the respective fields
* Click **Save**

[**Read more →**](/help/docs/content-security-policy)

---

## Improvements

### 1. 'Installed domains' in the Knowledge base assistant

Now you can view the domains in which your Knowledge base assistant has been embedded. This information helps you track and manage the embedded assistants effectively.  
 To view the installed domains:

* Go to **Settings** → **Knowledge base assistant** → **Setup configuration**
* Hover over the desired Knowledge base assistant and click **Edit**
* In the **Installation & Setup** tab, expand the **Installed domains**
* You can find the domains in which the respective Knowledge base assistant has been embedded

### 2. Cache mechanism

The cache mechanism has been implemented for the Knowledge base site of the public projects. With this improvement, the changes made in the Knowledge base portal can take up to 15 minutes to reflect on the Knowledge base site of the public projects.

### 3. Make extension

Make extension is now available for US data center projects. Earlier, it was available only for EU data center projects.

### 4. Custom language in code blocks

We have added a new option, "Custom" in the language list of code blocks. With this option, you can add the desired language title for the code block. This option is available only in the WYSIWYG editor.

[**Read more →**](/docs/code-blocks#creating-code-blocks-in-wysiwyghtml)

### 5. Other improvements

Minor performance, bug fixes, and security improvements can also be observed in the knowledge base portal and site.

The public-facing website where end-users can access articles and find answers to their questions.

<a id="january-2"></a>

## January 2023

## New features

### 1. Sandbox

Now you can create a Sandbox project to test and experiment with the features, configurations, and integrations without affecting your live projects.

The Sandbox project comes with a 14 days trial period. Team accounts associated with a paid project can create the Sandbox project.  
![1_Screenshot-New_Sandbox_button](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-New_Sandbox_button.png)

1. Go to the [project dashboard](https://portal.document360.io/)
2. Click **New Sandbox** at the top right
3. Follow the instructions that appear in the window

[**Read more →**](/docs/creating-a-sandbox-project)

### 2. X-Frame options

The X-Frame feature allows you to control whether your Knowledge base can be embedded in an iframe on other domains. This feature provides an additional layer of security by preventing malicious websites from embedding your Knowledge base in an iframe.  
![1_Screenshot-XFrame_options](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-XFrame_options.png)

1. Go to **Settings** → **Users & Security** → **Security**
2. Turn on the **Enable X-Frame options** toggle

NOTE

The toggle is disabled for projects created before January 28, 2023. It is enabled for projects created after January 28, 2023. You can change the setting as needed.

[**Read more →**](/docs/x-frame-options)

---

## Enhancement

### Single Sign-On

The Enterprise SSO module has been split to provide more flexibility in your configuration. Now you can have one of the SAML and OpenID configurations and also configure JWT at the same time. This enhancement allows for separate SSO configurations for your team accounts and readers.  Earlier, you could only configure one of the three available SSO configurations (SAML, OpenID, or JWT).

> **For example**, you can configure SAML for your SSO team accounts and JWT for SSO readers.

[**Read more →**](/docs/enterprise-sso)

---

## Improvements

### 1. Team account idle timeout

Now you can set the desired time duration in the Team account idle timeout section of SSO configuration. The default value is 2 hours.

[**Read more →**](/docs/team-account-idle-timeout)

### 2. Export - Performance Analytics

The export to CSV option is now available for Performance analytics data. The following data can be exported as a CSV file:

* Leading Contributors
* Leading Articles
* Leading Categories
* Countries

[**Read more →**](/docs/analytics-performance#export-data)

### 3. Knowledge base assistant

The Knowledge base assistant will now open in the language of your browser by default. Earlier, it would open in the default language of your Knowledge base. This improvement will enhance the user experience.

---

### UI/UX improvements

* A new module "Security" has been added in the Users & Security (Settings). The X-Frame options section is now available in Security. You can find more settings related to the Knowledge base site in the upcoming releases  
  ![2_Screenshot-Security_X_Frame_options](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Security_X_Frame_options.png)
* The Enterprise SSO is split into two modules: SAML/OpenID and JWT. You can find this module in the Users & Security (Settings)  
  ![1_Screenshot-Enterprise_SSO_Split](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Enterprise_SSO_Split.png)

---

### Other improvements

Minor performance, bug fixes, and security improvements can also be observed in the Knowledge base portal and Knowledge base site.

An online library where users can find information about a product, service, department, or topic. It helps users self-serve by providing answers and guidance.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The public-facing website where end-users can access articles and find answers to their questions.

<a id="december-2022-release-note"></a>

## December 2022

## New feature

### Multiple Knowledge base assistants

Earlier, you can configure only one Knowledge base assistant in a project. Now you can have up to **10** Knowledge base assistants in a project. We have made the UI simpler to configure the following settings in one place:

* Installation & setup
* Custom CSS
* Custom JavaScript
* URL mapping

The autosave option is available for navigation between the tabs. You can also clone an existing assistant and create a new Knowledge base assistant.

![1_Screenshot-Multiple_KB_assistant](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Multiple_KB_assistant.png)

[**Read more →**](/docs/knowledge-base-assistant-getting-started)

---

## Enhancements

### 1. No search results feedback

A search that does not return an article within the Knowledge base or Knowledge base assistant will return a feedback form. This option enables the readers to provide detailed feedback on their search. Team accounts can view the feedback data in the **Search analytics** module.

#### To enable the feedback form:

![12_Screenshot-No_search_feedback_setting](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/12_Screenshot-No_search_feedback_setting.png)

1. Go to **Settings** → **Knowledge base site** → **Article settings & SEO** → **Article settings**
2. Under **Search settings**, you can find the **No search result feedback** toggle
3. Switch it to **On**

[**Read more →**](/docs/dedicated-search-page#no-search-result)

---

### 2. Custom configuration for Analytics Integrations

**Custom configuration** section is added in Integrations related to Analytics. With this section, you can customize your Knowledge base integration with an external analytics platform in one window. Previously, you would have used Custom HTML integration to configure code-specific settings. The following integrations will have the custom configuration section:

* [Mixpanel](/docs/mixpanel)
* [Segment](/docs/segment-integration)
* [Hotjar](/docs/hotjar)
* [Google Analytics](/docs/google-analytics-integration)
* [Google Analytics (GA4)](/docs/google-analytics-new)
* [Heap](/docs/heap)
* [FullStory](/docs/fullstory)
* [Amplitude](/docs/amplitude)
* [Google Tag Manager](/docs/google-tag-manager)

![1_Screenshot-Custom_configuration_UI](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Custom_configuration_UI.png)

---

## Improvements

### 1. Auto register for SSO readers

Earlier, Single Sign-On (SSO) readers had to be registered with both identity providers and Document360. Now, readers that are registered with the identity provider don't need to register in Document360. They can directly access the Knowledge base with the identity provider credentials. You can enable/disable this option in SSO settings. This setting is applicable only for SAML and OpenID configurations.

When you have multiple projects and wish to have the same configuration, you can import the logged-in SSO readers from one project to the other with this option.

[**Read more →**](/docs/auto-register-for-sso-readers)

---

### 2. Team account idle timeout

Enable the 'Team account idle timeout' option in your project to log out the SSO team accounts that are idle for two hours. This setting is applicable only for SAML and OpenID configurations.  
[**Read more →**](/docs/team-account-idle-timeout)

---

### Other improvements

Minor performance upgrades, bug fixes, and security improvements can also be observed in the Knowledge base portal and Knowledge base site.

A widget that allows users to search for and find answers from your knowledge base directly within your site or application, without navigating away.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The public-facing website where end-users can access articles and find answers to their questions.

<a id="november-2022-release-note"></a>

## November 2022

## New feature

### Find and replace

Now you can search for any text/phrase and replace it across the Knowledge base project in one place. Use this feature when you update any keyword/phrase in multiple instances (articles/category pages) in your knowledge base.

> **Note**: This feature applies only to the article and category page content.

![1_Screenshot-Accessing_Find_and_replace](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Accessing_Find_and_replace.png)

1. Go to **Content tools** → **Documentation** → **Find and replace**
2. Enter the search keyword/phrase in the **Find** field
3. **Select** the articles and category pages in which you want to replace
4. Enter the desired keyword/phrase you want to replace in the **Replace with** field
5. Click **Replace**
6. Select the desired article status after replace and click **Proceed**

You can also utilize the Match whole words and below filter options to narrow down the search results:

* Version/Language
* Visibility
* Status
* Contributors
* Tags
* Updated on

[**Read more →**](/docs/find-and-replace)

---

## Improvements

### UI/UX improvements

#### Context menu consistency

Consistency across the context menus in the **Documentation** module is addressed. The context menus of the article, category, starred, and category manager is made consistent now.

---

#### Open the article/category in a new tab

Now you can open articles and categories in a new tab from the Knowledge base portal. This improvement helps you open the articles/categories in multiple browser tabs and perform a comparison, copy, and paste of the content effectively. Earlier, this option was unavailable for the articles and categories.

---

### Other improvements

Minor performance, bug fixes, and security improvements can also be observed in the Knowledge base portal and Knowledge base site.

An online library where users can find information about a product, service, department, or topic. It helps users self-serve by providing answers and guidance.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The public-facing website where end-users can access articles and find answers to their questions.

<a id="october-2022-release-note"></a>

## October 2022

## New feature

### Health check metrics

There are some great insights in this feature about the article's health. This feature is available only for articles and category pages of the English language.  
![2_Screenshot-Health_check_metrics_UI](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Health_check_metrics_UI.png)

1. Go to the desired article in the Documentation
2. Click **Health check metrics**  
    It has two sections: SEO metrics and Readability metrics.

NOTE

If you update any parameter with the 'Health check metrics blade' open, click **Check now** to view the insights of the latest changes.

* **SEO metrics** shows the insights of the article's SEO metrics. This metric help assess the parameters such as

  + Meta title length
  + Meta description length
  + External links
  + Internal links
  + Featured image.
* **Readability metrics** shows the insights on the article's readability. This metric help assess the parameters such as

  + Readability score
  + Paragraph length
  + Sentence length
  + Sub-heading distribution.

Based on the optimal condition, each parameter will be narrowed down under one of the following sections:

* **Problems**
* **Suggestions**
* **Good work**

Every writer would love this feature as it saves time checking the article metrics. Not just writers but the SEO team in your organization can also benefit from the SEO metrics. With the easy navigation for adding/updating meta titles, meta descriptions, and featured images, you can swiftly jump into the respective sections.

[**Read more →**](/docs/health-check-metrics)

---

## Improvement

### Bulk operations

Earlier, you could view only 200 articles on the bulk operations page. Now, you can view all the articles available in the selected version/language. This improvement helps you perform actions in the desired articles without hassle.

![1_Screenshot-Bulk_operations_UI_change](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Bulk_operations_UI_change.png)

---

### Other improvements

Minor performance, bug fixes, and security improvements can also be observed in the Knowledge base portal and Knowledge base site.

The platform where project members manage and create content for the knowledge base. It allows users to create categories, articles, and templates; manage files, team accounts, and readers; and configure site settings such as branding, domain, and security.

The public-facing website where end-users can access articles and find answers to their questions.

<a id="september-2022-release-note"></a>

## September 2022

## New feature

### Bubble up status

Earlier, readers had to open the category to view the articles with the New, Updated, Custom, or Deprecated article status. To view the latest articles in the knowledge base, readers would go to the 'What's New' page. However, there is no article status indicator on that page which leads the users to navigate to the article to find its status (New/Updated/Custom/Deprecated).

With the Bubble up status, readers can view which categories have been updated with the latest articles. The count of the articles with New, Updated, Custom, and Deprecated article status appears next to the category name. This feature helps you to notify the readers about new and updated articles in each category.

To enable the Bubble up status indicator:

> * Go to **Settings** → **Knowledge base site** → **Article settings & SEO** → **Article settings**
> * Under the **Category manager** section, enable the **Show bubble up status** to On

[**Read more →**](https://docs.document360.com/docs/knowledge-base-category-manager#bubble-up-status)

---

## New extension

### Make

The integration tool **Make** is available as an extension on your Document360 knowledge base portal. This integration allows you to connect and integrate multiple cloud apps and services. The Scenarios help automate your tasks in the background and automate certain workflows. You can easily create a Scenario (workflows that connect your app): choose a trigger for the workflow to activate and then choose a response action. This opens new possibilities and hundreds of possible use cases.

> Go to **Settings** → **Knowledge base portal** → **Extensions** → **Team collaboration**

[**Read more →**](https://docs.document360.com/docs/make-setup-guide)

---

## Enhancements

### 1. Glossary

* [**Export glossary**](/v3/docs/exporting-glossary) option has been added. So you can export the glossary data as a CSV file that contains the following information: Term name, Definition, Dependencies, Updated on, and Updated by.
* Earlier glossary terms were not highlighted in the Knowledge base assistant. Now users can experience the glossary terms in **knowledge base assistant** just like you do in the knowledge base site.
* **Importing images** in the definition is made available. Add image tag URLs in the definition field and import the glossary.

[**Read more →**](https://docs.document360.com/docs/import-glossary)

### 2. Convert regular Document360 account to SSO account

Previously, there was no option to convert a regular Document360 account to an SSO account directly. You must replicate the roles and access permissions correctly, even if you take a tricky workaround of deleting the Document360 account and adding a new SSO account.

With the **Convert to SSO** option, you can seamlessly convert the Document360 account(s) to SSO account(s) without changing the roles and access. This option would reduce your efforts in team account/reader conversion.

[**Read more →**](https://docs.document360.com/docs/convert-to-sso-account)

### 3. Translation in bulk operations for published articles

Earlier translation in bulk operations was available only for articles in New article and Draft status. You would spend considerable time in manual translation to perform translation for the published.

Now you can perform translation for the published articles in just a few clicks. So there is no restriction for translation in bulk operations concerning article status.

[**Read more →**](https://docs.document360.com/docs/translation-option-with-bulk-operations)

---

## Improvements

### 1. Team auditing

* Now, you can export the team auditing data as a CSV file
* A new section 'Users & security' has been added on the Audit configuration page
* The filters available on the Team auditing page have been revamped to enhance the user experience
* Now, you can search for the desired events, which have been placed in alphabetical order.

### 2. SEO description generator

* SEO description generator clicks have been renamed as **credits**. The credits available on your billing page are not to be confused with the SEO description generator credits
* Meta management tab available in 'Settings → Knowledge base site → SEO' has been renamed and moved into Content tools → Documentation as **SEO description**
* 'Article settings' & 'SEO' has been merged under **Article settings & SEO**. It has two tabs:

  + **Article settings**: Settings related to individual articles will be available here
  + **SEO**: SEO settings such as **Robots.txt** and **Sitemap** will be available here

### Other improvements

Minor performance, bug fixes, and security improvement can also be observed in the knowledge base portal and site.

<a id="august-2022-release-note"></a>

## August 2022

## New features

### 1. Glossary

Enhance your knowledge base by adding the glossary to help readers understand the terms(word/phrase/acronym/abbreviation) frequently used in articles. A dotted line highlights glossary terms so readers can hover over them with their mouse pointer to view their definitions. You can effortlessly import glossary terms in bulk with the Import glossary option.

> Go to **Content tools** → **Content reuse** → **Glossary**

![1_Screenshot-Glossary_overview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Glossary_overview.png)

In addition, the dedicated glossary terms page can also be added to the home page, header, footer, menu, and anywhere on the web using the glossary overview page link.

[**Read more →**](https://docs.document360.com/v3/docs/glossary-getting-started)

### 2. Feedback manager

Now you can manage and respond to your article and category page feedback in one place. You can also view all the past feedback in the Feedback manager.

To access reader feedback, earlier you would go to  **Analytics** → **Feedback**, but you can only view the feedback of a specific date range(last 30/90 days). There was no option to respond to the feedback in the same window. To respond, you would have to draft an email manually.

With the feedback manager, we have reduced your efforts in managing the feedback by tracking the actions in each feedback, and you can respond to the users in the same window.

> Go to **Content tools** → **Documentation** → **Feedback manager**

![2_Screenshot-Feedback_overview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Feedback_overview.png)

[**Read more**](https://docs.document360.com/v3/docs/getting-started-feedback-manager) **→**

---

## Improvements

### 1. Article feedback

Now, you can add multiple feedbacks for an article/category page as a team account or reader. Earlier, you could add only one feedback for an article/category page.  
 As a way to improve feedback, we have added standard predefined feedback options to choose from when you click the dislike button. Users can also select the **Notify me about change** checkbox to receive information about updates to the article/category page they have provided feedback.

![3_Screenshot-Article_Feedback_overview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Article_Feedback_overview.png)

### 2. GA4 integration with Document360

Previously, we only provided a direct integration option for the old Google Analytics version GA3 (Universal Analytics). You would use the custom HTML integration as a workaround to integrate the latest version of Google Analytics (GA4).

We have added a new integration, **Google Analytics (New)** to bypass the custom HTML workaround. All you need is just the Measurement ID to integrate GA4 in your knowledge base. It's that easy to integrate your knowledge base with GA4 now.

> * Go to **Settings** → **Knowledge base site** → **Integrations** → **Add new integration**
> * Select **Google Analytics (New)** → Add the **Measurement ID** in the Google Analytics field and click **Add**

![4_Screenshot-GA4_overview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-GA4_overview.png)

[**Read more →**](https://docs.document360.com/docs/google-analytics-new)

### 3. Date consistency

A standard date format is implemented in the knowledge base portal. The date format would appear in one of the below formats:

* Just now
* 30 seconds ago
* 1 minute ago
* 1 hour ago
* This Monday
* Aug 08, 2021

Hover your mouse pointer over the time/date details to view the exact date and time. The time details would be in your system local time.  
![5_Screenshot-Date_consitency](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Date_consitency.png)

---

### Other improvements

Minor performance, bug fixes, and security improvement can also be observed in the knowledge base portal and site.

<a id="july-2022-release-note"></a>

## July 2022

## New feature

### Advanced search in knowledge base site

Use the advanced search to find anything (titles, slugs, tags, text content inside the articles and categories) within your knowledge base site. This would help the readers find the desired search results with the available filter options. You can filter the search results based on version, language, category, contributor, tag, and updated date range.  
![1_Screenshot-Advanced_search_setting](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Advanced_search_setting.jpg)

a. Go to **Settings** → **Article settings** → **Search settings**  
 b. Toggle **On** the **Enable advanced search** option

> **For example**, you want the search results for the keyword "login" in the FAQ and Troubleshooting versions that have been updated in the last four months.
>
> * Search the keyword "login" on the knowledge base site and click **Go to advanced search**
> * Apply filters in the 'Version / Language' and 'Updated on' dropdowns
> * The desired search results are populated immediately

[**Read more →**](/v3/docs/advanced-search-in-knowledge-base-site)

---

## Enhancements

### 1. Markdown option for snippets

Earlier, you can only create the content of the snippets using the WYSIWYG editor. Now you can also create the content of the snippets using the Markdown editor.  
![12_Screenshot-Markdown_option_snippets](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/12_Screenshot-Markdown_option_snippets.png)

a. Go to **Content tools** → **Content reuse** → **Snippet** → **Add snippet**  
 b. Enable the **Markdown** toggle and click **Yes** in the confirmation prompt

[**Read more →**](/v3/docs/snippets)

### 2. Custom link color

By default, hyperlinks appear in blue. Now you can customize the below link colors:

* Link color - Color of the hyperlink
* Link hover color - Color of the mouseover hyperlink (under the mouse pointer)
* Visited link color - Color of the hyperlink that has been visited recently  
   ![1_Screenshot-Link_color_custom](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Link_color_custom.png)

> Go to **Settings** → **Knowledge base site** → **Design** → Update the desired colors under **Color** → **Save**

[**Read more →**](/help/docs/customize-site)

### 3. Updating team accounts profile image

Previously, only the respective team account could update their profile image. Additionally, the Owner(s) and Admin(s) of the project are now able to update any team account's profile image.

[**Read more →**](/v3/docs/managing-team-account)

### Other improvements

Minor performance, bug fixes, and security improvement can also be observed in the knowledge base portal and site.

<a id="june-2022-release-notes"></a>

## June 2022

## New features

### 1. SEO description generator

Use the SEO description generator to generate the meta descriptions for your articles and category pages effortlessly. This AI-powered feature will generate the best meta description for your articles and category pages based on the content. This is an addon feature and is available only for the English language.

**For an article/category page**:

> Go to the desired article/category page → **Article settings**/**Category settings** → **SEO** → **Generate meta description** → **Save**

**For multiple articles/category pages**:

> Go to **Settings** → **Knowledge base site** → **SEO settings** → **Meta management**  
>  Select the desired articles and category pages  
>  Click **Generate meta description** → **Save**

![1_Screenshot-Meta_description_article](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Meta_description_article.png)

[**Read more →**](/v3/docs/seo-description-generator)

---

### 2. Custom pages

**Custom pages** feature allows you to customize and style the static web pages in your Knowledge base. Both the basic and custom style (CSS/HTML) options are available.

> Go to **Settings** → **Knowledge base site** → **Custom pages**  
> ![1_Screenshot-Accessing_Custom_pages](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Accessing_Custom_pages.png)

You can customize the below static pages in Document360:

* [**404 page**](/v3/docs/404-page)
* [**Access denied page**](/v3/docs/access-denied-page)
* [**Unauthorized page**](/v3/docs/unauthorized-page)
* [**Login page**](/v3/docs/login-page)
* [**IP restriction page**](/v3/docs/ip-restriction-page)

[**Read more**](/v3/docs/custom-pages) **→**

---

### 3. Block inheritance

Earlier, if you want to restrict the content level access of inherited team accounts, you would be adding them to the denied list manually in the respective content level. With the **Block inheritance** option, you can restrict the content access of team accounts irrespective of the inheritance. This allows you to configure the access of any content level (version/language/category/article) to only the desired team accounts and team account groups.

> **For example**, you have six inherited team accounts in version 'V1', and you want to provide access only to two team accounts.

![2_Screeshot-Block_inheritance](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screeshot-Block_inheritance.png)

[**Read more →**](/v3/docs/block-inheritance)

---

## Enhancements

### 1. Dual linking

When dual linking is enabled, if Article-A is added as a related article in Article-B, then Article-B will appear as a related article in Article-A. Save time by using dual linking for adding related articles. With this option, you can avoid adding the related articles in both articles; instead, you can add one article and enable dual linking.  
![3_Screeshot-Dual_linking](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screeshot-Dual_linking.png)

NOTE

Dual linking is disabled by default for projects created before July 09, 2022, and enabled by default for projects created after that.

> Go to **Settings** → **Knowledge base site** → **Article settings** → **Article right or bottom**

[**Read more →**](https://docs.document360.com/docs/adding-related-articles#dual-linking)

---

### 2. Image cropping in WYSIWYG editor

The image cropping option is available now in the WYSIWYG editor. This option allows you to crop the image inside the editor. You can also add text and rotate the image.

1. Click the desired image in the editor, and you find the **Advanced edit** option in the image formatting popup
2. Click **Advanced edit** and an editing window appears with various options
3. Click **Crop** / **Text** / **Rotate**
4. Perform the desired actions and click **Save**

[**Read more →**](https://docs.document360.com/docs/adding-images-to-articles#formatting-images-in-html-wysiwyg-editor)

---

### 3. SSO login for Support page

SSO login has been enabled for the [support page](https://support.document360.com/support/login). All Document360 users can access the support page with the portal credentials. Previously only particular users with support page credentials could access the support page. You can track the support tickets raised through the email support (or) support page.  
![6_Screenshot-Support_ticket_page(1)](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Support_ticket_page%281%29.png)

[**Read more →**](https://docs.document360.com/docs/support-ticket)

---

### 4. Remember state

Remember state feature is enhanced to store the UI state of the below elements:

* Filter
* Accordion
* Grid sort
* Category manager slider
* Language dropdown
* Version dropdown

This functionality works when you navigate between different modules (Documentation/Drive/Analytics/Content tools/Settings).

[**Read more →**](/v3/docs/remember-state)

---

### 5. Export PDF

Previously, the export content size limit was 2 MB. Now it has been increased to 15 MB. This enhancement allows you to export large PDF files.

[**Read more →**](https://docs.document360.com/docs/pdf-content-templates#content-template-actions)

---

### 6. Ticket deflector localization

Localization for various elements in the ticket deflector has been added. You can localize the ticket deflector elements and enhance the user experience.

> * Go to **Settings** → **Knowledge base portal** → **Localization & Versions** → **Localization variables**
> * Select the desired language under the **Select language** section
> * Expand the **Ticket deflector** section and update the desired elements
> * Click **Save**

[**Read more →**](https://docs.document360.com/docs/adding-a-new-ticket-deflector#how-to-localize-the-variables-text-that-appears-in-the-ticket-deflector)

---

## Improvements

### UI/UX improvements

* **Help** icon is added in the left menu bar. Tutorial videos, Get assistance, Chat with us, Documentation, System status, and Feedback are moved into this section
* Slug change confirmation prompts of articles and tags have been updated to add individual fields for redirection and confirmation
* In the article/category pages, team accounts that contributed to the updates are listed at the top in the **Manage contributors** dropdown. This improvement makes it easier to identify who is responsible for updating content

---

### Resolution

#### Snippets in Markdown articles

Previously, snippets with spaces in their names were not rendered in Markdown articles. This issue has been fixed now. For existing articles, you can resolve the problem by republishing them.

---

#### What's new

What's new page slug `/whats-new` is changed to `/whats-newx`  
 All the recent articles published (new and forked) in the selected version would be displayed on this page.

<a id="may-2022-release-note"></a>

## May 2022

## New features

### 1. Starred articles and categories

With the Starred feature, you can mark your favorite or frequently used [articles](/v3/docs/starred-articles) and [categories](/v3/docs/starred-categories) as **starred**. This is similar to 'Starred' section in Drive.

![10_Screenshot-starring_an_category_method4](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-starring_an_category_method4.png)

Go to **Documentation** → **Starred**. The list of articles and categories that are starred appears here. You can use the **Entity** dropdown to filter the articles and categories.

![1_Screenshot-Starred_section_portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Starred_section_portal.png)

[**Read more →**](/v3/docs/starred-articles)

### 2. Open in portal

**Open in portal** allows team accounts to edit the content instantly. Clicking on this option would take you to the editor in the Knowledge base portal. It is available only for logged-in team accounts. It would reduce your efforts in navigating the article in the Knowledge base portal for editing.  
![7_Screenshot-Open_in_portal_site](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Open_in_portal_site.png)

[**Read more →**](/v3/docs/editing-an-article#open-in-portal)

---

## New plan

### Freemium

A new plan called Freemium is available now and completely free. We don't charge any fee or collect credit card details for this plan. Features such as Customization and Branding, Home page builder, Article templates, Tag management, and more are available in the Freemium plan. Check our [pricing page](https://document360.com/pricing/) for more information.

---

## Enhancements

### 1. SSO login for feedback portal

Earlier, users had to enter credentials to access the Document360 [feedback portal](https://feedback.document360.com/). Now, if the user clicks on the profile image and selects **Feedback**, it takes them directly to the feedback portal instead of a login page. Only Document360 authenticated users can access the feedback portal.  
![1_Screenshot-Accessing_the_feedback_option](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Accessing_the_feedback_option.png)

[**Read more →**](/v3/docs/portal-feedback)

### 2. Tag description

Now you can add a description for the Tags on the Tag Manager page. This helps you to identify the desired tags quickly.

![2_Screenshot-Tag_description_hover](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Tag_description_hover.png)

1. Go to **Content tools** → **Documentation** → **Tags** → **Add tag**
2. Add the desired **Tag name** and **Description** and click **Add**

You can now add Descriptions for the existing Tags.  
[**Read more→**](/v3/docs/adding-a-new-tag#method-1-from-the-tag-manager-overview-page)

### 3. Remember state

Enable the 'Remember state' option to retain the last done activity in the Document360 portal. It preserves and restores an activity's UI state.

![1_Screenshot-Remember_state](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Remember_state.png)

1. Click **Settings** → **Knowledge base portal** → **General**  
    and the **General** tab would be the default selection
2. Enable the status toggle bar on the **Remember state** section

> **For example**:  If a team member enables the 'Remember state', navigates to an article in the documentation section, navigates to another section, and again navigates back (Back button or relevant keyboard shortcut), the system remembers and retrieves the last activity in the documentation section.

[**Read more→**](/v3/docs/remember-state)

### 4. Notification for liked and disliked articles/category pages

Enable/Disable notifications for likes and dislikes on your knowledge base site. This helps you to engage with end-user feedback and expectations.  
![3_Screenshot-Notification_for_likes_dislikes](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Notification_for_likes_dislikes.png)

1. Go to **Settings** → **Knowledge base portal** → **Notifications** → **Notification mapping**
2. Expand **Knowledge base site** section and you can find the toggles to enable/disable notifications for likes and dislikes  
   [**Read more →**](/v3/docs/notification-mapping)

---

## Improvements

### UI/UX improvements

* **Create new version** option is added to all portal project version dropdown menus. This helps you to create new versions instantly
* Tag description appears when you hover any Tag across the Knowledge base portal and site

### Other improvements

Minor performance, bug fixes, and security improvement can also be observed in the knowledge base portal and site.

<a id="april-2022-release-note"></a>

## April 2022

## Enhancements

### 1. Version as menu

Add public versions as a menu on your knowledge base articles page. This helps showcase the available versions in your knowledge base and provides easy navigation for your end-users.

To access the version display setting in the knowledge base portal, go to  
**Settings → Knowledge base portal → Localization & Versions → Localization & Versions (tab) → Display versions as a menu (toggle) → ON**

![1_Screenshot-Version_as_menu_UI](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Version_as_menu_UI.png)

> **For example**, you have multiple public versions such as FAQ, Troubleshooting, Sales, and Customer support in your knowledge base. When the 'Display versions as a menu' toggle is on, versions are displayed as a menu. When the toggle is off, versions are displayed as a dropdown.

![9_Screenshot-Version_as_menu_kb_site](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Version_as_menu_kb_site.png)

[Read more →](/v3/docs/adding-a-new-project-version#public-versions-as-a-menu)

### 2. Readers self registration

* The **Export** option has been added to the domain restriction(s) section. The option can be seen at the top-right of this section on the Readers self registration page. The entire list can be exported as a CSV file to your local device storage
* Now, you can sort the **Domain** column by clicking the column header

![6_Screenshot-Reader_self_registration](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Reader_self_registration.png)

[Read more →](/v3/docs/reader-self-registration#adding-a-domain-restriction)

### 3. Team accounts and readers

* A new option to skip sending invitation mail when team accounts and readers are added has been introduced. The **Skip invitation mail** checkbox is available in the user addition module on the **Set up the basics** stage
* The invitation email can be disabled for bulk team accounts and readers import as well
* Earlier, this option was available only for SSO users. Now, this option is available for all users

![4_Screenshot-Team_accounts_skip_invmail](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Team_accounts_skip_invmail.png)

[Read more →](/v3/docs/managing-team-account#a-set-up-the-basics)

### 4. Find and replace option in WYSIWYG editor

The find and replace option is added in the WYSIWYG editor. This allows you to search any text within your article and replace it with another text. You can also use this to find the article's text content occurrences.

![2_Screenshot-Find_and_replace_html](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Find_and_replace_html.png)

[Read more →](/the-wysiwyg-editor#4-insert-options)

### 5. Backup & Restore

We had made a few enhancements to the Backup and Restore feature. The backup type and validity for the subscription plans are changed. Check our [pricing page](https://document360.com/pricing/) for more details.

The restore option has been enhanced to accommodate granular-level restoring. Below are the restore options available now:

* Documentation - You can restore any particular article/category/language/version. Earlier, you could only restore the complete documentation
* Home page builder - You can restore any particular home page. This includes the home page configured with custom CSS
* Custom CSS - You can compare the custom CSS of the backup and the current version. The changes made in the current version are highlighted
* Custom JavaScript - You can compare the custom JavaScript of the backup and the current version. The changes made in the current version are highlighted

![3_Screenshot-Restore_option](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Restore_option.png)

[Read more →](/v3/docs/backup-restore)

### 6. Variables (Content reuse)

Formatting options are added for the variable. Previously the variables' text would appear as normal text. This helps you to have formatted text as in-line content in your articles. The following formatting options are available now:

* Bold
* Italic
* Underline
* Strikethrough
* Font-size
* Font family
* Text color
* Background color
* Subscript
* Superscript
* Insert links

![8_Screenshot-Formatting_option_variable](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Formatting_option_variable.png)

[Read more →](/v3/docs/variables#adding-a-variable)

### 7. Export to PDF

**Cancel** option has been added in the export to PDF option. This allows you to cancel the ongoing export process.

If you want to cancel the export process, click the '✖' **Cancel** icon, and the '🚫' **Last export canceled** icon appears next to the last modified date.

![7_Screenshot-Content_pdf_template](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Content_pdf_template.png)

[Read more →](/v3/docs/pdf-content-templates#content-template-actions)

---

## Improvements

### UI/UX improvements

* **Copy link** icon is added to the published articles in the editor
* **+New** (New folder) icon is added on the bottom left of the Drive, similar to Documentation

### Other improvements

Minor performance, bug fixes, and security improvement can also be observed in the knowledge base portal and site.

<a id="march-2022-release-note"></a>

## March 2022

## New features

### 1. Shared articles

This feature is added to Document360 based on popular customer requests. The **Shared article** feature lets you display one article in multiple categories. The shared articles are termed as **References**.

* Use the ••• **More option** next to the article, select **Also display in**, choose the category/subcategory, and click on the **Share** button. You can choose multiple categories when you share an article. (This is one of four ways you can access the 'Also display in' option)  
  ![1_Screenshot-Accessing_also_display_in_method_1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Accessing_also_display_in_method_1.png)
* The shared article feature can also be accessed when creating a new article. Select the **Link existing** in the **Add article** module. Select an article from the **Select article** search bar, and click on the **Create** button.

![8_Screenshot-Add_article_module_Link_existing](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Add_article_module_Link_existing.png)

The article would be referenced in the selected category/subcategory and can be identified with the shared icon displayed next to it.

#### Original article & Referenced article

* The original article serves as a primary copy, and all the changes to content and settings would reflect across all the shared copies(references).
* Click on the **View references** icon on the right in the editor to view the linked instances.
* You can navigate to the shared article or remove the reference(stop sharing) in the selected category
* This referenced article does not have any edit capabilities. Except for the article slug, all the other elements are linked to the original article.

![6_Screenshot-Shared_article_POV](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Shared_article_POV.png)

[**Read more →**](/v3/docs/shared-articles)

### 2. Cloning articles

Create a **clone article** of an existing article from your project's respective version and language.

Select the **Copy existing** in the **Add article** module. Select an article from the **Select article** search bar, edit the title, and click on the **Create** button.

![7_Screenshot-Add_article_module_Copy_existing](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Add_article_module_Copy_existing.png)

Your clone article will be added to the respective category/subcategory with a new article indicator (light-blue dot) to show that it has not been published.

[**Read more →**](/v3/docs/creating-an-article)

---

## Enhancements

### 1. Intercom extension

There are two notable enhancements to the Intercom extension feature.

* When you share an article link to the customer in the chat response, the customer can open and read the Document360 article inside their messenger window. Earlier, the article would navigate and open in the knowledge base site
* Create an article from the Intercom, and the article is added to the selected category as a draft

[**Read more →**](/v3/docs/intercom-integration)

### 2. Internal links in the new version

When you create a new version in your project using an existing version as a base version, you can find a new selection, **Internal links** - New(default) or Existing.

![14_Screenshot-Internal_links_in_new_version](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/14_Screenshot-Internal_links_in_new_version.png)

* If you select **New**, all the internal article links would be altered to point to the newly created version of the article

> **For example**, */****v2****/docs/Installation* would be changed to ***v3****/docs/Installation*)

* If you select **Existing**, all the internal article links in the new version would still point to the base version's article

[**Read more →**](/v3/docs/getting-started-with-project-version)

### 3. Knowledge base assistant

Now, you can add a category page and category index in **Single** and **List** actions for a URL mapping in the Knowledge base assistant. Previously, you could add only articles in these actions. This improvement allows you to display categories in your knowledge base assistant.

[**Read more →**](/v3/docs/url-mapping)

### 4. Analytics

* We are now capturing the analytics data of category pages and category index under the **Leading categories** metric in the **Performance** analytics page. The index and pages can be identified with the **View in knowledge base** icon next to them
* Link validation at a Category page level has been introduced with this release
* In the **Team accounts** page in Analytics, we have included the category pages in the **Most viewed articles** and **Articles created** sections. The pages can be identified by a folder icon next to them
* We have added a new column **Feedback status** on Analytics's **Feedback** page. This section displays a percentage bar for each article/category page comparing the **likes** (green) to **dislikes** (red).

[**Read more →**](/v3/docs/analytics)

### 5. Users & Security

* Bulk select and add is now available while adding team accounts or readers to their respective groups. Earlier, only one account could be selected and added at a time
* For new or invited SSO team accounts and readers (also applies for regular Document360 users), the invited by and date/time information can be viewed. Click on the respective accounts in the Team accounts or Readers page in User & Security

[**Read more →**](/v3/docs/users-and-security)

---

## Improvements

### UI/UX improvements

* The **Add article** module in the documentation editor has been redesigned to accommodate the clone article and shared article feature
* We have added two new fields in the **mobile version of the Sign up** page. The subdomain and project access type(Public/Private/Mixed) can be added at the time of sign up
* Similar to articles, the likes, dislikes, and feedback option is now available on the **Category page**

### Other improvements

* Project version name's character limit has been extended from 20 to **30 characters**
* **Previous** and **Next** buttons at the article bottom can now be localized in the selected languages *(Settings → Localization & versions → Localization variables → Article bottom)*
* In the header section of the **Home page builder**, we have extended the ability to add article slugs in the Custom URL selection
* Minor performance, bug fixes, and security improvement can also be observed in the knowledge base portal and site

<a id="february-2022-release-note"></a>

## February 2022

## New features

### 1. Feature explorer 2.0

We have given the **Feature explorer** a brand new facelift and optimized the user learning experience. This page can be accessed by clicking on the trophy icon on the left menu bar (Only for **trial** accounts). There are two levels, **Basic quick start** and **Advanced quick start**. The phases are tracked, and each level of achievement is recognized with a virtual trophy. Complete the exploration list on the Basic quick start to unlock the Advanced quick start. The module also contains supporting materials such as a link to the feature document and tutorial videos(If available).

Even when using the knowledge base portal, if the user tries out a feature for the first time, this would be recognized and recorded in the feature explorer. You can choose to hide the automatic initiation of the 'Quick start' module for 24 hours by clicking on the checkbox below.

[**Read more →**](/v3/docs/feature-explorer)

### 2. Insert LaTeX in editor

We have added the **Insert LaTeX** tool in the Markdown and WYSIWYG editor. We can use LaTeX to write mathematical equations in Markdown. To write the inline LaTeX formula, use a single $ before and after the equation.

To add the LaTeX expression click on **Insert latex** option and a sample latex syntax () appears. You can add more equations and expressions using the free or paid LaTeX expression generator tools available on the web.  
 The frequently used LaTeX expressions can be saved as a Variable or Snippet for a quick insert.

[**Read more →**](/v3/docs/the-markdown-editor#insert-latex)

---

## Enhancements

### 1. Article redirect rules

* #### Redirection types

We have added two types of article redirect

* **Ends with** - To set redirection rule for URL text next to the domain name in the article URL

  > **For example**,  
  > **Source**: /docs/Installation-guide  
  >  to  
  > **Destination**: /docs/Support-guide
* **Replace with** - To set redirection rule for the URL text between the domain name and article slug

  > **For example**,  
  > **Source**: /v1/Installation-guide  
  >  to  
  > **Destination**: /v3/Installation-guide

To access the redirect types, go to **Settings → Knowledge base site → Article redirect rules → New redirect rule**(button). Select from either one of the types (Ends with or Replace with).

* #### Import redirect rules

You can now import redirect rules in bulk on the Article redirect rules page. To access the Import redirect rule, go to **Settings → Knowledge base site → Article redirect rules → Import redirect rule**(button). Choose and add the CSV file with all the sources, destinations, and redirection types.

The **CSV file** (less than or equal to 1MB) should follow the **Document360 standard import template**, which can be downloaded from the blade window by clicking on the **standard template**. The redirection rules (Source path, Destination path, and Redirection type) would be validated and reported in the blade with the valid and invalid rules available.

A **download** icon can be observed next to Invalid rules, which downloads a spreadsheet with the reason for the Invalid rule.

* #### Filter option

A **Search**, **Modified date**, and **Type** filter have been added to the redirect rule page. This helps you narrow down the rules you are looking for. This option comes in handy for bulk operations such as **Remove** or **Export**.

* #### Export redirect rules

The **Export** option has been added to the article redirect rules page. The option can be seen at the top-right of the page. The article redirect rules can be filtered using the **Type**(Ends with, Replace with, or Both), **Modified date**, and the **Search** keyword filter. The entire list or the filtered list can be exported as a CSV file onto your local device storage.

* #### Bulk redirect rule remove

The pagination display 50 redirect rules on a single page. If you click on the **Select all** button, the 50 records available on that page will be selected. If you wish to choose multiple other page records, navigate to the next page and click on the 'Select all' button. Click the **Remove** button at the top.

As an improvement, we have added more context to the auditing events captured for actions on individual redirect rules. The rule itself would be shown in the redirect rule record.

[**Read more →**](/v3/docs/redirecting-article-urls)

### 2. Localization

There are a couple of enhancements to the localization feature.

* When performing bulk or individual article translate, the content from the latest published article in default language would be translated and overwritten on the selected languages
* If you have linked any articles in the default language article or any internal article heading link, after translation, the link would be referenced to the selected language article rather than the original link.

  > **For example**, If the article '**Getting started**' in **English** language is linked in another English language article '**Installation support**'. When you translate the article '**Installation support**' to **French**, the hyperlink used to link the '**Getting started**' article would be altered to point to a similar article in the French language.

[**Read more →**](/v3/docs/bulk-operations#12-machine-translate)

### 3. Portal search - Articles

We have added two additional filters in the Full portal search for articles. The filters are **Status** (New, Draft, Published) and **Contributor**.  When you select any filter and click on the **Apply** button, the article will be narrowed down based on the selection.

[**Read more →**](/v3/docs/full-portal-search)

---

## Improvements

### 1. Users & Security

There are multiple enhancements in the Reader feature.

* A new option to skip sending Invitation mail when SSO users (Team accounts and Readers) are added has been introduced. The **Skip invitation mail** checkbox is available in the user addition module on the **Set up the basics** stage
* The Invitation email can be disabled for bulk SSO team account and reader import as well
* Reader can now customize their profile information such as first name, last name, and profile image. Previously, there was an option to change just the reader email.
* For reader email change, password verification has been added for added security

[**Read more →**](/v3/docs/managing-readers#how-to-change-my-profile-details-on-the-knowledge-base-site)

### 2. Knowledge base site

* On the knowledge base site, a clickable **breadcrumb** has been added below the menu section from the second-level category. For first-level categories and articles, this will not be applicable
* The navigation of **Next** and **Previous** articles have been added at the bottom of the article. This can be turned off on the **Settings → Knowledge base site → Article settings & SEO → Article bottom** page

[**Read more →**](/v3/docs/article-bottom)

### Other improvements

* The UI has been improved for the **Insert links** option on the Markdown and WYSIWYG editors
* Minor performance, bug fixes, and security improvement can also be observed in the knowledge base portal and site

<a id="january-2022-release-note"></a>

## January 2022

## New Features

### 1. Bookmark link in an article

Interlinking inside the article content was not directly available in the Document360 editors. With this release portal, users can search for and add links to the heading from the same article.

![1_Screenshot-Bookmarking_heading_links_in_article](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Bookmarking_heading_links_in_article.png)

Just click on the hyperlink tool in either of the editors (Markdown or WYSIWYG) and scroll down the overlay to find **link to current article heading**. Click on the dropdown and select from the Heading tags available in the article. The slug URL would be added to the Destination URL at the top, type in the **Link text** and click on **Ok**.

[**Read more →**](/v3/docs/linking-to-other-articles)

### 2. Home page builder Themes

Earlier users must choose the default home page builder template or write their custom CSS to customize the home page for their Document360 knowledge base. We have added three new pre-built home page themes that can be applied and customized easily.

![2_Screenshot-Home_page_builder_themes_1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Home_page_builder_themes_1.png)

You can preview the home page theme on its look and feel. If you are unsatisfied with the theme, click the discard button, and the home page will be reverted to the previously published version.

![3_Screenshot-Home_page_builder_themes_2](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Home_page_builder_themes_2.png)

[**Read more →**](/v3/docs/themes)

### 3. Full portal search for Tags, Users, and Settings.

![4_Screenshot-Full_portal_search_tab_addition_and_improvements](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Full_portal_search_tab_addition_and_improvements.png)

We have introduced a full portal search across **All, Tags, Users & Groups**, and **Settings** in addition to the existing **Article** and **Drive** tabs. This page can be accessed by clicking on the 'search' icon on the left main menu bar or the top bar search in the knowledge base portal. Another major update to this feature is that items from the recycle bin also appear in the search results.

![5_Screenshot-Full_portal_search_tab_addition_top-bar-search](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Full_portal_search_tab_addition_top-bar-search.png)

If you use the top bar search from anywhere in the knowledge base portal, a maximum of five results would be displayed in the dropdown.

[**Read more →**](/v3/docs/full-portal-search-1)

---

## Enhancement

### 1. Billing

#### Multicurrency support

We have introduced the multicurrency payment option to help customers avoid additional international transaction fees and currency conversion charges. Choose your convenient currency to pay for your Document360 subscriptions. You can pay your subscription bills in **USD** (United States dollar), **GBP** (Pound sterling), **EUR** (Euro), or **AUD** (Australian dollar).

![3_Screenshot-Pricing_page_trial](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Pricing_page_trial.jpg)

> **For example**, say you own a UK-based credit card, and you want to pay in **USD** instead of **GBP** because it's cheaper based on the currency conversion rate. You can choose USD as your currency, but the bank might impose an additional transaction fee for currency conversion on your credit card.

[**Read more →**](/v3/docs/upgrading-from-trial-version)

#### Best practices Add-on

We have introduced a one-time add-on that provides expert help setting up and managing your knowledge base. Our experts will assist you in configuring your knowledge base and guide you in best practices.  
[**Read more →**](/v3/docs/best-practice-setup-addon)

### 2. Links status

The link limit has been defined for each pricing tier (For example, the Business tier gets 5000 links). If the limit is exceeded, the validation would only be performed for the available limit (old links would be prioritized, and newer links would be excluded). The extra links that exceed the limit are not validated. Article level validation is also not possible for those links.

> **For example**, your total link limit is 10000, but the total links count in your project is 10500. Only the first 10000 links are validated when you perform the links validation. The recently added 500 links are not validated.

To validate all the links in your project, contact our support team [**support team**](https://document360.com/contact-us/) to increase the limit.

[**Read more →**](/v3/docs/links-status)

### 3. Zapier integration

Users can now choose to publish the articles created with the integration. Earlier, only the main version could be selected to add or append an article. With the latest update, users can choose any available version and language to manage articles.  
[**Read more →**](/v3/docs/zapier)

### 4. Export to PDF

#### Design template

Users can now disable hyperlinks in the exported PDF in the design template. Also, you can now choose the table of contents(TOC) to display the Heading (H2, H3, H4) tags in the exported PDF.

![6_Screenshot-Export_to_PDF_improvement_TOC_Heading_1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Export_to_PDF_improvement_TOC_Heading_1.png)

[**Read more →**](/v3/docs/pdf-design-templates)

#### Article/category page export

Earlier, only published articles/category pages could be exported. With the new update, new and draft articles/category pages would be exported as individual articles.

![7_Screenshot-Export_to_PDF_improvement_individual_draft_article_export](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Export_to_PDF_improvement_individual_draft_article_export.png)

### 5. Custom article status indicator

Now you can add a custom status indicator for your article. This status is visible on the knowledge base site.

> **For example**, you want to show the reader that an article is for a feature in your product that is still in beta-testing. You can add the custom status indicator as **Beta**.

![8_Screenshot-Enabling_custom_status_indicator_1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Enabling_custom_status_indicator_1.png)

The custom status indicator is enabled by default. You can enable/disable it as per your requirements. Go to **Settings** → **Knowledge base site** → **Article settings & SEO** → **Article settings** (tab) → **Category manager** → **Custom status indicator**.

Use the toggle switch to enable or disable the custom status indicator. Use the background color picker or HEX code to choose any custom color.

![9_Screenshot-Enabling_custom_status_indicator_Localization_variable](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Enabling_custom_status_indicator_Localization_variable.png)

To change the custom status indicator text in the available languages, go to **Setting → Localization & versions → Localization variables → Category manager**. Type the text for each available article status indicator in the respective language.

To set the custom status indicator in individual articles/category pages, go to **article/category page settings** in the documentation editor or via bulk operations.

[**Read more →**](https://docs.document360.com/docs/knowledge-base-category-manager#custom-status-indicator)

---

## Improvements

* '**Text**' has been added to code blocks in both the Markdown and the WYSIWYG editors
* Minor performance, bug fixes, and security improvement can also be observed in the knowledge base portal and site

<a id="december-2021-release-note"></a>

## December 2021

## New Features

### Full portal search

A dedicated space to search the entire project content is now available on the knowledge base portal. Perform a combined search across all the versions and languages at the same time.  Click on the **search** icon on the left-side main menu to access the **Full portal search**.

![1_Screenshot-Full_portal_search_in_portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Full_portal_search_in_portal.png)

The search engine work similar to the other search functionalities in the portal. Type in the keyword and narrow down the results using the filters (version, language, visibility, tags, date range). Users can preview the article/category page. Users can then preview the article or navigate to the article in the editor.

![2_Screenshot-Full_portal_search_article_preview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Full_portal_search_article_preview.png)

As the search is performed universally in the project, the search also covers files in the Drive as well. Users can switch between the article and Drive search using the tabs available below the search bar.

[**Read more →**](/v3/docs/full-portal-search)  
![3_Screenshot-Full_portal_search_file_preview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Full_portal_search_file_preview.png)

---

## Enhancement

### 1. Signup page

Earlier in the [**Document360 signup page**](https://document360.com/signup/), new users would provide a password on the initial form page. With this new update, the set password module has been moved to the post-activation stage. As a new user you would sign up for Document360, and an activation mail would be sent to the registered email address.

You can access the portal for the next 24 hours, but it is recommended that you activate your account. Post the 24 hours the activation link sent in the mail should be used and a password should be set to use the portal for the next 14 days. Also, the activation mail earlier had a 24-hour validity which has been removed.

### 2. JWT logout page

Earlier when JWT SSO reader logs out from KB, they would land on the regular Document360 identity logout page. With this new enhancement, any webpage can be set as a logout landing page. This option can be configured on the JWT setup page (\*\*Settings→ Security→ Enterprise SSO → JWT→ JWT Basic configuration). Add the custom page link in the **Logout URL**(optional).

![4_Screenshot-JWT_Logout_url_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-JWT_Logout_url_page.png)

If the custom logout link is not provided, they would land on the new logout page designated for the JWT SSO readers.  
[**Read more →**](/v3/docs/configuring-the-jwt-sso)

### 3. Export to PDF – Design template updates

Go to **Content tools → Import & Export → Export to PDF → Design template**

[**Read more →**](/v3/docs/pdf-design-templates)

#### a. Custom sizes for the Logo on the Cover  page

Earlier users can upload their logo on the cover page, but the size was predefined. Now with this enhancement, users can select the three standard square sizes available Small(100px), Medium(150px), Large(200px), or choose a custom size in pixels. The canvas size can be between 20 and 300 pixels in both width and height.

![5_Screenshot-Export_to_pdf_design_template_header_image_size](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Export_to_pdf_design_template_header_image_size.png)

#### b. Custom sizes for the watermark image

Earlier users can either add a watermark text (For ex. ‘Confidential’) or upload any image as a watermark, but the size was predefined. Now with this enhancement, users can select the three standard square sizes available Small(150px), Medium(200px), Large(250px) or choose a custom size in pixels. The canvas size can be between 20 and 350 pixels in both width and height.

![6_Screenshot-Export_to_pdf_design_template_waetrmark_sizes](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Export_to_pdf_design_template_waetrmark_sizes.png)

#### c. Footer text

Along with the page numbers in the footer section, users can add custom footer text to the PDF document. The footer text does not have a character limit, the font size can be customized based on the requirement. As the footer space in the PDF page is dynamic based on the text, and font size, the text would not appear truncated in the final document.

![7_Screenshot-Export_to_pdf_design_template_footer_text](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Export_to_pdf_design_template_footer_text.png)

---

## Improvements

* **Greek** has been added to the language list available for knowledge base localization
* Minor performance, bug fixes, and security improvement can also be observed in the knowledge base portal and site

<a id="november-2021-release-note"></a>

## November 2021

## New features

### 1. Recycle bin for categories and articles

One of the most requested features by our customers, the **Recycle bin** for deleted categories and articles is now available in Document360. Now users don’t have to worry about accidental article/category deletions, as the item would be available in the recycle bin.

Users can restore the deleted item anytime in the next 30 days unless the article/category has been manually deleted from the recycle bin as well.

![1_Screenshot-Recycle_bin_in_Documentation_editor](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Recycle_bin_in_Documentation_editor.png)

The **Recycle bin** can be found above the category manager (left navigation pane). Users can find the deleted article/category along with the information like **Name, category path, deleted by, date modified,** and **date deleted**. The deleted items can be restored in a matter of seconds by clicking on the **••• More → Restore** option.

![2_Screenshot-Recycle_bin_overview_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Recycle_bin_overview_page.png)

For easy access users can also use the **Delete forever** to remove specific articles/categories (or) use the **Empty recycle bin** option to remove all the items in the bin.

[**Read more →**](https://docs.document360.com/docs/recycle-bin-for-articles-and-categories)

### 2. Custom email domain authentication

By default, notification emails sent to the Document360 team members and readers are sent from **support@document360.com**.  Now users can configure their **custom email domain** on Document360, so the notification emails are sent from the configured custom email domain.

![3_Screenshot-Email_domain_authentication_overview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Email_domain_authentication_overview.png)

Users can access this new feature in the **Settings → Knowledge base portal → Notifications → Email domain** tab. To enable this feature users must first point **DNS entries** from their **DNS provider** (like GoDaddy, Rackspace, Cloudflare, etc.) to **Document360**. It may take up to **24 hours** after configuration for a custom email domain to be recognized.

[**Read more →**](https://docs.document360.com/docs/send-notifications-from-custom-email-domain)

---

## Enhancements

### 1. Drive file search

We have enhanced the file search capabilities in the Document360 Drive. We have also added an Empty recycle bin option to the Drive's bin folder.

#### a. Folder specific search

Earlier when the users perform a search on the Drive, the search would be spread across all the files on the Drive. Now with this update, users can search in the files specific to the folder or subfolder they are in at that moment.

#### b. Extended Search bar access

![4_Screenshot-Drive_enhancements_search_bar_extended_in_Recent_folder](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Drive_enhancements_search_bar_extended_in_Recent_folder.png)

Earlier search capabilities were only limited to the ‘All content’ page and overview pages of folder and subfolder on the Drive. Now with this update, the **search functionality has been added** to the **Recent, Starred,** and **Recycle bin** folders on the Drive. The search would be spread across the respective folder selected.

#### c. Empty recycle bin

![5_Screenshot-Drive_enhancements_empty_recycle_bin](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Drive_enhancements_empty_recycle_bin.png)

Another handy update to the Recycle bin on the Drive is the addition of the **Empty recycle bin** option. Earlier users had to manually select all the files in the recycle bin one page at a time and use the **Delete forever** option. Now with just the click of the **Empty recycle bin** button, the entire recycle bin can be emptied.

### 2. Export to PDF

#### a. Header image customization

![6_Screenshot-Export_to_PDF_enhancements_Header_image](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Export_to_PDF_enhancements_Header_image.png)

Earlier, in the PDF design template (**Content tools → Import & Export → Export to PDF → Design template**) the **Header image** was predefined and cannot be changed. With the latest update users can choose the **Image size** dropdown and select from small, medium, large, or any custom size in pixels (Height - 20px to 85px and Width - 20px to 150px).

#### b. Quick navigation in the Preview window

![7_Screenshot-Export_to_PDF_enhancements_quick_navigation](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Export_to_PDF_enhancements_quick_navigation.png)

Users can easily click on the quick navigation options (Cover page, Table of content, Content) found on the preview window on the right. The preview jumps to the selected option in the generated PDF.

#### c. Live preview

We have added the live preview option to the design template page. As the user edits the different aspects of the template (For ex. Cover page title) the preview window on the right would also display the changes live.

#### d. Team audit and notifications

Earlier, only the export event was captured in the **Team auditing** section. With this latest update, all the activities such as creating, updating, or deleting the content and design templates. The same applies to the notification sent for these events in the Export to PDF feature.

---

## Improvements

* We have introduced the option to input **Dart** language codes using the **Insert codeblocks** option in both the editors (Markdown and WYSIWYG)
* The **Search in PDF attachments** on-demand service can be activated by contacting support directly from the smart bar seen below the search bar in the Drive folder
* Minor performance, bug fixes, and security improvement can also be observed in the knowledge base portal and site

---

### Announcement

As a major pricing revision is being rolled out effective from **October 30, 2021**, some noticable changes can be observed in the **Billing** section and the [**Pricing page**](https://document360.com/pricing/)

<a id="october-2021-release-note"></a>

## October 2021

## New Feature

## Search in attachments

### Search inside attachments – Knowledge base portal

Project team members can perform keyword search for the content inside PDF files on the Drive. This comes in handy when a particular file needs to be chosen, but the file name does not clearly specify the search term. Earlier the same operation would involve manually downloading the PDF, opening it in a viewer, and then searching for the keyword.

This functionality can be used in the Drive menu option and the accessing Drive through ‘Insert file’’ from the documentation editor.

![1_Screenshot-Search_in_attachments_Drive_indexed_PDFs](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Search_in_attachments_Drive_indexed_PDFs.png)

Only a PDF file less than 10MB in size would get indexed for search and the cap for indexed files is 1GB. An indexed icon can be found next to the PDF files on the Drive.

[**Read more →**](https://docs.document360.com/docs/searching-files-and-filters#search-in-attachments)

### Enable attachment search filter - Knowledge base site

Readers of your knowledge base can now search for content inside PDF attachments. This search functionality is an **add-on** feature in the knowledge base portal and would be activated for customers **on-request** basis.

![2_Screenshot-Enabling_search_in_attachments_for _kb_readers](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Enabling_search_in_attachments_for%20_kb_readers.png)

Once activated, users can enable or disable the **search in attachment** option from the knowledge base portal *(Settings → Article settings & SEO → Article settings → Search setting → Show attachment tab in search)*. If the toggle is enabled, readers on the knowledge base using the search bar have the option to choose keyword search results from articles and attachments.

[**Read more →**](https://docs.document360.com/docs/dedicated-search-page#search-in-attachments-filter)

![3_Screenshot-Enabling_search_in_attachments_on_knowledge_base_site](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Enabling_search_in_attachments_on_knowledge_base_site.png)

Try out this feature!

Please contact customer support (**support@document360.com**) to activate this **add-on** feature in your project.

---

## Enhancement

### 1. JWT Reader Group restriction

Reader group restrictions have now been introduced for JWT readers. Henceforth, while creating a JWT token for readers, the reader group Id can also be passed. This will result in applying the same level of restrictions to JWT readers similar to that of the Document360 readers associated to that group. Multiple group Id can also be passed as comma-separated parameters. Another minor enhancement is the option to specify the 'session validity' (duration in minutes) during token generation.

[**Read more →**](/v3/docs/jwt-reader-groups)

### 2. Export option in ‘Page not found’ overview

Now users can export the ‘Page not found’ data from the ‘Page not found’ overview page *(Analytics → Page not found)* into a CSV file. Users can use call the filter options available such as User agent type, Date range, and search results. Once the data is filtered, click on the **Export** button at the top right, the report would be generated, and the **Download** option would be visible adjacent to the export button shortly after.

![4_Screenshot-Export_option_in_page_not_found_overview_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Export_option_in_page_not_found_overview_page.png)

The downloaded file can be accessed on MS Excel. All the data parameters you find in the ‘Page not found’ overview page would be presented as rows and columns in the spreadsheet.

![5_Screenshot-Export_option_in_page_not_found_spreadsheet_view](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Export_option_in_page_not_found_spreadsheet_view.png)

### 3 . 'All content' in Drive

A new section is available in the Document360 Drive called the **All content**. This option is available on the left side below the Recent, Starred, and Recycle bin folders on the Drive. Users can view all the individual knowledge base assets irrespective of the folder/sub-folder they are grouped in.

![6_Screenshot-Drive_All_content_folder_enhancement](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Drive_All_content_folder_enhancement.png)

This comes in handy when users want to perform bulk operations on all/selected files. The bulk operations available here are Remove, Move, Copy, Download, and Add to starred.

[**Read more →**](/v3/docs/all-content-overview)

### 4. Set editor folder in Drive (global level)

An editor folder is the default folder in the Drive where all the image files uploaded directly from the documentation editor using the Insert image would be saved. Earlier the **Documentation** system folder was set as the default editor folder and could not be changed. But with the new enhancement, users can set any parent folder on the Drive as an editor folder. Just click on the **••• More** option next to the folder and select the **Set editor folder** option.

![7_Screenshot-Set_editor_folder_on_drive](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Set_editor_folder_on_drive.png)

If a drive folder has already been set for a particular category, the images uploaded in that category articles would be saved in the mapped folder. The editor folder is just for images uploaded from the unmapped category articles. The image uploaded in templates and snippets would still be saved under the system ‘Documentation’ folder.

[**Read more →**](/v3/docs/editor-folder)

---

## Improvements

* We have renamed the **Project admin** to **Knowledge base portal** in the Settings menu grouping
* **YAML** is now available in the code block option on the editors. (YAML is a data serialization language that is often used for writing configuration files)
* Minor performance, bug fixes, and security improvement can also be observed in the knowledge base portal and site

<a id="september-2021-release-note"></a>

## September 2021

## New features

### 1. Workflow

The most requested and awaited feature ‘Workflow’ is now available in the Document360 knowledge base portal. Using this nifty feature project team members can define, manage, and track the different phases in the documentation of an article. This serves as a good assistance to editors in keeping track of the article statuses in the knowledge base project.

#### a. Workflow designer

The **Workflow designer** can be found under the **Documentation** menu grouping in the new **Content tools** menu. ***(Content tools → Documentation → Workflow designer)***

![1_Screenshot-Workflow_designer_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Workflow_designer_page.png)

The stages of the documentation cycle are referred to as **status** in the Document360 workflow. Two default system statuses (**Draft** and **Published**) and one custom status (**In review**) would be available by default.

However, users can add custom status based on their requirement, rearrange the order and delete (just custom status). When the status is set as **read only**, other users will not be able to edit inside the documentation since it would be available only in read-view. They can only assign a user and/or assign a due date.

#### b. Workflow assignments

A complete overview of all the documents (articles and category pages) in the selected version and language of the knowledge base project. To access this page, just click on the **Workflow assignments** option above the category manager on the left.

![2_Screenshot-Workflow_assignments](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Workflow_assignments.png)

Here, users can view the total document count, Documents that are assigned to the respective user by another team member, the article count in the different statuses, and the article list with filtering options.

Users can view the current **Workflow status** and the article workflow history at the top left in the documentation editor. By clicking on the dropdown, the user gets the complete information about the past, current, and upcoming article status.

### 2. Ticket deflector in Knowledge base assistant

Now users can map the existing and live ticket deflector forms on the Knowledge base assistant. We introduced the **Ticket deflector** (a feature that helps reduce the volume of support tickets by resolving customer queries with self-service support.) in our July release. And in the past release, we introduced Analytics data for the Ticket deflector forms.

When the user has mapped a live ticket deflector, all the form analytics data (such as satisfaction, feedback, answered from KB, search, and form submission) can be viewed. Go to **Analytics → Ticket deflectors** and select the Knowledge base assistant in the **Application** dropdown.

If any helpdesk (Freshdesk or Zendesk) is configured on a live Ticket deflector form, that configuration would also be available when you add the respective form on the Knowledge base assistant.

### 3. ‘Page not found’ data in Analytics

We have added an exclusive **Page not found** (**404 error**) section in the Analytics menu. If any visitor access unavailable URLs in your knowledge base, it would be recorded as 'Page not found (in technical terms 404 error). For a healthy knowledge base (and good SEO) this error should be avoided. Users can view the data when such errors occur and resolve it.

![4_Screenshot-Page_not_found_analytics_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Page_not_found_analytics_page.png)

Users can also view a drill-down of the **User-agent type** (source) such as **Browser, Bot,** or **Unknown**. Users can view the data for up to 30 days. On the overview page, users can view the list of links that throw the 404 error, User-agent type (Browser, bot, unknown), User agent (For ex. Mozilla 5.0), the timestamp (in UTC), and the URL referrer.

---

## Enhancements

### 1. Export to PDF data filtering

#### Content templates

We have added a new tab in the Export to pdf overview page (***Content tools → Import & Export → Export to PDF → Content templates***). Users can filter and save content templates for export at a category and article level.

![5_Screenshot-Content_templates_in_Export_to_pdf](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Content_templates_in_Export_to_pdf.png)

This comes in handy when exporting any segment repetitively in your knowledge base. The user doesn’t have to go through the entire process of compiling the articles and categories every time. Instead, they can just click on the **Download** option and the same content set would be exported again.

### 2. Import and Export – Language level

Now export and import project versions at a language level. This feature comes in handy when users want to localize/translate a particular version in their project. Users can make use of the translation capabilities in the knowledge base portal.

![6_Screenshot-Import_and_export_enhancement](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Import_and_export_enhancement.png)

However, when they want to translate huge volumes of articles, they can simply export a certain language, translate it, and then import the same file (.zip) back into the Document360 project. The article in the imported file would be saved as a new version if it’s from the same project. If the user imports a file from a different project, new articles would be created for the same.

This would help users move content from one project to another or have a copy of their knowledge base project as a backup either in markdown or HTML format.

### 3. Drive updates

1. We have capped the file limit to **5000 per folder**. If you have a sub-folder inside a parent folder, that would be treated as a separate folder.
2. Earlier, uploading files directly from the article editor would be added to the Documentation default folder. Now individual folders in the Drive can be mapped to different categories in the knowledge base. If no folder is selected, the files would be uploaded into the default Documentation folder.  
    Also, if the sub-category is not mapped to any specific folder in the Drive, then it would be saved under the default ‘Documentation’ folder.
3. **Set drive folder** – Click on the ••• more option in the top right when a category is selected and click on **Set drive folder**

![7_Screenshot-Drive_improvement_Set_drive_folder](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Drive_improvement_Set_drive_folder.png)

4. If the ‘Documentation’ default folder reaches its maximum limit of 5000 files, the next file uploaded or moved would be saved under a newly created default folder ‘Documentation\_1’
5. Folder selection can be done now for document elements (Images, Videos) while import of articles from .docx files

### 4. Category page integration

#### a. Links status

Category page links have been included in the Links status at the time of validations (Scheduled and Manual) and the link overview page. Earlier, the validation would only accommodate article links. The category page links can be distinguished using a category icon next to the link. This applies to the ignored links overview page as well.

![8_Screenshot-Category_link_selection_on_analytis_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Category_link_selection_on_analytis_page.png)

Users can easily filter the category page links in the links list by clicking on the quick filter option **Category links** (or) In the filter bar, select **Category links** in the **Source** dropdown.

#### b. Drive dependency viewer

When users view the file dependencies in the Dependency viewer blade (***Drive → Select folder → eye icon*** next to any file) the category page dependency would be distinguished using the **Category page** label.

---

## UI/UX updates in portal

### 1. Content tools

![9_Screenshot-UI_updates_content_tools](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-UI_updates_content_tools.png)

A parent menu item **’Content tools’** has been added to the main menu bar. You can find three menu groupings in this menu blade

#### a. Documentation

* Templates
* Bulk operations
* Article review reminders
* Tags
* Workflow designer

#### b. Content reuse

* Variable
* Snippet

#### c. Import & Export

* Import from Word
* Import & Export
* Export to PDF

### 2. Settings → Security

![10_Screenshot-UI_updates_security_menu](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-UI_updates_security_menu.png)

A new menu grouping **’Security’** has been added in place of the previous **Advanced** menu grouping. As the name implies, you can find all the settings pertaining to security options under this.

* Team & Security
* Access & Security
* Enterprise SSO

### 3. Other minor improvements

* **Advanced** menu grouping in **Settings** has been removed
* **Backup & Restore** moved from **Advanced** to **Project admin**
* **API tokens** moved from **Advanced** to **Project admin**
* **Extensions** moved from **Advanced** to **Project admin**
* Two new tabs **Content templates** and **Design templates** have been added in place of the **Export** and **Settings** tab in the **Export to PDF** page

---

## Improvements

* We have added the breadcrumb (a link trail for navigation till the current webpage) on the What's new feature
* Explainer videos for the feature have been added to modules in the knowledge base portal
* Users can now use category page tags in the Show/Hide rule for Smart bars

<a id="august-2021-release-notes"></a>

## August 2021

## New features

### 1. Ticket deflectors

### Ticket deflectors – Helpdesk configuration

We have added yet another feature to the Ticket deflectors. Now users can raise support tickets from the Document360 ticket deflectors form directly onto third-party helpdesks like **Freshdesk** or **Zendesk**.

Here’s how you can configure the helpdesk on the ticket deflector. Click on **Settings → Knowledge base site → Ticket deflectors → Notification & Ticket**. On the right when you scroll down you can find the **Helpdesk ticket** section.

![1_Screenshot_Ticket_deflector_Helpdesk_configuration_menu](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot_Ticket_deflector_Helpdesk_configuration_menu.png)

a. To configure Freshdesk, add the **API key** and **Domain URL** obtained from Freshdesk on the Document360 Helpdesk configuration blade.

b. To configure Zendesk, add the **API key**, **Domain URL**, and **Zendesk agents’ Email** obtained from Zendesk on the Document360 Helpdesk configuration blade.

![2_Screenshot_Ticket_deflector_Helpdesk_configuration_blade_view](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot_Ticket_deflector_Helpdesk_configuration_blade_view.png)

Each time a reader raises a ticket, a replica of the ticket would be recorded on the helpdesk platform you have configured.

### Ticket deflector – Analytics

Analytic data is now available for the Ticket deflectors. You can access this by clicking on the **Analytics** menu and **Ticket deflector** option.

Here you have access to four sections  
 • Dashboard  
 • Feedback  
 • Satisfaction  
 • Search

Each section gives a distinct drill down into the different analytics data. This data helps to understand the reader, retune the ticket deflector, and address the changes required in the knowledge base.

![5_Screenshot_Ticket_deflector_analytics](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot_Ticket_deflector_analytics.png)

---

### 2. JWT

A **JSON Web Token (JWT)** is a means of representing claims to be transferred between two applications. JWT is used only for the Readers login.

![3_Screenshot_JWT_login_client_secret_create_JWT](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot_JWT_login_client_secret_create_JWT.png)

You can easily create a JWT **(Settings → Advanced → Enterprise SSO → JWT)** which is referred to here as the **Client secret**. You can use this in your application to configure Document360 Enterprise SSO login for your reader. Unlike the other IdP options available (Okta, Azure AD, etc) the user is not required to have a separate reader account on Document360; the account on the client application would do. After the JWT login is enabled, the reader can use the client application credentials to log in to Document360 knowledge base site as well.

![4_Screenshot_JWT_login_client_secret](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot_JWT_login_client_secret.png)

---

### 3. Download article as PDF on Knowledge base site

We have now introduced the option for readers of your knowledge base site to download individual articles as a PDF. The download **PDF** option would be available on the top left of the article, along with **print** and **share** buttons.

![6_Screenshot_Knowledge_base_site_download_article_as_pdf_button](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot_Knowledge_base_site_download_article_as_pdf_button.png)

By default, this option is enabled in your new or existing project. You can disable this by going to **Settings → Knowledge base site → Article settings & SEO → Article settings**. In the **Article header** section, turn **off** the **Show download PDF button** toggle to disable this option for your readers.  
![7_Screenshot_Knowledge_base_site_download_article_as_pdf_control](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot_Knowledge_base_site_download_article_as_pdf_control.png)

---

## Enhancements

### 1. Billing and payments

#### a. Version add-on

Now you can buy additional version add-ons with new restrictions based on your higher plan tier (For ex. If you are a customer in the Standard plan, you can purchase a version add-on with the available business tier plan versions). This option is available across all the plan tiers.

#### b. Team accounts add-on

The restrictions for the number of team accounts have been lifted and you can now purchase any number of team accounts on your project irrespective of the plan tier. This option is available across all the plan tiers.

#### c. Downgrade plan by yourself

Earlier, if you wanted to downgrade your project from a higher plan tier to a lower plan tier (For ex. Enterprise → Business) you had to contact customer support on Document360. Now you can do it by yourself in few simple steps by unchecking the option in the downgrade window **(Settings → Billing → My plans → Downgrade)**. The only limitation here is that few dependency features like **Content reuse, Ticket deflector, Custom roles,** and **Enterprise SSO** have to be manually altered or disabled before you can proceed with the downgrade.

![8_Screenshot_Billing_downgrade_scenario](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot_Billing_downgrade_scenario.png)

#### d. Get feature

We have added the **Get feature** button on the different feature pages in Standard and business tier plans.  You can also view a brief intro on what the feature does and an explainer video on the right. When you click on the **Get feature** button, a billing blade would open with all the feature list, add-ons, and cost information. You can click on the **Confirm payment** button and your plan would be upgraded to an upper tier.

![9_Screenshot_Billing_get_feature](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot_Billing_get_feature.png)

#### e. Feature caps changed

Now you can enjoy the revised cap for API tokens and Article review reminder feature across all the plan tiers. **API token** is set to the max limit of **10** and **Article review reminders** to the max limit of **10**.

### 2. Integration rules (Show/Hide)

You can now set Show and Hide rules for all the configured third-party integrations in your knowledge base. You can configure the conditions based on **IP address, Project**, and **Language**.

Go to **Settings → Knowledge base site → Integrations** and click on an already configured integration or add a new integration. In the Add integration blade, you can find the **Advanced insertion rules** section. Now choose the **Show** and/or **Hide** rules. Once you’re done, click on the **Add** button at the bottom.

![10_Screenshot_Integration_show_hide_rules](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot_Integration_show_hide_rules.png)

### 3. Ignored links on Links status

Now we have added a new link type called **Ignored links** along with the working, broken, redirected, and unknown. In this context when you add a link to the Ignored link category, that link will be omitted from all the upcoming scheduled and manual validations. Any team member with access to Links status can Ignore or include links anytime and any number of times on their project.

![12_Screenshot_Link_Analytic_ignored_links_blade](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/12_Screenshot_Link_Analytic_ignored_links_blade.png)

---

## Improvements

• Overall performance and security of Document360 has been improved  
 • Adding new languages in a version is now easy with an exclusive icon for languages on the versions page  
 • Export to PDF in the Portal is capped at 2 MB. Users might face issues when they try to export the project to pdf, when the size of all the articles in the project is more than the 2 MB limit.  
 • We have now limited the subdomain name to 63 characters

<a id="july-2021-release-note"></a>

## July 2021

## New feature

### 1. Ticket deflector

Optimizing and balancing the role of a knowledge base and customer support in customer query resolution has always been a challenge. The all-new **Ticket deflector** feature does just that, helping customers find the solution before directly raising a ticket with customer support.

![1_Screenshot_Accessing_ticket_deflector_in_settings](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot_Accessing_ticket_deflector_in_settings.png)

Ticket deflector achieves this with a bit of reader interaction, a set of questions and responses called **block steps**, and a search assistant. Most customers' query gets resolved in this stage and this, in turn, reduces the number of support ticket significantly.

### 2. Dependency viewer – Drive

One of the most requested and awaited features in Document360 Drive, the **file dependency viewer** is a part of this release. Now users can view all the reference point articles/category pages where an individual file from the Drive has been added/attached. You can access the viewer in one of two ways on the Drive.

![2_Screenshot_Accessing_file_dependency_viewer_in_drive](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot_Accessing_file_dependency_viewer_in_drive.png)

You can either select the **View dependency article(s)** option after clicking on ••• button next to the file **(or)** clicking on the **‘eye’ icon** on the right when you hover your mouse pointer over the file.

This dependency viewer gives you the list of articles/pages the file has been used; along with details such as article name, link to the article, article status, version, language, and the contributor who has used/attached the file.  
[**Read more →**](https://docs.document360.com/docs/file-dependency-viewer)  
![3_Screenshot_File_dependency_viewer_blade_in_drive](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot_File_dependency_viewer_blade_in_drive.png)

### 3. Export to PDF

The Export to pdf feature is not an entirely new feature in the Document360 portal, but we now have a dedicated page with additional settings and a menu item for this added in **Settings** under **Advanced**.

![4_Screenshot_Accessing_export_to_pdf](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot_Accessing_export_to_pdf.png)

We have added two tabs in the Export to PDF page (**Export** and **Settings**)

#### Export

Select the published content from your knowledge base such as specific project version, language, with a predefined setting to be exported as a PDF. You can also choose to secure the PDF with password protection.

#### Settings

You can create and save predefined settings for your future PDF exports. You can customize and modify most of the PDF file attributes (cover page, watermark, page orientation, fonts, TOC, etc.) to better suit your company’s branding or style guide.

![5_Screenshot_export_to_pdf__add_settings](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot_export_to_pdf__add_settings.png)

---

## Enhancements

### 1. Private notes

We have renamed **Internal notes** to **Private notes** in the documentation editor. You can add the **private notes** to your articles/pages by using the respective icon on the formatting toolbar in both markdown and WYSIWYG editor.

![6_Screenshot_Private_notes_configuring_visibility](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot_Private_notes_configuring_visibility.png)

We have also added more controls for private notes exclusive to the **WYSIWYG editor**. You can control who can see the private note by configuring the visibility setting. You can enable and select the intended **security groups** and/or **reader groups** to view the private note. You can also leave it at the default setting of **All team accounts** if you want this to be visible to all team members (or) you can toggle to off on all options to not to show the private note to anyone in KB.

Note

Advanced private note visibility controls are **only available in WYSIWYG editor**.

### 2. Additional text formatting on snippets

Users can now edit their snippet content using additional tools added onto the formatting toolbar.  
 Previously only basic tools (bold, italic, underline, callouts, table, and code block) were available.  
 Here are some of the new tools added: **Font settings, lists, insert image, links,** and **code view.**  
[**Read more →**](https://docs.document360.com/v3/docs/snippets)  
![7_Screenshot_Additional_formatting_controls_on_snippets](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot_Additional_formatting_controls_on_snippets.png)

### 3. Mark as deprecated

You can notice a small change with the text formatting tools now available at the top in the deprecation message field. This was previously available but many of our users failed to notice or use this as it would only be visible when you click inside the deprecation message field.

![8_Screenshot_Mark_as_deprecated_formatting_controls](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot_Mark_as_deprecated_formatting_controls.png)

Another update to this feature is that now you can select multiple articles to bulk deprecate in the **All content** page.

[**Read more →**](/v3/docs/marking-articles-as-deprecated)

![9_Screenshot_Mark_as_deprecated_in_all_content_bulk](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot_Mark_as_deprecated_in_all_content_bulk.png)

### 4. Custom domain enhancements

* **Sub-domain** names can be directly edited by owners/admins on the knowledge base portal. Earlier you had to contact our customer support for custom domain changes
* You can now change the default **sub folder hosting path** (/docs) to match your needs. For example /help, /support, etc
* A new control to enable/disable article preview in sub folder hosting has also been added above the sub folder path setting

***(Settings → Knowledge base site → Custom domain → Custom domain mapping/Sub folder hosting)***

![10_Screenshot_Custom_domain_mapping_enhancement](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot_Custom_domain_mapping_enhancement.png)

---

## Improvements

* **Smart bars** feature has an improvement in the Advanced visibility rules. Now you can set show/hide rules at subcategory levels
* You can add, update, map, or delete, Readers and Reader groups with our public API docs.  Previously this could be done only from the knowledge base portal
* Overall performance, working, and design improvements

<a id="june-2021-release-note"></a>

## June 2021

We're here with our **June 2021** releases and we have a bunch of exciting new features and enhancements.

---

## New features

### 1. Import from word files (Beta)

Now you can import article content into your knowledge base directly from word files with **.docx** extension. You can find the import option added at the bottom of the category manager (left navigation pane) in the documentation editor right above the Content reuse and templates button.

![1_Screenshot-Importing_docs_in_word_format](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Importing_docs_in_word_format.jpg)

Click on the **Import** button and select the source word doc type and choose how you want to split the document. You can import the content into a **single article** (or) you can create **multiple articles** based on headings in the source document.

After that type in the article title, choose the category/ subcategory you want to import the article into. You can also preview the document or make changes to the article title or category at this stage. Click on ‘**next**’ and click on ‘**Start import**’.

![2_Screenshot-Splitting_multiple_docs_in_word_import](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Splitting_multiple_docs_in_word_import.jpg)

### 2. Tag management

We now have a separate module for all your tag management under a single menu. You can view, add, edit, redirect, and delete tags from this repository. Its so much easier when the same tags use in articles can also be used for files on your Drive. You can also view a dependency view for your tags. Access the Tag management page by ***Settings → Project admin → Tags***. You can export the Tags in form of an Excel or PDF file.

![3_Screenshot-Overview_page_of_tag_manager](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Overview_page_of_tag_manager.jpg)

### 3. Knowledge base assistant – Analytics

Similar to the different analytics data on your knowledge base, you can also view analytics data for Knowledgebase assistant as well. You can find the **Applications** dropdown in the Geography, Performance, Search, and Feedback page in the Analytics menu. You can easily switch back and forth between data here.

![4_Screenshot-Knowledge_base_assistant_analytics_overview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Knowledge_base_assistant_analytics_overview.jpg)

---

## Enhancements

### 1. Analytics comparison

Data comparison is key when it comes to analytics on your pages. It helps you strategize and rethink your approach. We have added a **comparison** feature in the Geography, Performance, and Search pages in your Analytics menu. You can view the comparison data for both knowledge base and knowledgebase assistant selections.  
![5_Screenshot-Knowledge_base_analytics_comparison_feature](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Knowledge_base_analytics_comparison_feature.jpg)

The following date range comparisons are available ***(Previous period, Previous month, Previous quarter, Previous year, and custom)***

### 2. Weekly report mail with analytics

Team members now receive weekly report mails about the project such as total weekly views, reads, likes, leading articles in terms of views, top search queries, and top countries data.

### 3. Custom filter addition in Bulk operations (All content)

We have added a feature to create a **custom filter** in bulk operations (now ‘All content’ menu). To create your own filter, click on the ‘**All content**’ option from the category manager (left navigation pane) in documentation editor. Now click on ‘**Filter**’ in the top-right and select **+ Add filter**. Add the filter name, the different filter conditions, and hit **Save**. If you want this filter to be accessible by all your team members, then switch on the **Filter visibility** toggle.

![6_Screenshot-All_content_creating_a_custom_filter](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-All_content_creating_a_custom_filter.jpg)

### 4. Search term highlight in article or category page

Earlier when readers search for a term using the bar at the top of the knowledge base and click on any of the search result listed, the page would just redirect to the particular article or category page.  
 With this new update the search term would be highlighted in ‘yellow’, and the page would automatically scroll to the section of the article with the search term.

![9_ScreenGIF-search_highlight_improvements_june_2021.jpg-min](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_ScreenGIF-search_highlight_improvements_june_2021.jpg-min.gif)

Default setting

This **Search highlight** feature would by default be **disabled** in your knowledge base setting. You can easily enable it from **Article settings & SEO**

#### Enabling the search highlight setting

Go to **Settings → Knowledge base site → Article settings & SEO → Article settings** and scroll down to find **Search highlight**. Switch the toggle on to enable this feature in your knowledge base site.

![10_Screenshot-Enabling_search_highlight_feature](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-Enabling_search_highlight_feature.jpg)

---

## Improvements

* Overall performance and security of Document360 has been improved
* Import export API has been added – [**Link to API doc**](https://apidocs.document360.com/docs/export-documentation); This feature is available for Enterprise and Enterprise Plus customers only
* For private project, when registered readers or team members want to leave a feedback at the end of an article, their **profile would be preselected** and added along with name and Email info

### UI/UX

![7_Screenshot-UI_improvements_june_2021](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-UI_improvements_june_2021.jpg)

1. **Bulk operations** has been renamed to ‘**All content**’ and moved to the top of the category manager (left navigation pane)
2. **Home page builder** option has been moved inside the category manager (left navigation pane) from main menu
3. **Categories and articles** can now be expanded and collapsed in the category manager (left navigation pane)
4. Import, Templates, and Content reuse has now been grouped under Tools which can be expanded or collapsed
5. A **New** button has been added to Categories and articles

### Links status

![8_Screenshot-Links_status_improvements_june_2021](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Links_status_improvements_june_2021.jpg)

1. The links status page links list has been set to this default sorting 1. Broken, 2. Unknown, and 3. Working
2. You can also find one-touch filter options like Hidden, Working, Broken, Unknown, Redirect URL, and Media URL above the links list
3. Users can search for links using URL, Article name, or Redirect URL
4. The main Redirect category has now been moved as a subcategory under other main categories- Working redirected, Broken redirected, and Unknown redirected

<a id="may-2021-release-note"></a>

## May 2021

We’re here with our **May 2021** updates. Unlike the previous release we don’t have any entirely new features per se. But we have a bunch of exciting enhancements and key performance improvements coming your way.

---

## Enhancements

### 1. Export team members and readers as a CSV file

Now you can export team member or reader list to a **CSV file**(Spreadsheet) with a click of a button.

1. **Reader export**  
    In case of a private project, ***(Settings → Access & Security → Access → Readers)***, you can find the **Export readers** icon next to the **Add readers** and **Import readers** buttons.

![2_Screenshot-Export_reader_account_details_as_CSV](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Export_reader_account_details_as_CSV.jpg)

2. **Team member export**  
    Similarly, if you want to export team member details ***(Setting → Team & Security → Team members)*** you can find the **Export team member** icon next to the **Add team member** and **Import team member** buttons.

![1_Screenshot-Export_team_member_as_CSV](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Export_team_member_as_CSV.jpg)

Click on the export icon; the CSV file will be generated and available to save in your local storage.

### 2. Automatic review reminder

Now you can add automatic review reminder for article/page at a project level. You can set the number of days before the newly published article/category page is up for a review reminder. You can set from 1 to 365 days from the date of publish. You can change this option in ***Settings → Project admin → General → Documentation → Review reminder***.

![3_Screenshot-Default_review_reminder_setting](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Default_review_reminder_setting.jpg)

### 3. Mark as deprecated

Earlier you had the option **‘Mark as deprecated’** (for outdated or obsolete content) at a version level on your project. Now you can use the same function at an article/page level, where in the article/page would appear with the **‘Deprecated’** public status indicator. Also, you can show custom description or reason for the deprecation and the link to a newer version of the article/page at the top.

![4_Screenshot-Mark_as_deprecated_reader_view](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Mark_as_deprecated_reader_view.jpg)

You can access this option under the **Mark as deprecated** section in the right side **article settings** menu.

![5_Screenshot-Mark_as_deprecated_setting_portal_view](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Mark_as_deprecated_setting_portal_view.jpg)

### 4. Disable feedback in article/page level

![7_Screenshot-Article_level_feedback_bottom](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Article_level_feedback_bottom.jpg)

Earlier we had a global project setting for article/page feedback where in you can just enable/disable feedback for the entire project ***(Settings → Article Settings & SEO → Article settings → Article bottom)***. As an enhancement to this feature, you have the option of **disabling feedback for individual article/page** in the article settings. At the same time if you have disabled feedback at project level, you cannot enable feedback for individual articles/pages.

![6_Screenshot-Disable_article_level_feedback](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-Disable_article_level_feedback.jpg)

### 5. Bulk delete on article/category versions

Earlier you could only delete one article/page version at a time in **view history**. Now you can select multiple versions the article/page has been forked from and do a bulk delete. This action would be logged in your Team audit and a notification would also be sent to the admin/owner.

![8_Screenshot-Article_version_bulk_delete](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/8_Screenshot-Article_version_bulk_delete.jpg)

### 6. Filter assistant content

Now you can control and choose what knowledge base content you want to show/hide in your Knowledge base assistant. Earlier all the versions, languages, categories, articles were shown to the readers when you activate the Knowledge base assistant in your project or elsewhere.

![9_Screenshot-Filter_kb_assistant_categories](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/9_Screenshot-Filter_kb_assistant_categories.jpg)

Go to ***(Settings → Knowledge base assistant → General → Filter assistant content)***. Here you can choose version level, language level, or even category level restriction of content to access and display on your assistant assistant.

### 7. Content reuse – UI enhancements

We have brought a quick access button for **Content reuse** in the documentation editor. You can find the new Content reuse button along with the **Templates** and **Bulk operations** button on the left. Also, the UI of the content reuse window has also been improved. You can notice the language selection has been moved on the top as a drop-down.

![10_Screenshot-Content_reuse_UI_revamp](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/10_Screenshot-Content_reuse_UI_revamp.jpg)

### 8. Restricting selective domains for Reader self-registration

For private projects you can allow/block specific domains from being used at the time of reader self-registration. You can do this by adding the domain name in ***(Settings → Access & Security → Access → Reader self registration → Add domain)*** and choosing **Allow/Block**.

![11_Screenshot-Blacklist_domain_self_signup](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/11_Screenshot-Blacklist_domain_self_signup.jpg)

---

## Improvements

* Overall performance, working, and design improvements
* Notification setting for article feedback and self-signup events
* A more granular level Team audit log for IP restriction event
* Now you can add a comment when you publish new or forked articles
* In documentation editor, we have improved the insert link option. We have added a separate field for search and display text
* Earlier we used static key for article or file search. As a security improvement we have adopted dynamic key for search

<a id="april-2021-release-note"></a>

## April 2021

We are back again with our **April 2021** new feature releases and enhancements. Some of the most awaited features like Article template and an all-new updated category manager is a part of this release. We are adding a new extension for Salesforce in this release. Other than these major highlights we also have few slightly smaller yet significant enhancements like import of team accounts, automatic article status indication, Enterprise SSO binding type addition, and minor performance improvements.

---

## New features

### Article templates

Document360 article templates are predefined templates that you or any other member from the project can make use of while writing articles for your Knowledge base. The templates could be for a simple user guide, FAQ, Release notes, or pretty much anything you can create as a custom article template. Regardless of the use cases, article templates provide design consistency and style for your brand.

![1_Screenshot-Article_template](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Article_template.jpg)

In Document360 you can create new articles from any of the basic system templates or create/save from your own article template, which you can reuse any number of times in your project. You can access templates on the portal by clicking on the **Templates** option at the bottom of the category manager.

[**Read more →**](https://docs.document360.com/docs/article-templates)

### Introduction of Category types

Earlier a category was just a folder for the articles, but now you can choose to do more with categories. We have introduced two new category types along with the basic folder type

![2_Screenshot-category_types](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-category_types.jpg)

1. **Folder**: This is the basic category type which acts just as a simple bucket folder for articles and sub-categories
2. **Index** :  This type of category acts as an index to all the articles present within the folder and a preview excerpt from the article.
3. **Page**: This type of category is similar to the articles you create under the categories in your project.

You can choose these category type when you create a new category or change the type of existing categories.

![2_Screenshot-category_types_index page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-category_types_index%20page.jpg)

We have also improved the UI of the existing category manager in the Documentation editor. You can find new option of Templates added to the left side category navigation pane.

[**Read more →**](https://docs.document360.com/docs/category-types)

---

## New Extensions

### Salesforce

We introduce another powerful Document360 integration with the Salesforce platform. What this integration achieves is, it enhances and equips your support agents with a powerful knowledge base while serving customers. You can look-up or share articles easily and create articles for your knowledge base right from Salesforce.

The multiple use cases with Document360 integration in Salesforce makes it a value proposition for brands and people who engage with Salesforce environment.

![3_Screenshot-Salesforce_extension](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Salesforce_extension.jpg)

[**Read more →**](https://docs.document360.com/docs/salesforce)

---

## New Integrations

We have introduced 4 new integrations to the Document360 platform.

|  | Integration | Type | About the platform/app |
| --- | --- | --- | --- |
| 1 | **Belco** | Chat | Live chat and messenger on your website to talk to visitors in real-time. |
| 2 | **Gorgios** | Chat | Gorgias helps you communicate with your customers from multiple channels. |
| 3 | **FullStory** | Analytics | Makes it easy to solve problems, find answers, and optimize your customer's experience. |
| 4 | **Sunshine Conversations** | Chat | Enables businesses to communicate with their customers across every popular messaging app. |

![4_Screenshot-4-new-integrations-added](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-4-new-integrations-added.jpg)

[**Read more →**](https://docs.document360.com/docs/integrations-getting-started)

---

## Enhancements

### Import team accounts

We have introduced the option to import team accounts from your local storage  in using CSV file. This work similar to the import of reader accounts. You can find the standard template in the portal for the .CSV file.

![4_Screenshot-import_team_accounts_csv_file](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-import_team_accounts_csv_file.jpg)

### Article attachments from external source

Now user can add attachments to the articles from external source via URL. Earlier attachments could only be added from your Document360 Drive.

![6_Screenshot-attachments_from_external_source](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/6_Screenshot-attachments_from_external_source.jpg)

### Automatic article status indication

Now you can set automatic status (New/Updated) for articles in your initial publish or forked publish accordingly. You can enable this feature in the portal *(Settings →Knowledge base site → Article settings & SEO → Category manager)*.

The default time period would be set as 30 days, however you can set any value between 1 and 90 days.

![7_Screenshot-Automatic_article_status_indicator_update](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/7_Screenshot-Automatic_article_status_indicator_update.jpg)

### Table of content in your Pdf export docs

Henceforth, when you export a category or entire Knowledge base into a Pdf, the document would contain a predefined table of content based on your categories and internal navigation links to each article in the .pdf document.

---

## Improvements

* The overall performance has been improved with considerable reduction in load times
* The Links status feature has been enhanced with hidden article filter and key performance improvements
* For Enterprise SSO SAML standard we have introduced Binding type (HttpPost and HttpRedirect) in the configuration
* ‘What's new’ is now supported on sub-folder hosted project and few security fixes have been implemented
* The Latest changes option has been moved from the profile section to the right top of the portal

<a id="march-2021-release-note"></a>

## March 2021

We are here with our March 2021 updates and improvements. We have a couple of updates in the Knowledge base site design. We have updated the direct portal login for SSO users. There is also a key security update in the recently released What’s new feature.

---

## Enhancements

### Knowledge base site design

You can now add logo and favicon from an external URL. You can also select the indent between small and medium in the fluid layout. This makes designing your knowledge base site easier along with the last month’s font selection options for body and heading texts.  
![1_Screenshot-Knowledge_base_design_favicon_external_url](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Knowledge_base_design_favicon_external_url.jpg)

### ‘What’s new’ security update

In our last release we introduced the ability to enable or disable the What’s new option in the document header. But reader’s who had bookmarked the URL were able to access the page irrespective of the option being disabled on the Knowledge base site. This has been addressed in this release and reader can only access the What’s new page only if the option is enabled in the portal settings *(Settings → Knowledge base site → Article Settings & SEO → Document header)*.

---

## Improvements

* Project creation performance has been improved
* Now you can use **File replace** to swap Draw.io format files which was not supported previously

<a id="february-2021-release-note"></a>

## February 2021

We’re here with our February 2021 releases and improvement. As an enhancement to the Drive, File replace feature has been added, which makes it easier for users to swap files which are used in documentation. We also have made a handful of minor improvements in UI/UX and Knowledge base font options.

---

## New Features

### File replace

Another important feature update to the Drive is the File replace option. You can replace files of the same extension and type (ex. Jpeg, .pdf, .png, and more) with the same file name and metadata. This comes in handy when you want to update a certain file in an article. To access this, click on the ••• **more option** adjacent to any file on the Drive. Another way to do this is to click on the file in the Drive page and in the right blade window click on the **File replace** button.  
[**Read more →**](https://docs.document360.com/docs/file-replace)

![3_Screenshot-File_replace_overview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-File_replace_overview.jpg)

---

## Improvements

* Few changes have been made for SSO users in our public [**API Documentation**](https://apidocs.document360.com/docs/get-users) under the Teams category
* You can now **Reorder the versions** display on your project for readers. In the **Settings→ Project Admin→Localization & versions** you can use your mouse pointer to drag drop the version vertically.
* **Font options** have been added to the Design section of your Knowledge base. Go to **Settings → Knowledge base site→ Design**. You can now change the **Body** and **heading fonts** of your Knowledge base.
* **Control on social media share feature** – You can now enable individual social media share option in your Knowledge base articles.
* The **Overview** option in the **Analytics** menu has been renamed to **Geography**

<a id="january-2021-release-note"></a>

## January 2021

We are starting of 2021 with new hopes and feature updates to Document360.  
 Before we get into that, here’s a **look back at Document360 in 2020**.

This past year Document360 was enhanced with major feature releases like [**Localization**](https://docs.document360.com/docs/localization-101), [**Enterprise SSO**](https://docs.document360.com/docs/single-sign-on-sso-getting-started), [**Knowledge base assistant**](https://docs.document360.com/docs/in-app-assistant-101), [**Drive**](https://docs.document360.com/docs/drive-getting-started), [**Content reuse**](https://docs.document360.com/docs/snippets), and a whole line-up of 3rd party [**integrations**](https://docs.document360.com/docs/integrations-getting-started) and [**extensions**](https://document360.com/integrations-and-extensions/).

Document360 portal also saw significant improvements in the Home page builder, Analytics, Article editors, Access and security, and an improved UI/UX for the portal.

With the January 2021 update, we bring you the addition of **smart bar** and **cookie consent** in your knowledge base and ‘**What’s new**’ feature is another exciting update. We have also made an enhancement with the Enterprise SSO by adding a login page bypass option and strict email domain restrictions.

---

## New features

### Smart bar

Smart bars allow you to display a banner/bar of info messages overlaying the knowledge base at site level or article level based on certain conditions. Using the smart bar option, you create and add banner(s) at the top and/or bottom of your knowledge base. You can choose if you want the smart bar to appear at a Global level (all the pages of your knowledge base) or Language specific.

The smart bar option can be found under ‘Knowledge base site’ in Settings menu. You can add text, numbers, characters, or links in the banner content. The smart bar can be set in four custom position and can be edited with styles (Colour theme) of the banner to best suit your page.  
[**Read more→**](https://docs.document360.com/v3/docs/smart-bar)

![3_Screenshot-Smart_bar_preview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3_Screenshot-Smart_bar_preview.jpg)

### Cookie consent

This option allows you to show a cookie consent banner for your page visitors on your knowledge base. The General Data Protection Regulation (GDPR) mandates that any website should obtain prior consent from the users before collecting, storing, or using their personal or behavioural data.

The cookie consent banner setting can be accessed under ‘Knowledge base site’ in the Settings menu.  You can enable cookie consent banner or pop-up at a global level (all the languages available in the project) or language specific. You can add custom cookie consent messages with basic formatting, add links, and add CTA (Call to action) buttons or icons. You can also edit the banner type (Bar or Pop-up), position, and the looks (theme colour) with live preview.  
[**Read more→**](https://docs.document360.com/v3/docs/cookie-consent)

![2_Screenshot-Cookie_consent_bar_preview](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2_Screenshot-Cookie_consent_bar_preview.jpg)

### What’s new

We have added a new What’s new page on your knowledge base window. Readers can access it by clicking on the ‘Present box’ icon at the top right (blow header section) of the page. Once clicked a new page (Recently updated articles) would appear with the list of recently published articles (both new and forked). Reader can click on the article to visit the article.

![5_Screenshot-Whats_new_icon](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/5_Screenshot-Whats_new_icon.jpg)

---

## Enhancements

### Enterprise SSO

#### Bypass Document360 common login page

Make use of this bypass option to skip the Document360 common login page and directly access the SSO login page. This option is available for private projects in which all the members of the project are SSO readers. Once you have configured the project using either of the SSO standards (SAML or OpenID), the bypass setting would appear above the Invite existing users setting.  
[**Read more→**](https://docs.document360.com/v3/docs/bypass-document360-common-login-page)

![1_Screenshot-Bypass_common_login_page_for_SSO_users](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Bypass_common_login_page_for_SSO_users.jpg)

#### Email domain restriction for SSO users

We have improved the level of security in your project by enhancing the existing email domain restrictions. Now users can sign up as SSO readers only using the permissible email domains specified by the Admin or Owner of the project.

### Idle screen timeout

We have added the idle screen timeout for the Document360 portal. If the portal is left idle for 2 hour the screen would display a warning prompt with 60 second timer with option (Stay logged in and Log out). After which the project would have an overlay and you have to hit the Refresh button displayed on your project screen to continue.

![4_Screenshot-idle_portal_screen_timeout](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-idle_portal_screen_timeout.jpg)

---

## Improvements

• Based on customer request, we have added article links in the Team audit and notification channel for specific article events (Ex. Article publish, Article contributors updated, and more)

• In the Team accounts section of Analytics menu, we have added an identifier badge for SSO user. This would help you differentiate regular team accounts from SSO team accounts.

<a id="november-2020-release-note"></a>

## November 2020

We’re here with our November 2020 releases and improvement. As new features, we have added Content reuse with custom Variables and Snippets. Also, in the Design & Navigations setting page we have added a dedicated Menu tab. Another major feature update is the inclusion of the most requested RSS feeds.

We have also added brand new external and internal integrations. The Zapier extension and Drift extension are a couple of exciting integration features. Regarding internal integrations, users can now choose to integrate with 21 platforms and applications.

There are few improvements in UI/UX updates in Home page builder, Machine translate, Drive, and other general improvements.

---

## New Features

### Content Reuse

The introduction of [**Variables**](https://docs.document360.com/v3/docs/variables) and [**Snippets**](https://docs.document360.com/docs/snippets) is a feature that would help users reuse a particular piece of content that is often repeated. If it is a small piece of information (like a contact number, mail Id) you can add and use a Variable instead of typing it every single time in your documentation. If in case the content should contain more information with different forms of content (like table, links, or more) you can use Snippets.

![1_Screenshot-Content_reuse_menu](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Content_reuse_menu.jpg)

#### Variables

Variables are short content containing Text, numbers, and special characters. Some of the common user cases of variables are Contact numbers, Emails, Company name, and more. With Variables you can either choose to have Global variable (available across all the languages), or Local variables specific to a Language in your project.  
[**Read more →**](https://docs.document360.com/v3/docs/variables)

#### Snippets

Snippets are predefined set of content that content manager identifies as reusable content. The content of the snippet can vary from simple text or phrases to lengthy paragraphs, tables, code blocks, and more. Snippets are stored in a library from which they can be inserted into articles at the time of edit by a simple click of a button.  
[**Read more →**](https://docs.document360.com/docs/snippets)

### Menu – Navigations

We have segregated the Menu tab in the Navigation setting page. This would make editing the menu items and links in your page so much easier. The interface is simple with drag and drop functionality and toggle to open the link in a new tab. You can do all this in the Menu section for all your versions and languages.  
[**Read more →**](https://docs.document360.com/v3/docs/menu)

### RSS feeds

We have brought in RSS feeds in the Header navigation tab under the Navigations menu. You can enable this on your home page and your reader can be aware of the recently published or updated articles. When the reader clicks on the RSS Feed option in your Home page menu bar, an XML file would be opened with the entries of recent 20 articles published or updated.

---

## New Extensions

### Drift

Drift is a conversational messenger platform that you can add to your website, knowledge bases, or online businesses. Now you can easily connect your Document360 knowledge base with the chat application. This gives you an additional edge to provide support or answer queries of your customers by sharing relevant article from your knowledge base, without having to leave the Drift conversation page  
[**Read more →**](https://docs.document360.com/docs/drift)

### Zapier

The integration tool Zapier is available as an extension on your Document360. This integration would allow users to connect and integrate between multiple cloud apps and service. You can easily create a Zap (workflows that connect your app). You can choose a trigger for the workflow to activate and then choose a response action. This opens new possibilities and hundreds of possible use cases.  
 The **Zaps** helps automate your tasks at the background, and basically automates certain workflows.

---

## Improvements

### Home page builder

The user interface in the Home page builder is made even easier with different functions segregated. We have added assistants (Most viewed, liked, read, modified, and created) which you can customize on your home page. Also, you can edit and add Language specific SEO titles for your page.

### Selective PDF export

Now you can perform the bulk operation of exporting your intended articles as a PDF file. You can select all or specific articles you want to be compiled and exported using the Generate pdf option.

### Article status indicator

We have introduced a new status indicator in articles. The newly created articles that haven’t yet been published are indicated in Blue. Also, previously the articles that are being forked would be represented in Yellow & Green will henceforth be indicated in just Yellow. The rest of the status indicators remain the same (Green for published articles and Red for article under review)

[**Read more →**](https://docs.document360.com/docs/article-status)

![4_Screenshot-Article_status_indicator_new](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/4_Screenshot-Article_status_indicator_new.jpg)

### Integrations

We have improved the UI in the Integrations page. Now there are about 21 integrations that can be connected with your Document360 project. Another notable feature is the ability to switch on/off the integration in your project without having to remove or delete the configuration completely.  
[**Read more →**](https://docs.document360.com/docs/integrations-getting-started)

### Machine translate

Earlier articles in the HTML editor (WYSIWYG) could be translated using the Machine translate option. If you wanted to translate an article in Markdown, you had to manually convert/change the editor settings to HTML editor before proceeding with the Translate.

With the latest improvement the articles created with markdown editor can be automatically changed to HTML when you click on Machine translate.  
[**Read more →**](https://docs.document360.com/docs/machine-translation)

### Drive

* You can now set restrictions for file formats that can be uploaded into the Drive
* Another minor improvement is with the folder colors. Earlier users can only select from a predefined color palette. But now, we have added the color picker and He code support.

### Table of content

Now you can choose to display even **H3** and **H4** subheadings on the right-side along with table of content in your articles. Earlier the default mode was only for H2 headings. This would give a complete tree-view skeleton of the article.  
[**Read more →**](https://docs.document360.com/docs/right-sidebar)

### UI/UX improvements

We have made few UI improvements in the portal. Some notable ones are

* In **Settings → Project admin → General**, we have split and segregated the options under three different tabs (**General**, **Editor**, and **Drive**)
* In **Settings**, under **Knowledge base site** we have split the earlier Design & Navigations to two main menu items (**Design**, **Navigations**)
* The loading graphics within the portal has been given a new design.

<a id="october-2020-release-note"></a>

## October 2020

October 2020 updates and releases are here! And we’ve got some big ones. One of the most anticipated features among customer is the Enterprise SSO (Single Sign-On) feature is now available on Document360. Another major integration update is the addition of a Google Chrome browser extension for Document360. Other than these major updates, we have also made such as version level article redirections and security fixes in the Document360 APIs.

---

## New Features

### Enterprise SSO

The **Enterprise SSO** (Single Sign-On) feature enriches the user experience in authentication and access within Document360. Enabling the SSO feature in your knowledge base projects simplifies the credential management, saves time, improves identity protections which in turn adds an additional level of security. The user need not worry about remembering the individual credentials for each project.

Users can choose from two different SSO standards, the [**SAML 2.0**](https://docs.document360.com/v3/docs/enabling-saml-sso) (Security Assertion Markup Language) and [**OpenID Connect**](https://docs.document360.com/v3/docs/enabling-openid-sso). Also, users can choose from different Identity Providers like **Okta**, **Microsoft Azure Active Directory**, and **Auth0**.

![1_Screenshot-Enabling-Enterprise-SSO](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_Screenshot-Enabling-Enterprise-SSO.jpg)

### Chrome extension

Now Document360 is available for access on Google Chrome browser as an extension. With the [**Document360 extension**](https://docs.document360.com/v3/docs/chrome-extension), personnel from your organization with access to API key can connect, access, and look-up content from your knowledge base in their browser tabs anytime, anywhere.

#### **Chrome Web Store :** [**Document360**](https://chrome.google.com/webstore/detail/document360/lifhmbmenhhiolpbbahnjicckcnnophl)

The highlights of the Document360 extension include birds eye view of your knowledge base categories and articles, quick launch label, easy article search, suggested articles based on top searches, and a convenient reader mode.  
![1_ScreenGIF-Adding-document360-extension-in-chrome-min](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1_ScreenGIF-Adding-document360-extension-in-chrome-min.gif)

---

## Other improvements

* We have added Version level article redirection based on popular customers’ request.
* Now roman numerals can be used for numbering in HTML (WYSIWYG) editor.
* We have also updated few security improvement fixes in Document360 APIs.

<a id="august-2020-release-note"></a>

## August 2020

We are back again with our 2020 mid-year product update and enhancements. We have added a couple of major features such as Localization and Document360 Drive. Other than the features we have also enhanced the overall product UI/UX experience. We are very keen on enriching Document360 as a holistic and powerful knowledge base platform in the SaaS documentation space.

---

## New Features

### Localization

Document360 now comes with complete localization as a major feature update. By offering your brand experience and support in a language that feels familiar, both existing and potential customers are much more likely to engage with your knowledge base content and reduce churn rate.  
![Image 7 - Screenshot - UI improvement- Language dropdown](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Image%207%20-%20Screenshot%20-%20UI%20improvement-%20Language%20dropdown.jpg)

Localizing your Home page and your knowledge base would eliminate many hindrances faced by your customers in understanding and connecting with your business, as opposed to single language website and documentation. The translation of your categories can either be done in-house or external human translators manually, with generic machine translation (MT) option, or on a cloud-based localization management platform ([Crowdin](https://docs.document360.com/docs/en/crowdin)) where machine and human translators can collaborate.

![2 ScreenGIF - Comparison English and Russian](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2%20ScreenGIF%20-%20Comparison%20English%20and%20Russian.gif)

There’s much more to gain from [localizing](https://docs.document360.com/docs/en/setting-up-a-multi-lingual-knowledge-base) your Document360 knowledge base than just translated articles. You would be able to customize functionalities, articles, and URL slug in the intended languages. This would mean the content is either just translated from the original language or content is modified to better suit the target audience. The graphics, colors, and the aesthetics of your pages, fonts, and images can also be modified.

Also read our [Localization blog article](https://document360.com/blog/multilingual-knowledge-base/) for a detailed walk-through of this feature.

### Drive

A new and improved repository for your entire digital assets is here. Sync, organize, backup, and work with your folders and digital file formats like images, videos, audios, documents, and many other formats.

You can upload your digital assets to [Drive](https://document360.com/blog/manage-knowledge-base-assets-using-the-new-document360-drive/) using the simple interfaces on your Document360 project dashboard. The way the Drive works is like most well-known cloud storage platforms and a no brainer to get used to. Also, your Drive size limit would be based on the monthly plan you’ve chosen.

Read our [Blog article on Drive](https://document360.com/blog/manage-knowledge-base-assets-using-the-new-document360-drive/) for a detailed walk-through of the feature.

![Image 2 - Screenshot - New drive window](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Image%202%20-%20Screenshot%20-%20New%20drive%20window.jpg)

---

## New Extensions

### Crowdin

**Crowdin** a cloud-based localization management platform, that can be integrated with Document360 knowledge base and achieve multilingual machine translation of categories and articles. The [integration of Crowdin](https://docs.document360.com/docs/en/crowdin) extension with Document360 provides an array of possibilities in context to high quality and near-perfect translations using the platform for collaboration between human and machine translation. This helps companies cater and provide support to a multi-linguistic clientele.

The integration is pretty much straight-forward and can be easily achieved with the aid of our installation guide.  
![Image 4 - Screenshot - UI improvement- Settings menu](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Image%204%20-%20Screenshot%20-%20UI%20improvement-%20Settings%20menu.jpg)

---

## Other improvements

### Knowledge base assistant

We have enhanced the already existing Knowledge base assistant ([In-app assistant](https://docs.document360.com/docs/en/in-app-assistant-101)) on Document360. Yes, we now call it the **Knowledge base assistant**. All the existing and new functions have been brought under more structured and easily accessible dropdowns.

And with the introduction of Localization, users can select and search articles in version and language-level specific knowledge bases. We have also introduced the Custom launcher icon where you can select from a list of icons or also insert your custom icon from any URL. In the Knowledge base, the assistant assistant is movable and not fixed to a static position.

### New and Simplified UI/UX

We revamped our existing User interface (UI) and introduced a better, fluidic, and streamlined controls and menu options. This UI change makes all the relevant functions more accessible and simplifies the project settings. Also, we have revamped the article settings, discussions, view history and more.  
 Check out our [August 2020 updates blog](https://document360.com/blog/august-2020-product-update/) for a more detailed coverage.  
![Image 3 - Screenshot - UI improvement- Settings menu](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Image%203%20-%20Screenshot%20-%20UI%20improvement-%20Settings%20menu.jpg)

<a id="june-2020-release-note"></a>

## June 2020

We’re in the mid months of 2020; the world seems to be coping with the changes. Yet we constantly strive to innovate and make Document360 better by the day. We have added sitemap improvements and also made some relaxations in Drive by increasing the maximum file size limit for upload.  As a feature update we’ve added the SendGrid email tracking history. Now browse through article with a specific tag using the dedicated tag page and we’ve also introduced a couple of reader filters in Access & Security.

---

## Enhancements

### Increase in file size limit for upload

We’ve now increased the limit of individual and bulk file size being uploaded into the [Drive](https://docs.document360.com/docs/using-the-file-manager).

#### New file size limit

* **Single file upload** - The maximum file size is **150MB** per file
* **Multiple files upload** - The maximum combined size of all the files selected should be no more than **160MB**

### Dedicated tag page

Similar to viewing articles by a particular author in a knowledge base; readers can now view a compilation of articles from your knowledge base with a specific tag in a separate **dedicated tag page**. By clicking on a particular [article tag](https://docs.document360.com/docs/article-tags) displayed adjacent to the article, readers would be redirected the dedicated tag page.

![3 Screenshot - Dedicated tags page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3%20Screenshot%20-%20Dedicated%20tags%20page.JPG)

### Sitemaps

Now you can utilize XML sitemaps with your knowledge base website. As a knowledge base, you are bound to add articles, update, and remove them on a regular basis. Make it easier for search engines to crawl the pages in your knowledge base by linking a verified XML sitemap in your document360 site.

### Email delivery status

Now it’s easier to know the delivery status of your sent **invite mail** (New user), **associate mail** (existing user when associated with another project), and **change password email**. Using the SendGrid email tracking history you can view the status and other parameters of the email.  
**Tracking status**:  Delivered | Not Delivered

---

## Access & Security updates

### Domain filter

You can allow only readers from specific domain to sign up. These authorized domains can be added from the [**Reader self-registration**](https://docs.document360.com/docs/reader-accounts) in the **Access & Security** section from the project dashboard.  
 But in some case when the admin has authorized over hundreds of domains, it’s quite difficult to search for any particular domain from the lists. With the new domain filter update you can type the domain name in the search bar and find it easily.

![1 Screenshot - Domain filter in Access and security](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1%20Screenshot%20-%20Domain%20filter%20in%20Access%20and%20security.JPG)

### Reader login status filter

You can now filter the [readers](https://docs.document360.com/docs/reader-accounts) based on their last login status on your private knowledge base.  Just select the criteria and the filtered reader list would be displayed.

#### Status filters

**Logged-in reader | Never logged-in reader**

You can further use a sub-filter on the Logged-in reader status. This would allow you to filter readers based on their last login time periods.

**Logged-in reader sub-filter**  
 1 year | 3 months | 30 days | 7 days | Specific date range

![2 Screenshot -Reader last login filter status](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/2%20Screenshot%20-Reader%20last%20login%20filter%20status.JPG)

### Custom password for reader self-signup

Based on customer feedback, we have added the option for readers to select their own custom password at the time of self-signup in your site. The invite mail sent to the readers post signup would contain the username and the password they've provided during signup.

<a id="may-2020-release-note"></a>

## May 2020

We’re here with our roll-out for the summer of 2020. Your in-product article search experience is getting even easier with the Category breadcrumb in search. Another functionality that’s new with this month release is a new mechanism to handle access permission of files displayed on your user landing pages. That’s not all; we’ve made Microsoft Teams integration with Document360 as an external integration.

Apart from these new and enhanced features, we’ve also implemented a couple of improvements to the product including a minor performance update.

---

## New features

### Secured files

For private projects we have introduced a mechanism to make images and files only accessible to authorized team members and registered readers within a project. This is achieved by appending an authorization token with short duration validity for the files being uploaded on Knowledge base.

### Microsoft Teams integration

Now users can integrate Microsoft Teams with Document360 seamlessly. This would enable users to search for and share articles from Document360 within Microsoft Teams platform. The integration is configurable in a matter of seconds by an authorization key.

![1 MS teams integration](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/1%20MS%20teams%20integration.JPG)

---

## Enhancements

### Category breadcrumb in search

Earlier when users type in the search bar to find an article, the search relevant articles would be listed. The user wouldn’t know which category these articles fall under.  
 Now we’ve implemented the ‘Category breadcrumb in search’ for article search results across the board in portal as well as Knowledge base. This makes it easier for the user to identify the most relevant articles by seeing their base category.

![3 Category breadcrumb search](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/3%20Category%20breadcrumb%20search.png)

Also, as an add-on enhancement, users can search for any article with the article’s slug.

---

## Other improvements

Users can experience Document360 with a slightly enhanced performance.

* These updates can be effectively observed with project creation and cache implementation; where the time taken has been considerably improved

<a id="april-2020-release-note"></a>

## April 2020

This month, we’ve made it easier than ever to keep your knowledge base fresher than the produce in your fridge with a plethora of new article tools. Easily see what state an article is in using new article status icons, set automatic review reminders to keep article information looking fresh, and more.

---

## New features

### Article Locking

Now, when you’re editing/writing an article, the article locks to keep multiple users from editing the same article at the same time. You can manually unlock the article once you’re done editing, or it will automatically unlock after fifteen minutes of inactivity.  
![April  Article Lock](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/April%20%20Article%20Lock.png)

### Article Review Reminder

Keep your knowledge base content up-to date by setting review reminders. Review reminders help teams deliver the most accurate information to customers and internal teams by alerting project members when an article is ready for a fresh pair of eyes. Create and apply review reminders to flag an article for review immediately, or set the review reminder to trigger on a specified date. You can also apply a review reminder individually or to a group of articles.

### Article Status

Once you have a bigger knowledge base you’ll have knowledge base articles in various states. Some articles might be brand new, some might be drafts, others published, and others might require review. Now, with status indicators, you don’t have to guess article state.  
![April Article  Status](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/April%20Article%20%20Status.png)

---

## Other improvements

We revisited the Home Page Builder! Now you’ll find:

* Collapsible/expandable sections
* Insert images from a URL or the Drive to replace icons in the Columns of Text or Category sections.
* Add a featured image to the home page.

<a id="march-2020-release-note"></a>

## March 2020

0This month, we’ve been cooped up in our houses and, though none of us are sure if time is a  thing any more, we’ve still made big changes to Document360. Stuff like a revamped payment process, personal analytics in My Profile, and a Slack integration.

---

## New features

### Payment Revamp

Our end-to-end payment flow is now much much better. The pricing page now includes a clear description of each feature and variable pricing for storage and page visits. One important update, we made “Private Readers” unlimited! Before we were charging an additional cost for extra private readers, so happy early birthday! (unless today is your birthday, then happy birthday!)

### My Analytics

Curious about how your articles are performing? We’ve added user-specific analytics to the My Profile panel. My Profile analytics will provide you with more insight about your recent activities and analytics data like most viewed articles and when you last contributed.  
![March My Profile Analytics](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/March%20My%20Profile%20Analytics.png)

### Slack Integration

Slack workspaces allow you to organize communications by channels for group discussions and allows for private messages to share information, files, and more all in one place. With our handy app, you will be able to search through the knowledge base, link the articles and create articles to your current workspace without leaving Slack.

---

## Enhancements

1. Multi-token option in Freshdesk: An extension to the Freshdesk integration feature supports integrating multiple knowledge base projects at the same time.
2. Codeblocks in WYSIWYG Editor: You  requested, we answered: code blocks can now be added to articles using the WYSIWYG text editor. Use the “Insert Codeblock” tool to post syntax-highlighted code in more than 30 programming language formats.

<a id="february-2020-release-note"></a>

## February 2020

February brings a long-awaited feature that’s been requested from many of our customers…a button that inserts a randomized kitten image! Just kidding, we’ve added an easier way to link to other articles within articles. We’ve also added some improvements to analytics and tags.

---

## New features

### Internal links

Previously, if you wanted to add a link to another article in your knowledge base, you needed to physically copy that link from the knowledge base and paste it into your editor. Now, we’ve added the Type-to-Search feature on the “Insert Link” tool in the editor.  
![feb 1](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/feb%201.png)

---

## Other improvements

1. Autocomplete on tags - When adding tags to articles or in the Drive  relevant tags that were previously will display in a dropdown.  
   ![feb autocomplete   tag](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/feb%20autocomplete%20%20%20tag.png)
2. Feedback Analytics - Feedback analytics now get their own tab instead of sharing space with performance analytics. All functionality is the same, they’ve just grown up and got their own rooms.

<a id="january-2020"></a>

## January 2020

New year, new changes!

In January 2020, we’ve added better analytics for article feedback, internal comment blocks, and improved URL mapping for the Knowledge base assistant. Smaller improvements include more filtering options in Bulk Operations, and the frequently requested ordered and unordered lists in callouts. Shoo. We’re going to go take a nap now.

---

## New features

### Feedback Analytics

We made it easier for customers to share praises or grumbles about your perfectly-written content. When they like or dislike an article, they now get the chance to add their feedback. Let’s be honest though, most will just tell you what they dislike, but the good news is, it opens up a brand new way to help you to understand your customer needs and wants.

Check out the project member-facing feedback UI  in the **feedback** tab found in the **performance** section of **Analytics.**

![Feedback in Portal](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Feedback%20in%20Portal.png)

If you’d like to see the feedback form live, scroll down to the bottom of this document and leave a (nice?) comment, or just look at this less interactive picture.

![Feedback Form](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Feedback%20Form.png)

### Internal Notes

Leave other team members secret notes that public readers will never ever see. Internal notes will only be visible by project members when included in a published articles and can be added in both the Markdown and WYSIWYG editors. They are perfect for telling a project member when a bit of information might not be accurate, that their boss is standing behind them, or even leaving a note to yourself for future improvements.

Check out internal notes by clicking on the internal notes icon in an editor toolbar.

![Internal Notes](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Internal%20Notes.png)

### An Improved Knowledge base assistant

We’ve made the Knowledge base assistant more assistive by:

1. Adding custom CSS/JS sections that let you whip up and include your own styles and functionality.
2. Making the  URL mapping feature more dynamic by allowing project members to include query parameters and hash values in their URLs.

Check out the improvements by visiting the **Knowledge base assistant** section in **Settings**.

---

## Enhancements

* We added better language around article states in “Bulk Operations”. “New Article” now refers to an article that’s never been published, while “Draft” refers to an article that has been published but is currently being edited.
* Twenty four hour project access during email verification. New team members will get one day of access without verifying their email. After one day, the link will expire, and the invite must be resent.
* Your votes have been heard and now any callout block can now include bullet points and numbered lists. They can also be multi-line.
* List pagination: In the Drive and team management lists, it’s easier to navigate through several pages of data with added pagination.
* Mac users rejoice, you can now save your article using `cmd+s`.

<a id="december"></a>

## December 2019

It’s the end of the year and we’re getting in one more release in before the holiday season. We’ve updated our Integrations UI, added the ability to manage an article’s contributors, and added more detailed analytics for team accounts.

---

## Improvements

### Integration UI Revamp

Internal and external integrations now have their own dedicated tabs. We’ve moved the Custom Tags tab out of the Custom CSS/Javascript Section, renamed it Custom HTML, and moved it into internal integrations so that you can easily add HTML-based widgets.

![Integrations](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Integrations.png)

### Manage Contributors

By default, users who create/fork/save/publish the articles are added to articles as contributors, but if a contributor leaves your company, what do you do? Now, you can add and remove contributors from the contributor list.

![Contributor list](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Contributor%20list.png)

### Expanded Team Accounts Analytics

We’ve added some new stuff to the Team Accounts section in analytics:

* Extra fields!

  + User Type
  + Articles Created
  + Last Contributed
* Export data to Excel & PDF

![Team Analytics](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Team%20Analytics.png)

See you next year!

<a id="november"></a>

## November 2019

Why have one text editor when you could have two? Our November 2019 release comes with a new WYSIWYG editor. A great option for media-heavy articles and those who prefer more of a Microsoft Word-like editing experience. We’ve also added export to PDF, a referral program, bulk reader import, and the ability to configure your team audit log.

---

## New features

### WYSIWYG editor

The WYSIWYG editor is our new alternative to the default markdown editor. WYSIWYG uses Rich Text Formatting, making it similar to Microsoft Word or Google Docs. The WYSIWYG editor includes features such as multi-line callouts, emoji support, table options, and links inside an image.

You can choose either the WYSIWYG or Markdown editor during project creation and later in your project settings. You can also set the editor on an article-by-article basis.

![WYSIWYG](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/WYSIWYG.gif)

### Export to PDF

You can now export your knowledge base as a PDF for offline users. Before importing, you can also password protect the file to make sure you have complete control over who can access it.

Check it out in the **Import & Export** section in **Settings**.

![PDF](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/PDF.png)

### Referral program

This isn’t a feature proper, but we’re just as excited about it! We have a new referral program. Share the love lets you earn discounts towards your subscription by inviting people you know to start using Document360. Send out your own unique link to your friends and if they sign up and become Document360 customers you will both earn $50 coupons towards your subscription.

![Share the Love](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Share%20the%20Love.jpg)

You can get a referral link in the **Share the love** section in **Settings**.

### Bulk Reader import

We’ve added the ability to import multiple readers by uploading.csv file. Simply drag and drop your file and we’ll handle the rest!

Check it out in the **Site Access (public/private)** section in **Settings**

![Import readers](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Import%20readers.jpg)

### Audit configuration

Team auditing is a great way to see what is happening in your knowledge base. However, there might be some events you don’t need to added to the audit list. Now you can choose which events are listed in your audit log.

![Audit Config](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Audit%20Config.gif)

<a id="october"></a>

## October 2019

Instead of October release, we've been focusing all our efforts on a hard launch of Document360 on the popular product finding platform Product Hunt.

And after months of hard work, building, and strategizing we're proud to say we've officially launched Document360!

Thanks to all our customers who have been with us so far!

[Check us out on Product Hunt!](https://www.producthunt.com/posts/document360)

<a id="september-2019"></a>

## September 2019

Fall is brisk, so we’ll try and make this update the same. September 2019 brings URL mapping to the Knowledge base assistant, an improved Settings UI, the option to open links in a new tab (how many tabs can you have open at one time?), and updates to our payment system.

---

## New features

### URL mapping for Knowledge base assistant

Set the Knowledge base assistant to show a list of articles, or an individual article, or search results for a keyword in your assistant, when a user navigates to a specific URL.

Check it out in the **Knowledge base** section in **Settings**.

---

## Improvements

### Improved Settings UI

We’ve made some design changes to the Settings section by making use of tabs to give you less chaos and more organization of various settings.

![Improved Settings UI](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Improved%20Settings%20UI.jpg)

### Open article links in new tab

A customer request, we added the ability to open any article links need in new tab. Go ahead. If you’re a Mac user, cmd + click, on an article link. Windows users? Ctrl+click. We dare you.

### Support for Strong Customer Authentication

We have made necessary changes to our payment system that are needed to meet the new requirements for authenticating online payments, introduced in Europe as part of the second Payment Services Directive (PSD2).

<a id="august"></a>

## August 2019

There are a few things that just need to be exactly how you like it, coffee, pillows, and application security. This release brings the frequently-requested Custom Security feature, as well as IP whitelisting. Smaller improvements include Find and Replace in articles, better category management in the Documentation Editor, and CSS snippet templates.

---

## New features

### Custom Security

The wait is over, you can now assign custom levels of access for both team accounts and readers. Access can be limited to project level, version level, or category level. Pre-define/assign sets of permissions for custom team roles or security groups.

![Custom Security](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Custom%20Security.png)

Similarly, you can create Reader Groups for a private knowledge base and restrict a group of readers to only view a limited set of documents.

Custom Security is available to tiers Enterprise or higher.

### IP Restriction

Restrict or allow knowledge base access for specified IP addresses.

Check it out in **Site Security** in **Settings**.

![IP Whitelist](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/IP%20Whitelist.png)

## Improvements

* You asked, we added. “Find and Replace” is now in our text editor. You can find it in the editor toolbar.
* Add categories, subcategories, and articles in the Documentation Editor from a quick add button that appears when you hover your mouse between items in the category manager.
* We whipped up some frequently used custom CSS snippets that you can add to your CSS editor with a click. Find them in **Custom CSS/JavaScript** in **Settings**.

![CSS](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/CSS.png)

<a id="july"></a>

## July 2019

In July 2019, we made you a treasure map, and by that we mean we’ve added an interactive Getting Started guide. This guide lets you know how many Document 360 features you’ve explored. We’ve also let readers self-register to your private knowledge base, and tossed in a few other smaller enhancements.

---

## New features

### Getting Started

Welcome to our new Getting Started guide! This guide will help users understand and explore all the Document360 features. The progress bar will let you know how many features you still get to experience for the first time. Click on any feature name to navigate to that section of Document360. You can find the guide in the **General** section of **Settings**.

![Getting Started](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Getting%20Started.png)

### Self Sign-up

Users can now self-register to a private knowledge base. You can also restrict the sign up for certain email-domains only, to prevent random access. You can enable self-sign up in the **Readers** **Self Registration** section of **Site Access (public/private)** in **Project Settings**.

![Public Knowledgebase](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Public%20Knowledgebase.png)

### Exclude Articles from SEO

You can now keep your articles away from the grabby hands of SEO crawlers. You can exclude articles from being returned in search engine results by checking “exclude from external search” in the Article Settings options on each article. We’ll add a noindex/nofollow meta tag to that article which will keep it off Google, Bing, Yahoo, and Ask Jeeves (does anyone even ask Jeeves anymore?).

![Exclude from Search](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Exclude%20from%20Search.png)

---

## Improvements

You asked, so we added a permanent redirect status code (301) for projects using a custom domain.

<a id="june"></a>

## June 2019

If your docs can’t contain cat videos to sooth customers while they try to solve their issues, can you even writing good documentation?

Yes. The answer is probably yes.

Good news for those of you who said “no”, though, or anyone who likes videos. With our June release, you can now add audio and video files to your docs, as well as PDF and other documents. We’ve also added a bulk operation option so you can manage multiple articles at the same time.

---

## New features

### Add Audio, Video, and other files

Document360 now supports audio and video uploading. You can add MP3, OGG, WAV, MP4, OGV, and WEBM files to the Drive and, once in the manager, into your docs.

We’ve also added the ability to insert PDFs and other file types such as .doc, .zip, and more. PDF files can be previewed within the text editor. Other files will show as download links.

![Add Media](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Add%20Media.png)

### Bulk Operations

Why publish one file at a time when you could publish five at a time? Outside of that fact that it wasn’t possible in Document360 before this release, no reason at all!   
 With bulk operations, you can create, update, publish, and delete multiple articles at the same time.

<a id="may-2019"></a>

## May 2019

Summer is on the horizon and we decided that nothing says summer like being able to audit the actions of your team members. For May 2019, we’ve added an automatic audit log, an Knowledge base assistant that will give your customers access to your knowledge base wherever they are, and opened up access to [Swagger](https://swagger.io/) so you can more easily test the Document360 APIs.

---

## New features

### Team Auditing

Notification channels were a good start to keeping you up to date with everything happening with your knowledge base. However, you may not want notifications every time someone updates their account settings. Enter the audit log. From now on, we will monitor your knowledge base around the clock and log it to a secure place. The audit log is available in **Project Settings** whenever you need it.

![Auditing](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Auditing.jpg)

### Knowledge base assistant

The brand-new Knowledge base assistant will replace all other assistants! This isn’t true at all, but it will allow your users to access your knowledge base on any page of your website or even in your app. We provide a script for you to inject into the website, and tadah, a small button will appear in the corner of your page so that the assistant can assist. Inside you or your users can search your knowledge base and open the articles.

![IAA](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/IAA.jpg)

### Swagger UI

With the release of our APIs to the public, many of you suggested that it would be handy if we expose Swagger for easier testability. It is now available from the root URL of the API <https://apidocs.document360.com/docs>

Just copy your API token to Swagger and start testing. Turns out, swagger isn’t just how awesome you look walking down a city street. Swagger is also a place to play around with our APIs, no need for extra software.

![Swagge](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/Swagge.jpg)

<a id="april-2019"></a>

## April 2019

The release notes are our monthly update that highlights recent product developments.\_

Here is up-to-date on what’s new in Document360 in the month of April 2019

## Brand new features

#### Comprehensive UI enhancement

We are delighted to inform that we have the improved UI in aspects of accessibility of Portal and Knowledge base in a comprehensive manner such as follows.

* In the Article settings,

1. You could easily insert files as attachment formats so that it could be downloaded by the end user from the knowledge base portal on any necessity.
2. You could locate the visibility of the “File attachments” either in the bottom or on the right side of the Article layout.
3. You have the provision to remove the previously uploaded Feature image.
4. You could add “tags” to articles to help your users find and benefit your information just on keyword search as they browse.

* The Icons UI had been improved greatly, such as you could notice the pleasing visibility of the Icons of much importance alone in the Markdown menu and other icons in the extended view of the menu.
* In the Documentation section, we have improved the UI of displaying the date in a user-friendly manner as hours or days or years.
* In the Discussion section, we have improved the UI of chat layout in a way you could effectively collaborate among team.
* The provision of toggling to enable the Landing page visibility is appropriately segregated from the Landing page to the General Section of the Settings page.
* We have enhanced the optimization of SEO with provision to include the SEO Title and SEO Meta Description of your Project under the General settings of the Knowledge base rather than including the summary of a Project.
* The Teams & Protection section is appropriately segregated into two separate sections such as follows

**Team access**:  
 You could only add users and define respective roles as needed.

**Security access**:  
 You could enable your Knowledge base access either by Private or Public.

* As many numbers of versions of an article created, you could possibly assign a friendly name and the same would be visible on the versions’ dropdown menu in the Documentation.

## Extended Storage limit

We have included the option to add-on storage in the Enterprise plan.

---

## Enhancements

* You could enable the Markdown view of published articles on a single pane without even forking the existing published article and this in fact helps to avoid unnecessary creation of an Article version.
* In the “Bulk Operations”, we have included the provision to directly open the latest version of a specific article in an Editor view.
* The Draft Writer henceforth could access the Article Settings.
* In the General settings of Knowledge base,

  1. You could to enable Visibility Settings and to add Canonical domain URL.
  2. You could enable the visibility of the first hierarchical level of level of Articles of all the main categories.
  3. You have the option to show or hide the estimated time to read in the Customer Portal
  4. Included provision to locate the link of “Related articles” either in the bottom or on the right side of the layout.

<a id="march"></a>

## March 2019

*The release notes are our monthly update that highlights recent product developments.*

Here is up-to-date on what’s new in Document360 in the month of March 2019

## Brand new feature

#### API Documentation

Document360 is open for Integration.

You can now integrate your software, flows and more with your Document360 documentation. On-boarding new users or dynamically creating articles from your support tickets is now possible with Document360 RESTful APIs. The possibilities are endless, so head over to our API documentation to get started with your first integration.

> Set API documentation in action easily with Document360 RESTful APIs.

#### To use the Document360 RESTful API:

API documentation made easy with Document360. All you need to do is just generating an API token, receive responses and make your first Document360 API call.

Document360 RESTful APIs uses HTTP requests to GET, PUT, POST and DELETE data and the Responses are in JSON format.

  

## Enhancements

#### Lightbox

The Lightbox zoom effect had been enabled for images within the Documentation as well as for the images on the landing page.  You just need to click on the images to zoom it. This Lightbox effect allows your images to be viewed center-stage in a larger format whenever they are clicked on.

**Note**: you can use your arrow keys to navigate between the two photos in this lightbox view.

#### Preview Hidden draft article

In Document360, we have included the functionality of previewing hidden articles. So that, once after authentication, you could see the hidden article preview on the landing page. If you are happy with the content and formatting, you could publish this article.

#### Exclude Internal and related article search in Analytics

Basically, we understand that Analytics helps to track how customers engage with your product knowledge base. So, to acquire precise analytics report, we have included the functionality to exclude internal and related article search from Analytics activity.

<a id="february"></a>

## February 2019

*The release notes are our monthly update that highlights recent product developments.*

**Here is up-to-date on what’s new in Document360 in the month of Feb 2019**

---

## New features

## Drive

The Drive interface allows users to predominantly organize, view, access, and manage all the files and folders in one place.

We are happy to announce that in this upcoming release, we have introduced the Drive interface in Document360 to systematically facilitate all kinds of file operations, such as create, upload, delete, etc.

### Images

The ‘Images’ folder is a central location for all your image files and makes it easy to upload all images.

Once you create a project, the folders of prime importance, such as Settings, Landing page, and Documentation, will be created by default.

**Note**:The default folders could not be deleted.

**You could easily perform file functions such as Image upload, view, or delete activities.**

#### Upload an image

You could easily upload an image directly by choosing the image file from the Images folder. Alternatively, you could drag and drop an image file onto this folder.

#### Upload Files

You can upload Files in the Drive, and the file size limit depends on your chosen pricing plan and can be from 5GB to 100 GB.

#### Storage Size (based on license)

* Standard: 5 GB
* Business: 25 GB
* Enterprise: 100 GB

*Single file upload limit: 25 MB*

#### Supported files formats

In Document360, we have included the ability to support various file formats in Drive, such as

* Images
* PDF
* Word Documents
* Presentation
* Zip
* Excel/CSV

### File Picker

In File Picker, you could pick image files from the Drive and insert them onto the Knowledge base, Landing page, etc., but you are not allowed to delete Files or create Folders.

**Note**: It is mandatory to pick image files from the Drive and not from the local browser, which was permitted earlier in Document360.  
(*File picker supports the upload of Image files alone.*)

---

## Enhancements

### Notification channel UI enhancements

In Document360, we have segregated the Notification events at the granular level.

We have revamped the event mapping layout, where the user could view the mapped channel adjacent to the respective event and remove the mapping without navigating to the Mapping blade.

---

### Export as html

Now, you can easily export the knowledge base articles in HTML format in addition to the Markdown format.

**Note:** Import of knowledge base can be achieved in Markdown format alone

<a id="january-2019"></a>

## January 2019

\*\**The release notes are our monthly update that highlights recent product developments.*\*\*

Here is up-to-date on what’s new in Document360 in the month of **Jan 2019**

---

#### Brand new feature(s)

## Notification Channel

> **Enjoy faster communication experience!**

Notifications are an established concept for alerting users. Mainly, it is a significant piece of information to make users aware of certain conditions that would need timely action. Notifications from Document360 could be sent through various external notification channels like Webhook, Slack, Microsoft Teams etc.

By default, external notification channels are in-built in Document360 to help your users enjoy faster communication. The only step you need to perform is to configure these notification channels with the appropriate URL, Access Token value (for Slack) and Authentication settings (for WebHook), and Teams WebHook Connector (for Microsoft Teams). What this means for you, is that if you are already using either of these channels in your organization, it becomes easier to receive alerts from Document360 right into these channels.

In Document360, you could set up custom Notification Channels easily as follows:

  

## Configure a Channel

On the Notification -> Channels page, click the '**Add New Channel**' button and navigate to the page you wish to configure and set up a new Notification Channel from the available options such as **WebHook, Microsoft Teams, Slack or SMTP**.

## Manage your Channel

Once you complete configuring the custom Notification channel, you could manage easily by mapping the events that you prefer to be notified to the respective channel to receive notifications.

Navigate to **Settings -> Notifications > Event Mapping**

In the Notification Event Mapping, you could enable alert notification in the core settings if any changes in the below-mentioned areas.

* Custom domain
* Custom CSS or JavaScript
* Custom Tags
* Project backup
* Project member
* Project Imported or Exported
* Article Redirection
* Notification Channel
* Appearance settings
* Integration

Additionally, you could enable alert notifications for any changes at the level of

* Documentation
* Landing page
* Category
* Article
* Drive
* Payment

## Notification History

In the ‘History’ section of Notification, you could view all the notifications that have been sent out from Document360 to the channels you have configured.

---

## Enhancements

### @Mentions in article comments

> "Ensuring effective collaboration on your articles, among the users."

We have enhanced the comments section of the Articles in the Documentation portal, enabling you to tag any of your team members.

* You could easily tag a user just by @mention in the text box in the Article comment section.
* Immediately, you could view the list of Project members, click on the user name you want to tag and mention your comment and click the ‘send’ icon.
* Once the user tagged, they would be notified via email with embedded comment description.

You could easily tag a user just by @mention a user in the text box of the Article comment section. Once a user tagged, they would be notified via email with embedded comment description.

---

## Hiding Category

We have added the ability to hide your Category from viewing on Knowledge base and excluding it from the Search results.

For instance, in case if any of the Category is under development and you could maintain its privacy by hiding this Category from clients’ view inclusive of the Subcategories and articles within it.

---

## Category tree enhancement

Another notable improvement was made in the Category tree, as we care your performance just like you. We have improvised the performance of the emoji library enabling it to load faster in your category manager and save your time.

---

## Custom Footer

You could easily configure advanced custom footer in Document360.

**To configure Custom Footer Navigation**

* We have included a Blank layout, so you could customize your preference with HTML & CSS sections.
* Alternatively, we have added two predefined themes A and B with default HTML & CSS, so you customize your preference.

<a id="support-ticket"></a>

## Support ticket

**Plans supporting access to the support page**

| Professional | Business | Enterprise |
| --- | --- | --- |
|  |  |  |

Need support or assistance? Feel free to contact us from the [Document360 support page](https://support.document360.com/support/login). Raising and tracking support tickets is very easy and user-friendly. Our support experts will respond to your queries within minutes.

![1-Screenshot-Support_portal_login](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1732093291652.png)

---

## Raising a support ticket

### Logging in to the Document360 support page

To log in to the Document360 support page,

1. Navigate to the [Document360 support page](https://support.document360.com/support/login).
2. Enter your credentials for the support page and click **Login**.
3. If you’re a Document360 customer without support page credentials, click **Login here** next to **Are you a customer?** to log in using your Document360 credentials or the SSO option.

![2_Screenshot-support_ticket_login_page](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1732093438088.png)

### Submitting a ticket

Once you log in to the support page, follow the below instructions to submit a ticket.

1. Click **Submit a ticket** at the top right corner of the support page.

![3_Screenshot-Doc360_Support_ticket_homepage](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1732095618736.png)

2. Input the required information in the Requester, Subject, Group, and Description fields.
3. Click **Attachments** to include any files relevant your issue.
4. Click **Submit.**

![4_Screenshot-Submitting_a_support_ticket](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1732095660957.png)

After submitting your ticket, you will be redirected to the ticket status page, where you can view details such as the Ticket ID, Date Created, and other relevant information.

---

## Viewing the status of your ticket

You can easily track the status of your tickets from the support page.

1. Log in to the [Document360 support page](https://support.document360.com/support/login) and click **Tickets** on the top.
2. Enter the desired keyword in the 'Search' field and click the **Search ()** icon**.**
3. Filter your tickets by status using the **Status** dropdown. It has the following options:

   * **All tickets**: View all the tickets you've submitted, regardless of their current status.
   * **Open or Pending**: Tickets that are still being worked on or need action.
   * **Resolved or Closed**: Tickets that have been completed or marked as finished.
   * **Archive**: Older tickets that are no longer active but are saved for your reference.
4. Click on the desired ticket.
5. The **Status** of the ticket appears on the right.
6. You can also find the ticket history on this page.

   ![5_Screenshot-Status_of_my_ticket](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1732095706901.png)

---

## Exporting tickets

You can export the tickets as a **.csv** or **.xls** file. To export your tickets,

1. Log in to the [Document360 support page](https://support.document360.com/support/login) and click **Tickets** on the top.
2. Click **Export Tickets** on the top right of this section.
3. Select the desired data from the **Export Tickets** window:

   * **Created in:** Select the date range for the tickets you want to export.
   * **Export as:** Choose the desired file format: **CSV** or **Excel**.
   * **Select field:** Select the fields to include in the export file, such as:

     + Ticket ID
     + Subject
     + Description
     + Status
     + Requestor source
     + Requestor email
     + Group
     + Created time
     + Last updated time
4. Click **Export**, and the exported file is saved in your local storage.

![6_Screenshot-Exporting_the_tickets](https://cdn.document360.io/860f9f88-412e-4570-8222-d5bf2f4b7dd1/Images/Documentation/image-1732095765194.png)

<a id="document360-support-generating-a-har-file"></a>

## Generating a HAR file

## What is an HAR file?

A **HAR** (HTTP Archive) file is a JSON formatted file that contains a log of a web browser's interaction with a web page. It captures details such as requests and responses between the browser and the web server, cookies, timings, and other metadata related to the page's loading and rendering process.

> NOTE
>
> HAR files are used by Document360 team for debugging and analyzing Document360 project's performance issues, as they provide a detailed record of the interactions between the browser and Document360.

### How to generate a HAR file?

They can be generated by most modern web browsers, as well as by various web development tools and browser extensions.

---

## Generate HAR files in web browsers

Follow the steps mentioned below to generate a HAR file in the following web browsers to aid the Document360 team in troubleshooting your issue

1. Google Chrome - HAR file generation
2. Mozilla Firefox - HAR file generation
3. Microsoft Edge - HAR file generation
4. Safari - HAR file generation
5. Opera - HAR file generation

The steps to generate a HAR file are mostly similar with minor UI changes that vary from web browser to web browser.

### How to generate a HAR file in Google Chrome?

You can generate a HAR file in Google Chrome using the built-in Developer Tools.

Here are the steps:

1. Open Google Chrome and go to [**portal.document360.io**](https://portal.document360.io/)**.**
2. Select your Document360 project.
3. Go to the **Chrome menu** (three dots on the top-right corner) > **More Tools** > **Developer Tools**.
4. In the Developer Tools panel that appears, click on the **Network** tab.
5. Make sure the **Preserve log** checkbox is checked, which will ensure that the network activity is not cleared when you navigate to a different page.
6. The network recording usually starts automatically. To ensure it is recording, check for a red dot in the Network panel. If it’s not recording, click on the Record () icon.
7. Reproduce the issue you face with your Document360 project.
8. Once you have reproduced the issue on your Document360 project, click on the red dot or **Ctrl+E** to stop capturing network activity.
9. Right-click anywhere in the network activity table and select **Save all as HAR with content** from the context menu.
10. Choose a file name and location to save the HAR file in your local storage.

You now have a HAR file that contains a log of all the network activity that occurred while reproducing the issue you faced in your Document360 project. You can share the file with the Document360 support personnel.

### How to generate a HAR file in Mozilla Firefox?

You can generate a HAR file in Mozilla Firefox using the built-in Developer Tools.

Here are the steps:

1. Open Mozilla Firefox and go to [**portal.document360.io**](https://portal.document360.io/)**.**
2. Select your Document360 project.
3. Click on the **Firefox menu** (three horizontal lines in the top-right corner) > **Web Developer** > **Network**.
4. In the Network panel, click on the **Persist Logs** button to ensure that the network activity is not cleared when you navigate to a different page.
5. Make sure the **All** tab is selected to capture all the network activity associated with the page.
6. The network recording usually starts automatically. To ensure its recording, check for a red dot in the Network panel. If it’s not recording, click on the Record () icon.
7. Reproduce the issue you face with your Document360 project.
8. Once you have reproduced the issue on your Document360 project, click on the red dot or **Ctrl+E** to stop capturing network activity.
9. Right-click anywhere within the list of network requests and select **Save All As HAR** from the context menu.
10. Choose a file name and location to save the HAR file in your local storage.

### How to generate a HAR file in Microsoft Edge?

You can generate a HAR file in Microsoft Edge using the built-in Developer Tools.

Here are the steps:

1. Open Microsoft Edge. Go to [**portal.document360.io**](https://portal.document360.io/).
2. Select your Document360 project.
3. Go to the **Edge menu** (three horizontal dots in the top-right corner) > **More Tools** > **Developer Tools**.
4. In the Developer Tools panel that appears, click on the **Network** tab.
5. Make sure the **Preserve log** checkbox is checked, which will ensure that the network activity is not cleared when you navigate to a different page.
6. The network recording usually starts automatically. To ensure its recording, check for a red dot in the Network panel. If it’s not recording, click on the Record () icon.
7. Reproduce the issue you face with your Document360 project
8. Once you have reproduced the issue on your Document360 project, click on the red dot to stop capturing network activity.
9. Right-click anywhere within the list of network requests and select **Save all as HAR with content** from the context menu.
10. Choose a file name and location to save the HAR file in your local storage.

### How to generate a HAR file in Safari?

You can generate a HAR file in Safari using the built-in Web Inspector.

Here are the steps:

1. Open Safari and go to [**portal.document360.io**](https://portal.document360.io/).
2. Select your Document360 project.
3. Enable the **Develop** menu by going to **Safari menu** > **Preferences** > **Advanced** and check the **Show Develop menu in menu bar** checkbox.
4. From the **Develop** menu in the menu bar, select **Show Web Inspector.**
5. In the Web Inspector panel, click on the **Network** tab.
6. Make sure the **Preserve log** checkbox is checked, which will ensure that the network activity is not cleared when you navigate to a different page.
7. The network recording usually starts automatically. To ensure its recording, check for a red dot in the Network panel. If it’s not recording, click on the Record () icon.
8. Reproduce the issue you face with your Document360 project.
9. Once you have reproduced the issue on your Document360 project, click on the red dot to stop capturing network activity.
10. Right-click anywhere within the list of network requests and select **Export HAR** from the context menu.
11. Choose a file name and location to save the HAR file in your local storage.

### How to generate a HAR file in Opera?

You can generate a HAR file in Opera using the built-in Developer Tools.

Here are the steps:

1. Open Opera and go to [**portal.document360.io**](https://portal.document360.io/).
2. Select your Document360 project.
3. Go to the **Opera menu** (three horizontal lines in the top-left corner) > **Developer** > **Developer Tools**.
4. In the Developer Tools panel, click on the **Network** tab.
5. Ensure the **Preserve log** checkbox is checked, which will ensure that the network activity is not cleared when you navigate to a different page.
6. The network recording usually starts automatically. To ensure its recording, check for a red dot in the Network panel. If it’s not recording, click on the Record () icon.
7. Reproduce the issue you face with your Document360 project
8. Once you have reproduced the issue on your Document360 project, click on the red dot to stop capturing network activity.
9. Right-click anywhere within the network requests and select **Save as HAR with Content** from the context menu.
10. Choose a file name and location to save the HAR file in your local storage.

